<?php

namespace App\Http\Controllers\Cadastros;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use Illuminate\Http\Request;

class CentrosDeCustoCadarisController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Cadastro_read ) )->only( [ 'index' ] );
    $this->middleware( CRP::role( CRP::P_Cadastro_edit ) )->only( [ 'store', 'edit', 'update', 'destroy' ] );
  }

  /**
   * Lista as CentrosDeCustoCadaris.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    $custosJSON = CentrosDeCustoCadaris::despesas_treeView();

    return view( 'Cadastros.CentrosDeCustoCadaris.index', compact( 'custosJSON' ) );
  }

  /**
   * Insere o CentrosDeCustoCadaris no BD.
   *
   * @param  \Illuminate\Http\Request $request
   * @return \Illuminate\Http\Response
   */
  public function store( Request $request ) {
    CentrosDeCustoCadaris::create( $request->all() );

    flash( 'Centros de Custo da Cadaris criado com sucesso!', 'success' );
    return redirect()->route( 'cadastros.centrosdecustocadaris.index' );
  }

  /**
   * Exibe o formulario para editar uma CentrosDeCustoCadaris no BD.
   *
   * @param $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function edit( $id ) {
    $centro = CentrosDeCustoCadaris::findOrFail( $id );

    return view( 'Cadastros.CentrosDeCustoCadaris.edit', compact( 'centro' ) );
  }

  /**
   * Atualiza uma CentrosDeCustoCadaris no BD.
   *
   * @param  \Illuminate\Http\Request $request
   * @param $id
   * @return \Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    $grupo = CentrosDeCustoCadaris::findOrFail( $id );
    $grupo->update( $request->all() );

    flash( 'Centros de Custo da Cadaris criado com sucesso!', 'success' );
    return redirect()->route( 'cadastros.centrosdecustocadaris.index' );
  }

  /**
   * Remove uma CentrosDeCustoCadaris no BD.
   *
   * @param $id
   * @return \Illuminate\Http\Response
   */
  public function destroy( $id ) {
    $centro = CentrosDeCustoCadaris::findOrFail( $id );
    $centro->delete();

    flash( 'Centros de Custo da Cadaris deletado com sucesso!', 'success' );
    return redirect()->route( 'cadastros.centrosdecustocadaris.index' );
  }
}
