<?php

namespace App\Http\Controllers\Cadastros\Config;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Http\Requests\FaixaSalarialRequest;
use App\Models\Config\FaixaSalarial;
use App\Models\Config\FaixaSalarialDissidio;

class FaixaSalarialController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Cadastro_edit ) )->only( [ 'get', 'post' ] );
  }

  /**
   * Exibe o formulario para preencher com as faixas de Salario.
   *
   * @return \Illuminate\Http\Response
   */
  public function get() {
    $dissidio = FaixaSalarialDissidio::orderby( 'ano' )->get();

    return view( 'Cadastros.Config.FaixaSalarial', compact( 'dissidio' ) );
  }

  /**
   * Atualiza as faixa de Salario e os Coeficientes para o Dissidio.
   *
   * @param FaixaSalarialRequest $request
   * @return \Illuminate\Http\Response
   */
  public function post( FaixaSalarialRequest $request ) {

    // insere ou atualiza os valores
    $r = $request->all();
    foreach ( range( 1, 17 ) as $i ) {
      $inf = intval( preg_replace( '/\D/', '', $r[ 'inferior_' . $i ] ) );
      $sup = intval( preg_replace( '/\D/', '', $r[ 'superior_' . $i ] ) );
      $med = intval( ( $inf + $sup ) / 2 );

      $fs = FaixaSalarial::where( 'nivel', '=', $i )->first();
      if ( $fs == null ) {
        $fs           = new FaixaSalarial();
        $fs->nivel    = $i;
        $fs->inferior = $inf;
        $fs->media    = $med;
        $fs->superior = $sup;
        $fs->save();
      } else {
        $fs->nivel    = $i;
        $fs->inferior = $inf;
        $fs->media    = $med;
        $fs->superior = $sup;
        $fs->update();
      }
    }

    // ============ Atualiza as Porcentagens ============
    // get do POST
    $dis_id     = array_key_exists( 'dis_id', $request->all() ) ? $request->all()[ 'dis_id' ] : [];
    $dis_ano    = array_key_exists( 'dis_ano', $request->all() ) ? $request->all()[ 'dis_ano' ] : [];
    $dis_valor1 = array_key_exists( 'dis_valor1', $request->all() ) ? $request->all()[ 'dis_valor1' ] : [];
    $dis_porc1  = array_key_exists( 'dis_porc1', $request->all() ) ? $request->all()[ 'dis_porc1' ] : [];
    $dis_valor2 = array_key_exists( 'dis_valor2', $request->all() ) ? $request->all()[ 'dis_valor2' ] : [];
    $dis_porc2  = array_key_exists( 'dis_porc2', $request->all() ) ? $request->all()[ 'dis_porc2' ] : [];
    $dis_valor3 = array_key_exists( 'dis_valor3', $request->all() ) ? $request->all()[ 'dis_valor3' ] : [];
    $dis_porc3  = array_key_exists( 'dis_porc3', $request->all() ) ? $request->all()[ 'dis_porc3' ] : [];
    $dis_valor4 = array_key_exists( 'dis_valor4', $request->all() ) ? $request->all()[ 'dis_valor4' ] : [];
    $dis_porc4  = array_key_exists( 'dis_porc4', $request->all() ) ? $request->all()[ 'dis_porc4' ] : [];

    // funcao usada no array_map para selecionar o 'id', e tornar o array associativo em somente array
    $soID = function ( $value ) { return $value[ 'id' ]; };

    // analisa as diferencas
    // flat a lista de ids, ex: [1, 2, 3, 4]
    $dis_antigo = array_map( $soID, FaixaSalarialDissidio::all()->toArray() );
    // calcula a diferença ( encontra os valores nao presente no $dis_id, mas que tinha no antigo) e reinicia o array associativo
    $dis_deletados = array_values( array_diff( $dis_antigo, $dis_id ) );

    // deleta os que nao existem mais do BD
    FaixaSalarialDissidio::destroy( $dis_deletados );

    // insere os novos ou atualiza os editados
    for ( $i = 0; $i < count( $dis_id ); $i++ ) {
      // array com os dados
      $dis = [
        'ano'    => $dis_ano[ $i ],
        'valor1' => $dis_valor1[ $i ],
        'porc1'  => $dis_porc1[ $i ],
        'valor2' => $dis_valor2 [ $i ],
        'porc2'  => $dis_porc2[ $i ],
        'valor3' => $dis_valor3[ $i ],
        'porc3'  => $dis_porc3[ $i ],
        'valor4' => $dis_valor4[ $i ],
        'porc4'  => $dis_porc4[ $i ]
      ];
      if ( $dis_id[ $i ] == '-1' ) { // cria novo telefone
        FaixaSalarialDissidio::create( $dis );
      } else { // atualiza telefone com aquele id
        FaixaSalarialDissidio::find( $dis_id[ $i ] )->update( $dis );
      }
    }

    flash( 'Configuração salva com sucesso!', 'success' );
    return redirect()->route( 'configadmin.faixasalarial.get' );
  }
}
