<?php

namespace App\Http\Controllers\Cadastros;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Cadastros\Funcionarios;
use Carbon\Carbon;
use Excel;
use Illuminate\Support\Facades\Input;
use PHPExcel_Style_Border;
use PHPExcel_Style_NumberFormat;

class ControleDePontoController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Cadastro_read ) )->only( [ 'index' ] );
  }

  /**
   * Lista os eventos em um calendario.
   *
   * @param int $id
   * @return \Illuminate\Http\Response
   */
  public function index( $id ) {
    /** @var Funcionarios $func */
    $func = Funcionarios::findOrFail( $id );

    return view( 'Cadastros.ControleDePontos.index', compact( 'func' ) );
  }

  /**
   * Lista os eventos em um calendario.
   *
   * @param int $funcionario_id
   * @return array
   */
  public function relatorio_individual( $funcionario_id ) {
    /** @var Funcionarios $func */
    $func      = Funcionarios::findOrFail( $funcionario_id );
    $dt_inicio = Input::get( 'dt_inicio' );
    $dt_fim    = Input::get( 'dt_fim' );
    $pontos    = $func->_ArrayControleDePontos( $dt_inicio, $dt_fim );
    $pontos    = array_map( function ( $el ) {
      $el[ 0 ] = ( new Carbon( $el[ 0 ] ) )->format( 'd/m/Y' );
      return $el;
    }, $pontos );

    // Monta a tabela
    $XLSX     = [];
    $XLSX[]   = [
      'Data',
      'Dia da Semana',
      'Tipo do Evento',
      'Nome do Funcionário',
      'Horas',
      'Nome do Aprovador',
      'Observação',
    ];
    $XLSX     = array_merge( $XLSX, $pontos );
    $filename = 'Pontos_' . str_slug( $func->nome ) . '_' . $dt_inicio . '_' . $dt_fim;
    $title    = 'Pontos do ' . $func->nome . ' de ' . $dt_inicio . ' até ' . $dt_fim;
    Excel::create( $filename, function ( $excel ) use ( $XLSX, $title ) {
      /** @var \Maatwebsite\Excel\Writers\LaravelExcelWriter $excel */
      $excel->setTitle( $title );
      $excel->setDescription( $title );
      $excel->sheet( 'Pontos', function ( $sheet ) use ( $XLSX ) {
        /** @var \Maatwebsite\Excel\Classes\LaravelExcelWorksheet $sheet */
        // Dados
        $sheet->fromArray( $XLSX, null, 'A1', false, false );
        // Style geral
        $sheet->setStyle( [
          'font' => [
            'name' => 'Arial',
            'size' => 10
          ]
        ] );
        $sheet->setAutoSize( true );
        $sheet->setBorder( 'A1:G' . \count( $XLSX ), PHPExcel_Style_Border::BORDER_THIN );
        // Style do Header
        $sheet->setHeight( 1, 25 );
        $sheet->cells( 'A1:G1', function ( $cells ) {
          /** @var \Maatwebsite\Excel\Writers\CellWriter $cells */
          $cells->setFontColor( '#ffffff' );
          $cells->setBackground( '#404040' );
          $cells->setAlignment( 'center' );
          $cells->setValignment( 'center' );
          $cells->setFontWeight( 'bold' );
        } );
        // Column formatting
        $sheet->setColumnFormat( [
          'A' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'B' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'C' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'D' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'E' => PHPExcel_Style_NumberFormat::FORMAT_DATE_TIME3,
          'F' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'G' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
        ] );
        // Auto Filter
        $sheet->setAutoFilter();
      } );
    } )->download( 'xlsx' );

    return null;
  }

  /**
   * Lista os eventos em um calendario.
   *
   * @return \Illuminate\Http\Response
   */
  public function relatorio_todos() {
    /** @var Funcionarios[] $funcionarios */
    $funcionarios = Funcionarios::whereInativo( 0 )->get();
    $todos_pontos = [];

    $dt_inicio = Input::get( 'dt_inicio' );
    $dt_fim    = Input::get( 'dt_fim' );
    foreach ( $funcionarios as $funcionario ) {
      $pontos = $funcionario->_ArrayControleDePontos( $dt_inicio, $dt_fim );
      /** @noinspection SlowArrayOperationsInLoopInspection */
      $todos_pontos = array_merge( $todos_pontos, $pontos );
    }
    usort( $todos_pontos, function ( $a, $b ) {
      return $a[ 0 ] <=> $b[ 0 ];
    } );
    $todos_pontos = array_map( function ( $el ) {
      $el[ 0 ] = ( new Carbon( $el[ 0 ] ) )->format( 'd/m/Y' );
      return $el;
    }, $todos_pontos );

    // Monta a tabela
    $XLSX     = [];
    $XLSX[]   = [
      'Data',
      'Dia da Semana',
      'Tipo do Evento',
      'Nome do Funcionário',
      'Horas',
      'Nome do Aprovador',
      'Observação',
    ];
    $XLSX     = array_merge( $XLSX, $todos_pontos );
    $filename = 'Pontos_' . $dt_inicio . '_' . $dt_fim;
    $title    = 'Pontos de todos os Funcionários de ' . $dt_inicio . ' até ' . $dt_fim;
    Excel::create( $filename, function ( $excel ) use ( $XLSX, $title ) {
      /** @var \Maatwebsite\Excel\Writers\LaravelExcelWriter $excel */
      $excel->setTitle( $title );
      $excel->setDescription( $title );
      $excel->sheet( 'Pontos', function ( $sheet ) use ( $XLSX ) {
        /** @var \Maatwebsite\Excel\Classes\LaravelExcelWorksheet $sheet */
        // Dados
        $sheet->fromArray( $XLSX, null, 'A1', false, false );
        // Style geral
        $sheet->setStyle( [
          'font' => [
            'name' => 'Arial',
            'size' => 10
          ]
        ] );
        $sheet->setAutoSize( true );
        $sheet->setBorder( 'A1:G' . \count( $XLSX ), PHPExcel_Style_Border::BORDER_THIN );
        // Style do Header
        $sheet->setHeight( 1, 25 );
        $sheet->cells( 'A1:G1', function ( $cells ) {
          /** @var \Maatwebsite\Excel\Writers\CellWriter $cells */
          $cells->setFontColor( '#ffffff' );
          $cells->setBackground( '#404040' );
          $cells->setAlignment( 'center' );
          $cells->setValignment( 'center' );
          $cells->setFontWeight( 'bold' );
        } );
        // Column formatting
        $sheet->setColumnFormat( [
          'A' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'B' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'C' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'D' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'E' => PHPExcel_Style_NumberFormat::FORMAT_DATE_TIME3,
          'F' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'G' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
        ] );
        // Auto Filter
        $sheet->setAutoFilter();
      } );
    } )->download( 'xlsx' );

    return null;
  }
}

/*
  LINKs:
    https://fullcalendar.io/
    http://www.jqueryajaxphp.com/fullcalendar-crud-with-jquery-and-php/
    http://blog.pisyek.com/create-room-booking-system-laravel-fullcalendar
    http://blog.pisyek.com/create-room-booking-system-laravel-fullcalendar-part-2
    https://github.com/pisyek/room-booking-system
    http://demo.pisyek.com/book-a-room/events/3/edit
    https://github.com/maddhatter/laravel-fullcalendar
*/
/*
  Evento - Descrição
  At. Comp. - Atestado Comparecimento
  At. Méd. - Atestado Médico
  Atras. Bus - Atraso do Ônibus
  Comp. Hora - Compensação de Horas
  Falta Just. - Falta Justificada
  Falta ñ Just. - Falta não justificada
  Feriado - Feriado
  Férias - Férias
  Lib. Chef. - Liberação Chefia
  Lib. Pres. - Liberação Presidência
  Viagem Serv. - Viagem a Serviço
*/