<?php

namespace App\Http\Controllers\Cadastros;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Http\Requests\FornecedoresRequest;
use App\Models\Cadastros\FornecedoresDespesas;
use App\Models\Cadastros\FornecedoresEmpresas;
use App\Models\Cadastros\FornecedoresEmpresasEnderecos;
use App\Models\Cadastros\FornecedoresServicosProdutos;
use App\Models\Cadastros\FornecedoresServicosProdutosContatos;
use App\Models\Cadastros\FornecedoresTags;
use Request;

class FornecedoresController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Cadastro_read ) )->only( [ 'index', 'show' ] );
    $this->middleware( CRP::role( CRP::P_Cadastro_edit ) )->only( [ 'create', 'store', 'edit', 'update', 'destroy' ] );
  }

  /**
   * Exibe o formulario para inserir novo Fornecedor.
   *
   * @return \Illuminate\Http\JsonResponse
   */
  public function index() {
    $fornecedores = [];

    foreach ( FornecedoresEmpresas::orderBy( 'codigo' )->get() as $empresa ) {
      /** @var FornecedoresEmpresas $empresa */
      $emp           = [];
      $empID         = $empresa->id;
      $empCod        = $empresa->codigo;
      $emp[ 'text' ] = sprintf( '%02d - %s', $empCod, $empresa->nome );
      $emp[ 'href' ] = route( 'fornecedores.show', [ $empID, 0 ] );
      /** @var FornecedoresServicosProdutos[] $produtos */
      $produtos      = $empresa->ServicosProdutos()->orderBy( 'codigo' )->get();
      $emp[ 'tags' ] = [ count( $produtos ) ];

      foreach ( $produtos as $produto ) {
        $prod           = [];
        $depID          = $produto->id;
        $cdcCod         = $produto->codigo;
        $prod[ 'text' ] = sprintf( '%02d.%02d - %s', $empCod, $cdcCod, $produto->nome );
        $prod[ 'href' ] = route( 'fornecedores.show', [ $empID, $depID ] );
        $tags           = [];
        foreach ( $produto->Tags()->orderBy( 'nome' )->get() as $tag ) {
          $tags[] = $tag->nome;
        }
        $prod[ 'tags' ]   = $tags;
        $emp[ 'nodes' ][] = $prod;
      }
      $fornecedores[] = $emp;
    }

    $fornecedoresJSON = json_encode( $fornecedores );
    return view( 'Cadastros.Fornecedores.index', compact( 'fornecedoresJSON' ) );
  }

  /**
   * Exibe o formulario para inserir novo Fornecedor.
   *
   * @return \Illuminate\Http\Response
   */
  public function create() {

    return view( 'Cadastros.Fornecedores.create' );
  }

  /**
   * Armazena um novo Fornecedor no BD.
   *
   * @param FornecedoresRequest $request
   * @return \Illuminate\Http\Response
   */
  public function store( FornecedoresRequest $request ) {

    $emp_id = $request->get( 'empresa', '' );

    if ( $emp_id == '' ) { // nova Empresa
      $dados = $request->all();
      /** @var FornecedoresEmpresas $emp */
      $emp = FornecedoresEmpresas::create( [
        'codigo' => $request->get( 'codigo' ),
        'nome'   => $request->get( 'nome' ),

        'cnpj'            => $request->getOrNull( 'cnpj' ),
        'razao_social'    => $request->getOrNull( 'razao_social' ),
        'inscr_estadual'  => $request->getOrNull( 'inscr_estadual' ),
        'inscr_municipal' => $request->getOrNull( 'inscr_municipal' ),
        'condpagamento'   => $request->getOrNull( 'condpagamento' ),

        'nota_geral'        => $request->getOrNull( 'nota_geral', 1 ),
        'nota_qualidade'    => $request->getOrNull( 'nota_qualidade', 1 ),
        'nota_atendimento'  => $request->getOrNull( 'nota_atendimento', 1 ),
        'nota_prazo'        => $request->getOrNull( 'nota_prazo', 1 ),
        'nota_obs'          => $request->getOrNull( 'nota_obs' ),
        'nota_recomendacao' => $request->getOrNull( 'nota_recomendacao' ),

        'bancario_banco'   => $request->getOrNull( 'bancario_banco' ),
        'bancario_agencia' => $request->getOrNull( 'bancario_agencia' ),
        'bancario_conta'   => $request->getOrNull( 'bancario_conta' ),

        'obs' => $request->getOrNull( 'obs' ),
      ] );

      // enderecos
      $end_apelido     = array_get( $dados, 'end_apelido', [] );
      $end_cep         = array_get( $dados, 'end_cep', [] );
      $end_logradouro  = array_get( $dados, 'end_logradouro', [] );
      $end_numero      = array_get( $dados, 'end_numero', [] );
      $end_complemento = array_get( $dados, 'end_complemento', [] );
      $end_bairro      = array_get( $dados, 'end_bairro', [] );
      $end_cidade      = array_get( $dados, 'end_cidade', [] );
      $end_estado      = array_get( $dados, 'end_estado', [] );

      // insere os enderecos da empresa
      for ( $i = 0; $i < count( $end_cep ); $i++ ) {
        // cria novo endereco
        $emp->Enderecos()->create(
          [
            'apelido'     => $end_apelido[ $i ],
            'cep'         => $end_cep[ $i ],
            'logradouro'  => $end_logradouro[ $i ],
            'numero'      => $end_numero[ $i ],
            'complemento' => $end_complemento[ $i ],
            'bairro'      => $end_bairro[ $i ],
            'cidade'      => $end_cidade[ $i ],
            'estado'      => $end_estado[ $i ],
          ]
        );
      }

    } else {
      $dados = $request->all();
      /** @var FornecedoresEmpresas $emp */
      $emp = FornecedoresEmpresas::findOrFail( $emp_id );
      /** @var FornecedoresServicosProdutos $prod */
      $prod = $emp->ServicosProdutos()->create( $dados );

      // Contatos
      $contato_nome  = array_get( $dados, 'contato_nome', [] );
      $contato_tel   = array_get( $dados, 'contato_tel', [] );
      $contato_cel   = array_get( $dados, 'contato_cel', [] );
      $contato_email = array_get( $dados, 'contato_email', [] );

      // insere os contatos do centro de custo
      for ( $i = 0; $i < count( $contato_nome ); $i++ ) {
        // cria novo contato
        $prod->Contatos()->create( [
          'nome'  => $contato_nome[ $i ],
          'tel'   => $contato_tel[ $i ],
          'cel'   => $contato_cel[ $i ],
          'email' => $contato_email[ $i ],
        ] );
      }

      // TAGs
      $tagsID = $request->get( 'tags', [] );
      $prod->Tags()->attach( $tagsID );

    }

    flash( 'Fornecedor criado com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.index' );
  }

  /**
   * Exibe os atributos do Fornecedor.
   *
   * @param $empCod
   * @param $prodCod
   * @return \Illuminate\Http\Response
   */
  public function show( $empCod, $prodCod ) {
    $empresa   = null;
    $centro    = null;
    $conta     = null;
    $enderecos = null;
    $contatos  = null;
    $tags      = null;

    if ( $empCod <= 0 ) {
      return abort( '400', 'Falta parametro Codigo da Empresa' );

    } else {
      /** @var FornecedoresEmpresas $empresa */
      $empresa = FornecedoresEmpresas::findOrFail( $empCod );

      if ( $prodCod <= 0 ) {
        $enderecos = $empresa->Enderecos()->get();
        $tipo      = 1;
      } else {
        /** @var FornecedoresServicosProdutos $produto */
        $produto  = $empresa->ServicosProdutos()->findOrFail( $prodCod );
        $contatos = $produto->Contatos()->get();
        $tags     = $produto->Tags()->orderBy( 'nome' )->get();
        $tipo     = 2;

      }
    }

    return view( 'Cadastros.Fornecedores.show', compact( 'empresa', 'produto', 'enderecos', 'contatos', 'tags', 'tipo', 'empCod', 'prodCod' ) );
  }

  /**
   * Exibe o formulario para editar um Fornecedor.
   *
   * @param $empCod
   * @param $prodCod
   * @return \Illuminate\Http\Response
   */
  public function edit( $empCod, $prodCod ) {
    $empresa   = null;
    $centro    = null;
    $conta     = null;
    $enderecos = null;
    $contatos  = null;
    $tags      = null;

    if ( $empCod <= 0 ) {
      return abort( '400', 'Falta parametro Codigo da Empresa' );

    } else {
      /** @var FornecedoresEmpresas $empresa */
      $empresa = FornecedoresEmpresas::findOrFail( $empCod );

      if ( $prodCod <= 0 ) {
        $enderecos = $empresa->Enderecos()->get();
        $tipo      = 1;
      } else {
        /** @var FornecedoresServicosProdutos $produto */
        $produto  = $empresa->ServicosProdutos()->findOrFail( $prodCod );
        $contatos = $produto->Contatos()->get();
        $tags     = $produto->getTagsIDs();
        $tipo     = 2;

      }
    }

    return view( 'Cadastros.Fornecedores.edit', compact( 'empresa', 'produto', 'tipo', 'empCod', 'prodCod', 'enderecos', 'contatos', 'tags' ) );
  }

  /**
   * Atualiza os dados de um Fornecedor.
   *
   * @param FornecedoresRequest $request
   * @param $empCod
   * @param $prodCod
   * @return \Illuminate\Http\Response
   */
  public function update( FornecedoresRequest $request, $empCod, $prodCod ) {
    $dados = $request->all();
    if ( $empCod > 0 && $prodCod == 0 ) {
      // update Empresa
      /** @var FornecedoresEmpresas $empresa */
      $empresa = FornecedoresEmpresas::findOrFail( $empCod );
      $empresa->update( [
        'codigo' => $request->get( 'codigo' ),
        'nome'   => $request->get( 'nome' ),

        'cnpj'            => $request->getOrNull( 'cnpj' ),
        'razao_social'    => $request->getOrNull( 'razao_social' ),
        'inscr_estadual'  => $request->getOrNull( 'inscr_estadual' ),
        'inscr_municipal' => $request->getOrNull( 'inscr_municipal' ),
        'condpagamento'   => $request->getOrNull( 'condpagamento' ),

        'nota_geral'        => $request->getOrNull( 'nota_geral', 1 ),
        'nota_qualidade'    => $request->getOrNull( 'nota_qualidade', 1 ),
        'nota_atendimento'  => $request->getOrNull( 'nota_atendimento', 1 ),
        'nota_prazo'        => $request->getOrNull( 'nota_prazo', 1 ),
        'nota_obs'          => $request->getOrNull( 'nota_obs' ),
        'nota_recomendacao' => $request->getOrNull( 'nota_recomendacao' ),

        'bancario_banco'   => $request->getOrNull( 'bancario_banco' ),
        'bancario_agencia' => $request->getOrNull( 'bancario_agencia' ),
        'bancario_conta'   => $request->getOrNull( 'bancario_conta' ),

        'obs' => $request->getOrNull( 'obs' ),
      ] );
      $enderecos = $empresa->Enderecos();

      // update Enderecos
      $end_id          = array_get( $dados, 'end_id', [] );
      $end_apelido     = array_get( $dados, 'end_apelido', [] );
      $end_cep         = array_get( $dados, 'end_cep', [] );
      $end_logradouro  = array_get( $dados, 'end_logradouro', [] );
      $end_numero      = array_get( $dados, 'end_numero', [] );
      $end_complemento = array_get( $dados, 'end_complemento', [] );
      $end_bairro      = array_get( $dados, 'end_bairro', [] );
      $end_cidade      = array_get( $dados, 'end_cidade', [] );
      $end_estado      = array_get( $dados, 'end_estado', [] );

      // funcao usada no array_map para selecionar o 'id', e tornar o array associativo em somente array
      $soID = function ( $value ) { return $value[ 'id' ]; };

      // analisa as diferencas
      // flat a lista de ids, ex: [1, 2, 3, 4]
      $end_antigo = array_map( $soID, $enderecos->get( [ 'id' ] )->toArray() );
      // calcula a diferença ( encontra os valores nao presente no $end_id, mas que tinha no antigo) e reinicia o array associativo
      $end_deletados = array_values( array_diff( $end_antigo, $end_id ) );

      // deleta os anteriores do BD
      FornecedoresEmpresasEnderecos::destroy( $end_deletados );

      // insere os novos ou atualiza os editados
      for ( $i = 0; $i < count( $end_cep ); $i++ ) {
        // cria novo endereco
        $end = [
          'apelido'     => $end_apelido[ $i ],
          'cep'         => $end_cep[ $i ],
          'logradouro'  => $end_logradouro[ $i ],
          'numero'      => $end_numero[ $i ],
          'complemento' => $end_complemento[ $i ],
          'bairro'      => $end_bairro[ $i ],
          'cidade'      => $end_cidade[ $i ],
          'estado'      => $end_estado[ $i ],
        ];
        if ( $end_id[ $i ] == '-1' ) { // cria novo endereco
          $empresa->Enderecos()->create( $end );
        } else { // atualiza endereco com aquele id
          $empresa->Enderecos()->find( $end_id[ $i ] )->update( $end );
        }
      }

    } elseif ( $empCod > 0 && $prodCod > 0 ) {
      // update Produto Servico
      /** @var FornecedoresEmpresas $empresa */
      $empresa = FornecedoresEmpresas::findOrFail( $empCod );
      /** @var FornecedoresServicosProdutos $produto */
      $produto = $empresa->ServicosProdutos()->findOrFail( $prodCod );
      $produto->update( $dados );

      // CONTATOS
      $contatos = $produto->Contatos();
      // get do post
      $contato_id    = array_get( $dados, 'contato_id', [] );
      $contato_nome  = array_get( $dados, 'contato_nome', [] );
      $contato_tel   = array_get( $dados, 'contato_tel', [] );
      $contato_cel   = array_get( $dados, 'contato_cel', [] );
      $contato_email = array_get( $dados, 'contato_email', [] );

      // funcao usada no array_map para selecionar o 'id', e tornar o array associativo em somente array
      $soID = function ( $value ) { return $value[ 'id' ]; };

      // analisa as diferencas
      // flat a lista de ids, ex: [1, 2, 3, 4]
      $contato_antigo = array_map( $soID, $contatos->get( [ 'id' ] )->toArray() );
      // calcula a diferença ( encontra os valores nao presente no $contato_id, mas que tinha no antigo) e reinicia o array associativo
      $contato_deletados = array_values( array_diff( $contato_antigo, $contato_id ) );

      // deleta os anteriores do BD
      FornecedoresServicosProdutosContatos::destroy( $contato_deletados );

      // insere os novos ou atualiza os editados
      for ( $i = 0; $i < count( $contato_nome ); $i++ ) {
        $cont = [
          'nome'  => $contato_nome[ $i ],
          'tel'   => $contato_tel[ $i ],
          'cel'   => $contato_cel[ $i ],
          'email' => $contato_email[ $i ],
        ];
        if ( $contato_id[ $i ] == '-1' ) { // cria novo endereco
          $produto->Contatos()->create( $cont );
        } else { // atualiza endereco com aquele id
          $produto->Contatos()->find( $contato_id[ $i ] )->update( $cont );
        }
      }

      // TAGs
      $tagsID = $request->get( 'tags', [] );
      $produto->Tags()->sync( $tagsID );

    }

    flash( 'Fornecedor editado com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.show', [ $empCod, $prodCod ] );
  }

  /**
   * Remove um Fornecedor do BD.
   *
   * @param $empCod
   * @param $prodCod
   * @return \Illuminate\Http\Response
   */
  public function destroy( $empCod, $prodCod ) {

    if ( $empCod > 0 && $prodCod == 0 ) {
      // delete Empresa
      $empresa = FornecedoresEmpresas::findOrFail( $empCod );
      $empresa->delete();

    } elseif ( $empCod > 0 && $prodCod > 0 ) {
      // delete Produto Servico
      /** @var FornecedoresEmpresas $empresa */
      $empresa = FornecedoresEmpresas::findOrFail( $empCod );
      /** @var FornecedoresServicosProdutos $centro */
      $prod = $empresa->ServicosProdutos()->findOrFail( $prodCod );
      $prod->delete();

    }

    flash( 'Fornecedor deletado com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.index' );
  }

  /**
   * Lista as TAGs.
   *
   * @return \Illuminate\Http\Response
   */
  public function tagIndex() {
    $tags      = FornecedoresTags::orderBy( 'nome' )->get();
    $tagsCount = $tags->count();

    return view( 'Cadastros.Fornecedores.tags', compact( 'tags', 'tagsCount' ) );
  }

  /**
   * Insere uma TAG no BD.
   *
   * @param FornecedoresRequest $request
   * @return \Illuminate\Http\Response
   */
  public function tagCreate( FornecedoresRequest $request ) {
    FornecedoresTags::create( $request->all() );

    flash( 'TAG criado com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.tagIndex' );
  }

  /**
   * Remove uma TAG do BD.
   *
   * @param $id
   * @return \Illuminate\Http\Response
   */
  public function tagDestroy( $id ) {
    $tag = FornecedoresTags::findOrFail( $id );
    $tag->delete();

    flash( 'TAG deletado com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.tagIndex' );
  }

  /**
   * Lista as TAGs.
   *
   * @return \Illuminate\Http\Response
   */
  public function despesasIndex() {
    $despesas      = FornecedoresDespesas::orderBy( 'codigo' )->get();
    $despesasCount = $despesas->count();

    return view( 'Cadastros.Fornecedores.despesas', compact( 'despesas', 'despesasCount' ) );
  }

  /**
   * Insere uma TAG no BD.
   *
   * @param FornecedoresRequest $request
   * @return \Illuminate\Http\Response
   */
  public function despesasCreate( FornecedoresRequest $request ) {
    FornecedoresDespesas::create( $request->all() );

    flash( 'Despesa criada com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.despesasIndex' );
  }

  /**
   * Remove uma TAG do BD.
   *
   * @param $id
   * @return \Illuminate\Http\Response
   */
  public function despesasDestroy( $id ) {
    $despesa = FornecedoresDespesas::findOrFail( $id );
    $despesa->delete();

    flash( 'Despesa deletada com sucesso!', 'success' );
    return redirect()->route( 'fornecedores.despesasIndex' );
  }

  /**
   * Teste de Orcamento.
   *
   * @return \Illuminate\Http\Response
   */
  public function testeOrcamento() {
    $prod      = [];
    $prodCount = 0;
    if ( Request::has( 'tag' ) ) {
      $id = Request::get( 'tag' );
      /** @var FornecedoresTags $tag */
      $tag          = FornecedoresTags::find( $id );
      $fornecedores = $tag->ServicosProdutos;
      foreach ( $fornecedores as $fornecedor ) {
        $prod[] = $fornecedor->getNomeOrcamento();
      }
      $prodCount = count( $prod );
    }

    return view( 'Cadastros.Fornecedores.testeOrcamento', compact( 'prod', 'prodCount' ) );
  }
}
