<?php

namespace App\Http\Controllers\Cadastros;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Cadastros\PlanoDeContas;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Http\Request;

class PlanoDeContasController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Cadastro_read ) )->only( [ 'index' ] );
    $this->middleware( CRP::role( CRP::P_Cadastro_edit ) )->only( [ 'store', 'edit', 'update', 'destroy' ] );
  }

  /**
   * Lista as PlanoDeContas.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    $planoDeContasJSON = PlanoDeContas::despesas_treeView();

    return view( 'Cadastros.PlanoDeContas.index', compact( 'planoDeContasJSON' ) );
  }

  /**
   * Insere o PlanoDeContas no BD.
   *
   * @param  \Illuminate\Http\Request $request
   * @return \Illuminate\Http\Response
   */
  public function store( Request $request ) {
    $tipo = $request->get( 'tipo', '' );

    if ( $tipo == 'GRUPO' ) {
      PlanoDeContas::create( $request->all() );

      flash( 'Grupo de Plano de Contas criado com sucesso!', 'success' );
    } elseif ( $tipo == 'ITEM' ) {
      PlanoDeContasItem::create( $request->all() );

      flash( 'Item de Plano de Contas criado com sucesso!', 'success' );
    }

    return redirect()->route( 'cadastros.planodecontas.index' );
  }

  /**
   * Exibe o formulario para editar uma PlanoDeContas no BD.
   *
   * @param int $grupoID
   * @param int $itemID
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function edit( $grupoID, $itemID ) {
    if ( $itemID == 0 ) { // GRUPO
      $tipo  = 'GRUPO';
      $grupo = PlanoDeContas::findOrFail( $grupoID );

      return view( 'Cadastros.PlanoDeContas.edit', compact( 'tipo', 'grupoID', 'itemID', 'grupo' ) );

    } else { // ITEM
      $tipo = 'ITEM';
      $item = PlanoDeContasItem::findOrFail( $itemID );

      return view( 'Cadastros.PlanoDeContas.edit', compact( 'tipo', 'grupoID', 'itemID', 'item' ) );
    }
  }

  /**
   * Atualiza uma PlanoDeContas no BD.
   *
   * @param  \Illuminate\Http\Request $request
   * @param int $grupoID
   * @param int $itemID
   * @return \Illuminate\Http\Response
   */
  public function update( Request $request, $grupoID, $itemID ) {
    if ( $itemID == 0 ) { // GRUPO
      $grupo = PlanoDeContas::findOrFail( $grupoID );
      $grupo->update( $request->all() );

      flash( 'Grupo de Plano de Contas criado com sucesso!', 'success' );
      return redirect()->route( 'cadastros.planodecontas.index' );

    } else { // ITEM
      $item = PlanoDeContasItem::findOrFail( $itemID );
      $item->update( $request->all() );

      flash( 'Item de Plano de Contas criado com sucesso!', 'success' );
      return redirect()->route( 'cadastros.planodecontas.index' );
    }
  }

  /**
   * Remove uma PlanoDeContas no BD.
   *
   * @param int $grupoID
   * @param int $itemID
   * @return \Illuminate\Http\Response
   */
  public function destroy( $grupoID, $itemID ) {
    if ( $itemID == 0 ) { // GRUPO
      $grupo = PlanoDeContas::findOrFail( $grupoID );
      $grupo->delete();

      flash( 'Grupo de Plano de Contas deletado com sucesso!', 'success' );
      return redirect()->route( 'cadastros.planodecontas.index');

    } else { // ITEM
      $item = PlanoDeContasItem::findOrFail( $itemID );
      $item->delete();

      flash( 'Item de Plano de Contas deletado com sucesso!', 'success' );
      return redirect()->route( 'cadastros.planodecontas.index' );
    }
  }
}
