<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Comercial\Jobs;
use Request;
use Response;

class JobsControllerApi extends Controller {
  /**
   * Upload de um arquivo anexo ao Briefing do job.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse
   */
  public function upload( $id ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );

    if ( Request::hasFile( 'arquivo' ) ) {
      $file = Request::file( 'arquivo' );

      $nome     = $file->getClientOriginalName();
      $extensao = $file->getClientOriginalExtension();

      $local = public_path() . '/uploads/jobs/' . $job->id;
      $file->move( $local, $nome );

      $b = $job->BriefingFiles()->create( [
        'arquivo'  => $nome,
        'extensao' => $extensao
      ] );

      return Response::json( [ $b ] );
    }

    return Response::json( [ 'oi' => 'nao hasFile' ] );
  }


  /**
   * Retorna a lista de arquivos anexos a este Briefing do Job.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse
   */
  public function listFile( $id ) {
    /** @var Jobs $job */
    $job   = Jobs::findOrFail( $id );
    $files = $job->getAllBriefingFiles();

    return Response::json( $files );
  }

  /**
   * Deleta um arquivo anexo ao Briefing do Job.
   *
   * @param $id
   * @param $arq
   * @return \Illuminate\Http\JsonResponse
   */
  public function deleteFile( $id, $arq ) {
    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $file = $job->BriefingFiles()->find( $arq );

    $local = public_path() .
      DIRECTORY_SEPARATOR . 'uploads' .
      DIRECTORY_SEPARATOR . 'jobs' .
      DIRECTORY_SEPARATOR . $job->id .
      DIRECTORY_SEPARATOR . $file->arquivo;
    if ( file_exists( $local ) ) {
      unlink( $local );
    }

    $file->delete();

//    return Response::json( $file );
    return Response::json( [ 'oi' => 'deu bom' ] );
  }

  /**
   * Retorna os Job na Busca do Importador de Cronograma.
   *
   * @return \Illuminate\Http\JsonResponse
   */
  function busca_cronos() {
    /** @var Jobs[] $jobs */
    $jobs = Jobs::where( function ( \Illuminate\Database\Eloquent\Builder $query ) {
                  $query->where( 'nome_job', 'like', '%' . Request::get( 'nome', '' ) . '%' )
                        ->orWhere( 'id', 'like', '%' . Request::get( 'nome', '' ) . '%' );
                } )
                ->whereHas( 'Cronograma', function ( \Illuminate\Database\Eloquent\Builder $q ) {
                  $q->where( 'json', '!=', '[]' );
                } )
                ->get();

    $data = [];
    foreach ( $jobs as $job ) {
      $data[] = [
        'id'       => $job->id,
        'nome_job' => $job->nome_job,
        'cliente'  => $job->_ClienteConta(),
      ];
    }

    return Response::json( $data, 200 );
  }

  /**
   * Retorna um Cronograma para ser importado no Importador de Cronograma.
   *
   * @param $job_id
   * @return \Illuminate\Http\JsonResponse
   */
  function get_crono( $job_id ) {
    /** @var Jobs $job */
    $job   = Jobs::findOrFail( $job_id );
    $crono = $job->_Cronograma()->json;
    $crono = json_decode( $crono );

    return Response::json( $crono, 200 );
  }
}
