<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Cadastros\ClientesCentrosDeCustosContatos;
use App\Models\Comercial\Jobs;
use App\Models\Comercial\Orcamento;
use App\Models\Financeiro\JobParcela;
use Carbon\Carbon;
use Maatwebsite\Excel\Facades\Excel;
use PDF;
use PHPExcel_Style_Border;
use Request;
use Response;

class JobsPDFController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
  }

  /**
   * Gera o PDF de uma estimativa de Orcamento.
   *
   * @param $id
   * @return \Illuminate\Http\Response
   */
  public function gerarPDF( $id ) {
    // Get Parametros =>  tipo = A1 & orc = 1 & contato = 1
    $tipo    = strtoupper( Request::get( 'tipo', null ) );
    $orc_ids = Request::get( 'orc', [] );
    $cont_id = Request::get( 'contato', null );
    $logo    = Request::get( 'logo', 1 );

    if ( !in_array( $tipo, [ 'A1', 'A2', 'B', 'C', 'D' ] ) ) {
      abort( 403, 'falta param "tipo".' );
    }

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );

    // Orcamento
    $enumOrcamentosAprovadosDiretoria = $job->enum_OrcamentosAprovados_Diretoria();
    foreach ( $orc_ids as $orc_id ) {
      if ( !array_key_exists( $orc_id, $enumOrcamentosAprovadosDiretoria ) ) {
        abort( 403, 'Não existe este Orçamento Aprovado.' );
      }
    }
    $orcs = $job->Orcamentos()->whereIn( 'id', $orc_ids )->get();
    if ( ( $orcs_count = $orcs->count() ) === 0 ) {
      abort( 403, 'Não existe este Orçamento.' );
    }

    // Contato
    if ( !$job->ClienteConta ) {
      abort( 403, 'Este Job não tem Cliente.' );
    }
    $contatos = $job->ClienteConta->CentroDeCusto->Contatos;
    if ( !$contatos ) {
      abort( 403, 'Este Cliente não tem Contatos.' );
    }
    /** @var ClientesCentrosDeCustosContatos $contato */
    $contato = $contatos->find( $cont_id );
    if ( !$contato ) {
      abort( 403, 'Não existe este Contato.' );
    }


    $hj    = Carbon::now();
    $datas = [
      'job_id'           => $job->id,
      'nome_job'         => $job->nome_job,
      'cliente'          => $job->ClienteUnidade ? $job->ClienteUnidade->nome : '!! Job Sem Unidade do Cliente Definido !!',
      'ac'               => $contato->nome, // responsavel pra receber
      'data'             => $hj->day . ' de ' . $this->enum_mes[ $hj->month ] . ' de ' . $hj->year,
      'previsao_entrega' => \Carbon\Carbon::parse( $job->previsao_entrega )->format( 'd/m/Y H:i' ),
      'condpagto'        => $job->condpagto,
      'proposta_codigo'  => 'Job ' . $job->id,
      'logoCadaris'      => $logo != 2,
      'orcs_count'       => $orcs_count,
      'itens'            => []
    ];

    foreach ( $orcs as $orc ) {
      /** @var Orcamento $orc */

      // Custos Internos ( itens[nome valor], subtotal )
      $ci_itens    = [];
      $ci_subtotal = 0;
      foreach ( $orc->ItensCI as $ci ) {
        $v           = $ci->Calcular()[ 'total' ];
        $ci_subtotal += $v;
        $ci_itens[]  = [
          'nome'  => $ci->nome,
          'valor' => $v
        ];
      }

      // Custos de Operacionalizacao ( itens[nome valor], subtotal )
      $co_itens    = [];
      $co_subtotal = 0;
      foreach ( $orc->ItensCO as $co ) {
        $v           = $co->Calcular()[ 'total' ];
        $co_subtotal += $v;
        $co_itens[]  = [
          'nome'  => $co->nome,
          'valor' => $v
        ];
      }


      // Codigo do Orcamento no formato 'Job 1234-C'
      $orc_letra                  = '';
      $letra                      = 0;
      $alphabet                   = range( 'A', 'Z' );
      foreach ( $enumOrcamentosAprovadosDiretoria as $o_id => $o ) {
        /** @var Orcamento $o */
        if ( $orc->id === $o_id ) {
          $orc_letra = $letra <= 25 ? $alphabet[ $letra ] : $letra;
          break;
        }
        $letra++;
      }
      if ( $orcs_count === 1 ) {
        $datas[ 'proposta_codigo' ] .= '-' . $orc_letra;
      }

      // Dados utilizados
      $datas[ 'itens' ][] = [
        'est_id'        => $orc->id,
        'orc_letra'     => $orc_letra,
        'orc_nome'      => $orc->nome,
        'orc_descricao' => $orc->descricao_geral,
        'ci_itens'      => $ci_itens,
        'ci_subtotal'   => $ci_subtotal,
        'co_itens'      => $co_itens,
        'co_subtotal'   => $co_subtotal,
        'orc_total'     => $ci_subtotal + $co_subtotal,
      ];
    }

    //  return $datas;
    // return view( 'Comercial.PDF.jobsPDFtipo' . $tipo, [ 'datas' => $datas ] );
    $pdf = PDF::loadView( 'Comercial.PDF.jobsPDFtipo' . $tipo, [ 'datas' => $datas ] );
    $pdf->setOption( 'lowquality', false );
    $pdf->setOption( 'page-size', 'A4' );
    $pdf->setOption( 'dpi', 300 );
    $pdf->setOption( 'image-dpi', 300 );

    return $pdf->inline( 'Orçamento da Proposta Comercial - ' . $datas[ 'nome_job' ] . '.pdf' );
  }


  /**
   * Gera o PDF do Cronograma.
   *
   * @param $id
   * @return \Illuminate\Http\Response
   */
  public function cronogramaPDF( $id ) {
    /** @var Jobs $job */
    $job               = Jobs::findOrFail( $id );
    $cronograma_hidden = $job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }

      return $val;
    } );

    $data                 = [];
    $data[ 'job' ]        = $job;
    $data[ 'cronograma' ] = $cronograma;
    $data[ 'nome' ]       = $job->nome_job;
    $data[ 'resp' ]       = $job->_Responsavel();
    $data[ 'cliente' ]    = $job->_ClienteConta();
    $hj                   = Carbon::now();
    $data[ 'data' ]       = $hj->day . ' de ' . $this->enum_mes[ $hj->month ] . ' de ' . $hj->year;

    $data[ 'proposta_codigo' ] = 'Job ' . $job->id;

    // return view( 'Comercial.PDF.jobsCronoPDF', [ 'data' => $data ] );
    $pdf = PDF::loadView( 'Comercial.PDF.jobsCronoPDF', [ 'data' => $data ] );
    $pdf->setOption( 'lowquality', false );
    $pdf->setOption( 'page-size', 'A4' );
    $pdf->setOption( 'dpi', 300 );
    $pdf->setOption( 'image-dpi', 300 );

    return $pdf->inline( 'Cronograma - ' . $data[ 'nome' ] . '.pdf' );
  }

  /**
   * Gera o CSV do Cronograma.
   *
   * @param $id
   * @return \Symfony\Component\HttpFoundation\StreamedResponse
   */
  public function cronogramaCSV( $id ) {
    /** @var Jobs $job */
    $job               = Jobs::findOrFail( $id );
    $cronograma_hidden = $job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }

      return $val;
    } );

    $callback = function () use ( $cronograma ) {
      $CSV = fopen( 'php://output', 'w' );
      fputs( $CSV, $bom = ( chr( 0xEF ) . chr( 0xBB ) . chr( 0xBF ) ) );
      fputcsv( $CSV, [
        'Data Início', 'Data Término', 'Responsável', 'Descrição'
      ] );
      foreach ( $cronograma as $crono ) {
        fputcsv( $CSV, [
          \Carbon\Carbon::parse( $crono->startDate )->format( 'd/m/Y' ),
          \Carbon\Carbon::parse( $crono->endDate )->format( 'd/m/Y' ),
          $crono->name,
          $crono->descricao
        ] );
      }
      fclose( $CSV );
    };

    $headers = [
      'Cache-Control'       => 'must-revalidate, post-check=0, pre-check=0',
      'Content-type'        => 'text/csv',
      'Content-Disposition' => 'attachment; filename=cronograma.csv',
      'Expires'             => '0',
      'Pragma'              => 'public',
    ];

    return Response::stream( $callback, 200, $headers );
  }

  /**
   * Gera o XLSX do Cronograma.
   *
   * @param $id
   * @return void
   */
  public function cronogramaXLSX( $id ) {
    /** @var Jobs $job */
    $job               = Jobs::findOrFail( $id );
    $cronograma_hidden = $job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }

      return $val;
    } );

    $XLSX   = [];
    $XLSX[] = [ 'Data Início', 'Data Término', 'Responsável', 'Descrição' ];
    foreach ( $cronograma as $crono ) {
      $XLSX[] = [
        \Carbon\Carbon::parse( $crono->startDate )->format( 'd/m/Y' ),
        \Carbon\Carbon::parse( $crono->endDate )->format( 'd/m/Y' ),
        $crono->name,
        $crono->descricao
      ];
    }

    Excel::create( 'Job ' . $job->id . ' - Cronograma', function ( $excel ) use ( $XLSX ) {
      /** @var \Maatwebsite\Excel\Writers\LaravelExcelWriter $excel */
      $excel->setTitle( 'Cronograma' );
      $excel->setDescription( 'Cronograma' );
      $excel->sheet( 'Cronograma', function ( $sheet ) use ( $XLSX ) {
        /** @var \Maatwebsite\Excel\Classes\LaravelExcelWorksheet $sheet */
        // Dados
        $sheet->fromArray( $XLSX, null, 'A1', false, false );

        // Style geral
        $sheet->setStyle( [
          'font' => [
            'name' => 'Arial',
            'size' => 10
          ]
        ] );
        $sheet->setAutoSize( true );

        // Style do Header
        $sheet->setHeight( 1, 25 );
        $sheet->cells( 'A1:D1', function ( $cells ) {
          /** @var \Maatwebsite\Excel\Writers\CellWriter $cells */
          $cells->setFontColor( '#ffffff' );
          $cells->setBackground( '#404040' );
          $cells->setAlignment( 'center' );
          $cells->setValignment( 'center' );
          $cells->setFontWeight( 'bold' );
        } );
      } );
    } )->download( 'xlsx' );
  }

  /**
   * Gera o CSV dos Jobs.
   *
   * @return \Symfony\Component\HttpFoundation\StreamedResponse
   */
  public function export_jobs_CSV() {
    /** @var Jobs[] $jobs */
    $jobs = Jobs::orderBy( 'id' )->get();

    $jobs_data = [];
    foreach ( $jobs as $job ) {
      $jobs_data[] = [
        $job->id,
        $job->nome_job,
        $job->etapa_atual,
        $job->ValorPropostaFormatado(),
        $job->_ClienteConta()
      ];
    }

    $callback = function () use ( $jobs_data ) {
      $CSV = fopen( 'php://output', 'w' );
      fputs( $CSV, $bom = ( chr( 0xEF ) . chr( 0xBB ) . chr( 0xBF ) ) );
      fputcsv( $CSV, [
        'ID', 'Nome do Job', 'Estágio', 'Valor (Aprovado pelo Cliente)', 'Cliente'
      ] );
      foreach ( $jobs_data as $job ) {
        fputcsv( $CSV, $job );
      }
      fclose( $CSV );
    };

    $headers = [
      'Cache-Control'       => 'must-revalidate, post-check=0, pre-check=0',
      'Content-type'        => 'text/csv',
      'Content-Disposition' => 'attachment; filename=export_jobs.csv',
      'Expires'             => '0',
      'Pragma'              => 'public',
    ];

    return Response::stream( $callback, 200, $headers );
  }

  /**
   * Gera o XLSX dos Jobs.
   *
   * @return void
   */
  public function export_jobs_XLSX() {
    /** @var Jobs[] $jobs */
    $jobs = Jobs
      ::orderBy( 'id' )
      ->with( [
        'Orcamentos',
        'Orcamentos.ItensCI',
        'Orcamentos.ItensCI.Servicos',
        'Orcamentos.ItensCO',
        'Orcamentos.ItensCO.Servicos',
        'ClienteConta',
        'ClienteUnidade',
      ] )
      ->get();

    $XLSX   = [];
    $XLSX[] = [
      'ID',
      'NOME DO JOB',
      'CENTRO DE CUSTO',
      'NOME ESTIMATIVA',
      'APROV. DIRETORIA',
      'APROV. CLIENTE',
      'VALOR',
      'CÓD RECEITA',
      'ETAPA',
      'PREVISÃO FATURAMENTO',
      'DT FATUR. (1)',
      'DT FATUR. (2)',
      'DT FATUR. (3)',
      'DT FATUR. (4)',
      'DT FATUR. (5)',
      'DT FATUR. (6)',
      'DT FATUR. (7)',
      'DT FATUR. (8)',
      'DT FATUR. (9)',
      'DT FATUR. (10)',
      'DT FATUR. (11)',
      'DT FATUR. (12)',
      'SALDO'
    ];
    foreach ( $jobs as $job ) {
      foreach ( $job->Orcamentos as $orc ) {
        $linha = [
          $job->id,
          $job->nome_job,
          $job->_ClienteConta(),
          $orc->nome,
          $orc->_aprovDiretoria(),
          $orc->_aprovCliente(),
          $orc->CalcularValorTotal() / 100,
          $job->_codReceitaNome(),
          $job->etapa_atual,
        ];

        // Previsão Faturamento
        $linha[] =
          ( !empty( $job->previsao_entrega ) &&
            !empty( $job->ClienteUnidade ) &&
            !empty( $job->ClienteUnidade->condpagamento_dias ) ) ?
            $job->previsao_entrega->addDays( $job->ClienteUnidade->condpagamento_dias )->format( 'd/m/Y' ) :
            '';

        // Data de Faturamento (parcela 1..12)
        $maximo_doze = 0;
        $parcelas    = $job->Parcelas()->orderBy( 'data' )->get();
        foreach ( $parcelas as $parcela ) {
          /** @var JobParcela $parcela */
          $maximo_doze++;
          $linha[] = $parcela->data->format( 'd/m/Y' );
          if ( $maximo_doze >= 12 ) {
            break;
          }
        }
        for ( $i = $maximo_doze; $i < 12; $i++ ) {
          $linha[] = '';
        }

        // Saldo
        $linha[] = '';

        $XLSX[] = $linha;
      }
    }

    Excel::create( 'Sistema Cadaris - Jobs (' . Carbon::now()->format( 'd-m-Y' ) . ')', function ( $excel ) use ( $XLSX ) {
      /** @var \Maatwebsite\Excel\Writers\LaravelExcelWriter $excel */
      $excel->setTitle( 'Sistema Cadaris - Jobs' );
      $excel->setDescription( 'Sistema Cadaris - Jobs' );
      $excel->sheet( 'Sistema Cadaris - Jobs', function ( $sheet ) use ( $XLSX ) {
        /** @var \Maatwebsite\Excel\Classes\LaravelExcelWorksheet $sheet */
        // Dados
        $sheet->fromArray( $XLSX, null, 'A1', false, false );

        // Style geral
        $sheet->setStyle( [
          'font' => [
            'name' => 'Arial',
            'size' => 10
          ]
        ] );
        $sheet->setAutoSize( true );
        $sheet->setBorder( 'A1:W' . count( $XLSX ), PHPExcel_Style_Border::BORDER_THIN );

        // Style do Header
        $sheet->setHeight( 1, 25 );
        $sheet->cells( 'A1:W1', function ( $cells ) {
          /** @var \Maatwebsite\Excel\Writers\CellWriter $cells */
          $cells->setFontColor( '#ffffff' );
          $cells->setBackground( '#404040' );
          $cells->setAlignment( 'center' );
          $cells->setValignment( 'center' );
          $cells->setFontWeight( 'bold' );
        } );

        // Auto Filter
        $sheet->setAutoFilter();
      } );
    } )->download( 'xlsx' );
  }

  private $enum_mes = [
    1  => 'Janeiro',
    2  => 'fevereiro',
    3  => 'março',
    4  => 'abril',
    5  => 'maio',
    6  => 'junho',
    7  => 'julho',
    8  => 'agosto',
    9  => 'setembro',
    10 => 'outubro',
    11 => 'novembro',
    12 => 'dezembro'
  ];

  /*
  Tipos de PDF
  - gerar um pdf só com custos internos e outro só com custos de operacionalização
  - gerar um pdf com custo geral e descrição geral
  - gerar um pdf com custo por item (interno e operacionalização) e total geral
  - gerar um pdf só com custos por item (interno e operacionalização) sem o total geral
  */
}
