<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Comercial\Jobs;
use App\Models\Comercial\Orcamento;
use App\Models\Comercial\OrcamentoItemCI;
use App\Models\Comercial\OrcamentoItemCIServico;
use App\Models\Comercial\OrcamentoItemCO;
use App\Models\Comercial\OrcamentoItemCOServico;
use Carbon\Carbon;
use Request;
use Response;

class OrcamentoEstimativaControllerApi extends Controller {
  /**
   * Lista todos oas Estimativas.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse
   */
  public function index( $id ) {
    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orcs = $job->Orcamentos;

    $data = [];
    foreach ( $orcs as $orc ) {
      $data[] = [
        'id'              => $orc->id,
        'nome'            => $orc->nome,
        'data'            => Carbon::createFromFormat( 'Y-m-d', $orc->data )->format( 'd/m/Y' ),
        'descricao_geral' => $orc->descricao_geral,
        'aprov_diretor'   => $orc->_aprovDiretoria(),
        'aprov_diretor_c' => $orc->orc_aprov_diretoria_color(),
        'aprov_cliente'   => $orc->_aprovCliente(),
        'aprov_cliente_c' => $orc->orc_aprov_cliente_color(),
      ];
    }

    return Response::json( $data );
  }

  /**
   * Armazena uma estimativa.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse
   */
  public function store( $id ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->Orcamentos()->create( [
      'nome'            => Request::get( 'nome', '' ),
      'data'            => Request::get( 'data', Carbon::now()->format( 'T-m-d' ) ),
      'descricao_geral' => Request::get( 'descricao_geral', null ),
    ] );

    return Response::json( $orc, 200 );
  }

  /**
   * Retorna um Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse
   */
  public function show( $id, $id2 ) {
    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orc  = $job->_Orcamentos( $id2 );
    $orc2 = $orc->toArray();

    $orc2[ 'data_formatada' ] = Carbon::createFromFormat( 'Y-m-d', $orc->data )->format( 'd/m/Y' );

    return Response::json( $orc2, 200 );
  }

  /**
   * Atualiza um Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse
   */
  public function update( $id, $id2 ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $id2 );

    $orc->update( [
      'nome'            => Request::get( 'nome', '' ),
      'data'            => Request::get( 'data', Carbon::now()->format( 'T-m-d' ) ),
      'descricao_geral' => Request::get( 'descricao_geral', null ),
    ] );

    return Response::json( $orc, 201 );
  }

  /**
   * Destroi um Item.
   *
   * @param $id
   * @param $id2
   * @return Response
   */
  public function destroy( $id, $id2 ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $id2 );
    $orc->delete();

    return response( '', 200 );
  }

  /**
   * Duplica um Orcamento qlqr por completo para este Job.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse
   */
  public function est_duplicar( $id, $id2 ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    /** @var Orcamento $orc */
    $orc = Orcamento::findOrFail( $id2 );

    /** @var Orcamento $neworc */
    $neworc       = $job->Orcamentos()->create( $orc->toArray() );
    $neworc->nome .= ' - Cópia';
    $neworc->data = Carbon::now()->format( 'Y-m-d' );
    $neworc->orc_aprov_diretor = null;
    $neworc->orc_aprov_cliente = null;
    $neworc->save();

    // itens de CI
    foreach ( $orc->ItensCI as $ci ) {
      /** @var OrcamentoItemCI $itensCI */
      $itensCI = $neworc->ItensCI()->create( $ci->toArray() );
      // servicos deste item CI
      foreach ( $ci->Servicos as $serv ) {
        /** @var OrcamentoItemCIServico $s */
        $itensCI->Servicos()->create( $serv->toArray() );
      }
    }

    // itens de CO
    foreach ( $orc->ItensCO as $co ) {
      /** @var OrcamentoItemCO $itensCO */
      $itensCO = $neworc->ItensCO()->create( $co->toArray() );
      // servicos deste item CO
      foreach ( $co->Servicos as $serv ) {
        /** @var OrcamentoItemCOServico $s */
        $itensCO->Servicos()->create( $serv->toArray() );
      }
    }

    return Response::json( $neworc, 200 );
  }

  /**
   * Retorna uma busca por Jobs.
   *
   * @return \Illuminate\Http\JsonResponse
   */
  public function busca_jobs() {
    /** @var Jobs[] $jobs */
    $jobs = Jobs::where( 'nome_job', 'like', '%' . Request::get( 'nome', '' ) . '%' )->get();

    $data = [];
    foreach ( $jobs as $job ) {
      $data[] = [
        'id'                   => $job->id,
        'nome_job'             => $job->nome_job,
        'cliente'              => $job->_ClienteConta(),
        'contagem_estimativas' => $job->Orcamentos()->count(),
      ];
    }

    return Response::json( $data, 200 );
  }

  /**
   * Retorna as Estimativas de um Jobs buscado.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse
   */
  public function busca_jobs_estimativas( $id ) {
    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orcs = $job->Orcamentos;

    $data = [];
    foreach ( $orcs as $orc ) {
      $data[] = [
        'id'              => $orc->id,
        'nome'            => $orc->nome,
        'data_formatada'  => Carbon::createFromFormat( 'Y-m-d', $orc->data )->format( 'd/m/Y' ),
        'descricao_geral' => $orc->descricao_geral
      ];
    }

    return Response::json( $data, 200 );
  }
}
