<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Comercial\Jobs;
use Request;
use Response;

class OrcamentoItemCIControllerApi extends Controller {
  /**
   * Lista todos os Itens deste OrcamentoCI.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function index( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job             = Jobs::findOrFail( $id );
    $orc             = $job->_Orcamentos( $orcEST_id );
    $cis             = $orc->ItensCI;
    $data            = [];
    $data[ 'itens' ] = [];
    $valor_total     = 0;
    foreach ( $cis as $ci ) {
      $item                = [];
      $item[ 'id' ]        = $ci->id;
      $item[ 'nome' ]      = $ci->nome;
      $item[ 'descricao' ] = $ci->descricao;
      $item[ 'valor' ]     = $ci->Calcular()[ 'total' ];
      $valor_total += $item[ 'valor' ];
      $data[ 'itens' ] [] = $item;
    }
    $data[ 'valor' ] = $valor_total;

    return Response::json( $data );
  }

  /**
   * Armazena um item.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function store( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $ci  = $orc->ItensCI()->create( [
      'nome'              => Request::get( 'nome', '' ),
      'descricao'         => Request::get( 'descricao', null ),
      'custos_apoio'      => Request::get( 'custos_apoio', 0 ),
      'arredondamento'    => null,
      'taxa_comissao'     => Request::get( 'taxa_comissao', 0 ),
      'taxa_planejamento' => Request::get( 'taxa_planejamento', 0 ),
      'taxa_impostos'     => Request::get( 'taxa_impostos', 0 ),
    ] );

    return Response::json( $ci, 200 );
  }

  /**
   * Retorna um Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function show( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $ci  = $orc->_ItensCI( $id2 );

    return Response::json( $ci, 200 );
  }

  /**
   * Atualiza um Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function update( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $ci  = $orc->_ItensCI( $id2 );
    $ci->update( [
      'nome'              => Request::get( 'nome', '' ),
      'descricao'         => Request::get( 'descricao', null ),
      'custos_apoio'      => Request::get( 'custos_apoio', 0 ),
      'arredondamento'    => null,
      'taxa_comissao'     => Request::get( 'taxa_comissao', 0 ),
      'taxa_planejamento' => Request::get( 'taxa_planejamento', 0 ),
      'taxa_impostos'     => Request::get( 'taxa_impostos', 0 ),
    ] );

    return Response::json( $ci, 201 );
  }

  /**
   * Destroi um Item.
   *
   * @param $id
   * @param $id2
   * @return Response
   */
  public function destroy( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $ci  = $orc->_ItensCI( $id2 );
    $ci->delete();

    return response( '', 200 );
  }

}
