<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Comercial\Jobs;
use Request;
use Response;

class OrcamentoItemCOControllerApi extends Controller {
  /**
   * Lista todos os Itens deste OrcamentoCO.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function index( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job             = Jobs::findOrFail( $id );
    $orc             = $job->_Orcamentos( $orcEST_id );
    $cos             = $orc->ItensCO;
    $data            = [];
    $data[ 'itens' ] = [];
    $valor_total     = 0;

    foreach ( $cos as $co ) {
      $item                = [];
      $item[ 'id' ]        = $co->id;
      $item[ 'nome' ]      = $co->nome;
      $item[ 'descricao' ] = $co->descricao;
      $item[ 'valor' ]     = $co->Calcular()[ 'total' ];
      $valor_total += $item[ 'valor' ];
      $data[ 'itens' ] [] = $item;
    }
    $data[ 'valor' ] = $valor_total;

    return Response::json( $data );
  }

  /**
   * Armazena um Item.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function store( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $co  = $orc->ItensCO()->create( [
      'nome'              => Request::get( 'nome', '' ),
      'descricao'         => Request::get( 'descricao', null ),
      'arredondamento'    => null,
      'taxa_bv'           => Request::get( 'taxa_bv', 0 ),
      'taxa_planejamento' => Request::get( 'taxa_planejamento', 0 ),
      'taxa_impostos'     => Request::get( 'taxa_impostos', 0 ),
    ] );

    return Response::json( $co, 200 );
  }

  /**
   * Retorna um Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function show( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $co  = $orc->_ItensCO( $id2 );

    return Response::json( $co, 200 );
  }

  /**
   * Atualiza um Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function update( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $co  = $orc->_ItensCO( $id2 );
    $co->update( [
      'nome'              => Request::get( 'nome', '' ),
      'descricao'         => Request::get( 'descricao', null ),
      'arredondamento'    => null,
      'taxa_bv'           => Request::get( 'taxa_bv', 0 ),
      'taxa_planejamento' => Request::get( 'taxa_planejamento', 0 ),
      'taxa_impostos'     => Request::get( 'taxa_impostos', 0 ),
    ] );

    return Response::json( $co, 201 );
  }

  /**
   * Destroi um Item.
   *
   * @param $id
   * @param $id2
   * @return Response
   */
  public function destroy( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $co  = $orc->_ItensCO( $id2 );
    $co->delete();

    return response( '', 200 );
  }

}
