<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Comercial\Jobs;
use Request;
use Response;

class OrcamentoServCIControllerApi extends Controller {
  /**
   * Retorna a lsita de todos os Servicos deste Item.
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function index( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job    = Jobs::findOrFail( $id );
    $orc    = $job->_Orcamentos( $orcEST_id );
    $itemCI = $orc->_ItensCI( $item_id );

    $data                = [];
    $data[ 'nome' ]      = $itemCI->nome;
    $data[ 'descricao' ] = $itemCI->descricao;
    $data[ 'servicos' ]  = $itemCI->Calcular();

    return Response::json( $data );
  }

  /**
   * Armazena um Servico deste Item.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function store( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $ci  = $orc->_ItensCI( $item_id );

    $serv = $ci->Servicos()->create( [
      'tipo_servico'        => Request::get( 'tipo_servico', '' ),
      'tipo_servico_nivel'  => Request::get( 'tipo_servico_nivel', '' ),
      'tipo_servico_string' => Request::get( 'tipo_servico_string', '' ),
      'obs'                 => Request::get( 'obs', null ),
      'valor_unitario'      => Request::get( 'valor_unitario', '0' ),
      'horas'               => Request::get( 'horas', '0' ),
      'valor_total'         => Request::get( 'valor_total', '0' ),
    ] );

    return Response::json( $serv, 201 );
  }

  /**
   * Retorna um Servico deste Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function show( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orc  = $job->_Orcamentos( $orcEST_id );
    $ci   = $orc->_ItensCI( $item_id );
    $serv = $ci->_Servicos( $id2 );

    return Response::json( $serv, 200 );
  }

  /**
   * Atualiza um Servico deste Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function update( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orc  = $job->_Orcamentos( $orcEST_id );
    $ci   = $orc->_ItensCI( $item_id );
    $serv = $ci->_Servicos( $id2 );

    $serv->update( [
      'tipo_servico'        => Request::get( 'tipo_servico', 0 ),
      'tipo_servico_nivel'  => Request::get( 'tipo_servico_nivel', 0 ),
      'tipo_servico_string' => Request::get( 'tipo_servico_string', '' ),
      'obs'                 => Request::get( 'obs', null ),
      'valor_unitario'      => Request::get( 'valor_unitario', '0' ),
      'horas'               => Request::get( 'horas', '0' ),
      'valor_total'         => Request::get( 'valor_total', '0' ),
    ] );
    return Response::json( $serv, 201 );
  }

  /**
   * Destroi um Servico deste Item.
   *
   * @param $id
   * @param $id2
   * @return Response
   */
  public function destroy( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orc  = $job->_Orcamentos( $orcEST_id );
    $ci   = $orc->_ItensCI( $item_id );
    $serv = $ci->_Servicos( $id2 );
    $serv->delete();

    return response( '', 200 );
  }

}
