<?php

namespace App\Http\Controllers\Comercial;

use App\Http\Controllers\Controller;
use App\Models\Comercial\Jobs;
use App\Models\Comercial\Orcamento;
use App\Models\Comercial\OrcamentoItemCO;
use App\Models\Comercial\OrcamentoItemCOServico;
use Request;
use Response;

class OrcamentoServCOControllerApi extends Controller {
  /**
   * Retorna a lista de todos os Servicos deste Item.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function index( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job    = Jobs::findOrFail( $id );
    $orc    = $job->_Orcamentos( $orcEST_id );
    $itemCO = $orc->_ItensCO( $item_id );

    $data                = [];
    $data[ 'nome' ]      = $itemCO->nome;
    $data[ 'descricao' ] = $itemCO->descricao;
    $data[ 'servicos' ]  = $itemCO->Calcular();

    return Response::json( $data );
  }

  /**
   * Armazena um Servico deste Item.
   *
   * @param $id
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function store( $id ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    $orc = $job->_Orcamentos( $orcEST_id );
    $co  = $orc->_ItensCO( $item_id );

    /** @var OrcamentoItemCOServico $serv */
    $serv = $co->Servicos()->create( [
      'fornecedor_id'     => Request::get( 'fornecedor_id', '' ),
      'fornecedor_string' => '',
      'obs'               => Request::get( 'obs', null ),
      'valor_unitario'    => Request::get( 'valor_unitario', '' ),
      'quantidade'        => Request::get( 'quantidade', '' ),
      'valor_total'       => Request::get( 'valor_total', '' )
    ] );

    $prod = $serv->FornecedoresServicosProdutos;
    $emp  = $prod->Empresa;

    $serv->fornecedor_string = sprintf( '%02d - %s > %02d.%02d - %s', $emp->id, $emp->nome, $emp->id, $prod->id, $prod->nome );
    $serv->save();

    return Response::json( $serv, 201 );
  }

  /**
   * Retorna um Servico deste Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function show( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orc  = $job->_Orcamentos( $orcEST_id );
    $co   = $orc->_ItensCO( $item_id );
    $serv = $co->_Servicos( $id2 );

    return Response::json( $serv, 200 );
  }

  /**
   * Atualiza um Servico deste Item.
   *
   * @param $id
   * @param $id2
   * @return \Illuminate\Http\JsonResponse|Response
   */
  public function update( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );
    /** @var Orcamento $orc */
    $orc = $job->_Orcamentos( $orcEST_id );
    /** @var OrcamentoItemCO $co */
    $co = $orc->_ItensCO( $item_id );
    /** @var OrcamentoItemCOServico $serv */
    $serv = $co->_Servicos( $id2 );

    $serv->update( [
      'fornecedor_id'     => Request::get( 'fornecedor_id', '' ),
      'fornecedor_string' => '',
      'obs'               => Request::get( 'obs', null ),
      'valor_unitario'    => Request::get( 'valor_unitario', '' ),
      'quantidade'        => Request::get( 'quantidade', '' ),
      'valor_total'       => Request::get( 'valor_total', '' )
    ] );

    $prod = $serv->FornecedoresServicosProdutos;
    $emp  = $prod->Empresa;

    $serv->fornecedor_string = sprintf( '%02d - %s > %02d.%02d - %s', $emp->id, $emp->nome, $emp->id, $prod->id, $prod->nome );
    $serv->save();

    return Response::json( $serv, 201 );
  }

  /**
   * Destroi um Servico deste Item.
   *
   * @param $id
   * @param $id2
   * @return Response
   */
  public function destroy( $id, $id2 ) {
    if ( !Request::has( 'orcEST_id' ) ) {
      return response( 'sem parametro "orcEST_id"', 400 );
    }
    $orcEST_id = Request::get( 'orcEST_id' );
    if ( !Request::has( 'item_id' ) ) {
      return response( 'sem parametro "item_id"', 400 );
    }
    $item_id = Request::get( 'item_id' );

    /** @var Jobs $job */
    $job  = Jobs::findOrFail( $id );
    $orc  = $job->_Orcamentos( $orcEST_id );
    $co   = $orc->_ItensCO( $item_id );
    $serv = $co->_Servicos( $id2 );
    $serv->delete();

    return response( '', 200 );
  }
}
