<?php

namespace App\Http\Controllers\Comercial;

use App\CRP;
use App\Http\Requests\JobRequest;
use App\Models\Comercial\JobLogs;
use App\Models\Comercial\Jobs;
use Carbon\Carbon;

class StageA extends Stage {
  public $job;
  public $PERMISSION_edit = CRP::P_Comercial_A_edit;
  public $PERMISSION_read = CRP::P_Comercial_A_read;

  function __construct( Jobs $j ) {
    $this->job = $j;
  }

  /**
   * Visualiza a etapa deste Job.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function showDados() {
    $job               = $this->job;
    $BriefingLivre     = $this->job->_BriefingLivre();
    $BriefingGrafico   = $this->job->_BriefingGrafico();
    $BriefingWeb       = $this->job->_BriefingWeb();
    $BriefingBrinde    = $this->job->_BriefingBrinde();
    $BriefingFiles     = $this->job->BriefingFiles;
    $cronograma_hidden = $this->job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );
    $logs              = $this->job->_Logs();

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }
      return $val;
    } );

    return view( 'Comercial.stageA', compact( 'job', 'BriefingLivre', 'BriefingGrafico', 'BriefingWeb', 'BriefingBrinde', 'BriefingFiles', 'cronograma_hidden', 'cronograma', 'logs' ) );
  }

  /**
   * Salvamento desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function saveDados( JobRequest $request ) {

    // atualiza o etapa atual
    $antigoStage = $this->job->StageTop();
    $antigoStage->update( [
      'salvo' => Carbon::now()->format( 'Y-m-d H:i:s' )
    ] );

    // save
    StageUtil::SALVAR_INFO( $this->job, $request );
    StageUtil::SALVAR_BRIEFING( $this->job, $request );
    StageUtil::SALVAR_CRONOGRAMA( $this->job, $request );
    StageUtil::LOG( $this->job, StageUtil::A, JobLogs::LOG_SALVAR );

    return redirect()->route( 'jobs.show', $this->job->id );
  }

  /**
   * Submissao desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function submitDados( JobRequest $request ) {

    // save
    StageUtil::SALVAR_INFO( $this->job, $request );
    StageUtil::SALVAR_BRIEFING( $this->job, $request );
    StageUtil::SALVAR_CRONOGRAMA( $this->job, $request );

    StageUtil::NEXT( $this->job, StageUtil::B );
    StageUtil::sendEmail( $this->job, CRP::P_Comercial_email_B_entrou );
    StageUtil::LOG( $this->job, StageUtil::B, JobLogs::LOG_AVANCAR );

    return redirect()->route( 'jobs.index' );
  }

  /**
   * Retorna uma etapa do Job.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function back( JobRequest $request ) {
    return redirect()->route( 'jobs.index' );
  }

}
