<?php

namespace App\Http\Controllers\Comercial;

use App\CRP;
use App\Http\Requests\JobRequest;
use App\Models\Comercial\JobLogs;
use App\Models\Comercial\Jobs;
use Carbon\Carbon;

class StageB extends Stage {
  public $job;
  public $PERMISSION_edit = CRP::P_Comercial_B_edit;
  public $PERMISSION_read = CRP::P_Comercial_B_read;

  function __construct( Jobs $j ) {
    $this->job = $j;
  }

  /**
   * Visualiza a etapa deste Job.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function showDados() {
    $job = $this->job;

    if ( $job->condpagto === null ) {
      $dia            = $job->ClienteUnidade ? $job->ClienteUnidade->condpagamento : '';
      $job->condpagto = $dia;
      $job->save();
    }

    $BriefingLivre     = $this->job->_BriefingLivre();
    $BriefingGrafico   = $this->job->_BriefingGrafico();
    $BriefingWeb       = $this->job->_BriefingWeb();
    $BriefingBrinde    = $this->job->_BriefingBrinde();
    $BriefingFiles     = $this->job->BriefingFiles;
    $cronograma_hidden = $this->job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );
    $orcamentosAprov   = [];
    $logs              = $this->job->_Logs();

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }
      return $val;
    } );

    if ( $job->aprov_diretoria == 1 ) {
      $orcamentosAprov = $this->job->Orcamentos;
    }

    return view( 'Comercial.stageB', compact( 'job', 'BriefingLivre', 'BriefingGrafico', 'BriefingWeb', 'BriefingBrinde', 'BriefingFiles', 'cronograma_hidden', 'cronograma', 'orcamentosAprov', 'logs' ) );
  }

  /**
   * Salvamento desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function saveDados( JobRequest $request ) {
    // atualiza o etapa atual
    $antigoStage = $this->job->StageTop();
    $antigoStage->update( [
      'salvo' => Carbon::now()->format( 'Y-m-d H:i:s' )
    ] );

    // save
    StageUtil::SALVAR_INFO( $this->job, $request );
    StageUtil::SALVAR_BRIEFING( $this->job, $request );
    StageUtil::SALVAR_CRONOGRAMA( $this->job, $request );
    $this->job->update( [
      // somente os atributos q devem serem salvo neste estagio
      'condpagto'     => $request->getOrNull( 'condpagto' ),
      'condpagto_obs' => $request->getOrNull( 'condpagto_obs' )
    ] );
    StageUtil::LOG( $this->job, StageUtil::B, JobLogs::LOG_SALVAR );

    return $this->showDados();
  }

  /**
   * Submissao desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function submitDados( JobRequest $request ) {
    // save
    StageUtil::SALVAR_INFO( $this->job, $request );
    StageUtil::SALVAR_BRIEFING( $this->job, $request );
    StageUtil::SALVAR_CRONOGRAMA( $this->job, $request );
    $this->job->update( [
      // somente os atributos q devem serem salvo neste estagio
      'condpagto'     => $request->getOrNull( 'condpagto' ),
      'condpagto_obs' => $request->getOrNull( 'condpagto_obs' )
    ] );

    StageUtil::NEXT( $this->job, StageUtil::C );
    StageUtil::sendEmail( $this->job, CRP::P_Comercial_email_C_entrou );
    StageUtil::LOG( $this->job, StageUtil::C, JobLogs::LOG_AVANCAR );

    return redirect()->route( 'jobs.index' );
  }

  /**
   * Retorna uma etapa do Job.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function back( JobRequest $request ) {
    StageUtil::BACK( $this->job );
    StageUtil::LOG( $this->job, StageUtil::A, JobLogs::LOG_RETORNAR );
    return redirect()->route( 'jobs.index' );
  }
}