<?php

namespace App\Http\Controllers\Comercial;

use App\CRP;
use App\Http\Requests\JobRequest;
use App\Models\Comercial\JobLogs;
use App\Models\Comercial\Jobs;
use App\Models\Comercial\Orcamento;
use Carbon\Carbon;
use Illuminate\Support\Facades\Input;

class StageD extends Stage {
  public $job;
  public $PERMISSION_edit = CRP::P_Comercial_D_edit;
  public $PERMISSION_read = CRP::P_Comercial_D_read;

  function __construct( Jobs $j ) {
    $this->job = $j;
  }

  /**
   * Visualiza a etapa deste Job.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function showDados() {
    $job               = $this->job;
    $BriefingLivre     = $this->job->_BriefingLivre();
    $BriefingGrafico   = $this->job->_BriefingGrafico();
    $BriefingWeb       = $this->job->_BriefingWeb();
    $BriefingBrinde    = $this->job->_BriefingBrinde();
    $BriefingFiles     = $this->job->BriefingFiles;
    $cronograma_hidden = $this->job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );
    $orcamentosAprov   = $this->job->Orcamentos;
    $orcamentosAprovC  = $this->job->_OrcamentosAprovados_Diretoria();
    $logs              = $this->job->_Logs();

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }
      return $val;
    } );

    return view( 'Comercial.stageD', compact( 'job', 'BriefingLivre', 'BriefingGrafico', 'BriefingWeb', 'BriefingBrinde', 'BriefingFiles', 'cronograma_hidden', 'cronograma', 'orcamentosAprov', 'orcamentosAprovC', 'logs' ) );
  }

  /**
   * Armazena a aprovacao do Cliente.
   *
   */
  private function SALVAR_APROV_CLIENTE() {
    $orcs = $this->job->_OrcamentosAprovados_Diretoria();
    foreach ( $orcs as $orc ) {
      /** @var Orcamento $orc */
      $aprov = Input::get( 'orc_aprov_cliente.' . $orc->id );
      if ( $aprov != '' ) {
        $orc->update( [ 'orc_aprov_cliente' => $aprov ] );
      }
    }
  }

  /**
   * Salvamento desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function saveDados( JobRequest $request ) {
    // atualiza o etapa atual
    $antigoStage = $this->job->StageTop();
    $antigoStage->update( [
      'salvo' => Carbon::now()->format( 'Y-m-d H:i:s' )
    ] );

    StageUtil::SALVAR_INFO( $this->job, $request );
    StageUtil::SALVAR_BRIEFING( $this->job, $request );
    StageUtil::SALVAR_CRONOGRAMA( $this->job, $request );
    $this->SALVAR_APROV_CLIENTE();
    $this->job->update( [
      // somente os atributos q devem serem salvo neste estagio
      'aprov_cliente'     => $request->getOrNull( 'aprov_cliente' ),
      'aprov_cliente_obs' => $request->getOrNull( 'aprov_cliente_obs' )
    ] );
    StageUtil::LOG( $this->job, StageUtil::D, JobLogs::LOG_SALVAR );

    return $this->showDados();
  }

  /**
   * Submissao desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function submitDados( JobRequest $request ) {

    StageUtil::SALVAR_INFO( $this->job, $request );
    StageUtil::SALVAR_BRIEFING( $this->job, $request );
    StageUtil::SALVAR_CRONOGRAMA( $this->job, $request );
    $this->SALVAR_APROV_CLIENTE();
    $aprov = $request->getOrNull( 'aprov_cliente' );

    $this->job->update( [
      // somente os atributos q devem serem salvo neste estagio
      'aprov_cliente'     => $aprov,
      'aprov_cliente_obs' => $request->getOrNull( 'aprov_cliente_obs' )
    ] );

    if ( $aprov == '1' ) {
      // Arquivar (Z)
      StageUtil::sendEmail( $this->job, CRP::P_Comercial_email_D_arquivou );
      StageUtil::NEXT( $this->job, StageUtil::Z );
      StageUtil::LOG( $this->job, StageUtil::Z, JobLogs::LOG_AVANCAR );

    } elseif ( $aprov == '2' ) {
      // volta Atendimento (A)
      StageUtil::sendEmail( $this->job, CRP::P_Comercial_email_D_reprovou );
      StageUtil::NEXT( $this->job, StageUtil::A );
      StageUtil::LOG( $this->job, StageUtil::A, JobLogs::LOG_AVANCAR );

    } elseif ( $aprov == '3' ) {
      // Sege pra Producao (E)
      StageUtil::sendEmail( $this->job, CRP::P_Comercial_email_D_aprovou );
      StageUtil::NEXT( $this->job, StageUtil::E );
      StageUtil::sendEmail( $this->job, CRP::P_Comercial_email_E_entrou );
      StageUtil::LOG( $this->job, StageUtil::E, JobLogs::LOG_AVANCAR );

    } else {

      return $this->showDados();
    }

    return redirect()->route( 'jobs.index' );
  }

  /**
   * Retorna uma etapa do Job.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function back( JobRequest $request ) {
    StageUtil::BACK( $this->job );
    StageUtil::LOG( $this->job, StageUtil::C, JobLogs::LOG_RETORNAR );
    return redirect()->route( 'jobs.index' );
  }
}