<?php

namespace App\Http\Controllers\Comercial;

use App\CRP;
use App\Http\Requests\JobRequest;
use App\Models\Comercial\JobLogs;
use App\Models\Comercial\Jobs;

class StageZ extends Stage {
  public $job;
  public $PERMISSION_edit = CRP::P_Comercial_Z_edit;
  public $PERMISSION_read = CRP::P_Comercial_Z_read;

  function __construct( Jobs $j ) {
    $this->job = $j;
  }

  /**
   * Visualiza a etapa deste Job.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function showDados() {
    $job               = $this->job;
    $BriefingLivre     = $this->job->_BriefingLivre();
    $BriefingGrafico   = $this->job->_BriefingGrafico();
    $BriefingWeb       = $this->job->_BriefingWeb();
    $BriefingBrinde    = $this->job->_BriefingBrinde();
    $BriefingFiles     = $this->job->BriefingFiles;
    $cronograma_hidden = $this->job->_Cronograma()->json;
    $cronograma        = $cronograma_hidden == '' ? [] : json_decode( $cronograma_hidden );
    $orcamentosAprov   = $this->job->Orcamentos;
    $orcamentosAprovC  = $this->job->_OrcamentosAprovados_Diretoria();
    $logs              = $this->job->_Logs();

    usort( $cronograma, function ( $a, $b ) {
      $val = $a->startDate <=> $b->startDate;
      if ( $val == 0 ) {
        $val = $a->endDate <=> $b->endDate;
      }
      return $val;
    } );

    return view( 'Comercial.stageZ', compact( 'job', 'BriefingLivre', 'BriefingGrafico', 'BriefingWeb', 'BriefingBrinde', 'BriefingFiles', 'cronograma_hidden', 'cronograma', 'orcamentosAprov', 'orcamentosAprovC', 'logs' ) );
  }

  /**
   * Salvamento desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function saveDados( JobRequest $request ) {
    return $this->showDados();
  }

  /**
   * Submissao desta etapa.
   *
   * @param JobRequest $request
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function submitDados( JobRequest $request ) {
    return $this->showDados();
  }

  /**
   * Retorna uma etapa do Job.
   *
   * @param JobRequest $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function back( JobRequest $request ) {
    StageUtil::BACK( $this->job );
    StageUtil::LOG( $this->job, StageUtil::D, JobLogs::LOG_RETORNAR );
    return redirect()->route( 'jobs.index' );
  }
}