<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\ContaBancaria;
use App\Models\Financeiro\ContaDeConsumo;
use App\Models\Financeiro\ContaFornecedor;
use App\Models\Financeiro\Ferias;
use App\Models\Financeiro\Investimentos;
use App\Models\Financeiro\JobParcela;
use App\Models\Financeiro\OutroRecebimento;
use App\Models\Financeiro\Rescisao;
use App\Models\Financeiro\RetiradaDeSocios;
use App\Models\Financeiro\Salario;
use App\Models\Financeiro\Salario13;
use App\Models\Financeiro\Transferencia;
use Carbon\Carbon;
use Maatwebsite\Excel\Facades\Excel;
use PHPExcel_Style_Border;
use PHPExcel_Style_NumberFormat;

class CaixaController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista os Caixas.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    return view( 'Financeiro.Caixas.caixas_index' );
  }

  /**
   * Exibe o caixa no periodo.
   *
   * @param $periodo
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function showPeriodo( $periodo ) {
    list( $inicio, $fim ) = explode( ':', $periodo );
    try {
      $inicio   = Carbon::createFromFormat( 'd-m-Y', $inicio );
      $fim      = Carbon::createFromFormat( 'd-m-Y', $fim );
      $inicio_f = $inicio->format( 'd/m/Y' );
      $fim_f    = $fim->format( 'd/m/Y' );
      $inicio   = $inicio->format( 'Y-m-d' );
      $fim      = $fim->format( 'Y-m-d' );
    } catch ( \InvalidArgumentException $e ) {
      return redirect()->route( 'financeiro.caixa.index' );
    }

    // Conta Bancaria visualizada
    $conta_id = \Request::get( 'conta_bancaria' );
    /** @var ContaBancaria $contaBancaria */
    $contaBancaria = ContaBancaria::find( $conta_id );
    if ( !$contaBancaria ) {
      return view( 'Financeiro.Caixas.caixas_show', [
        'semCaixa' => true,
        'inicio_f' => $inicio_f,
        'fim_f'    => $fim_f,
        'periodo'  => $periodo,
      ] );
    }

    $valorInicial = $contaBancaria->CalcularValorInicial( $inicio );

    $receber    = 0;
    $receberEst = 0;
    $pagar      = 0;
    $pagarEst   = 0;
    $subtotal   = [
      'contas'              => 0,
      'contasEst'           => 0,
      'salarios'            => 0,
      'salariosEst'         => 0,
      'ferias'              => 0,
      'feriasEst'           => 0,
      'jobFornecedores'     => 0,
      'jobFornecedoresEst'  => 0,
      'transfSai'           => 0,
      'retiradaDeSocios'    => 0,
      'retiradaDeSociosEst' => 0,
      'rescisao'            => 0,
      'rescisaoEst'         => 0,
      'salarios13'          => 0,
      'salarios13Est'       => 0,
      'jobClientes'         => 0,
      'jobClientesEst'      => 0,
      'transfEnt'           => 0,
      'investimentos'       => 0,
      'recebimentos'        => 0,
      'recebimentosEst'     => 0,
      'receber'             => 0,
      'receberEst'          => 0,
      'pagar'               => 0,
      'pagarEst'            => 0,
    ];

    /// PAGAR
    // Contas Consumo
    $contas = ContaDeConsumo::Periodo( $inicio, $fim, $conta_id );
    foreach ( $contas as $conta ) {
      $subtotal[ 'contasEst' ] += $conta->valor;
      if ( $conta->pago ) {
        $subtotal[ 'contas' ] += $conta->valor;
      }
    }
    $pagar    += $subtotal[ 'contas' ];
    $pagarEst += $subtotal[ 'contasEst' ];

    // Pagamento de salario
    $salarios = Salario::Periodo( $inicio, $fim, $conta_id );
    foreach ( $salarios as $salario ) {
      $subtotal[ 'salariosEst' ] += $salario->valor_total;
      if ( $salario->pago ) {
        $subtotal[ 'salarios' ] += $salario->valor_total;
      }
    }
    $pagar    += $subtotal[ 'salarios' ];
    $pagarEst += $subtotal[ 'salariosEst' ];

    // Pagamento de Ferias
    $ferias = Ferias::Periodo( $inicio, $fim, $conta_id );
    foreach ( $ferias as $feria ) {
      $subtotal[ 'feriasEst' ] += $feria->valor_total_liquido;
      if ( $feria->pago ) {
        $subtotal[ 'ferias' ] += $feria->valor_total_liquido;
      }
    }
    $pagar    += $subtotal[ 'ferias' ];
    $pagarEst += $subtotal[ 'feriasEst' ];

    // Pagamento do Fornecedor pelo Job Realizado
    $jobFornecedores = ContaFornecedor::Periodo( $inicio, $fim, $conta_id );
    foreach ( $jobFornecedores as $jobFornecedor ) {
      $subtotal[ 'jobFornecedoresEst' ] += $jobFornecedor->valor;
      if ( $jobFornecedor->pago ) {
        $subtotal[ 'jobFornecedores' ] += $jobFornecedor->valor;
      }
    }
    $pagar    += $subtotal[ 'jobFornecedores' ];
    $pagarEst += $subtotal[ 'jobFornecedoresEst' ];

    // Transferencia Saida
    $transfSais = Transferencia::PeriodoSaida( $inicio, $fim, $conta_id );
    foreach ( $transfSais as $transfSai ) {
      $subtotal[ 'transfSai' ] += $transfSai->valor + $transfSai->valor_taxa;
    }
    $pagar    += $subtotal[ 'transfSai' ];
    $pagarEst += $subtotal[ 'transfSai' ];

    // Retirada de Sócios
    $retiradaDeSocios = RetiradaDeSocios::Periodo( $inicio, $fim, $conta_id );
    foreach ( $retiradaDeSocios as $retiradaDeSocio ) {
      $subtotal[ 'retiradaDeSociosEst' ] += $retiradaDeSocio->valor;
      if ( $retiradaDeSocio->pago ) {
        $subtotal[ 'retiradaDeSocios' ] += $retiradaDeSocio->valor;
      }
    }
    $pagar    += $subtotal[ 'retiradaDeSocios' ];
    $pagarEst += $subtotal[ 'retiradaDeSociosEst' ];

    // Rescisao
    $rescisoes = Rescisao::Periodo( $inicio, $fim, $conta_id );
    foreach ( $rescisoes as $rescisao ) {
      $subtotal[ 'rescisaoEst' ] += $rescisao->valor_total;
      if ( $rescisao->pago ) {
        $subtotal[ 'rescisao' ] += $rescisao->valor_total;
      }
    }
    $pagar    += $subtotal[ 'rescisao' ];
    $pagarEst += $subtotal[ 'rescisaoEst' ];

    // Pagamento de 13 salario
    $salarios13 = Salario13::Periodo( $inicio, $fim, $conta_id );
    foreach ( $salarios13 as $salario13 ) {
      $subtotal[ 'salarios13Est' ] += $salario13->valor_total;
      if ( $salario13->pago ) {
        $subtotal[ 'salarios13' ] += $salario13->valor_total;
      }
    }
    $pagar    += $subtotal[ 'salarios13' ];
    $pagarEst += $subtotal[ 'salarios13Est' ];

    /// RECEBER
    // Recebimento do Cliente pelo Job Realizado
    $jobClientes = JobParcela::Periodo( $inicio, $fim, $conta_id );
    foreach ( $jobClientes as $jobCliente ) {
      $subtotal[ 'jobClientesEst' ] += $jobCliente->valor_liquido;
      if ( $jobCliente->pago ) {
        $subtotal[ 'jobClientes' ] += $jobCliente->valor_liquido;
      }
    }
    $receber    += $subtotal[ 'jobClientes' ];
    $receberEst += $subtotal[ 'jobClientesEst' ];

    // Transferencia Entrada
    $transfEnts = Transferencia::PeriodoEntrada( $inicio, $fim, $conta_id );
    foreach ( $transfEnts as $transfEnt ) {
      $subtotal[ 'transfEnt' ] += $transfEnt->valor;
    }
    $receber    += $subtotal[ 'transfEnt' ];
    $receberEst += $subtotal[ 'transfEnt' ];

    // Investimentos
    $investimentos = Investimentos::Periodo( $inicio, $fim, $conta_id );
    foreach ( $investimentos as $investimento ) {
      $subtotal[ 'investimentos' ] += $investimento->valor_liquido;
    }
    $receber    += $subtotal[ 'investimentos' ];
    $receberEst += $subtotal[ 'investimentos' ];

    // Outros Recebimentos
    $recebimentos = OutroRecebimento::Periodo( $inicio, $fim, $conta_id );
    foreach ( $recebimentos as $recebimento ) {
      $subtotal[ 'recebimentosEst' ] += $recebimento->valor;
      if ( $recebimento->pago ) {
        $subtotal[ 'recebimentos' ] += $recebimento->valor;
      }
    }
    $receber    += $subtotal[ 'recebimentos' ];
    $receberEst += $subtotal[ 'recebimentosEst' ];

    // TOTAL
    $subtotal[ 'receber' ]    = $receber;
    $subtotal[ 'receberEst' ] = $receberEst;
    $subtotal[ 'pagar' ]      = $pagar;
    $subtotal[ 'pagarEst' ]   = $pagarEst;

    $total    = $receber - $pagar;
    $totalEst = $receberEst - $pagarEst;

    $totalFinal    = $valorInicial + $receber - $pagar;
    $totalFinalEst = $valorInicial + $receberEst - $pagarEst;

    return view( 'Financeiro.Caixas.caixas_show', [
      'inicio_f'         => $inicio_f,
      'fim_f'            => $fim_f,
      'periodo'          => $periodo,
      'caixaVoltar'      => '?caixa=' . $periodo,
      'conta_id'         => $conta_id,
      'contas'           => $contas,
      'salarios'         => $salarios,
      'ferias'           => $ferias,
      'jobFornecedores'  => $jobFornecedores,
      'transfSais'       => $transfSais,
      'retiradaDeSocios' => $retiradaDeSocios,
      'rescisoes'        => $rescisoes,
      'salarios13'       => $salarios13,
      'jobClientes'      => $jobClientes,
      'transfEnts'       => $transfEnts,
      'investimentos'    => $investimentos,
      'recebimentos'     => $recebimentos,
      'valorInicial'     => $valorInicial,
      'total'            => $total,
      'totalFinal'       => $totalFinal,
      'totalFinalEst'    => $totalFinalEst,
      'totalEst'         => $totalEst,
      'subtotal'         => $subtotal
    ] );
  }


  /**
   * Gera o XLSX do Fluxo de Caixa.
   *
   * @param $periodo
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Http\RedirectResponse|\Illuminate\View\View
   */
  public function fluxoDeCaixaXLSX( $periodo ) {
    list( $inicio, $fim ) = explode( ':', $periodo );
    try {
      $inicio    = Carbon::createFromFormat( 'd-m-Y', $inicio );
      $fim       = Carbon::createFromFormat( 'd-m-Y', $fim );
      $inicio_f  = $inicio->format( 'd/m/Y' );
      $fim_f     = $fim->format( 'd/m/Y' );
      $inicio_f2 = $inicio->format( 'd-m-Y' );
      $fim_f2    = $fim->format( 'd-m-Y' );
      $inicio    = $inicio->format( 'Y-m-d' );
      $fim       = $fim->format( 'Y-m-d' );
    } catch ( \InvalidArgumentException $e ) {
      return redirect()->route( 'financeiro.caixa.index' );
    }

    // Conta Bancaria visualizada
    $todas_contas = \Request::get( 'todas_contas', 0 );
    $conta_id     = \Request::get( 'conta_bancaria', 0 );
    /** @var ContaBancaria $contaBancaria */
    $contaBancaria = ContaBancaria::find( $conta_id );
    if ( !$contaBancaria ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    $valorInicial = $contaBancaria->CalcularValorInicial( $inicio );

    $dados = [];

    /// PAGAR
    // Contas Consumo
    $contas = ContaDeConsumo::Periodo( $inicio, $fim, $conta_id );
    foreach ( $contas as $conta ) {
      $dados [] = [
        'dt'         => $conta->data,
        'fav'        => $conta->nome,
        'recet_desp' => '',
        'desc'       => $conta->nome,
        'nf'         => $conta->nota_fiscal,
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $conta->pago ? true : false,
        'c_custo'    => $conta->DespesaCodigoNome(),
        'desp_reduz' => $conta->DespesaCodigoReduzida(),
        'valor_deb'  => $conta->valor,
        'valor_cred' => '',
      ];
    }

    // Pagamento de salario
    $salarios = Salario::Periodo( $inicio, $fim, $conta_id );
    foreach ( $salarios as $salario ) {
      // Descricao do Salario: 'Salário Ref. Maio/2017' , 'Pagamento ref. Abril' ,  'Bolsa Auxílio Ref.Maio/2017'
      $desc = 'Salário';
      if ( $salario->Funcionario ) {
        $func = $salario->Funcionario;
        switch ( $func->regime ) {
          case 0:// CLT
            $desc = 'Salário';
            break;
          case 1 :// Estagio
            $desc = 'Bolsa Auxílio';
            break;
          case 2: // Freela
            $desc = 'Pagamento';
            break;
          case 3 : // Pro-labore
            $desc = 'Pagamento';
            break;
          default:
            $desc = 'Salário';
            break;
        }
      }
      $desc .= ' ref. ' . $salario->mes . '/' . $salario->ano;

      $dados [] = [
        'dt'         => $salario->data_pagamento,
        'fav'        => $salario->FuncionarioNome(),
        'recet_desp' => '',
        'desc'       => $desc,
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $salario->pago ? true : false,
        'c_custo'    => $salario->DespesaCodigoNome(),
        'desp_reduz' => $salario->DespesaCodigoReduzida(),
        'valor_deb'  => $salario->valor_total,
        'valor_cred' => '',
      ];
    }

    // Pagamento de Ferias
    $ferias = Ferias::Periodo( $inicio, $fim, $conta_id );
    foreach ( $ferias as $feria ) {
      $dados [] = [
        'dt'         => $feria->data_pagamento,
        'fav'        => $feria->FuncionarioNome(),
        'c_custo'    => $feria->DespesaCodigoNome(),
        'desp_reduz' => $feria->DespesaCodigoReduzida(),
        'desc'       => 'Pagamento ref. Férias',
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $feria->pago ? true : false,
        'recet_desp' => '', // ?
        'valor_deb'  => $feria->valor_total_liquido,
        'valor_cred' => '',
      ];
    }

    // Pagamento do Fornecedor pelo Job Realizado
    $jobFornecedores = ContaFornecedor::Periodo( $inicio, $fim, $conta_id );
    foreach ( $jobFornecedores as $jobFornecedor ) {
      $dados [] = [
        'dt'         => $jobFornecedor->data,
        'fav'        => $jobFornecedor->FornecedorNome(),
        'recet_desp' => '',
        'desc'       => $jobFornecedor->nome,
        'nf'         => $jobFornecedor->nota_fiscal,
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $jobFornecedor->pago ? true : false,
        'c_custo'    => $jobFornecedor->PlanoDeContas ?
          $jobFornecedor->PlanoDeContas->getContaNome() : '', // Centro de Custo
        'desp_reduz' => '',
        'valor_deb'  => $jobFornecedor->valor,
        'valor_cred' => '',
      ];
    }

    // Transferencia Saida
    $transfSais = Transferencia::PeriodoSaida( $inicio, $fim, $conta_id );
    foreach ( $transfSais as $transfSai ) {
      $dados [] = [
        'dt'         => $transfSai->data,
        'fav'        => $transfSai->nome,
        'c_custo'    => '',
        'desp_reduz' => '',
        'desc'       => 'Debito de Transferência Bancária',
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => true,
        'recet_desp' => '', // ?
        'valor_deb'  => $transfSai->valor + $transfSai->valor_taxa,
        'valor_cred' => '',
      ];
    }

    // Retirada de Sócios
    $retiradaDeSocios = RetiradaDeSocios::Periodo( $inicio, $fim, $conta_id );
    foreach ( $retiradaDeSocios as $retiradaDeSocio ) {
      $dados [] = [
        'dt'         => $retiradaDeSocio->data,
        'fav'        => $retiradaDeSocio->FuncionarioNome(),
        'recet_desp' => '',
        'desc'       => $retiradaDeSocio->nome,
        'nf'         => $retiradaDeSocio->nota_fiscal,
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $retiradaDeSocio->pago ? true : false,
        'c_custo'    => '', // ?
        'desp_reduz' => '',
        'valor_deb'  => $retiradaDeSocio->valor,
        'valor_cred' => '',
      ];
    }

    // Rescisao
    $rescisoes = Rescisao::Periodo( $inicio, $fim, $conta_id );
    foreach ( $rescisoes as $rescisao ) {
      $dados [] = [
        'dt'         => $rescisao->data,
        'fav'        => $rescisao->FuncionarioNome(),
        'recet_desp' => '',
        'desc'       => 'Rescisao: ' . $rescisao->nome,
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $rescisao->pago ? true : false,
        'c_custo'    => $rescisao->DespesaCodigoNome(),
        'desp_reduz' => $rescisao->DespesaCodigoReduzida(),
        'valor_deb'  => $rescisao->valor_total,
        'valor_cred' => '',
      ];
    }

    // 13 salario
    $salarios13 = Salario13::Periodo( $inicio, $fim, $conta_id );
    foreach ( $salarios13 as $salario13 ) {
      $dados [] = [
        'dt'         => $salario13->data,
        'fav'        => $salario13->FuncionarioNome(),
        'recet_desp' => '',
        'desc'       => '13º Salário: ' . $salario13->FuncionarioNome(),
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => false, // false deb | true cred
        'pago'       => $salario13->pago ? true : false,
        'c_custo'    => $salario13->DespesaCodigoNome(),
        'desp_reduz' => $salario13->DespesaCodigoReduzida(),
        'valor_deb'  => $salario13->valor_total,
        'valor_cred' => '',
      ];
    }

    /// RECEBER
    // Recebimento do Cliente pelo Job Realizado
    $jobClientes = JobParcela::Periodo( $inicio, $fim, $conta_id );
    foreach ( $jobClientes as $jobCliente ) {
      $dados [] = [
        'dt'         => $jobCliente->data,
        'fav'        => $jobCliente->Job->_ClienteUnidade(),
        'c_custo'    => $jobCliente->Job->_ClienteConta(),
        'desp_reduz' => '',
        'desc'       => $jobCliente->Job->nome_job,
        'nf'         => $jobCliente->nota_fiscal,
        'emissao_nf' => $jobCliente->nota_fiscal_data_emissao ?
          Carbon::createFromFormat( 'Y-m-d', $jobCliente->nota_fiscal_data_emissao )->format( 'd/m/Y' ) : '',
        'val_bruto'  => $jobCliente->valor_bruto ? (int) $jobCliente->valor_bruto / 100 : 0,
        'val_retido' => $jobCliente->valor_imposto ? (int) $jobCliente->valor_imposto / 100 : 0,
        'tipo'       => true, // false deb | true cred
        'pago'       => $jobCliente->pago ? true : false,
        'recet_desp' => $jobCliente->Job->_codReceitaNome(),
        'valor_deb'  => '',
        'valor_cred' => $jobCliente->valor_liquido,
      ];
    }

    // Transferencia Entrada
    $transfEnts = Transferencia::PeriodoEntrada( $inicio, $fim, $conta_id );
    foreach ( $transfEnts as $transfEnt ) {
      $dados [] = [
        'dt'         => $transfEnt->data,
        'fav'        => $transfEnt->nome,
        'recet_desp' => '',
        'desc'       => 'Crédito de Transferência Bancária',
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => true, // false deb | true cred
        'pago'       => true,
        'c_custo'    => '', // ?
        'desp_reduz' => '',
        'valor_deb'  => '',
        'valor_cred' => $transfEnt->valor,
      ];
    }

    // Investimentos
    $investimentos = Investimentos::Periodo( $inicio, $fim, $conta_id );
    foreach ( $investimentos as $investimento ) {
      $dados [] = [
        'dt'         => $investimento->data,
        'fav'        => $investimento->nome,
        'recet_desp' => '',
        'desc'       => 'Rendimentos de Investimentos',
        'nf'         => '',
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => true, // false deb | true cred
        'pago'       => $investimento->pago ? true : false,
        'c_custo'    => '', // ?
        'desp_reduz' => '',
        'valor_deb'  => '',
        'valor_cred' => $investimento->valor_liquido,
      ];
    }

    // Outros Recebimentos
    $recebimentos = OutroRecebimento::Periodo( $inicio, $fim, $conta_id );
    foreach ( $recebimentos as $recebimento ) {
      $dados [] = [
        'dt'         => $recebimento->data,
        'fav'        => $recebimento->FornecedorNome(),
        'recet_desp' => $recebimento->_codReceitaNome(),
        'desc'       => $recebimento->nome,
        'nf'         => $recebimento->nota_fiscal,
        'emissao_nf' => '',
        'val_bruto'  => '',
        'val_retido' => '',
        'tipo'       => true, // false deb | true cred
        'pago'       => $recebimento->pago ? true : false,
        'c_custo'    => '',
        'desp_reduz' => '',
        'valor_deb'  => '',
        'valor_cred' => $recebimento->valor,
      ];
    }

    // Ordena as datas
    usort( $dados, function ( $a, $b ) {
      return $a[ 'dt' ] <=> $b[ 'dt' ];
    } );

    // Monta a tabela
    $XLSX   = [];
    $XLSX[] = [
      'DT. VENCTO',
      'FAVORECIDO',
      'CENTRO DE CUSTO',
      'CÓD DE RECEITA / DESPESA',
      'DESCRIÇÃO',
      'NR. NF / DOCTO',
      'EMISSÃO DA NF',
      'VALOR BRUTO',
      'VALOR RETIDO',
      'TIPO DE LANÇAMENTO',
      'CÓD REDUZIDO',
      'CONTA BANCÁRIA',
      'PAGO',
      'CRÉDITO',
      'DÉBITO',
      'SALDO'
    ];

    $tem_todas_contas = '';
    if ( $todas_contas == 1 ) {
      $contas       = ContaBancaria::all();
      $inicio_add_1 = ( new Carbon( $inicio ) )->addDay()->format( 'Y-m-d' );
      foreach ( $contas as $conta ) {
        if ( $conta->id == $conta_id ) {
          continue;
        }

        $valorConta = $conta->CalcularValorInicial( $inicio_add_1 );
        $XLSX[]     = [
          $inicio_f, // data de inicial
          'SALDO DA CONTA: ' . $conta->nome,
          '', '', '', '', '', '', '', '', '', '', '', '', '',
          (int) $valorConta / 100 // Saldo Inicial
        ];
      }
      $tem_todas_contas = '_Todas';
    }

    $XLSX[] = [
      $inicio_f, // data de inicial
      'SALDO INICIAL DO PERÍODO',
      '', '', '', '', '', '', '', '', '', '', '', '', '',
      // number_format( ( intval( $valorInicial ) ) / 100, 2, ',', '.' ) // Saldo Inicial
      intval( $valorInicial ) / 100 // Saldo Inicial
    ];

    $saldo = $valorInicial;
    foreach ( $dados as $dado ) {
      if ( $dado[ 'tipo' ] ) {
        $saldo += $dado[ 'valor_cred' ];
      } else {
        $saldo -= $dado[ 'valor_deb' ];
      }
      $XLSX[] = [
        \Carbon\Carbon::parse( $dado[ 'dt' ] )->format( 'd/m/Y' ), // data de vencimento
        $dado[ 'fav' ],  // Favorecido
        $dado[ 'c_custo' ], // Centro de Custo
        $dado[ 'recet_desp' ],  // Cod Receita / Despesa
        $dado[ 'desc' ],  // Descricao
        $dado[ 'nf' ],  // NF
        $dado[ 'emissao_nf' ],  // emissão da NF
        $dado[ 'val_bruto' ],  // valor bruto
        $dado[ 'val_retido' ],  // valor retido
        $dado[ 'tipo' ] ? 'Contas a Receber' : 'Contas a Pagar', // Tipo de Lancamento [ 'Contas a Receber' , 'Contas a Pagar' ]
        $dado[ 'desp_reduz' ],  // Cod Reduzido
        $contaBancaria->nome, // Conta Bancaria
        $dado[ 'pago' ] ? 'Sim' : 'Não',
        //  $dado[ 'valor_cred' ] != '' ? number_format( ( intval( $dado[ 'valor_cred' ] ) ) / 100, 2, ',', '.' ) : '',  // Credito
        $dado[ 'valor_cred' ] != '' ? intval( $dado[ 'valor_cred' ] ) / 100 : '',  // Credito
        //  $dado[ 'valor_deb' ] != '' ? number_format( ( intval( $dado[ 'valor_deb' ] ) * -1 ) / 100, 2, ',', '.' ) : '',  // Debito
        $dado[ 'valor_deb' ] != '' ? ( intval( $dado[ 'valor_deb' ] ) * -1 ) / 100 : '',  // Debito
        //  number_format( $saldo / 100, 2, ',', '.' ),  // Saldo?
        $saldo / 100,  // Saldo?
      ];
    }

    $filename = 'Fluxo_de_Caixa_' . $inicio_f2 . '_' . $fim_f2 . $tem_todas_contas;
    $title    = 'Fluxo de Caixa ' . $inicio_f2 . ' - ' . $fim_f2 . $tem_todas_contas;
    Excel::create( $filename, function ( $excel ) use ( $XLSX, $title ) {
      /** @var \Maatwebsite\Excel\Writers\LaravelExcelWriter $excel */
      $excel->setTitle( $title );
      $excel->setDescription( $title );
      $excel->sheet( 'Fluxo de Caixa', function ( $sheet ) use ( $XLSX ) {
        /** @var \Maatwebsite\Excel\Classes\LaravelExcelWorksheet $sheet */

        // Dados
        $sheet->fromArray( $XLSX, null, 'A1', false, false );

        // Style geral
        $sheet->setStyle( [
          'font' => [
            'name' => 'Arial',
            'size' => 10
          ]
        ] );
        $sheet->setAutoSize( true );
        $sheet->setBorder( 'A1:P' . count( $XLSX ), PHPExcel_Style_Border::BORDER_THIN );

        // Style do Header
        $sheet->setHeight( 1, 25 );
        $sheet->cells( 'A1:P1', function ( $cells ) {
          /** @var \Maatwebsite\Excel\Writers\CellWriter $cells */
          $cells->setFontColor( '#ffffff' );
          $cells->setBackground( '#404040' );
          $cells->setAlignment( 'center' );
          $cells->setValignment( 'center' );
          $cells->setFontWeight( 'bold' );
        } );

        // Column formatting
        $sheet->setColumnFormat( [
          'A' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'B' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'C' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'D' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'E' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'F' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'G' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'H' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'I' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'J' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'K' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'L' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'M' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'N' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'O' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'P' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER
        ] );

        // Auto Filter
        $sheet->setAutoFilter();
      } );
    } )->download( 'xlsx' );

    return null;
  }
}
