<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\ContaBancaria;
use Illuminate\Http\Request;

class ContaBancariaController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Contas Bancarias.
   *
   * @return \Illuminate\Http\Response
   */
  public function index() {
    $contas = ContaBancaria::all();

    return view( 'Financeiro.ContasBancarias.index', compact( 'contas' ) );
  }

  /**
   * Exibe o formulario para criar uma Conta Bancaria.
   *
   * @return \Illuminate\Http\Response
   */
  public function create() {

    return view( 'Financeiro.ContasBancarias.create' );
  }

  /**
   * Armazena uma Conta Bancaria do BD.
   *
   * @param  \Illuminate\Http\Request $request
   * @return \Illuminate\Http\Response
   */
  public function store( Request $request ) {
    $dados = $request->all();

    $dados[ 'valor_inicial' ] = preg_replace( '/\D/', '', $dados[ 'valor_inicial' ] );
    ContaBancaria::create( $dados );

    flash( 'Conta Bancária criada com sucesso!', 'success' );
    return redirect()->route( 'financeiro.contas.index' );
  }

  /**
   * Mostra o Formulario de um Conta Bancaria.
   *
   * @param  int $id
   * @return \Illuminate\Http\Response
   */
  public function edit( $id ) {
    $conta = ContaBancaria::findOrFail( $id );

    return view( 'Financeiro.ContasBancarias.edit', compact( 'conta' ) );
  }

  /**
   * Atualiza uma Conta Bancaria do BD.
   *
   * @param  \Illuminate\Http\Request $request
   * @param  int $id
   * @return \Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var ContaBancaria $conta */
    $conta = ContaBancaria::findOrFail( $id );
    $dados = $request->all();

    $valorAntigo              = $conta->valor_inicial;
    $dados[ 'valor_inicial' ] = preg_replace( '/\D/', '', $dados[ 'valor_inicial' ] );

    $conta->update( $dados );

    // Se o valor inicial for diferente, atualizar as ContaBancariaSync
    if ( intval( $dados[ 'valor_inicial' ] ) != intval( $valorAntigo ) ) {
      // TODO: nao ter q deletar todas as ContaBancariaSync
      $conta->ContaBancariaSync()->delete();
      $conta->reSyncConta( $conta->data_inicial );
    }

    flash( 'Conta Bancária atualizada com sucesso!', 'success' );
    return redirect()->route( 'financeiro.contas.index' );
  }

  /**
   * Deleta uma Conta Bancaria do BD.
   *
   * @param  int $id
   * @return \Illuminate\Http\Response
   */
  public function destroy( $id ) {
    $conta = ContaBancaria::findOrFail( $id );
    $conta->delete();

    flash( 'Conta Bancária deletada com sucesso!', 'success' );
    return redirect()->route( 'financeiro.contas.index' );
  }
}
