<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\ContaDeConsumoGerador;
use Illuminate\Http\Request;

class ContaDeConsumoGeradorController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista ContaDeConsumoGerador.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\View\View
   */
  public function index() {
    ContaDeConsumoGerador::$LB_SORTABLE_DEFAULT = [ 'nome' => 'asc' ];

    $indexSearch = ContaDeConsumoGerador::IndexSearchMap();
    $consumos    = ContaDeConsumoGerador::listarPaginadoBuscavelOrdenavel( ContaDeConsumoGerador::query(), $indexSearch );

    return view( 'Financeiro.ContasConsumosGerador.index', compact( 'consumos', 'indexSearch' ) );
  }

  /**
   * Exibem o formulario para criar uma nova ContaDeConsumoGerador.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function create() {

    return view( 'Financeiro.ContasConsumosGerador.create' );
  }

  /**
   * Armazena uma nova ContaDeConsumoGerador no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function store( Request $request ) {
    ContaDeConsumoGerador::create( $request->all() );

    flash( 'Conta de Consumo Gerador criada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.contasdeconsumogerador.index' );
  }


  /**
   * Exibe o formulario para editar uma ContaDeConsumoGerador no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function edit( $id ) {
    $consumo = ContaDeConsumoGerador::findOrFail( $id );

    return view( 'Financeiro.ContasConsumosGerador.edit', compact( 'consumo' ) );
  }

  /**
   * Atualiza uma ContaDeConsumoGerador no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var ContaDeConsumoGerador $consumo */
    $consumo = ContaDeConsumoGerador::findOrFail( $id );
    $consumo->update( $request->all() );

    flash( 'Conta de Consumo Gerador atualizada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.contasdeconsumogerador.index' );
  }

  /**
   * Remove uma ContaDeConsumoGerador no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function destroy( $id ) {
    /** @var ContaDeConsumoGerador $consumo */
    $consumo = ContaDeConsumoGerador::findOrFail( $id );
    $consumo->delete();

    flash( 'Conta de Consumo Gerador deletada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.contasdeconsumogerador.index' );
  }
}
