<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\Ferias;
use Illuminate\Http\Request;

class FeriasController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Ferias.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    Ferias::$LB_SORTABLE_DEFAULT = [ 'data_pagamento' => 'desc' ];

    $indexSearch = Ferias::IndexSearchMap();
    $ferias      = Ferias::listarPaginadoBuscavelOrdenavel( Ferias::query()->with('Funcionario'), $indexSearch );

    $total = [
      'valor_total_bruto'   => 0,
      'valor_total_liquido' => 0,
    ];
    foreach ( $ferias as $feria ) {
      $total[ 'valor_total_bruto' ]   += $feria->valor_total_bruto;
      $total[ 'valor_total_liquido' ] += $feria->valor_total_liquido;
    }

    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Ferias.index', compact( 'ferias', 'indexSearch', 'total', 'caixaVoltar' ) );
  }

  /**
   * Exibe o formulario para criar uma Ferias no BD.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function create() {
    // TODO: $salarioMensal
    $ferias = new \App\Models\Financeiro\Ferias();

    return view( 'Financeiro.Ferias.create', compact( 'ferias' ) );
  }


  /**
   * Lanca o Ferias dos Funcionarios.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function store( Request $request ) {
    /** @var Ferias $ferias */
    $ferias = Ferias::create( $request->all() );
    $ferias->reSyncStore();

    flash( 'Férias adicionada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.ferias.index' );
  }

  /**
   * Exibe o formulario para editar uma Ferias no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function edit( $id ) {
    /** @var Ferias $ferias */
    $ferias = Ferias::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.ferias.index' );
    }

    return view( 'Financeiro.Ferias.edit', compact( 'ferias', 'periodo', 'caixaVoltar' ) );
  }

  /**
   * Atualiza uma Ferias no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse
   */
  public function update( Request $request, $id ) {
    /** @var Ferias $ferias */
    $ferias = Ferias::findOrFail( $id );
    $ferias->reSyncUpdateBegin();
    $ferias->update( $request->all() );
    $ferias->reSyncUpdateEnd();

    flash( 'Férias atualizado com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.ferias.index' );
  }

  /**
   * Remove uma Ferias no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse
   * @throws \Exception
   * @throws \Exception
   */
  public function destroy( $id ) {
    /** @var Ferias $ferias */
    $ferias = Ferias::findOrFail( $id );
    $ferias->reSyncDestroy();
    $ferias->delete();

    flash( 'Férias deletada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.ferias.index' );
  }
}
