<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\Investimentos;
use Illuminate\Http\Request;

class InvestimentosController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Rendimento.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    $indexSearch   = Investimentos::IndexSearchMap();
    $investimentos = Investimentos::listarPaginadoBuscavelOrdenavel( Investimentos::query(), $indexSearch );
    $caixaVoltar   = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Investimentos.index', compact( 'investimentos', 'indexSearch', 'caixaVoltar' ) );
  }

  /**
   * Exibe o formulario para criar uma Investimentos no BD.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function create() {
    $investimentos = new\App\Models\Financeiro\Investimentos();

    return view( 'Financeiro.Investimentos.create', compact( 'investimentos' ) );
  }


  /**
   * Lanca o Rendimento dos Funcionarios.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function store( Request $request ) {
    /** @var Investimentos $investimentos */
    $investimentos = Investimentos::create( $request->all() );
    $investimentos->reSyncStore();

    flash( 'Investimento adicionado com sucesso!', 'success' );

    return redirect()->route( 'financeiro.investimentos.index' );
  }

  /**
   * Exibe o formulario para editar uma Rendimento no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function edit( $id ) {
    /** @var Investimentos $investimentos */
    $investimento = Investimentos::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.investimentos.index' );
    }

    return view( 'Financeiro.Investimentos.edit', compact( 'investimento', 'periodo', 'caixaVoltar' ) );
  }

  /**
   * Atualiza uma Rendimento no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse
   */
  public function update( Request $request, $id ) {
    /** @var Investimentos $investimentos */
    $investimentos = Investimentos::findOrFail( $id );
    $investimentos->reSyncUpdateBegin();
    $investimentos->update( $request->all() );
    $investimentos->reSyncUpdateEnd();

    flash( 'Rendimento atualizado com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.investimentos.index' );
  }

  /**
   * Remove uma Rendimento no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse
   */
  public function destroy( $id ) {
    /** @var Investimentos $investimentos */
    $investimentos = Investimentos::findOrFail( $id );
    $investimentos->reSyncDestroy();
    $investimentos->delete();

    flash( 'Rendimento deletado com sucesso!', 'success' );

    return redirect()->route( 'financeiro.investimentos.index' );
  }
}
