<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Comercial\StageUtil;
use App\Http\Controllers\Controller;
use App\Models\Cadastros\FornecedoresServicosProdutos;
use App\Models\Comercial\Jobs;
use App\Models\Comercial\Orcamento;
use App\Models\Comercial\OrcamentoItemCO;
use App\Models\Comercial\OrcamentoItemCOServico;
use App\Models\Financeiro\JobParcela;
use Carbon\Carbon;
use Excel;
use PHPExcel_Style_Border;
use PHPExcel_Style_NumberFormat;

class JobReceberController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista os Jobs em Faturamento.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    $indexSearch = Jobs::IndexSearchMap();
    /** @var Jobs[] $jobsF */
    Jobs::$LB_SORTABLE_DEFAULT = [ 'id' => 'asc' ];
    $jobsF                     = Jobs::listarPaginadoBuscavelOrdenavel( Jobs::query()->where( 'etapa_atual', '=', StageUtil::F ), $indexSearch );
    foreach ( $jobsF as &$j ) {
      $j->valor_total = $j->_OrcamentoAprovado_valor_total() ?? -100;
    }

    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Jobs.jobs_index', compact( 'jobsF', 'indexSearch', 'caixaVoltar' ) );
  }

  /**
   * Exibe o Job a ser Faturado.
   *
   * @param integer $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function show( $id ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );

    // Todos os Valores
    $valores = [
      'ci'          => [
        'valor'        => 0,
        'comissao'     => 0,
        'planejamento' => 0,
        'impostos'     => 0,
        'subtotal'     => 0,
      ],
      'co'          => [
        'valor'        => 0,
        'bv'           => 0,
        'planejamento' => 0,
        'impostos'     => 0,
        'subtotal'     => 0,
      ],
      'valor_total' => 0
    ];
    foreach ( $job->_OrcamentosAprovados_Cliente() as $orc ) {
      $val = $orc->CalcularTodosValores();

      $valores[ 'ci' ][ 'valor' ]        += $val[ 'ci' ][ 'valor' ];
      $valores[ 'ci' ][ 'comissao' ]     += $val[ 'ci' ][ 'comissao' ];
      $valores[ 'ci' ][ 'planejamento' ] += $val[ 'ci' ][ 'planejamento' ];
      $valores[ 'ci' ][ 'impostos' ]     += $val[ 'ci' ][ 'impostos' ];
      $valores[ 'ci' ][ 'subtotal' ]     += $val[ 'ci' ][ 'subtotal' ];

      $valores[ 'co' ][ 'valor' ]        += $val[ 'co' ][ 'valor' ];
      $valores[ 'co' ][ 'bv' ]           += $val[ 'co' ][ 'bv' ];
      $valores[ 'co' ][ 'planejamento' ] += $val[ 'co' ][ 'planejamento' ];
      $valores[ 'co' ][ 'impostos' ]     += $val[ 'co' ][ 'impostos' ];
      $valores[ 'co' ][ 'subtotal' ]     += $val[ 'co' ][ 'subtotal' ];

      $valores[ 'valor_total' ] += $val[ 'valor_total' ];
    }

    // Parcelas
    /** @var JobParcela[] $parcelas */
    $parcelas        = $job->Parcelas()->orderBy( 'data' )->get();
    $soma_parcelas_b = 0;
    $soma_parcelas_l = 0;
    foreach ( $parcelas as $parcela ) {
      $soma_parcelas_b += $parcela->valor_bruto;
      $soma_parcelas_l += $parcela->valor_liquido;
    }

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.jobs.index' );
    }

    return view( 'Financeiro.Jobs.jobs_show', compact( 'job', 'valores', 'parcelas', 'soma_parcelas_b', 'soma_parcelas_l', 'caixaVoltar' ) );
  }

  /**
   * Exibe o Job a ser Faturado.
   *
   * @param integer $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function add_parcela_manual( $id ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );

    $dados = \Request::all();
    if ( \Request::get( 'conta_id' ) == 0 ) {
      $dados[ 'conta_id' ] = null;
    }
    /** @var JobParcela $parcela */
    $parcela = $job->Parcelas()->create( $dados );
    $parcela->reSyncStore();

    return redirect()->route( 'financeiro.jobs.show', $job->id );
  }

  /**
   * Exibe o Job a ser Faturado.
   *
   * @param integer $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function add_parcela_iguais( $id ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );

    $dados = \Request::all();
    $vezes = $dados[ 'vezes' ];

    // TODO: fix calcula total de orcs[]
    dd( 'fix orcs[]' );
    $orcs       = $job->_OrcamentosAprovados_Cliente();
    $valorTotal = $orcs[ 0 ]->CalcularValorTotal();

    $valorParcelas = 0;
    foreach ( $job->Parcelas as $parcela ) {
      $valorParcelas += $parcela->valor;
    }
    $valor = intval( ( $valorTotal - $valorParcelas ) / $vezes );

    for ( $i = 1; $i <= $vezes; $i++ ) {
      $job->Parcelas()->create( [
        'nome'  => $dados[ 'nome' ] . ' - ' . $i,
        'data'  => $dados[ 'data' ],
        'valor' => $valor,
      ] );
    }

    return redirect()->route( 'financeiro.jobs.show', $job->id );
  }


  /**
   * Exibe o Job a ser Faturado.
   *
   * @param integer $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function add_parcela_porcentagem( $id ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id );

    /** @var JobParcela $parcela */
    $parcela = $job->Parcelas()->create( [
      'nome'          => \Request::get( 'nome' ),
      'data'          => \Request::get( 'data' ),
      'valor_bruto'   => \Request::get( 'valor_bruto' ),
      'valor_imposto' => \Request::get( 'valor_imposto' ),
      'valor_liquido' => \Request::get( 'valor_liquido' ),
      'conta_id'      => \Request::get( 'conta_id' ) == 0 ? null : \Request::get( 'conta_id' ),
    ] );
    $parcela->reSyncStore();

    return redirect()->route( 'financeiro.jobs.show', $job->id );
  }


  /**
   * Edita a Parcela.
   *
   * @param int $id1
   * @param int $id2
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function parcela_edit( $id1, $id2 ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id1 );
    /** @var JobParcela $parcela */
    $parcela = $job->Parcelas()->find( $id2 );

    if ( $parcela->conta_id == null ) {
      $parcela->conta_id = 0;
    }

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $voltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $voltar = route( 'financeiro.jobs.show', $job->id );
    }

    return view( 'Financeiro.Jobs.jobs_show_parcelas_edit', compact( 'job', 'parcela', 'voltar', 'periodo' ) );
  }


  /**
   * Atualiza a Parcela.
   *
   * @param int $id1
   * @param int $id2
   * @return \Illuminate\Http\RedirectResponse
   */
  public function parcela_update( $id1, $id2 ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id1 );

    /** @var JobParcela $parcela */
    $parcela = $job->Parcelas()->find( $id2 );

    $dados = \Request::all();
    if ( \Request::get( 'nota_fiscal_data_emissao' ) == '' ) {
      $dados[ 'nota_fiscal_data_emissao' ] = null;
    }
    if ( \Request::get( 'conta_id' ) == 0 ) {
      $dados[ 'conta_id' ] = null;
    }

    $parcela->reSyncUpdateBegin();
    $parcela->update( $dados );
    $parcela->reSyncUpdateEnd();

    flash( 'Parcela Atualiza com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.jobs.show', $job->id );
  }


  /**
   * Deleta a Parcela.
   *
   * @param int $id1
   * @param int $id2
   * @return \Illuminate\Http\RedirectResponse
   * @throws \Exception
   */
  public function parcela_destroy( $id1, $id2 ) {
    /** @var Jobs $job */
    $job = Jobs::findOrFail( $id1 );

    /** @var JobParcela $parcela */
    $parcela = $job->Parcelas()->find( $id2 );
    $parcela->reSyncDestroy();
    $parcela->delete();

    flash( 'Parcela Deletada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.jobs.show', $job->id );
  }

  /**
   * Gera o XLSX do Faturamento de Jobs.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Http\RedirectResponse|\Illuminate\View\View
   */
  public function jobFaturamentoXLSX() {
    $XLSX   = [];
    $XLSX[] = [
      // JOB:
      'ID',
      'NOME DO JOB',
      'ABERTURA',
      'RESPONSÁVEL',
      'CLIENTE',
      'CENTRO DE CUSTO DO CLIENTE',

      // PARCELAS:
      'NOME DA PARCELA',
      'CÓDIGO DE RECEITA',
      'DATA DE PAGAMENTO',
      'CONTA BANCÁRIA',
      'ESTÁ PAGA',
      'VALOR BRUTO DESTA PARCELA',
      'VALOR RETIDO',
      'VALOR LÍQUIDO DESTA PARCELA',
      'NOTA FISCAL',
      'DATA DE EMISSÃO',

      // Fornecedores:
      'TERCEIROS'
    ];
    /** @var Jobs[] $jobsF */
    $jobsF = Jobs::whereEtapaAtual( StageUtil::F )
                 ->orderBy( 'id' )
                 ->get();
    foreach ( $jobsF as &$job ) {

      $terceiros = '';
      try {
        $fornecedores = [];
        foreach ( $job->_OrcamentosAprovados_Cliente() as $orcamento ) {
          /** @var Orcamento $orcamento */
          foreach ( $orcamento->ItensCO as $itemCO ) {
            /** @var OrcamentoItemCO $itemCO */
            foreach ( $itemCO->Servicos as $itemCOServicos ) {
              /** @var OrcamentoItemCOServico $itemCOServicos */
              foreach ( $itemCOServicos->FornecedoresServicosProdutos()->get() as $fornecedor ) {
                /** @var FornecedoresServicosProdutos $fornecedor */
                $fornecedores[] = $fornecedor->getCodigoNome();
              }
            }
          }
        }
        $terceiros = implode( ', ', array_unique( $fornecedores, SORT_STRING ) );
      } catch ( \Exception $e ) {
        $terceiros = 'ERROR';
      }
      $jobParcelas = $job->Parcelas;
      if ( $jobParcelas->count() ) {
        foreach ( $jobParcelas as $parcela ) {
          $XLSX[] = [
            // JOB:
            // ID
            $job->id,
            // Nome do Job
            $job->nome_job,
            // Abertura
            $job->created_at->format( 'd/m/Y' ),
            // Responsável
            $job->_Responsavel(),
            // Cliente
            $job->_ClienteUnidade(),
            // Centro de Custo do Cliente
            $job->_ClienteConta(),

            // PARCELA:
            // Nome da Parcela
            $parcela->nome,
            // Código de Receita
            \App\Models\Cadastros\CodigoReceita::getCodReceitaNome( $job->cod_receita ),
            // Data de Pagamento
            $parcela->data->format( 'd/m/Y' ),
            // Conta Bancária
            \App\Models\Financeiro\ContaBancaria::enum_contas_pelo_cliente()[ $parcela->conta_id ],
            // Está Paga
            $parcela->pago === 1 ? 'Sim' : 'Não',
            // Valor Bruto desta Parcela
            $parcela->valor_bruto / 100,
            // Valor Retido
            $parcela->valor_imposto / 100,
            // Valor Líquido desta Parcela
            $parcela->valor_liquido / 100,
            // Nota Fiscal
            $parcela->nota_fiscal,
            // Data de Emissão
            $parcela->nota_fiscal_data_emissao ? Carbon::createFromFormat( 'Y-m-d', $parcela->nota_fiscal_data_emissao )->format( 'd/m/Y' ) : '',

            $terceiros,
          ];
        }
      } else {
        $XLSX[] = [
          // JOB:
          // ID
          $job->id,
          // Nome do Job
          $job->nome_job,
          // Abertura
          $job->created_at->format( 'd/m/Y' ),
          // Responsável
          $job->_Responsavel(),
          // Cliente
          $job->_ClienteUnidade(),
          // Centro de Custo do Cliente
          $job->_ClienteConta(),

          // PARCELA:
          '',
          '',
          '',
          '',
          '',
          '',
          '',
          '',
          '',
          '',

          $terceiros,
        ];
      }

    }


    $dtHoje   = Carbon::now()->format( 'Y-m-d' );
    $filename = 'FaturamentoDeJobs_' . $dtHoje;
    $title    = 'Faturamento De Jobs ' . $dtHoje;
    Excel::create( $filename, function ( $excel ) use ( $XLSX, $title ) {
      /** @var \Maatwebsite\Excel\Writers\LaravelExcelWriter $excel */
      $excel->setTitle( $title );
      $excel->setDescription( $title );
      $excel->sheet( 'Faturamento De Jobs', function ( $sheet ) use ( $XLSX ) {
        /** @var \Maatwebsite\Excel\Classes\LaravelExcelWorksheet $sheet */

        // Dados
        $sheet->fromArray( $XLSX, null, 'A1', false, false );

        // Style geral
        $sheet->setStyle( [
          'font' => [
            'name' => 'Arial',
            'size' => 10
          ]
        ] );
        $sheet->setAutoSize( true );
        $sheet->setBorder( 'A1:Q' . count( $XLSX ), PHPExcel_Style_Border::BORDER_THIN );

        // Style do Header
        $sheet->setHeight( 1, 25 );
        $sheet->cells( 'A1:Q1', function ( $cells ) {
          /** @var \Maatwebsite\Excel\Writers\CellWriter $cells */
          $cells->setFontColor( '#ffffff' );
          $cells->setBackground( '#404040' );
          $cells->setAlignment( 'center' );
          $cells->setValignment( 'center' );
          $cells->setFontWeight( 'bold' );
        } );

        // Column formatting
        $sheet->setColumnFormat( [
          'A' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'B' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'C' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'D' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'E' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'F' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'G' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'H' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'I' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'J' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'K' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'L' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'M' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'N' => PHPExcel_Style_NumberFormat::FORMAT_NUMBER,
          'O' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
          'P' => PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY,
          'Q' => PHPExcel_Style_NumberFormat::FORMAT_TEXT,
        ] );

        // Auto Filter
        $sheet->setAutoFilter();
      } );
    } )->download( 'xlsx' );

    return null;
  }
}
