<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\Rescisao;
use App\Models\Financeiro\RetiradaDeSocios;
use Illuminate\Http\Request;

class RescisaoController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Rescisao.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function index() {
    $indexSearch = Rescisao::IndexSearchMap();
    $rescisoes   = Rescisao::listarPaginadoBuscavelOrdenavel( Rescisao::query(), $indexSearch );
    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Rescisao.index', compact( 'rescisoes', 'indexSearch', 'caixaVoltar' ) );
  }

  /**
   * Exibem o formulario para criar uma nova Rescisao.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function create() {

    return view( 'Financeiro.Rescisao.create' );
  }

  /**
   * Armazena uma nova Rescisao no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function store( Request $request ) {
    /** @var Rescisao $rescisao */
    $rescisao = Rescisao::create( $request->all() );
    $rescisao->reSyncStore();

    flash( 'Rescisão criada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.rescisao.index' );
  }

  /**
   * Exibe o formulario para editar uma Rescisao no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function edit( $id ) {
    $rescisao = Rescisao::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.rescisao.index' );
    }

    return view( 'Financeiro.Rescisao.edit', compact( 'rescisao', 'periodo', 'caixaVoltar' ) );
  }

  /**
   * Atualiza uma Rescisao no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var Rescisao $rescisao */
    $rescisao = Rescisao::findOrFail( $id );
    $rescisao->reSyncUpdateBegin();
    $rescisao->update( $request->all() );
    $rescisao->reSyncUpdateEnd();

    flash( 'Rescisão atualizada com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.rescisao.index' );
  }

  /**
   * Remove uma Rescisao no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function destroy( $id ) {
    /** @var Rescisao $rescisao */
    $rescisao = Rescisao::findOrFail( $id );
    $rescisao->reSyncDestroy();
    $rescisao->delete();

    flash( 'Rescisão deletada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.rescisao.index' );
  }
}
