<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\RetiradaDeSocios;
use Illuminate\Http\Request;

class RetiradaDeSociosController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as RetiradaDeSocios.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function index() {
    $indexSearch = RetiradaDeSocios::IndexSearchMap();
    $retiradas   = RetiradaDeSocios::listarPaginadoBuscavelOrdenavel( RetiradaDeSocios::query(), $indexSearch );
    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.RetiradaDeSocios.index', compact( 'retiradas', 'indexSearch', 'caixaVoltar' ) );
  }

  /**
   * Exibem o formulario para criar uma nova RetiradaDeSocios.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function create() {

    return view( 'Financeiro.RetiradaDeSocios.create' );
  }

  /**
   * Armazena uma nova RetiradaDeSocios no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function store( Request $request ) {
    /** @var RetiradaDeSocios $retirada */
    $retirada = RetiradaDeSocios::create( $request->all() );

    if ( $request->hasFile( 'file_boleto' ) ) {
      $fileB     = $request->file( 'file_boleto' );
      $filenameB = $fileB->getClientOriginalName();
      $localB    = $retirada->getLocalBoleto();
      $fileB->move( $localB, $filenameB );

      $retirada->boleto = $filenameB;
      $retirada->save();
    }
    if ( $request->hasFile( 'file_comprovante' ) ) {
      $fileC     = $request->file( 'file_comprovante' );
      $filenameC = $fileC->getClientOriginalName();
      $localC    = $retirada->getLocalComprovante();
      $fileC->move( $localC, $filenameC );

      $retirada->comprovante = $filenameC;
      $retirada->save();
    }
    $retirada->reSyncStore();

    flash( 'Retirada de Sócio criada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.retiradadesocios.index' );
  }

  /**
   * Exibe o formulario para editar uma RetiradaDeSocios no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function edit( $id ) {
    $retirada = RetiradaDeSocios::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.retiradadesocios.index' );
    }

    return view( 'Financeiro.RetiradaDeSocios.edit', compact( 'retirada', 'periodo', 'caixaVoltar' ) );
  }

  /**
   * Atualiza uma RetiradaDeSocios no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var RetiradaDeSocios $retirada */
    $retirada = RetiradaDeSocios::findOrFail( $id );
    $retirada->reSyncUpdateBegin();
    $retirada->update( $request->all() );

    $reSave = false;
    if ( $request->has( 'deletar_boleto' ) && $retirada->boleto ) {
      $localB = public_path( $retirada->getLocalBoletoLink() );
      if ( file_exists( $localB ) ) {
        unlink( $localB );
      }
      $retirada->boleto = null;

      $reSave = true;
    }
    if ( $request->hasFile( 'file_boleto' ) ) {
      $localB = public_path( $retirada->getLocalBoletoLink() );
      if ( file_exists( $localB ) && $retirada->boleto ) {
        unlink( $localB );
      }
      $retirada->boleto = null;

      $fileB     = $request->file( 'file_boleto' );
      $filenameB = $fileB->getClientOriginalName();
      $localB    = $retirada->getLocalBoleto();
      $fileB->move( $localB, $filenameB );

      $retirada->boleto = $filenameB;

      $reSave = true;
    }

    if ( $request->has( 'deletar_comprovante' ) && $retirada->comprovante ) {
      $localC = public_path( $retirada->getLocalComprovanteLink() );
      if ( file_exists( $localC ) ) {
        unlink( $localC );
      }
      $retirada->comprovante = null;

      $reSave = true;
    }
    if ( $request->hasFile( 'file_comprovante' ) ) {
      $localC = public_path( $retirada->getLocalComprovanteLink() );
      if ( file_exists( $localC ) && $retirada->comprovante ) {
        unlink( $localC );
      }
      $retirada->comprovante = null;

      $fileC     = $request->file( 'file_comprovante' );
      $filenameC = $fileC->getClientOriginalName();
      $localC    = $retirada->getLocalComprovante();
      $fileC->move( $localC, $filenameC );

      $retirada->comprovante = $filenameC;

      $reSave = true;
    }
    if ( $reSave ) {
      $retirada->save();
    }
    $retirada->reSyncUpdateEnd();

    flash( 'Retirada de Sócio atualizada com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.retiradadesocios.index' );
  }

  /**
   * Remove uma RetiradaDeSocios no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function destroy( $id ) {
    /** @var RetiradaDeSocios $retirada */
    $retirada = RetiradaDeSocios::findOrFail( $id );

    if ( $retirada->boleto ) {
      $localB = public_path( $retirada->getLocalBoletoLink() );
      if ( file_exists( $localB ) ) {
        unlink( $localB );
      }
    }
    if ( $retirada->comprovante ) {
      $localC = public_path( $retirada->getLocalComprovanteLink() );
      if ( file_exists( $localC ) ) {
        unlink( $localC );
      }
    }
    $retirada->reSyncDestroy();
    $retirada->delete();

    flash( 'Retirada de Sócio deletada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.retiradadesocios.index' );
  }
}
