<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\Rescisao;
use App\Models\Financeiro\RetiradaDeSocios;
use App\Models\Financeiro\Salario13;
use Illuminate\Http\Request;

class Salario13Controller extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Rescisao.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function index() {
    $indexSearch = Salario13::IndexSearchMap();
    $salarios    = Salario13::listarPaginadoBuscavelOrdenavel( Salario13::query()->with( 'Funcionario' ), $indexSearch );
    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Salario13.index', compact( 'salarios', 'indexSearch', 'caixaVoltar' ) );
  }

  /**
   * Exibem o formulario para criar uma nova Salario13.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function create() {

    return view( 'Financeiro.Salario13.create' );
  }

  /**
   * Armazena uma nova Salario13 no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function store( Request $request ) {
    /** @var Salario13 $salario13 */
    $salario13 = Salario13::create( $request->all() );
    $salario13->reSyncStore();

    flash( '13º Salário criado com sucesso!', 'success' );

    return redirect()->route( 'financeiro.salario13.index' );
  }

  /**
   * Exibe o formulario para editar uma Salario13 no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function edit( $id ) {
    $salario13 = Salario13::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.salario13.index' );
    }

    return view( 'Financeiro.Salario13.edit', compact( 'salario13', 'periodo', 'caixaVoltar' ) );
  }

  /**
   * Atualiza uma Salario13 no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var Salario13 $salario13 */
    $salario13 = Salario13::findOrFail( $id );
    $salario13->reSyncUpdateBegin();
    $salario13->update( $request->all() );
    $salario13->reSyncUpdateEnd();

    flash( '13º Salário atualizado com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.salario13.index' );
  }

  /**
   * Remove uma Salario13 no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function destroy( $id ) {
    /** @var Salario13 $salario13 */
    $salario13 = Salario13::findOrFail( $id );
    $salario13->reSyncDestroy();
    $salario13->delete();

    flash( '13º Salário deletado com sucesso!', 'success' );

    return redirect()->route( 'financeiro.salario13.index' );
  }
}
