<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Cadastros\Funcionarios;
use App\Models\Financeiro\Salario;
use Carbon\Carbon;
use File;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;

class SalarioController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Salario.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function index() {
    $ano      = \Request::get( 'ano' );
    $mes      = \Request::get( 'mes' );
    $salarios = [];

    $total = [
      'valor_salario_total' => 0,
      'valor_vr_total'      => 0,
      'valor_vt_total'      => 0,
      'valor_total'         => 0,
    ];
    if ( $ano != '' && $mes != '' ) {
      /** @var Salario[] $salarios */
      $salarios = Salario::whereAno( $ano )
                         ->whereMes( $mes )
                         ->get();
      foreach ( $salarios as $salario ) {
        $total[ 'valor_salario_total' ] += $salario->valor_salario_total;
        $total[ 'valor_vr_total' ]      += $salario->valor_vr_total;
        $total[ 'valor_vt_total' ]      += $salario->valor_vt_total;
        $total[ 'valor_total' ]         += $salario->valor_total;
      }
    }
    $anos = [];
    //dd( Salario::groupBy( [ 'ano' ] )->orderBy( 'ano' )->get( [ 'ano' ] )->toArray() );
    foreach ( Salario::groupBy( [ 'ano' ] )->orderBy( 'ano', 'desc' )->get( [ 'ano' ] ) as $a ) {
      $anos[ $a->ano ] = $a->ano;
    }

    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Salarios.index', compact( 'salarios', 'ano', 'mes', 'total', 'anos', 'caixaVoltar' ) );
  }


  /**
   * Lanca o Salario dos Funcionarios.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\Response
   */
  public function store( Request $request ) {
    $ano            = $request->get( 'ano' );
    $mes            = $request->get( 'mes' );
    $conta_id       = $request->get( 'conta_id' );
    $data_pagamento = $request->get( 'data_pagamento' );
    $dias_uteis     = $request->get( 'dias_uteis' );
    $anoMes         = Carbon::create( $ano, $mes, 2, 0, 0, 0 );

    // funcionarios ativos
    foreach ( Funcionarios::whereInativo( false )->orderBy( 'nome' )->get() as $func ) {
      /** @var Funcionarios $func */
      $hist    = $func->pilhaHistorico();
      $salario = $hist[ 'salario' ] == null ? 0 : $hist[ 'salario' ];
      $vr      = $hist[ 'vr' ] == null ? 0 : $hist[ 'vr' ];
      $vt      = $hist[ 'vt' ] == null ? 0 : $hist[ 'vt' ];

      $pontos  = $func->_CalcControleDePontos( $anoMes );
      $salDesc = $pontos[ 'salarioDescontado' ];
      $vrvt    = $pontos[ 'vrvt' ];

      // Salario
      $valor_salario       = $salario;
      $valor_salario_desc  = intval( $salario / 30 * $salDesc );
      $valor_salario_total = $valor_salario - $valor_salario_desc;

      // VR
      $valor_vr          = intval( $vr * $dias_uteis );
      $valor_vr_desc_dia = $vrvt;
      $valor_vr_desc     = intval( $vr * $vrvt );
      $valor_vr_total    = $valor_vr - $valor_vr_desc;

      // VT
      $valor_vt          = intval( $vt * $dias_uteis );
      $valor_vt_desc     = intval( $vt * $vrvt );
      $valor_vt_desc_dia = $vrvt;
      $valor_vt_total    = $valor_vt - $valor_vt_desc;


      $valor_total = $valor_salario_total + $valor_vr_total + $valor_vt_total;

      /** @var Salario $sal */
      $sal = Salario::whereFuncionarioId( $func->id )
                    ->whereAno( $ano )
                    ->whereMes( $mes )
                    ->first();

      if ( $sal != null ) { // existe ja, entao update
        $sal->reSyncUpdateBegin();
        $sal->update( [
          'data_pagamento'      => $data_pagamento,
          'pago'                => false,
          'dias_uteis'          => $dias_uteis,
          'conta_id'            => $conta_id,

          // Salario
          'valor_salario'       => $valor_salario,
          'valor_salario_desc'  => $valor_salario_desc,
          'valor_salario_total' => $valor_salario_total,

          // VR
          'valor_vr_unitario'   => $vr,
          'valor_vr'            => $valor_vr,
          'valor_vr_desc_dia'   => $valor_vr_desc_dia,
          'valor_vr_desc'       => $valor_vr_desc,
          'valor_vr_total'      => $valor_vr_total,

          // VT
          'valor_vt_unitario'   => $vt,
          'valor_vt'            => $valor_vt,
          'valor_vt_desc_dia'   => $valor_vt_desc_dia,
          'valor_vt_desc'       => $valor_vt_desc,
          'valor_vt_total'      => $valor_vt_total,

          // Acrescimos
          'comissao'            => 0,
          'reembolso'           => 0,

          'valor_total' => $valor_total,
        ] );
        $sal->reSyncUpdateEnd();
      } else { // nao existe, entao create
        $sal = Salario::create( [
          'ano'                 => $ano,
          'mes'                 => $mes,
          'conta_id'            => $conta_id,
          'funcionario_id'      => $func->id,
          'data_pagamento'      => $data_pagamento,
          'pago'                => false,
          'dias_uteis'          => $dias_uteis,

          // Salario
          'valor_salario'       => $valor_salario,
          'valor_salario_desc'  => $valor_salario_desc,
          'valor_salario_total' => $valor_salario_total,

          // VR
          'valor_vr_unitario'   => $vr,
          'valor_vr'            => $valor_vr,
          'valor_vr_desc_dia'   => $valor_vr_desc_dia,
          'valor_vr_desc'       => $valor_vr_desc,
          'valor_vr_total'      => $valor_vr_total,

          // VT
          'valor_vt_unitario'   => $vt,
          'valor_vt'            => $valor_vt,
          'valor_vt_desc_dia'   => $valor_vt_desc_dia,
          'valor_vt_desc'       => $valor_vt_desc,
          'valor_vt_total'      => $valor_vt_total,

          // Acrescimos
          'comissao'            => 0,
          'reembolso'           => 0,

          'valor_total' => $valor_total,
        ] );
        $sal->reSyncStore();
      }
    }

    flash( 'Salários lançados com sucesso!', 'success' );

    return redirect()->to( route( 'financeiro.salarios.index' ) . '?ano=' . $ano . '&mes=' . $mes );
  }

  /**
   * Exibe o formulario para editar uma Salario no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function edit( $id ) {
    /** @var Salario $salario */
    $salario = Salario::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $voltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $voltar = route( 'financeiro.salarios.index' ) . '?ano=' . $salario->ano . '&mes=' . $salario->mes;
    }

    return view( 'Financeiro.Salarios.edit', compact( 'salario', 'periodo', 'voltar' ) );
  }

  /**
   * Atualiza uma Salario no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var Salario $salario */
    $salario = Salario::findOrFail( $id );
    $salario->reSyncUpdateBegin();
    $salario->update( $request->all() );
    $salario->reSyncUpdateEnd();

    if ( $salario->holerite !== null && $request->has( 'deletar_holerite' ) ) {
      $salario->update( [
        'holerite'         => null,
        'holerite_nome'    => null,
        'holerite_visited' => Salario::HOLERITE_VISITED_NONE
      ] );
    }
    if ( $request->hasFile( 'file_holerite' ) ) {
      $salario->storeHolerite( $request->file( 'file_holerite' ) );
    }

    flash( 'Salário atualizado com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->to( route( 'financeiro.salarios.index' ) . '?ano=' . $salario->ano . '&mes=' . $salario->mes );
  }

  /**
   * Remove uma Salario no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\Response
   */
  public function destroy( $id ) {
    /** @var Salario $salario */
    $salario = Salario::findOrFail( $id );
    $salario->reSyncDestroy();
    $salario->delete();

    flash( 'Salário deletado com sucesso!', 'success' );

    return redirect()->route( 'financeiro.salarios.index' );
  }

  /**
   * Download do Holerite.
   *
   * @param $id
   * @return string|\Symfony\Component\HttpFoundation\BinaryFileResponse
   */
  public function downloadHolerite( $id ) {
    /** @var Salario $salario */
    $salario = Salario::findOrFail( $id );
    if ( empty( $salario->holerite ) ) {
      return 'Sem Holerite/Recibo Anexado';
    }

    $holeriteFilepath = $salario->getHoleriteFileAbsolutePath();
    if ( !File::exists( $holeriteFilepath ) ) {
      return 'Arquivo nao encontrado';
    }

    return Response::download( $holeriteFilepath, $salario->holerite_nome, [], 'inline' );
  }
}
