<?php

namespace App\Http\Controllers\Financeiro;

use App\CRP;
use App\Http\Controllers\Controller;
use App\Models\Financeiro\Transferencia;
use Illuminate\Http\Request;

class TransferenciaController extends Controller {
  /**
   * Cria uma nova instancia deste Controller.
   *
   */
  public function __construct() {
    $this->middleware( 'auth' );
    $this->middleware( CRP::role( CRP::P_Financeiro ) );
  }

  /**
   * Lista as Transferencias.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function index() {
    $indexSearch = Transferencia::IndexSearchMap();
    $transfs     = Transferencia::listarPaginadoBuscavelOrdenavel( Transferencia::query(), $indexSearch );
    $caixaVoltar = \Request::has( 'caixa' ) ? route( 'financeiro.caixa.show_periodo', \Request::get( 'caixa' ) ) : '';

    return view( 'Financeiro.Transferencias.index', compact( 'transfs', 'indexSearch', 'caixaVoltar' ) );
  }

  /**
   * Exibem o formulario para criar uma nova Transferencia.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function create() {

    return view( 'Financeiro.Transferencias.create' );
  }

  /**
   * Armazena uma nova Transferencia no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function store( Request $request ) {
    /** @var Transferencia $transf */
    $transf = Transferencia::create( $request->all() );
    $transf->reSyncStore();

    flash( 'Transferência entre Contas Bancárias criada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.transferencias.index' );
  }


  /**
   * Exibe o formulario para editar uma Transferencia no BD.
   *
   * @param int $id
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\Response|\Illuminate\View\View
   */
  public function edit( $id ) {
    $transf = Transferencia::findOrFail( $id );

    $periodo = \Request::get( 'caixa', '' );
    if ( $periodo ) {
      $caixaVoltar = route( 'financeiro.caixa.show_periodo', $periodo );
    } else {
      $caixaVoltar = route( 'financeiro.transferencias.index' );
    }

    return view( 'Financeiro.Transferencias.edit', compact( 'transf', 'periodo', 'caixaVoltar' ) );
  }

  /**
   * Atualiza uma Transferencia no BD.
   *
   * @param \Illuminate\Http\Request $request
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function update( Request $request, $id ) {
    /** @var Transferencia $transf */
    $transf = Transferencia::findOrFail( $id );
    $transf->reSyncUpdateBegin();
    $transf->update( $request->all() );
    $transf->reSyncUpdateEnd();

    flash( 'Transferência entre Contas Bancárias atualizada com sucesso!', 'success' );

    $periodo = \Request::get( '_voltar', '' );
    if ( $periodo ) {
      return redirect()->route( 'financeiro.caixa.show_periodo', $periodo );
    }

    return redirect()->route( 'financeiro.transferencias.index' );
  }

  /**
   * Remove uma Transferencia no BD.
   *
   * @param int $id
   * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response
   */
  public function destroy( $id ) {
    /** @var Transferencia $transf */
    $transf = Transferencia::findOrFail( $id );
    $transf->delete();
    $transf->reSyncDestroy();

    flash( 'Transferência entre Contas Bancárias deletada com sucesso!', 'success' );

    return redirect()->route( 'financeiro.transferencias.index' );
  }
}
