<?php
/**
 * Created by PhpStorm
 * User: rafaelcardoso
 * Date: 2019-07-12
 * Time: 19:26
 */

namespace App\Http\Controllers\Usuario;


use App\Http\Controllers\Controller;
use App\Models\Cadastros\Usuarios;
use Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use function bcrypt;
use function compact;
use function flash;
use function password_verify;
use function redirect;
use function view;

class ConfigurarContaController extends Controller {
  /**
   * Exibe a tela de Configurar Conta.
   *
   * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
   */
  public function getConfigurarConta() {
    $user = Usuarios::find( Auth::user()->id );

    return view( 'Usuario.ConfigurarConta', compact( 'user' ) );
  }

  /**
   * Altera a Senha do usuario logado.
   *
   * @param Request $request
   * @return \Illuminate\Http\RedirectResponse
   */
  public function postConfigurarConta_alteraSenha( Request $request ) {

    $this->validate( $request, [
      'senha'      => 'required|min:6',
      'nova_senha' => 'required|confirmed|min:6',
    ], [] );

    $senha    = $request->get( 'senha', '' );
    $nv_senha = $request->get( 'nova_senha', '' );

    $user = Auth::user();
    if ( !password_verify( $senha, $user->password ) ) {
      return redirect()
        ->back()
        ->withErrors( [
          'senha' => 'A Senha digitada não coincide com a Atual.'
        ] );
    }

    $user->forceFill( [
      'password'       => bcrypt( $nv_senha ),
      'remember_token' => Str::random( 60 ),
    ] )->save();

    Auth::guard()->login( $user );

    flash( 'Senha Alterada com Sucesso!', 'success' )->important();

    return redirect()->route( 'usuario.ConfigurarConta.get' );
  }
}
