<?php
/**
 * Created by PhpStorm
 * User: rafaelcardoso
 * Date: 2019-07-12
 * Time: 19:20
 */

namespace App\Http\Controllers\Usuario;


use App\Http\Controllers\Controller;
use App\Models\Cadastros\Usuarios;
use App\Models\Financeiro\Salario;
use Auth;
use File;
use Response;
use View;

/**
 * Class HoleritesController
 *
 * @package App\Http\Controllers\Usuario
 */
class HoleritesController extends Controller {
  /**
   * Lista os Holerites dos Funcionarios.
   *
   * @return \Illuminate\Contracts\View\View|string
   */
  public function listarHolerites() {
    $user = Auth::user();
    if ( !$user ) {
      return 'Usuário não encontrado';
    }

    $func_id = $user->funcionarios_id;
    if ( !$func_id ) {
      return 'Sem Funcionário associado ao seu Usuário';
    }

    $funcionario = $user->Funcionario;
    if ( !$funcionario ) {
      return 'Funcionário nao encontrado';
    }

    $salarios = Salario
      ::whereFuncionarioId( $funcionario->id )
      ->whereNotNull( 'holerite' )
      ->orderBy( 'ano', 'DESC' )
      ->orderBy( 'mes', 'DESC' )
      ->get();

    return View::make( 'Usuario.Holerites', compact( 'funcionario', 'salarios' ) );
  }

  /**
   * Usuario faz download do Holerite se foi dele mesmo.
   *
   * @param $id
   * @return string|\Symfony\Component\HttpFoundation\BinaryFileResponse
   */
  public function downloadHolerite( $id ) {
    /** @var Usuarios $user */
    $user = Auth::user();
    if ( !$user ) {
      return 'Usuário não encontrado';
    }

    $func_id = $user->funcionarios_id;
    if ( !$func_id ) {
      return 'Sem Funcionário associado ao seu Usuário';
    }

    $funcionario = $user->Funcionario;
    if ( !$funcionario ) {
      return 'Funcionário nao encontrado';
    }

    /** @var Salario $salario */
    $salario = Salario::find( $id );
    if ( !$salario ) {
      return 'Folha de Pagamento não encontrado';
    }

    if ( $funcionario->id !== $salario->funcionario_id ) {
      return 'Não Permitido';
    }

    if ( empty( $salario->holerite ) ) {
      return 'Sem Holerite/Recibo Anexado';
    }

    $holeriteFilepath = $salario->getHoleriteFileAbsolutePath();
    if ( !File::exists( $holeriteFilepath ) ) {
      return 'Arquivo nao encontrado';
    }

    // Mark visualized
    $salario->update( [
      'holerite_visited' => Salario::HOLERITE_VISITED_VISUALIZED,
    ] );

    return Response::download( $holeriteFilepath, $salario->holerite_nome, [], 'inline' );
  }
}
