<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class ClientesRequest extends FormRequest {
  /**
   * Determina se o usuário está autorizado a fazer este pedido.
   *
   * @return bool
   */
  public function authorize() {
    return true;
  }

  /**
   * Retorna as regras de validacao a ser aplicada na requisicao.
   *
   * @return array
   */
  public function rules() {
    $EDIT = $this->get( 'EDIT', false );
    $emp  = $this->get( 'empresa', '' );
    $cen  = $this->get( 'centro', '' );
    $cnt  = $this->get( 'conta', '' );
    $UNI  = $this->get( 'UNI', false );

    if ( $UNI == 'UNIDADE' ) {
      return [
        'nome' => 'required|string|max:255',

        'cnpj'               => 'required|string',
        'razao_social'       => 'required|string|max:255',
        'inscr_estadual'     => 'required|string|max:255',
        'inscr_municipal'    => 'required|string|max:255',
        'condpagamento_dias' => 'required|integer',
        'condpagamento'      => 'nullable|string|max:255',

        'bancario_banco'   => 'required|numeric',
        'bancario_agencia' => 'nullable|string|max:10',
        'bancario_conta'   => 'nullable|string|max:10',

        'end_cep'         => 'required|string|max:9',
        'end_logradouro'  => 'required|string|max:255',
        'end_numero'      => 'required|string|max:255',
        'end_complemento' => 'nullable|string|max:255',
        'end_bairro'      => 'required|string|max:255',
        'end_cidade'      => 'required|string|max:255',
        'end_estado'      => 'required|string|max:2',

        'obs' => 'nullable|string',
      ];
    }

    if (
      ( $EDIT && $emp != '' && $cen == '' && $cnt == '' ) ||
      ( !$EDIT && $emp == '' && $cen == '' && $cnt == '' )
    ) { // Empresa
      return [
        'codigo' => 'required|numeric',
        'nome'   => 'required|string|max:255',
      ];

    } elseif (
      ( $EDIT && $emp != '' && $cen != '' && $cnt == '' ) ||
      ( !$EDIT && $emp != '' && $cen == '' && $cnt == '' )
    ) { // Centro de Custo
      return [
        'empresa' => 'required|numeric',
        'codigo'  => 'required|numeric',
        'nome'    => 'required|max:255',

        'contato_nome'  => 'nullable|array',//'array|required|string|max:255',
        'contato_tel'   => 'nullable|array',//'array|required|string|max:14',
        'contato_cel'   => 'nullable|array',//'array|required|string|max:15',
        'contato_email' => 'nullable|array',//'array|required|email|max:255'
      ];

    } else { // Conta
      return [
        'empresa' => 'required|numeric',
        'centro'  => 'required|numeric',

        'codigo' => 'required|numeric',
        'nome'   => 'required|string|max:255',

      ];
    }
  }

  /**
   * Mensagens de erros amigaveis.
   *
   * @return array
   */
  public function messages() {
    return [
      'empresa.required' => 'Selecione uma Empresa.',
      'centro.required'  => 'Selecione um Departamento.',
      'codigo.required'  => 'Selecione um Código.',
      'nome.required'    => 'O campo Nome Fantasia é obrigatório.',

      'cnpj.required'            => 'O campo CNPJ é obrigatório.',
      'razao_social.required'    => 'O campo Razão Social é obrigatório.',
      'inscr_estadual.required'  => 'O campo Inscrição Estadual é obrigatório.',
      'inscr_municipal.required' => 'O campo Inscrição Municipal é obrigatório.',

      'bancario_banco.required'   => 'O campo Banco da Conta Bancária é obrigatório.',
      'bancario_agencia.required' => 'O campo Agência Bancária é obrigatório.',
      'bancario_conta.required'   => 'O campo Conta Bancária é obrigatório.',

      'end_cep.required'        => 'O campo CEP do Endereço é obrigatório.',
      'end_logradouro.required' => 'O campo Logradouro do Endereço é obrigatório.',
      'end_numero.required'     => 'O campo Número do Endereço é obrigatório.',
      'end_bairro.required'     => 'O campo Bairro do Endereço é obrigatório.',
      'end_cidade.required'     => 'O campo Cidade do Endereço é obrigatório.',
      'end_estado.required'     => 'Selecione um Estado do Endereço.',

      'contato_nome.required'  => 'O campo Nome de Contato é obrigatório.',
      'contato_tel.required'   => 'O campo Telefone de Contato é obrigatório.',
      'contato_cel.required'   => 'O campo Celular de Contato é obrigatório.',
      'contato_email.required' => 'O campo E-mail de Contato é obrigatório.',
    ];
  }

  /**
   * Retorna o valor do input, se caso vazio ("") retorna null ou default.
   *
   * @param string $key
   * @param null $default
   * @return mixed|string|null
   */
  public function getOrNull( $key, $default = null ) {
    $valor = $this->get( $key, '' );
    if ( empty( $valor ) || trim( $valor ) === '' ) {
      return $default;
    }

    return $valor;
  }
}
