<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class FornecedoresRequest extends FormRequest {
  /**
   * Determine if the user is authorized to make this request.
   *
   * @return bool
   */
  public function authorize() {
    return true;
  }

  /**
   * Get the validation rules that apply to the request.
   *
   * @return array
   */
  public function rules() {
    $EDIT = $this->get( 'EDIT', false );
    $emp  = $this->get( 'empresa', '' );
    $prod = $this->get( 'produto', '' );

    if (
      ( $EDIT && $emp != '' && $prod == '' ) ||
      ( !$EDIT && $emp == '' && $prod == '' )
    ) { // Empresa
      return [ // TODO:
        'codigo'          => 'required|numeric',
        'nome'            => 'required|string|max:255',
        'cnpj'            => 'required|string|max:18',
        'razao_social'    => 'required|string|max:255',
        'inscr_estadual'  => 'required|string|max:255',
        'inscr_municipal' => 'required|string|max:255',
        'condpagamento'   => 'nullable',

        'bancario_banco'   => 'nullable|numeric',
        'bancario_agencia' => 'nullable|string|max:10',
        'bancario_conta'   => 'nullable|string|max:10',

        'end_apelido'     => 'nullable|array',
        'end_cep'         => 'nullable|array',
        'end_logradouro'  => 'nullable|array',
        'end_numero'      => 'nullable|array',
        'end_complemento' => 'nullable|array',
        'end_bairro'      => 'nullable|array',
        'end_cidade'      => 'nullable|array',
        'end_estado'      => 'nullable|array',
      ];

    } else { // Produto Servico
      return [// TODO:
        'empresa' => 'required|numeric',
        'codigo'  => 'required|numeric',
        'nome'    => 'required|max:255',

        'fornecedores_despesas_id' => 'required|numeric',

        'contato_nome'  => 'nullable|array',//'array|required|string|max:255',
        'contato_tel'   => 'nullable|array',//'array|required|string|max:14',
        'contato_cel'   => 'nullable|array',//'array|required|string|max:15',
        'contato_email' => 'nullable|array',//'array|required|email|max:255'

        // TODO TAGs
        'tags'          => 'nullable|array',
      ];
    }
  }

  /**
   * Mensagens de erros amigaveis.
   *
   * @return array
   */
  public function messages() {
    $EDIT = $this->get( 'EDIT', false );
    $emp  = $this->get( 'empresa', '' );
    $prod = $this->get( 'produto', '' );
    if (
      ( $EDIT && $emp != '' && $prod == '' ) ||
      ( !$EDIT && $emp == '' && $prod == '' )
    ) { // Empresa
      return [
        'codigo.required'          => 'O campo Código é obrigatório.',
        'nome.required'            => 'O campo Nome Fantasia é obrigatório.',
        'cnpj.required'            => 'O campo CNPJ é obrigatório.',
        'razao_social.required'    => 'O campo Razão Social é obrigatório.',
        'inscr_estadual.required'  => 'O campo Inscrição Estadual é obrigatório.',
        'inscr_municipal.required' => 'O campo Inscrição Municipal é obrigatório.'
      ];
    } else { // Produto Servico
      return [
        'empresa.required' => 'Selecione uma Empresa.',
        'codigo.required'  => 'O campo Código é obrigatório.',
        'nome.required'    => 'O campo Nome do Departamento é obrigatório.',

        'fornecedores_despesas_id.required' => 'O campo Despesa é obrigatório.'
      ];
    }
  }

  /**
   * Retorna o valor do input, se caso vazio ("") retorna null ou default.
   *
   * @param string $key
   * @param null $default
   * @return mixed|string|null
   */
  public function getOrNull( $key, $default = null ) {
    $valor = $this->get( $key, '' );
    if ( empty( $valor ) || trim( $valor ) === '' ) {
      return $default;
    }

    return $valor;
  }
}
