<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class FuncionarioHistoricoLoteRequest extends FormRequest {
  /**
   * Determine if the user is authorized to make this request.
   *
   * @return bool
   */
  public function authorize() {
    return true;
  }

  /**
   * Retorna as regras de validacao a ser aplicada na requisicao.
   *
   * @return array
   */
  public function rules() {
    $tipo = $this->toArray()[ 'tipo' ];
    switch ( $tipo ) {
      case 0: //Contratação
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'required|numeric',
          'nivel'             => 'required|numeric',
          'salario'           => 'required|numeric',
          'vr'                => 'required|numeric',
          'vt'                => 'required|numeric',
          'seguro_vida'       => 'required|numeric',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 1: //Demissâo
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 2: //Merito
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'required|numeric',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 3: //Dissídio
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 4: //Promoção
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'required|numeric',
          'nivel'             => 'required|numeric',
          'salario'           => 'required|numeric',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 5: // Reajuste VR
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'required|numeric',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 6: //Reajuste VT
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'nullable',
          'vt'                => 'required|numeric',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 7: //Modificação do Seguro de Vida
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'required|numeric',
          'ferias_dt_inicio'  => 'nullable',
          'ferias_dt_termino' => 'nullable'
        ];
      case 8: //Aquisição de periodo aquisitivo
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'required|date',
          'ferias_dt_termino' => 'required|date'
        ];
      case 9: //Gozo de férias
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => 'nullable',
          'nivel'             => 'nullable',
          'salario'           => 'nullable',
          'vr'                => 'nullable',
          'vt'                => 'nullable',
          'seguro_vida'       => 'nullable',
          'ferias_dt_inicio'  => 'required|date',
          'ferias_dt_termino' => 'required|date'
        ];
      default:
        return [
          'idFunc'            => 'required|array',
          'data'              => 'required|date',
          'tipo'              => 'required|numeric',
          'cargo'             => '',
          'nivel'             => '',
          'salario'           => '',
          'vr'                => '',
          'vt'                => '',
          'seguro_vida'       => '',
          'ferias_dt_inicio'  => '',
          'ferias_dt_termino' => ''
        ];
    }
  }

  /**
   * Mensagens de erros amigaveis.
   *
   * @return array
   */
  public function messages() {
    return [
      'idFunc.required'            => 'É necessario selecionar pelo menos um Funcionário.',
      'data.required'              => 'O campo Data é obrigatório.',
      'tipo.required'              => 'Selecione um Tipo de Histórico.',
      'cargo.required'             => 'Selecione um Cargo.',
      'nivel.required'             => 'Selecione um Nível.',
      'salario.required'           => 'O campo Salário é obrigatório.',
      'vr.required'                => 'O campo Vale Refeição é obrigatório.',
      'vt.required'                => 'O campo Vale Transporte é obrigatório.',
      'seguro_vida.required'       => 'Selecione um Seguro de Vida.',
      'ferias_dt_inicio.required'  => 'O campo Data de Início das Férias é obrigatório.',
      'ferias_dt_termino.required' => 'O campo Data de Término das Férias é obrigatório.'
    ];
  }
}
