<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Request;

class FuncionarioRequest extends FormRequest {
  /**
   * Determina se o usuário está autorizado a fazer este pedido.
   *
   * @return bool
   */
  public function authorize() {
    return true;
  }

  /**
   * Retorna as regras de validacao a ser aplicada na requisicao.
   *
   * @return array
   */
  public function rules() {
    $contratar = ( Request::get( 'usar_contratacao', 0 ) == 1 );
    $usuario   = ( Request::get( 'usar_usuario', 0 ) == 1 );
    return [
      'nome'          => 'required|max:255',
      'sexo'          => 'required|max:1',
      'email'         => 'required|email|max:255',
      'rg'            => 'required|string|max:12',
      'cpf'           => 'required|string|max:14',
      'dt_nascimento' => 'required|date',
      'nome_pai'      => 'required|string|max:255',
      'nome_mae'      => 'required|string|max:255',
      'estado_civil'  => 'required|numeric',
      'foto'          => 'nullable|image', //mimes:jpeg,png',

      'end_cep'         => 'required|string|max:9',
      'end_logradouro'  => 'required|string|max:255',
      'end_numero'      => 'required|string|max:255',
      'end_complemento' => 'nullable|string|max:255',
      'end_bairro'      => 'required|string|max:255',
      'end_cidade'      => 'required|string|max:255',
      'end_estado'      => 'required|string|max:2',

      'teste_mbti' => 'required|string|max:4',
      'inativo'    => 'required|numeric',
      'regime'     => 'required|numeric',
      'hr_entrada' => 'required',
      'hr_saida'   => 'required',

      'tel_tipo[]'     => 'nullable|array',
      'tel_telefone[]' => 'nullable|array',
      'tel_recado[]'   => 'nullable|array',
      'tel_obs[]'      => 'nullable|array',
      'tel_id[]'       => 'nullable|array',

      'dep_nome[]'       => 'nullable|array',
      'dep_parentesco[]' => 'nullable|array',
      'dep_nascimento[]' => 'nullable|array',
      'dep_falecido[]'   => 'nullable|array',
      'dep_id[]'         => 'nullable|array',

      'departamentos_id' => 'required|numeric',

      'usar_usuario' => $usuario ? 'required|numeric' : 'nullable',

      'usar_contratacao' => $contratar ? 'required|numeric' : 'nullable',
      'hist_data'        => $contratar ? 'required|date' : 'nullable',
      'hist_cargo'       => $contratar ? 'required|numeric' : 'nullable',
      'hist_nivel'       => $contratar ? 'required|numeric' : 'nullable',
      'hist_salario'     => $contratar ? 'required|numeric' : 'nullable',
      'hist_vr'          => $contratar ? 'required|numeric' : 'nullable',
      'hist_vt'          => $contratar ? 'required|numeric' : 'nullable',
      'hist_seguro_vida' => $contratar ? 'required|numeric' : 'nullable',
    ];
  }

  /**
   * Mensagens de erros amigaveis.
   *
   * @return array
   */
  public function messages() {
    return [
      // TODO: msg do endereco
      'nome.required'          => 'O campo Nome é obrigatório.',
      'sexo.required'          => 'Selecione um Sexo.',
      'email.required'         => 'O campo E-mail é obrigatório.',
      'rg.required'            => 'O campo RG é obrigatório.',
      'cpf.required'           => 'O campo CPF é obrigatório.',
      'dt_nascimento.required' => 'O campo Data de Nascimento é obrigatório.',
      'nome_pai.required'      => 'O campo Nome Completo do Pai é obrigatório.',
      'nome_mae.required'      => 'O campo Nome Completo da Mãe é obrigatório.',
      'estado_civil.required'  => 'O campo Estado Civil é obrigatório.',

      'end_cep.required'        => 'O campo CEP do Endereço é obrigatório.',
      'end_logradouro.required' => 'O campo Logradouro do Endereço é obrigatório.',
      'end_numero.required'     => 'O campo Número do Endereço é obrigatório.',
      'end_bairro.required'     => 'O campo Bairro do Endereço é obrigatório.',
      'end_cidade.required'     => 'O campo Cidade do Endereço é obrigatório.',
      'end_estado.required'     => 'Selecione um Estado do Endereço.',

      'teste_mbti.required' => 'O campo Teste MBTI é obrigatório.',
      'inativo.required'    => 'O campo Inativo é obrigatório.',
      'regime.required'     => 'O campo Regime é obrigatório.',
      'hr_entrada.required' => 'O campo Horário do Expediente Entrada é obrigatório.',
      'hr_saida.required'   => 'O campo Horário do Expediente Saida é obrigatório.',

      'departamentos_id.required' => 'Selecione um Departamento.',

      'hist_data.required'        => 'O campo Data de Contratação é obrigatório.',
      'hist_cargo.required'       => 'Selecione um Cargo de Contratação.',
      'hist_nivel.required'       => 'Selecione um Nível de Contratação.',
      'hist_salario.required'     => 'O campo Salário de Contratação é obrigatório.',
      'hist_vr.required'          => 'O campo Vale Refeição de Contratação é obrigatório.',
      'hist_vt.required'          => 'O campo Vale Transporte de Contratação é obrigatório.',
      'hist_seguro_vida.required' => 'Selecione um Seguro de Vida de Contratação.',
    ];
  }
}
