<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class JobRequest extends FormRequest {
  /**
   * Determine if the user is authorized to make this request.
   *
   * @return bool
   */
  public function authorize() {
    return true;
  }

  /**
   * Retorna o valor do input, se caso vazio ("") retorna null ou default.
   *
   * @param string $key
   * @param null $default
   * @return mixed|string|null
   */
  public function getOrNull( $key, $default = null ) {
    $valor = $this->get( $key, '' );
    if ( empty( $valor ) || trim( $valor ) === '' ) {
      return $default;
    }

    return $valor;
  }

  /**
   * Get the validation rules that apply to the request.
   *
   * @return array
   */
  public function rules() {
    // so salvando ou retrocedendo
    if (
      $this->get( 'BTN_submit' ) == 'save' ||
      $this->get( 'BTN_submit' ) == 'back' ||
      $this->get( 'tipo_submit' ) == 'save' ||
      $this->get( 'tipo_submit' ) == 'back'
    ) {
      return [];
    }

    // enviando para o proximo Stage
    $etapa = $this->get( 'JOB_ETAPA_ATUAL' );
    switch ( $etapa ) {
      case 'START':
        return [
          'nome_job'              => 'required|string',
          'cliente_unidd_id'      => 'required|integer',
          'cliente_cdc_id'        => 'required|integer',
          'campanha_id'           => 'nullable|integer',
          'cod_receita'           => 'required|integer',
          'descricao_evento'      => 'nullable|string',
          'previsao_proposta'     => 'required|string',
          'previsao_entrega_date' => 'required|string',
          'previsao_entrega_time' => 'required|string',
        ];
      case 'A':
        return [
          // Info
          'info_nome_job'              => 'required|string',
          'info_cliente_unidd_id'      => 'required|integer',
          'info_cliente_cdc_id'        => 'required|integer',
          'info_campanha_id'           => 'nullable|integer',
          'info_cod_receita'           => 'required|integer',
          'info_descricao_evento'      => 'nullable|string',
          'info_previsao_proposta'     => 'required|string',
          'info_previsao_entrega_date' => 'required|string',
          'info_previsao_entrega_time' => 'required|string',

          // Briefing Livre
          'briefing_livre'             => 'nullable|string',
        ];
      case 'B':
        return [
          // Info
          'info_nome_job'              => 'required|string',
          'info_cliente_unidd_id'      => 'required|integer',
          'info_cliente_cdc_id'        => 'required|integer',
          'info_campanha_id'           => 'nullable|integer',
          'info_cod_receita'           => 'required|integer',
          'info_descricao_evento'      => 'nullable|string',
          'info_previsao_proposta'     => 'required|string',
          'info_previsao_entrega_date' => 'required|string',
          'info_previsao_entrega_time' => 'required|string',

          // Condicao de Pagamento
          'condpagto'                  => 'required|string',
          'condpagto_obs'              => 'nullable|string',
        ];

      case 'C':
        return [
          // Info
          'info_nome_job'              => 'required|string',
          'info_cliente_unidd_id'      => 'required|integer',
          'info_cliente_cdc_id'        => 'required|integer',
          'info_campanha_id'           => 'nullable|integer',
          'info_cod_receita'           => 'required|integer',
          'info_descricao_evento'      => 'nullable|string',
          'info_previsao_proposta'     => 'required|string',
          'info_previsao_entrega_date' => 'required|string',
          'info_previsao_entrega_time' => 'required|string',

          // Aprovacao da Diretoria
          'aprov_diretoria'            => 'required|integer',
          'aprov_diretoria_obs'        => 'nullable|string',
        ];
      case 'D':
        return [
          // Info
          'info_nome_job'              => 'required|string',
          'info_cliente_unidd_id'      => 'required|integer',
          'info_cliente_cdc_id'        => 'required|integer',
          'info_campanha_id'           => 'nullable|integer',
          'info_cod_receita'           => 'required|integer',
          'info_descricao_evento'      => 'nullable|string',
          'info_previsao_proposta'     => 'required|string',
          'info_previsao_entrega_date' => 'required|string',
          'info_previsao_entrega_time' => 'required|string',

          // Aprovacao do Cliente
          'aprov_cliente'              => 'required|integer',
        ];
      case 'E':
        return [

        ];
      case 'F':
        return [

        ];
      case 'G':
        return [

        ];
      case 'Z':
        return [

        ];
      default:
        dd( 'DEU RUIM > JobRequest.rules' );

    }
    return dd( 'DEU RUIM > JobRequest.rules' );
  }

  /**
   * Mensagens de erros amigaveis.
   *
   * @return array
   */
  public function messages() {
    return [
      // START
      'nome_job.required'                   => 'O campo Nome da Campanha é obrigatório.',
      'nome_job.max'                        => 'O campo Nome da Campanha é de no máximo 255 caracteres.',
      'cliente_unidd_id.required'           => 'O campo Cliente é obrigatório.',
      'cliente_cdc_id.required'             => 'O campo Centro de Custo do Cliente é obrigatório.',
      'cod_receita.required'                => 'O campo Código de Receita é obrigatório.',
      'descricao_evento.required'           => 'O campo Descrição do Evento é obrigatório.',
      'descricao_evento.max'                => 'O campo Descrição do Evento é de no máximo 255 caracteres.',
      'previsao_proposta.required'          => 'O campo Previsão da Entrega da Proposta é obrigatório.',
      'previsao_entrega_date.required'      => 'O campo Data da Previsão da Entrega do Material é obrigatório.',
      'previsao_entrega_time.required'      => 'O campo Horário da Previsão da Entrega do Material é obrigatório.',

      // START
      'info_nome_job.required'              => 'O campo Nome da Campanha é obrigatório.',
      'info_nome_job.max'                   => 'O campo Nome da Campanha é de no máximo 255 caracteres.',
      'info_cliente_unidd_id.required'      => 'O campo Cliente é obrigatório.',
      'info_cliente_cdc_id.required'        => 'O campo Centro de Custo do Cliente é obrigatório.',
      'info_cod_receita.required'           => 'O campo Código de Receita é obrigatório.',
      'info_descricao_evento.required'      => 'O campo Descrição do Evento é obrigatório.',
      'info_descricao_evento.max'           => 'O campo Descrição do Evento é de no máximo 255 caracteres.',
      'info_previsao_proposta.required'     => 'O campo Previsão da Entrega da Proposta é obrigatório.',
      'info_previsao_entrega_date.required' => 'O campo Data da Previsão da Entrega do Material é obrigatório.',
      'info_previsao_entrega_time.required' => 'O campo Horário da Previsão da Entrega do Material é obrigatório.',

      // B Financeiro
      'condpagto.required'                  => 'O campo Condição de Pagamento é obrigatório.',

      // C Aprovacao da Diretoria
      'aprov_diretoria.required'            => 'Selecione um item em Aprovação da Diretoria.',
      'aprov_diretoria_orc_id.required'     => 'Selecione um item em Orçamento Aprovado.',

      // D Aprovacao do Cliente
      'aprov_cliente.required'              => 'Selecione um item em Aprovação do Cliente.',
    ];
  }
}
