<?php

namespace App;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Str;
use Kyslik\ColumnSortable\Sortable;

/**
 * Trait ListagemPadronizada
 *
 * Unificando e padronizando as Listagens de itens do Financeiro com Paginação, Busca e Ordenação
 *
 * @package App
 */
trait ListagemPadronizada {
  use Sortable;

  // Tipos do formulário
  public static $LB_TYPE_TEXT       = 'text';
  public static $LB_TYPE_SELECT     = 'select';
  public static $LB_TYPE_DATE_RANGE = 'date_range';

  // Defaults
  public static $LB_SORTABLE_DEFAULT = [ 'data' => 'desc' ];
  public static $LB_PAGINATE_DEFAULT = 15;

  /**
   * @param \Illuminate\Database\Eloquent\Builder $query
   * @param array $indexSearch
   * @return \Illuminate\Pagination\LengthAwarePaginator|static[]
   */
  public static function listarPaginadoBuscavelOrdenavel( Builder $query, array $indexSearch ) {

    // Pesquisa de Texto
    $text = \Request::get( 'search', '' );
    if ( $text !== '' ) {
      $query->where( function ( Builder $q ) use ( $text, $indexSearch ) {
        foreach ( $indexSearch[ 'search_text' ][ 'fields' ] as $field ) {
          if ( Str::contains( $field, '.' ) ) {
            $relation = explode( '.', $field );
            $q->orWhereHas( $relation[ 0 ], function ( $q2 ) use ( $text, $relation ) {
              $q2->where( $relation[ 1 ], 'like', '%' . $text . '%' );
            } );
          } else {
            $q->orWhere( $field, 'like', '%' . $text . '%' );
          }
        }
      } );
    }

    // Pesquisa Avançada
    foreach ( $indexSearch[ 'search_advanced' ] as $key => $item ) {
      $text = \Request::get( $key, '' );

      if ( self::$LB_TYPE_TEXT === $item[ 'type' ] && $text !== '' ) {
        // Text
        $query->where( $key, 'like', '%' . $text . '%' );

      } elseif ( self::$LB_TYPE_SELECT === $item[ 'type' ] && $text !== '' ) {
        // Select
        $query->where( $key, '=', $text );

      } elseif ( self::$LB_TYPE_DATE_RANGE === $item[ 'type' ] ) {
        // Data Range
        foreach ( [ '_after' => '>=', '_before' => '<=' ] as $suffix => $operation ) {
          $text = \Request::get( $key . $suffix, '' );
          if ( $text !== '' ) {
            $query->where( $key, $operation, $text );
          }
        }
      }
    }

    // dd( \Request::all(), $indexSearch, $query->toSql(), $query->getBindings(), $query->get() );

    return $query
      ->sortable( self::$LB_SORTABLE_DEFAULT )
      ->paginate( self::$LB_PAGINATE_DEFAULT );
  }

  abstract public static function IndexSearchMap() : array;
  /*
    return [
      'search_text'     => [
        'fields' => [ 'name', 'Funcionario.nome' ],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'field_text'   => [
          'type'        => self::$FLS_TYPE_TEXT,
          'label'       => 'Texto:'
          'placeholder' => 'Digite algo'
        ],
        'field_select' => [
          'type'    => self::$FLS_TYPE_SELECT,
          'label'   => 'Selecione:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'field_dates'  => [
          'type'         => self::$FLS_TYPE_DATE_RANGE,
          'label_after'  => 'Data após:',
          'label_before' => 'Data antes de:',
        ]
      ],
    ];
   */
}
