<?php

namespace App\Models\Cadastros;

use App\Models\Financeiro\ContaDeConsumo;
use App\Models\Financeiro\ContaFornecedor;
use App\Models\Financeiro\Ferias;
use App\Models\Financeiro\Salario;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\CentrosDeCustoCadaris
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\ContaDeConsumo[] $ContaDeConsumos
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\ContaFornecedor[] $ContaFornecedores
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\Ferias[] $Ferias
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\Salario[] $Salarios
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\CentrosDeCustoCadaris whereCodigo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\CentrosDeCustoCadaris whereConta( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\CentrosDeCustoCadaris whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\CentrosDeCustoCadaris whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\CentrosDeCustoCadaris whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\CentrosDeCustoCadaris whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class CentrosDeCustoCadaris extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'cadastro_centros_de_custo_cadaris';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome'
  ];

  /**
   * Retorna o codigo e o nome da empresa (00.00 - nome).
   *
   * @return string
   */
  public function getCodigoNome() {
    return sprintf( '05.%02d - %s', $this->codigo, $this->nome );
  }

  /**
   * Retorna o codigo e o nome da empresa (00.00 - nome).
   *
   * @return array
   */
  public static function enum_centros_de_custo_cadaris() {
    $dados = [];
    /** @var CentrosDeCustoCadaris $centro */
    foreach ( CentrosDeCustoCadaris::orderBy( 'codigo' )->get() as $centro ) {
      $dados[ $centro->id ] = $centro->getCodigoNome();
    }

    return $dados;
  }

  /**
   * Json para a TreeView.
   *
   * @return string
   */
  public static function despesas_treeView() {
    $contas = [];

    foreach ( CentrosDeCustoCadaris::orderBy( 'codigo' )->get() as $conta ) {
      /** @var CentrosDeCustoCadaris $conta */
      $contas[] = [
        'text' => $conta->getCodigoNome(),
        'href' => route( 'cadastros.centrosdecustocadaris.edit', $conta->id ),
      ];
    }

    return json_encode( $contas );
  }

  /**
   * Retorna os ContaDeConsumos do CentrosDeCustoCadaris.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Illuminate\Database\Eloquent\Builder
   */
  public function ContaDeConsumos() {
    return $this->hasMany( ContaDeConsumo::class, 'financeiro_cc_cdcc_fk' );
  }

  /**
   * Retorna os ContaFornecedores do CentrosDeCustoCadaris.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Illuminate\Database\Eloquent\Builder
   */
  public function ContaFornecedores() {
    return $this->hasMany( ContaFornecedor::class, 'financeiro_cf_cdcc_fk' );
  }

  /**
   * Retorna os Salarios do CentrosDeCustoCadaris.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Illuminate\Database\Eloquent\Builder
   */
  public function Salarios() {
    return $this->hasMany( Salario::class, 'financeiro_fs_cdcc_fk' );
  }

  /**
   * Retorna as Ferias do CentrosDeCustoCadaris.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Illuminate\Database\Eloquent\Builder
   */
  public function Ferias() {
    return $this->hasMany( Ferias::class, 'financeiro_ff_cdcc_fk' );
  }
}
