<?php

namespace App\Models\Cadastros;

use App\Models\Comercial\Jobs;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\ClientesCentrosDeCustos
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @property int $clientes_empresas_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\ClientesContas[] $Contas
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\ClientesCentrosDeCustosContatos[] $Contatos
 * @property-read \App\Models\Cadastros\ClientesEmpresas $Empresa
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\Jobs[] $Jobs
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesCentrosDeCustos whereClientesEmpresasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesCentrosDeCustos whereCodigo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesCentrosDeCustos whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesCentrosDeCustos whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesCentrosDeCustos whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesCentrosDeCustos whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class ClientesCentrosDeCustos extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'clientes_centros_de_custos';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome'
  ];

  /**
   * Retorna o codigo e o nome da empresa (00.00 - nome).
   *
   * @return string
   */
  public function getCodigoNome() {
    $emp = $this->Empresa;
    return sprintf( '%d.%d - %s', $emp->codigo, $this->codigo, $this->nome );
  }

  /**
   * Retorna os Contas do ClientesCentrosDeCustos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Illuminate\Database\Eloquent\Builder
   */
  public function Contas() {
    return $this->hasMany( ClientesContas::class );
  }

  /**
   * Retorna a Empresa do ClientesCentrosDeCustos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Empresa() {
    return $this->belongsTo( ClientesEmpresas::class, 'clientes_empresas_id' );
  }

  /**
   * Retorna os Contatos do ClientesCentrosDeCustos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Contatos() {
    return $this->hasMany( ClientesCentrosDeCustosContatos::class );
  }

  /**
   * Retorna os Contatos do ClientesCentrosDeCustos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Jobs() {
    return $this->hasMany( Jobs::class, 'cliente_id' );
  }
}
