<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\ClientesContas
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @property int $clientes_centros_de_custos_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\ClientesCentrosDeCustos $CentroDeCusto
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesContas whereClientesCentrosDeCustosId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesContas whereCodigo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesContas whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesContas whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesContas whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesContas whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class ClientesContas extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'clientes_contas';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome'
  ];

  /**
   * Retorna o codigo e o nome da empresa (00.00.00 - nome).
   *
   * @return string
   */
  public function getCodigoNome() {
    $cdc = $this->CentroDeCusto;
    $emp = $cdc->Empresa;

    return sprintf( '%d.%d.%d - %s', $emp->codigo, $cdc->codigo, $this->codigo, $this->nome );
  }

  /**
   * Retorna a CentroDeCusto do ClientesContas.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function CentroDeCusto() {
    return $this->belongsTo( ClientesCentrosDeCustos::class, 'clientes_centros_de_custos_id' );
  }
}
