<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\ClientesEmpresasUnidades
 *
 * @property int $id
 * @property string $nome
 * @property int $clientes_empresas_id
 * @property string $cnpj
 * @property string $razao_social
 * @property string $inscr_estadual
 * @property string $inscr_municipal
 * @property int $condpagamento_dias
 * @property string $condpagamento
 * @property int $bancario_banco
 * @property string $bancario_agencia
 * @property string $bancario_conta
 * @property string $end_cep
 * @property string $end_logradouro
 * @property string $end_numero
 * @property string $end_complemento
 * @property string $end_bairro
 * @property string $end_cidade
 * @property string $end_estado
 * @property mixed $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\ClientesEmpresas $Empresa
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereBancarioAgencia( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereBancarioBanco( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereBancarioConta( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereClientesEmpresasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereCnpj( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereCondpagamentoDias( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereCondpagamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndBairro( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndCep( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndCidade( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndComplemento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndEstado( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndLogradouro( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereEndNumero( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereInscrEstadual( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereInscrMunicipal( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereRazaoSocial( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ClientesEmpresasUnidades whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class ClientesEmpresasUnidades extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'clientes_empresas_unidades';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',

    'cnpj',
    'razao_social',
    'inscr_estadual',
    'inscr_municipal',
    'condpagamento_dias',
    'condpagamento',

    'bancario_banco',
    'bancario_agencia',
    'bancario_conta',

    'end_cep',
    'end_logradouro',
    'end_numero',
    'end_complemento',
    'end_bairro',
    'end_cidade',
    'end_estado',

    'obs',
  ];

  /**
   * Retorna os Empresas do ClientesEmpresasUnidades.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Empresa() {
    return $this->belongsTo( ClientesEmpresas::class, 'clientes_empresas_id' );
  }

  /**
   * Retorna o codigo e o nome da empresa (00 - nome).
   *
   * @return string
   */
  public function getCodigoNome() {
    $empresa = $this->Empresa;

    return sprintf( '%d - %s', $empresa->codigo, $this->nome );
  }

  /**
   * Retorna o Endereço completo desta Unidade.
   *
   * @return string
   */
  public function _EnderecoCompleto() {
    return $this->end_logradouro
      . ', '
      . $this->end_numero
      . ', '
      . ( $this->end_complemento != '' ? $this->end_complemento . ', ' : '' )
      . $this->end_bairro
      . ', '
      . $this->end_cidade
      . ' - '
      . $this->end_estado
      . ', '
      . $this->end_cep;
  }
}
