<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\CodigoReceita
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Cadastros\CodigoReceita whereCodigo( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Cadastros\CodigoReceita whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Cadastros\CodigoReceita whereNome( $value )
 * @mixin \Eloquent
 */
class CodigoReceita extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'cadastro_codigo_receitas';

  public $timestamps = false;

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome'
  ];

  public static function enum_cod_receita() {
    $enum = [];
    foreach ( self::orderBy( 'codigo' )->get() as $receita ) {
      $enum[ $receita->codigo ] = $receita->getCodigoNome();
    }

    return $enum;
  }

  /**
   * Retorna o CodigoNome de uma receita
   *
   * @param int $cod
   * @return string
   */
  public static function getCodReceitaNome( $cod ) {
    return !( $receita = self::whereCodigo( $cod )->first() ) ?
      'Sem Código de Receita' :
      $receita->getCodigoNome();
  }

  /**
   * Retorna o Codigo da Receita formatado
   *
   * @return string
   */
  public function getCodigoNome() {
    return sprintf( '%s %s', $this->codigo, $this->nome );
  }
}
