<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\ControleDePontos
 *
 * @property int $id
 * @property bool $tipo
 * @property string $data
 * @property string $horas
 * @property int $funcionarios_id
 * @property int $aprovador_id
 * @property string $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\Funcionarios $Aprovador
 * @property-read \App\Models\Cadastros\Funcionarios $Funcionario
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereAprovadorId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereFuncionariosId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereHoras( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereTipo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\ControleDePontos whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class ControleDePontos extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'controle_de_pontos';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'tipo',
    'data',
    'horas',
    'funcionarios_id',
    'aprovador_id',
    'obs'
  ];

  /**
   * Atraso desconta dno banco de horas.
   */
  const ATRASO = 1;

  /**
   * Falta descontada no Banco de Horas.
   */
  const FALTA_BANCO = 2;

  /**
   * Fala descontada no Salário.
   */
  const FALTA_DESCONTADA = 3;

  /**
   * Falta com Atestado.
   */
  const FALTA_ATESTADO = 4;

  /**
   * Folga descontada no banco de horas.
   */
  const FOLGA_BANCO = 5;

  /**
   * Folga Abonada.
   */
  const FOLGA_ABONADA = 6;

  /**
   * Hora extra no banco de horas.
   */
  const HORA_EXTRA_BANCO = 7;

  /**
   * Hora Extra remunerada.
   */
  const HORA_EXTRA_REMUNERADA = 8;

  /**
   * Gozo de férias.
   */
  const GOZO_DE_FERIAS = 9;

  /**
   * HOme Office.
   */
  const HOME_OFFICE = 10;

  /**
   * Enumerador dos tipos de eventos.
   */
  public static function enum_tipos() {
    return [
      ControleDePontos::ATRASO                => 'Atraso',
      ControleDePontos::FALTA_BANCO           => 'Falta',
      ControleDePontos::FALTA_DESCONTADA      => 'Falta Descontado',
      ControleDePontos::FALTA_ATESTADO        => 'Falta com Atestado',
      ControleDePontos::FOLGA_BANCO           => 'Folga',
      ControleDePontos::FOLGA_ABONADA         => 'Folga Abonada',
      ControleDePontos::HORA_EXTRA_BANCO      => 'Hora Extra',
      ControleDePontos::HORA_EXTRA_REMUNERADA => 'Hora Extra Remunerada',
      ControleDePontos::GOZO_DE_FERIAS        => 'Gozo de Férias',
      ControleDePontos::HOME_OFFICE           => 'Home Office',
    ];
  }

  /**
   * Enumerador das corres do background do evento no FullCalendar.
   */
  public static function enum_tipos_backgroundColor() {
    return [
      ControleDePontos::ATRASO                => '#fcf8e3', // Atraso = bg-warning
      ControleDePontos::FALTA_BANCO           => '#fcf8e3', // Falta = bg-warning
      ControleDePontos::FALTA_DESCONTADA      => '#f2dede', // Falta banco = bg-danger
      ControleDePontos::FALTA_ATESTADO        => '#d9edf7', // Falta com Atestado = bg-info
      ControleDePontos::FOLGA_BANCO           => '#fcf8e3', // Folga = bg-warning
      ControleDePontos::FOLGA_ABONADA         => '#d9edf7', // Folga Abonada = bg-info
      ControleDePontos::HORA_EXTRA_BANCO      => '#dff0d8', // Hora Extra = bg-success
      ControleDePontos::HORA_EXTRA_REMUNERADA => '#dff0d8', // Hora Extra Remunerada = bg-success
      ControleDePontos::GOZO_DE_FERIAS        => '#d9edf7', // Gozo de férias = bg-info
      ControleDePontos::HOME_OFFICE           => '#d9edf7', // Home Office = bg-info
    ];
  }

  /**
   * Retorna o Funcionario deste ControleDePonto.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class );
  }

  /**
   * Retorna o Funcionario Aprovador deste ControleDePonto.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Aprovador() {
    return $this->belongsTo( Funcionarios::class );
  }
}
