<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;
use Kyslik\ColumnSortable\Sortable;

/**
 * App\Models\Cadastros\Departamentos
 *
 * @property int $id
 * @property string $nome
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\Funcionarios[] $Funcionarios
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Departamentos sortable( $defaultSortParameters = null )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Departamentos whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Departamentos whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Departamentos whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Departamentos whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class Departamentos extends Model {
  use Sortable;
  /**
   * metodos de Sortable e quais colunas são ordenaveis.
   *
   * @var array
   */
  public $sortable = [ 'id', 'nome' ];

  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'departamentos';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome'
  ];

  /**
   * Retorna o enumerador dinamico ordenado dos Departamentos cadastrados.
   *
   * @return array
   */
  public static function enum_Departamentos() {
    $dep = [];
    foreach ( Departamentos::all()->sortBy( 'nome' ) as $d ) {
      $dep[ $d->id ] = $d->nome;
    }

    return $dep;
  }

  /**
   * Retorna os Funcionario do Departamento.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Funcionarios() {
    return $this->hasMany( Funcionarios::class );
  }
}
