<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\FornecedoresDespesas
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FornecedoresServicosProdutos[] $ServicosProdutos
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresDespesas whereCodigo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresDespesas whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresDespesas whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresDespesas whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresDespesas whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class FornecedoresDespesas extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'fornecedores_despesas';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome',
  ];

  /**
   * Enumerados das Despesas disponiveis (id => "codigo - nome").
   *
   * @return array
   */
  public static function enum_despesas() {
    $despesas = [];
    foreach ( FornecedoresDespesas::all()->sortBy( 'codigo' ) as $d ) {
      $despesas[ $d->id ] = sprintf( '%d - %s', $d->codigo, $d->nome );
    }

    return $despesas;
  }

  /**
   * "codigo - nome" desta Despesa.
   *
   * @return string
   */
  public function getCodigoNome() {
    return sprintf( '%d - %s', $this->codigo, $this->nome );
  }

  /**
   * Retorna a Servicos e Produtos desta Despesa
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ServicosProdutos() {
    return $this->hasMany( FornecedoresServicosProdutos::class, 'fornecedores_despesas_id' );
  }
}
