<?php

namespace App\Models\Cadastros;

use App\Models\Financeiro\ContaFornecedor;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\FornecedoresEmpresas
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @property string $cnpj
 * @property string $razao_social
 * @property string $inscr_estadual
 * @property string $inscr_municipal
 * @property string $condpagamento
 * @property int $bancario_banco
 * @property string $bancario_agencia
 * @property string $bancario_conta
 * @property bool $nota_geral
 * @property bool $nota_qualidade
 * @property bool $nota_atendimento
 * @property bool $nota_prazo
 * @property mixed $nota_obs
 * @property mixed $nota_recomendacao
 * @property mixed $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\ContaFornecedor[] $ContasDesteFornecedor
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FornecedoresEmpresasEnderecos[] $Enderecos
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FornecedoresServicosProdutos[] $ServicosProdutos
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereBancarioAgencia( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereBancarioBanco( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereBancarioConta( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereCnpj( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereCodigo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereCondpagamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereInscrEstadual( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereInscrMunicipal( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNotaAtendimento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNotaGeral( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNotaObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNotaPrazo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNotaQualidade( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereNotaRecomendacao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereRazaoSocial( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresEmpresas whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class FornecedoresEmpresas extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'fornecedores_empresas';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome',

    'cnpj',
    'razao_social',
    'inscr_estadual',
    'inscr_municipal',
    'condpagamento',

    'nota_geral',
    'nota_qualidade',
    'nota_atendimento',
    'nota_prazo',
    'nota_obs',
    'nota_recomendacao',

    // DADOS BANCARIOS
    'bancario_banco',
    'bancario_agencia',
    'bancario_conta',

    'obs'
  ];

  /**
   * Retorna o Codigo - Nome do FornecedoresEmpresas.
   *
   * @return string
   */
  public function getCodigoNome() {
    return sprintf( '%02d - %s', $this->codigo, $this->nome );
  }

  /**
   * Enumerador dos FornecedoresEmpresas
   *
   * @return array
   */
  public static function enum_fornecedores() {
    $forn = [];
    //$forn[ '' ] = '-- Criar nova Empresa --';
    foreach ( FornecedoresEmpresas::all()->sortBy( 'codigo' ) as $f ) {
      $forn[ $f->id ] = sprintf( '%02d - %s', $f->codigo, $f->nome );
    }

    return $forn;
  }

  /**
   * Enumerador dos FornecedoresEmpresas e Servicos
   *
   * @return array
   */
  public static function enum_fornecedores_servicos() {
    $forn = [];
    /** @var FornecedoresEmpresas[] $fornecedores */
    $fornecedores = FornecedoresEmpresas::all()->sortBy( 'codigo' );
    foreach ( $fornecedores as $f ) {
      $serv = [];
      /** @var FornecedoresServicosProdutos $s */
      foreach ( $f->ServicosProdutos->sortBy( 'codigo' ) as $s ) {
        $serv [ $s->id ] = $s->getCodigoNome();
      }
      $forn[ $f->getCodigoNome() ] = $serv;
    }

    return $forn;
  }

  /**
   * Enumerador das notas de classificacao da FornecedorEmpresa
   *
   * @return array
   */
  public static function enum_notas() {
    return [
      '4' => '4 - Muito Satisfeito',
      '3' => '3 - Satisfeito',
      '2' => '2 - Insatisfeito',
      '1' => '1 - Muito Insatisfeito'
    ];
  }


  /**
   * retorna a media das notas da classificacao do FornecedorEmpresa
   *
   * @return float
   */
  public function getNotaMedia() {
    return ( $this->nota_geral + $this->nota_qualidade + $this->nota_atendimento + $this->nota_prazo ) / 4;
  }


  /**
   * Retorna os Servicos e Produtos do FornecedoresEmpresas.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Eloquent
   */
  public function ServicosProdutos() {
    return $this->hasMany( FornecedoresServicosProdutos::class, 'fornecedores_empresas_id' );
  }


  /**
   * Retorna os Enderecos do FornecedoresEmpresa.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Enderecos() {
    return $this->hasMany( FornecedoresEmpresasEnderecos::class );
  }

  /**
   * Retorna as Contas deste Fornecedor Empresa.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ContasDesteFornecedor() {
    return $this->hasMany( ContaFornecedor::class, 'fornecedor_id' );
  }

}
