<?php

namespace App\Models\Cadastros;

use App\Models\Comercial\OrcamentoItemCOServico;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\FornecedoresServicosProdutos
 *
 * @property int $id
 * @property int $codigo
 * @property string $nome
 * @property int $fornecedores_despesas_id
 * @property int $fornecedores_empresas_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FornecedoresServicosProdutosContatos[] $Contatos
 * @property-read \App\Models\Cadastros\FornecedoresDespesas $Despesa
 * @property-read \App\Models\Cadastros\FornecedoresEmpresas $Empresa
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\OrcamentoItemCOServico[] $OrcamentoItemCOServico
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FornecedoresTags[] $Tags
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereCodigo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereFornecedoresDespesasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereFornecedoresEmpresasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresServicosProdutos whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class FornecedoresServicosProdutos extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'fornecedores_servicos_produtos';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'codigo',
    'nome',
    'fornecedores_despesas_id'
  ];

  /**
   * Enumerador do Tipo de Despesa DEPRECATED.
   *
   * @return array
   */
  public static function enum_despesas() {
    return [
      'Balões',
      'Brindes Personalizados',
      'Cartuchos',
      'Consultoria',
      'Contabilidade',
      'Disparo E-mail marketing',
      'Doces',
      'Domínio',
      'Evento',
      'Filmagem ',
      'Filmagem / Fotografia',
      'Fotografia',
      'Gráfica',
      'Gráfica Grande Tiragem',
      'Gráfica Pequena Tiragem',
      'Gráfica Rápida',
      'Gráfica Rotativa',
      'Hospedagem',
      'Informática',
      'Livraria',
      'Locação de Sistema',
      'Papelaria',
      'Plotagem / Adesivos',
      'Programação',
      'Redação',
      'Revisão',
      'Tradução ',
      'Tradução Espanhol',
      'Tradução Inglês',
      'Transporte'
    ];
  }

  /**
   * Retorna os IDs das TAGs deste ServicoProduto.
   *
   * @return array
   */
  public function getTagsIDs() {
    $ids  = [];
    $tags = $this->Tags()->get( [ 'id' ] );
    foreach ( $tags as $tag ) {
      $ids[] = $tag->id;
    }
    return $ids;
  }

  /**
   * Retorna os Tags do FornecedoresServicosProdutos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany | \Eloquent
   */
  public function Tags() {
    return $this->belongsToMany( FornecedoresTags::class, 'fornecedores_servico_produto_tag' )->withTimestamps();
  }

  /**
   * Retorna o Codigo - Nome do Servico/Produto.
   *
   * @return string
   */
  public function getCodigoNome() {
    return sprintf( '%02d.%02d - %s', $this->Empresa->codigo, $this->codigo, $this->nome );
  }

  /**
   * Retorna o nome do Servico/Produto para exibir no Teste de Orcamento.
   *
   * @return array
   */
  public function getNomeOrcamento() {
    $emp = $this->Empresa;
    $p   = [];

    $p[ 'id' ]    = $this->id;
    $p[ 'idEmp' ] = $emp->id;
    $p[ 'text' ]  = sprintf( '%02d - %s > %02d.%02d - %s', $emp->id, $emp->nome, $emp->id, $this->id, $this->nome );

    return $p;
  }

  /**
   * Retorna a Empresa do FornecedoresServicosProdutos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Empresa() {
    return $this->belongsTo( FornecedoresEmpresas::class, 'fornecedores_empresas_id' );
  }

  /**
   * Retorna a Despesa do FornecedoresServicosProdutos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( FornecedoresDespesas::class, 'fornecedores_despesas_id' );
  }

  /**
   * Retorna a Empresa do FornecedoresServicosProdutos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Contatos() {
    return $this->hasMany( FornecedoresServicosProdutosContatos::class );
  }

  /**
   * Retorna os Orcamentos q utiliza este FornecedoresServicosProdutos.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function OrcamentoItemCOServico() {
    return $this->hasMany( OrcamentoItemCOServico::class, 'fornecedor_id' );
  }
}
