<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\FornecedoresTags
 *
 * @property int $id
 * @property string $nome
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FornecedoresServicosProdutos[] $ServicosProdutos
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresTags whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresTags whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresTags whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FornecedoresTags whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class FornecedoresTags extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'fornecedores_tags';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
  ];

  /**
   * Enumerados das TAGs disponiveis (id => nome).
   *
   * @return array
   */
  public static function enum_tags() {
    $tags = [];
    foreach ( FornecedoresTags::all()->sortBy( 'nome' ) as $t ) {
      $tags[ $t->id ] = $t->nome;
    }

    return $tags;
  }

  /**
   * Retorna a Servicos e Produtos desta Tag
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany | \Illuminate\Database\Query\Builder
   */
  public function ServicosProdutos() {
    return $this->belongsToMany( FornecedoresServicosProdutos::class, 'fornecedores_servico_produto_tag' )->withTimestamps();

  }
}
