<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\FuncHistoricos
 *
 * @property int $id
 * @property string $data
 * @property bool $tipo
 * @property bool $cargo
 * @property bool $nivel
 * @property int $salario
 * @property int $vr
 * @property int $vt
 * @property bool $seguro_vida
 * @property string $ferias_dt_inicio
 * @property string $ferias_dt_termino
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property int $funcionarios_id
 * @property-read \App\Models\Cadastros\Funcionarios $Funcionario
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereCargo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereFeriasDtInicio( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereFeriasDtTermino( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereFuncionariosId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereNivel( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereSalario( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereSeguroVida( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereTipo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereVr( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\FuncHistoricos whereVt( $value )
 * @mixin \Eloquent
 */
class FuncHistoricos extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'funcionarios_historicos';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'data',
    'tipo',
    'cargo',              //0
    'nivel',              //0
    'salario',            //1
    'vr',                 //2
    'vt',                 //3
    'seguro_vida',        //4
    'ferias_dt_inicio',   //5
    'ferias_dt_termino'   //5
  ];

  /**
   * Campos desda classe
   *
   * @return array
   */
  public static function getCampos() {
    return [ 'cargo', 'nivel', 'salario', 'vr', 'vt', 'seguro_vida', 'ferias_dt_inicio', 'ferias_dt_termino' ];
  }

  /**
   * enumerador dos tipos possiveis de Historicos
   *
   * @return array
   */
  public static function enum_historico() {
    return [
      'Contratação', // 0
      'Demissâo', // 1
      'Mérito', // 2
      'Dissídio', // 3
      'Promoção', // 4
      'Reajuste VR', // 5
      'Reajuste VT', // 6
      'Modificação do Seguro de Vida', // 7
      'Aquisição de período aquisitivo', // 8
      'Gozo de férias', // 9
    ];
  }


  /**
   * Campos referentes ao enumerador enum_historico()
   *
   * @return array
   */
  public static function enum_tipo_historico() {
    return [
      0 => [ 'cargo', 'nivel', 'salario', 'vr', 'vt', 'seguro_vida' ], //Contratação
      1 => [], //Demissâo
      2 => [ 'salario' ], //Mérito
      3 => [ 'salario' ], //Dissídio
      4 => [ 'cargo', 'nivel', 'salario' ], //Promoção
      5 => [ 'vr' ], // Reajuste VR
      6 => [ 'vt' ], //Reajuste VT
      7 => [ 'seguro_vida' ], //Modificação do Seguro de Vida
      8 => [ 'ferias_dt_inicio', 'ferias_dt_termino' ], //Aquisição de periodo aquisitivo
      9 => [ 'ferias_dt_inicio', 'ferias_dt_termino' ], //Gozo de férias
    ];
  }

  /**
   * Set null nos valores vazios ('') e retorna o array
   *
   * @param array $dados
   * @return array
   */
  public static function setNulls( array $dados ) {
    $hist = new FuncHistoricos();
    foreach ( $hist->fillable as $v ) {
      $hist->{$v} = ( $dados[ $v ] === '' ) ? null : $dados[ $v ];
    }
    return $hist->toArray();
  }

  /**
   * Retorna formatado o Cargo e o Nivel
   *
   * @param $cargo
   * @param $nivel
   * @return string
   */
  public static function getCargoNivel( $cargo, $nivel ) {
    if ( $cargo === null || $nivel === null ) {
      return '';
    }
    return FuncHistoricos::enum_cargos()[ $cargo ] . ' nível ' . FuncHistoricos::enum_DescricaoCargoNivel()[ $cargo ][ $nivel ];
  }

  /**
   * Enumerador dos cargos
   *
   * @return array
   */
  public static function enum_cargos() {
    return [ // 0          1       2                3             4
      'Administrativo', 'Arte', 'Atendimento', 'Planejamento', 'Redação'
    ];
  }

  /**
   * enumerador dos niveis de cada cargo
   *
   * @return array
   */
  public static function enum_DescricaoCargoNivel() {
    return [
      0 => [
        1  => '1 - Estagiário',
        2  => '2 - Auxiliar Administrativo',
        3  => '3 - Assistente Administrativo',
        4  => '4 - Analista Administrativo',
        5  => '5 - Analista Pleno Administrativo',
        6  => '6 - Especialista Administrativo',
        7  => '7 - Especialista Pleno Administrativo',
        8  => '8 - Especialista Master Administrativo',
        9  => '9 - Coordenador Administrativo',
        10 => '10 - Coordenador Pleno Administrativo',
        11 => '11 - Coordenador Master Administrativo',
        12 => '12 - Gerente Administrativo',
        13 => '13 - Gerente Pleno Administrativo',
        14 => '14 - Gerente Master Administrativo',
        15 => '15 - Diretor Administrativo',
        16 => '16 - Diretor Pleno Administrativo',
        17 => '17 - Diretor Executivo Administrativo' ],
      1 => [
        1  => '1 - Estagiário',
        2  => '2 - Auxiliar de Arte',
        3  => '3 - Assistente de Designer',
        4  => '4 - Designer',
        5  => '5 - Designer Pleno',
        6  => '6 - Diretor de Arte Assistente',
        7  => '7 - Diretor de Arte',
        8  => '8 - Diretor de Arte Pleno',
        9  => '9 - Coordenador de Arte',
        10 => '10 - Coordenador Pleno de Arte',
        11 => '11 - Coordenador Master de Arte',
        12 => '12 - Gerente do Depto de Arte',
        13 => '13 - Gerente Pleno do Depto de Arte',
        14 => '14 - Gerente Master do Depto de Arte',
        15 => '15 - Diretor do Depto de Arte',
        16 => '16 - Diretor Pleno do Depto de Arte',
        17 => '17 - Diretor Executivo do Depto de Arte' ],
      2 => [
        1  => '1 - Estagiário',
        2  => '2 - Auxiliar de Atendimento',
        3  => '3 - Assistente de Atendimento',
        4  => '4 - Atendimento',
        5  => '5 - Atendimento Pleno',
        6  => '6 - Especialista em Atendimento',
        7  => '7 - Especialista Pleno em Atendimento',
        8  => '8 - Especialista Master em Atendimento',
        9  => '9 - Coordenador de Atendimento',
        10 => '10 - Coordenador Pleno de Atendimento',
        11 => '11 - Coordenador Mastr de Atendimento',
        12 => '12 - Gerente do Depto de Atendimento',
        13 => '13 - Gerente Pleno do Depto de Atendimento',
        14 => '14 - Gerente Master do Depto de Atendimento',
        15 => '15 - Diretor do Depto de Atendimento',
        16 => '16 - Diretor Pleno do Depto de Atendimento',
        17 => '17 - Diretor Executivo do Depto de Atendimento' ],
      3 => [
        1  => '1 - Estagiário',
        2  => '2 - Auxiliar de Planejamento',
        3  => '3 - Assistente de Planejamento',
        4  => '4 - Planejamento',
        5  => '5 - Planejamento Pleno',
        6  => '6 - Especialista em Planejamento',
        7  => '7 - Especialista Pleno em Planejamento',
        8  => '8 - Especialista Master em Planejamento',
        9  => '9 - Coordenador de Planejamento',
        10 => '10 - Coordenador Pleno de Planejamento',
        11 => '11 - Coordenador Master de Planejamento',
        12 => '12 - Gerente do Depto de Planejamento',
        13 => '13 - Gerente Pleno do Depto de Planejamento',
        14 => '14 - Gerente Master do Depto de Planejamento',
        15 => '15 - Diretor do Depto de Planejamento',
        16 => '16 - Diretor Pleno do Depto de Planejamento',
        17 => '17 - Diretor Executivo do Depto de Planejamento' ],
      4 => [
        1  => '1 - Estagiário',
        2  => '2 - Auxiliar de Redação',
        3  => '3 - Assistente de Redação',
        4  => '4 - Redator',
        5  => '5 - Redator Pleno',
        6  => '6 - Editor Assistente',
        7  => '7 - Editor',
        8  => '8 - Editor Pleno',
        9  => '9 - Coordenador de Redação',
        10 => '10 - Coordenador Pleno de Redação',
        11 => '11 - Coordenador Master de Redação',
        12 => '12 - Gerente do Depto de Redação',
        13 => '13 - Gerente Pleno do Depto de Redação',
        14 => '14 - Gerente Master do Depto de Redação',
        15 => '15 - Diretor do Depto de Redação',
        16 => '16 - Diretor Pleno do Depto de Redação',
        17 => '17 - Diretor Executivo do Depto de Redação' ],
    ];
  }

  /**
   * Retorna o Funcionario deste Historico.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class );
  }
}
