<?php

namespace App\Models\Cadastros;

use App\Models\Config\FaixaSalarialDissidio;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Kyslik\ColumnSortable\Sortable;

/**
 * \App\Models\Cadastros\Funcionarios
 *
 * @property int $id
 * @property string $nome
 * @property string $sexo
 * @property string $email
 * @property string $rg
 * @property string $cpf
 * @property string $dt_nascimento
 * @property string $nome_pai
 * @property string $nome_mae
 * @property int $estado_civil
 * @property string|null $foto
 * @property string $end_cep
 * @property string $end_logradouro
 * @property string $end_numero
 * @property string|null $end_complemento
 * @property string $end_bairro
 * @property string $end_cidade
 * @property string $end_estado
 * @property int $teste_mbti
 * @property int $regime
 * @property string $hr_entrada
 * @property string $hr_saida
 * @property int $inativo
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property int|null $departamentos_id
 * @property int $perm_aprovador_ctl_pontos
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\ControleDePontos[] $ControleDePontoAprovacoes
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\ControleDePontos[] $ControleDePontos
 * @property-read \App\Models\Cadastros\Departamentos|null $Departamento
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FuncDependentes[] $Dependentes
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FuncHistoricos[] $Historicos
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\FuncTelefones[] $Telefones
 * @property-read \App\Models\Cadastros\Usuarios $user
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios sortable( $defaultSortParameters = null )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereCpf( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereDepartamentosId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereDtNascimento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEmail( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndBairro( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndCep( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndCidade( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndComplemento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndEstado( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndLogradouro( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEndNumero( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereEstadoCivil( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereFoto( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereHrEntrada( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereHrSaida( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereInativo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereNomeMae( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereNomePai( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios wherePermAprovadorCtlPontos( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereRegime( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereRg( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereSexo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereTesteMbti( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Funcionarios whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class Funcionarios extends Model {
  use Sortable;
  /**
   * metodos de Sortable e quais colunas são ordenaveis.
   *
   * @var array
   */
  public $sortable = [ 'id', 'nome', 'regime', 'inativo', 'departamentos_id' ];

  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'funcionarios';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'sexo',
    'email',
    'end_cep',
    'end_logradouro',
    'end_numero',
    'end_complemento',
    'end_bairro',
    'end_cidade',
    'end_estado',
    'rg',
    'cpf',
    'dt_nascimento',
    'nome_pai',
    'nome_mae',
    'estado_civil',
    'teste_mbti',
    'regime',
    'hr_entrada',
    'hr_saida',
    'inativo',
    'foto',
    'departamentos_id',
    'perm_aprovador_ctl_pontos'
  ];

  /**
   * Enumerador dos possiveis casos de Sexo
   *
   * @return array
   */
  public static function enum_sexo() {
    return [ 'F' => 'Feminino', 'M' => 'Masculino' ];
  }

  /**
   * Enumerador dos possiveis casos de Estado Civil
   *
   * @return array
   */
  public static function enum_estado_civil() {
    return [ 'Solteiro(a)', 'Casado(a)', 'Divorciado(a)', 'Viúvo(a)' ];
  }

  /**
   * Enumerador dos possiveis Estados do Brasil
   *
   * @return array
   */
  public static function enum_estado() {
    return [
      'AC' => 'Acre', 'AL' => 'Alagoas', 'AM' => 'Amazonas', 'AP' => 'Amapá',
      'BA' => 'Bahia', 'CE' => 'Ceará', 'DF' => 'Distrito Federal',
      'ES' => 'Espírito Santo', 'GO' => 'Goiás', 'MA' => 'Maranhão',
      'MT' => 'Mato Grosso', 'MS' => 'Mato Grosso do Sul',
      'MG' => 'Minas Gerais', 'PA' => 'Pará', 'PB' => 'Paraíba',
      'PR' => 'Paraná', 'PE' => 'Pernambuco', 'PI' => 'Piauí',
      'RJ' => 'Rio de Janeiro', 'RN' => 'Rio Grande do Norte',
      'RO' => 'Rondônia', 'RS' => 'Rio Grande do Sul', 'RR' => 'Roraima',
      'SC' => 'Santa Catarina', 'SE' => 'Sergipe', 'SP' => 'São Paulo',
      'TO' => 'Tocantins'
    ];
  }

  /**
   * Html Select > option dos possiveis Estados do Brasil
   *
   * @param string $id
   * @return string
   */
  public static function enum_estado_select( $id ) {
    $selected = '';
    foreach ( self::enum_estado() as $sigla => $estado ) {
      $selected .= '<option value="' . $sigla . '" ' . ( $id == $sigla ? 'selected' : '' ) . '>' . e( $estado ) . '</option>';
    }

    return $selected;
  }

  /**
   * Enumerador dos possiveis categorias do MBTI (usado no select)
   *
   * @return array
   */
  public static function enum_MBTI() {
    return [
      'Analista'   => [
        0 => 'INTJ - O Arquiteto',
        1 => 'INTP - O Lógico',
        2 => 'ENTJ - O Comandante',
        3 => 'ENTP - O Inovador'
      ],
      'Diplomata'  => [
        4 => 'INFJ - O Advogado',
        5 => 'INFP - O Mediador',
        6 => 'ENFJ - O Protagonista',
        7 => 'ENFP - O Ativista'
      ],
      'Sentinela'  => [
        8  => 'ISTJ - O Logístico',
        9  => 'ISFJ - O Defensor',
        10 => 'ESTJ - O Executivo',
        11 => 'ESFJ - O Cônsul'
      ],
      'Explorador' => [
        12 => 'ISTP - O Virtuoso',
        13 => 'ISFP - O Aventureiro',
        14 => 'ESTP - O Empreendedor',
        15 => 'ESFP - O Animador'
      ]
    ];
  }

  /**
   * Enumerador dos possiveis categorias do MBTI
   *
   * @return array
   */
  public static function enum_MBTI_string() {
    return [
      'INTJ - O Arquiteto',
      'INTP - O Lógico',
      'ENTJ - O Comandante',
      'ENTP - O Inovador',
      'INFJ - O Advogado',
      'INFP - O Mediador',
      'ENFJ - O Protagonista',
      'ENFP - O Ativista',
      'ISTJ - O Logístico',
      'ISFJ - O Defensor',
      'ESTJ - O Executivo',
      'ESFJ - O Cônsul',
      'ISTP - O Virtuoso',
      'ISFP - O Aventureiro',
      'ESTP - O Empreendedor',
      'ESFP - O Animador'
    ];
  }

  /**
   * Enumerador dos possiveis categorias do MBTI
   *
   * @return string
   */
  public function _MBTI() {
    return Funcionarios::enum_MBTI_string()[ $this->teste_mbti ];
  }

  public static function enum_Funcionarios() {
    $funcs = [];
    foreach ( Funcionarios::all()->sortBy( 'nome' ) as $f ) {
      $funcs[ $f->id ] = $f->nome;
    }

    return $funcs;
  }

  public static function possiveis_aprovadores() {
    // TODO: somente funcionarios de alto nivel
    $funcs = [];
    foreach ( Funcionarios::wherePermAprovadorCtlPontos( 1 )->orderBy( 'nome' )->get() as $f ) {
      $funcs[ $f->id ] = $f->nome;
    }

    return $funcs;
  }

  /**
   * Enumerador dos possiveis Regimes
   *
   * @return array
   */
  public static function enum_regime() {
    return [ 'CLT', 'Estágio', 'Freela', 'Pró-labore' ];
  }

  /**
   * Retorna um Telefone do Funcionario.
   *
   * @return String | ''
   */
  public function getUmTelefone() {
    $tel = $this->Telefones()->where( 'recado', '0' )->first();

    return $tel == null ? '' : $tel->telefone;
  }

  /**
   * Retorna o valor do Regime
   *
   * @return array
   */
  public function getRegimeString() {
    return Funcionarios::enum_regime()[ $this->regime ];
  }

  /**
   * Retorna o empilhamento dos historicos, descobrindo sua ultima situacao.
   *
   * @return array
   */
  public function pilhaHistorico() {
    $topo   = [];//new FuncHistoricos();
    $hist   = $this->Historicos()->orderBy( 'data', 'ASC' )->get();
    $campos = FuncHistoricos::enum_tipo_historico();
    $pilha  = [ 'cargo', 'nivel', 'salario', 'vr', 'vt', 'seguro_vida', 'ferias_dt_inicio', 'ferias_dt_termino', 'dataContratacao', 'dataDemissao', 'aquisitivo_inicio', 'aquisitivo_termino' ];
    foreach ( $pilha as $c ) {
      $topo[ $c ] = null;
    }
    foreach ( $hist as $h ) {
      foreach ( $campos[ $h->tipo ] as $c ) {
        if ( $h->{$c} !== null ) {
          $topo[ $c ] = $h->{$c};
        }
      }
      if ( $h->tipo === 0 ) { // contratacao
        $topo[ 'dataContratacao' ] = $h->data;
      } elseif ( $h->tipo === 1 ) { // demissao
        $topo[ 'dataDemissao' ] = $h->data;
      } elseif ( $h->tipo === 8 ) { // ultimo periodo aquisitivo
        $topo[ 'aquisitivo_inicio' ]  = $h->ferias_dt_inicio;
        $topo[ 'aquisitivo_termino' ] = $h->ferias_dt_termino;
      }
    }
    $topo[ 'numHist' ] = $this->Historicos()->count();

    return $topo;
  }

  public function jaTeveDissidioEsteAno() {
    $hist = $this->Historicos()->where( 'tipo', '3' )->where( 'data', '>=', Carbon::now()->year . '-01-01' )->get();
    // verifica se ja teve dissidio neste ano e retorna
    if ( count( $hist ) > 0 ) {
      return true;
    }

    return false;
  }

  /**
   * Verifica e calcula o dissido do Funcionario
   *
   * @return  array
   */
  public function calcDissidio() {
    // codigo
    // 1 OK
    // 2 func nao encontrado
    // 3 ja tem
    // 4 nao tem salario (null)
    // 5 nao tem dissidio cadastrado

    // array a ser retornado
    $resp = [
      'codigo'      => 0,
      'mensagem'    => '',
      'salOrig'     => 0,
      'regra'       => 0,
      'porc'        => 0,
      'salAjust'    => 0,
      'dissInteiro' => true,
    ];

    // get este ano
    $dt = Carbon::today();

    // get Func
    $func = $this;
    // verifica se ele existe
    if ( $func == null ) {
      $resp[ 'codigo' ]   = 2;
      $resp[ 'mensagem' ] = 'Funcionário não encontrado';

      return $resp;
    }

    // lista FuncHist somente Dissido deste ano
    $hist = $func->Historicos()->where( 'tipo', '3' )->where( 'data', '>=', $dt->year . '-01-01' )->get();
    // verifica se ja teve dissidio neste ano e retorna
    if ( count( $hist ) > 0 ) {
      $resp[ 'codigo' ]   = 3;
      $resp[ 'mensagem' ] = 'Já houve Dissídio para este Funcionário neste ano!';

      return $resp;
    }

    // gt o empilhamento de seu historicos
    $pilhaH = $func->pilhaHistorico();
    // get salario
    $sal = $pilhaH[ 'salario' ];
    // verifica se tem um salario atual
    if ( $sal === 0 || $sal === null ) {
      $resp[ 'codigo' ]   = 4;
      $resp[ 'mensagem' ] = 'Não há um salário atual definido para aplicar Dissídio.';

      return $resp;
    }

    // get dissidio deste ano
    $diss = FaixaSalarialDissidio::where( 'ano', $dt->year )->first();
    // verifica se ha dissidio cadastrado
    if ( $diss === null ) {
      $resp[ 'codigo' ]   = 5;
      $resp[ 'mensagem' ] = 'Não tem Dissídio cadastrado no sistema para este ano.';

      return $resp;
    }

    // REALIZA O CALCULO
    $salAjustado = 0;
    $coef        = 1.0;

    // Verificar se recebera a porcentagem inteira (somente apos 12 meses)
    $diffMeses = $dt->diffInMonths( new Carbon( $pilhaH[ 'dataContratacao' ] ), true );
    if ( $diffMeses < 12 ) {
      $coef = $diffMeses / 12;

      $resp[ 'dissInteiro' ] = false;
    }

    // verificar ql eh a margem da regra, ajusta o salario e ql foi a porcentagem
    if ( $sal < $diss->valor1 ) { // menor q o valor 1
      $salAjustado     = $sal * ( ( ( $diss->porc1 * $coef ) + 10000 ) / 10000 );
      $resp[ 'regra' ] = 1;
      $resp[ 'porc' ]  = $diss->porc1;

    } elseif ( $sal <= $diss->valor2 ) { // menor q valor2
      $salAjustado     = $sal * ( ( ( $diss->porc2 * $coef ) + 10000 ) / 10000 );
      $resp[ 'regra' ] = 2;
      $resp[ 'porc' ]  = $diss->porc2;

    } elseif ( $sal <= $diss->valor3 ) { // menor q valor3
      $salAjustado     = $sal * ( ( ( $diss->porc3 * $coef ) + 10000 ) / 10000 );
      $resp[ 'regra' ] = 3;
      $resp[ 'porc' ]  = $diss->porc3;

    } else { // maior q valor 4
      $salAjustado     = $sal + ( $diss->porc4 * $coef );
      $resp[ 'regra' ] = 4;
      $resp[ 'porc' ]  = $diss->porc4;
    }

    // Responde OK
    $resp[ 'codigo' ]   = 1;
    $resp[ 'mensagem' ] = 'OK';
    $resp[ 'salOrig' ]  = $sal;
    $resp[ 'salAjust' ] = intval( $salAjustado );

    return $resp;
  }

  /**
   * Retorna os Telefones do Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Telefones() {
    return $this->hasMany( FuncTelefones::class );
  }

  /**
   * Retorna os Dependentes do Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Dependentes() {
    return $this->hasMany( FuncDependentes::class );
  }

  /**
   * Retorna os Historicos do Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Historicos() {
    return $this->hasMany( FuncHistoricos::class );
  }

  /**
   * Retorna o Departamento do Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Departamento() {
    return $this->belongsTo( Departamentos::class, 'departamentos_id' );
  }

  /**
   * Retorna o Usuario do Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasOne | \Illuminate\Database\Query\Builder
   */
  public function user() {
    return $this->hasOne( Usuarios::class );
  }

  /**
   * Retorna os ControleDePonto deste Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder | \Eloquent
   */
  public function ControleDePontos() {
    return $this->hasMany( ControleDePontos::class, 'funcionarios_id' );
  }

  /**
   * Retorna os ControleDePonto aprovados por este Funcionario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ControleDePontoAprovacoes() {
    return $this->hasMany( ControleDePontos::class, 'aprovador_id' );
  }

  /**
   * @param Carbon $anoMes
   * @return array
   */
  public function _CalcControleDePontos( $anoMes ) {
    // do dia 20/(mes--) até 19/mes
    $inicioMes = $anoMes->copy()
                        ->subMonth( 1 )
                        ->day( 20 )
                        ->format( 'Y-m-d' );
    $fimMes    = $anoMes->copy()
                        ->day( 19 )
                        ->format( 'Y-m-d' );

    // obtem seus eventos
    /** @var ControleDePontos[] $eventos */
    $eventos = $this->ControleDePontos()
                    ->whereBetween( 'data', [ $inicioMes, $fimMes ] )// WHERE entre as datas
                    ->orderBy( 'data' )// ordena pela data
                    ->get();

    // array com os valores do resultado a ser calculado
    $resp = [
      'dia_inicio'         => ( new Carbon( $inicioMes ) )->format( 'd/m/Y' ),
      'dia_fim'            => ( new Carbon( $fimMes ) )->format( 'd/m/Y' ),
      'atrasos'            => 0,
      'faltas'             => 0,
      'faltasDescontada'   => 0,
      'faltasAtestado'     => 0,
      'folgas'             => 0,
      'folgasAbonada'      => 0,
      'hrExtras'           => 0,
      'hrExtrasRemunerada' => 0,
      'ferias'             => 0,
      'vrvt'               => 0,
      'salarioDescontado'  => 0,
      'saldo'              => 0,
      'acumulado'          => 0,
    ];

    // ===== Calcula do mes =====
    foreach ( $eventos as $evento ) {
      $horas = ( new Carbon( $evento->horas ) )->hour;
      // conforme o tipo, regras sao tomadas para descontar/creditar horas/vt
      switch ( $evento->tipo ) {
        case ControleDePontos::ATRASO: // Atraso
          $resp[ 'atrasos' ] += $horas;
          $resp[ 'saldo' ]   -= $horas;
          break;
        case ControleDePontos::FALTA_BANCO: // Falta
          $resp[ 'faltas' ] += $horas;
          $resp[ 'vrvt' ]   += 1;
          $resp[ 'saldo' ]  -= $horas;
          break;
        case ControleDePontos::FALTA_DESCONTADA: // Falta Descontada
          $resp[ 'faltasDescontada' ]  += $horas;
          $resp[ 'vrvt' ]              += 1;
          $resp[ 'salarioDescontado' ] += 1;
          break;
        case ControleDePontos::FALTA_ATESTADO: // Falta com Atestado
          $resp[ 'faltasAtestado' ] += $horas;
          $resp[ 'vrvt' ]           += 1;
          break;
        case ControleDePontos::FOLGA_BANCO: // Folga
          $resp[ 'folgas' ] += $horas;
          $resp[ 'vrvt' ]   += 1;
          $resp[ 'saldo' ]  -= $horas;
          break;
        case ControleDePontos::FOLGA_ABONADA: // Folga Abonada
          $resp[ 'folgasAbonada' ] += $horas;
          $resp[ 'vrvt' ]          += 1;
          break;
        case ControleDePontos::HORA_EXTRA_BANCO: // Hora Extra
          $resp[ 'hrExtras' ] += $horas;
          $resp[ 'saldo' ]    += $horas;
          break;
        case ControleDePontos::HORA_EXTRA_REMUNERADA: // Hora Extra Remunerada
          $resp[ 'hrExtrasRemunerada' ] += $horas;
          break;
        case ControleDePontos::GOZO_DE_FERIAS: // Gozo de férias
          $resp[ 'ferias' ] += $horas;
          $resp[ 'vrvt' ]   += 1;
          break;
        case ControleDePontos::HOME_OFFICE: // Home Office
          $resp[ 'vrvt' ] += 1;
          break;
        default :
          break;
      }
    }

    // ===== Calcula o Acumulado =====
    /** @var ControleDePontos[] $eventosAll */
    $eventosAll = $this->ControleDePontos()->orderby( 'data' )->get();
    $acumulado  = 0;
    foreach ( $eventosAll as $evento ) {
      // conforme o tipo, regras sao tomadas para descontar/creditar horas/vt
      switch ( $evento->tipo ) {
        // Subtraem no Bando de horas
        case ControleDePontos::ATRASO: // Atraso
        case ControleDePontos::FALTA_BANCO: // Falta
        case ControleDePontos::FOLGA_BANCO: // Folga
          $acumulado -= ( new Carbon( $evento->horas ) )->hour;
          break;
        // Somam no Bando de horas
        case ControleDePontos::HORA_EXTRA_BANCO: // Hora Extra
          $acumulado += ( new Carbon( $evento->horas ) )->hour;
          break;
        // Nada no Bando de horas
        case ControleDePontos::FALTA_DESCONTADA: // Falta Descontada
        case ControleDePontos::FALTA_ATESTADO: // Falta com Atestado
        case ControleDePontos::FOLGA_ABONADA: // Folga Abonada
        case ControleDePontos::HORA_EXTRA_REMUNERADA: // Hora Extra Remunerada
        case ControleDePontos::GOZO_DE_FERIAS: // Gozo de férias
        case ControleDePontos::HOME_OFFICE: // Home Office
        default :
          break;
      }
    }
    $resp[ 'acumulado' ] = $acumulado;

    return $resp;
  }

  /**
   * @param $dt_inicio string
   * @param $dt_fim    string
   * @return array
   */
  public function _ArrayControleDePontos( $dt_inicio, $dt_fim ) {
    $arr           = [];
    $dia_da_semana = [
      'DOMINGO',
      '2ª feira',
      '3ª feira',
      '4ª feira',
      '5ª feira',
      '6ª feira',
      'SÁBADO'
    ];
    $func_nome     = $this->nome;
    /** @var ControleDePontos[] $pontos */
    $pontos = $this->ControleDePontos()
                   ->whereBetween( 'data', [ $dt_inicio, $dt_fim ] )
                   ->orderBy( 'data' )
                   ->get();
    foreach ( $pontos as $ponto ) {
      $arr[] = [
        $ponto->data, //  data
        $dia_da_semana[ ( new Carbon( $ponto->data ) )->dayOfWeek ], // dia da semana
        ControleDePontos::enum_tipos()[ $ponto->tipo ], //  tipo do evento
        $func_nome, //  nome do funcionário
        $ponto->horas, //  total de horas
        $ponto->Aprovador->nome, //  nome do aprovador
        $ponto->obs, // observação
      ];
    }

    return $arr;
  }

  /**
   * Retorna o Endereço completo deste Funcionario.
   *
   * @return string
   */
  public function _EnderecoCompleto() {
    return $this->end_logradouro
      . ', '
      . $this->end_numero
      . ', '
      . ( $this->end_complemento != '' ? $this->end_complemento . ', ' : '' )
      . $this->end_bairro
      . ', '
      . $this->end_cidade
      . ' - '
      . $this->end_estado
      . ', '
      . $this->end_cep;
  }

  /**
   * Retorna o Salario atual deste Funcionario.
   *
   * @return integer
   */
  public function _SalarioAtual() {
    $hist = $this->pilhaHistorico();
    if ( !array_key_exists( 'salario', $hist ) ) {
      return 0;
    }

    return $hist[ 'salario' ];
  }
}
