<?php

namespace App\Models\Cadastros;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\PlanoDeContas
 *
 * @property int $id
 * @property int $conta
 * @property string $descricao
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Cadastros\PlanoDeContasItem[] $PlanoDeContasItem
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContas whereConta( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContas whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContas whereDescricao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContas whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContas whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class PlanoDeContas extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'cadastro_plano_de_contas';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'conta',
    'descricao',
  ];

  /**
   * Enumerador dos Grupos.
   *
   * @return array
   */
  public static function enum_grupos() {
    $grupos = [];
    foreach ( PlanoDeContas::all()->sortBy( 'conta' ) as $grupo ) {
      /** @var PlanoDeContas $grupo */
      $grupos[ $grupo->id ] = $grupo->getContaNome();
    }

    return $grupos;
  }

  /**
   * Enumerados das Despesas disponiveis (id => "conta_reduzida - nome").
   *
   * @return array
   */
  public static function enum_despesas() {
    $despesas = [];
    foreach ( PlanoDeContas::all()->sortBy( 'conta' ) as $plConta ) {
      /** @var PlanoDeContas $plConta */
      $item = [];
      foreach ( $plConta->PlanoDeContasItem as $plContaItem ) {
        /** @var PlanoDeContasItem $plContaItem */
        $item[ $plContaItem->id ] = $plContaItem->getContaNome();
      }
      $despesas[ $plConta->getContaNome() ] = $item;
    }

    return $despesas;
  }

  /**
   * Enumerados das Despesas disponiveis (id => "conta_reduzida - nome").
   *
   * @return array
   */
  public static function enum_despesas_reduzida() {
    $despesas = [];
    foreach ( PlanoDeContas::all()->sortBy( 'conta' ) as $plConta ) {
      /** @var PlanoDeContas $plConta */
      $item = [];
      foreach ( $plConta->PlanoDeContasItem as $plContaItem ) {
        /** @var PlanoDeContasItem $plContaItem */
        $item[ $plContaItem->id ] = $plContaItem->getContaReduzidaNome();
      }
      $despesas[ $plConta->getContaReduzidaNome() ] = $item;
    }

    return $despesas;
  }

  /**
   * Json para a TreeView.
   *
   * @return string
   */
  public static function despesas_treeView() {
    $planodecontas = [];

    foreach ( PlanoDeContas::orderBy( 'conta' )->get() as $pai ) {
      /** @var PlanoDeContas $pai */
      $paiD           = [];
      $paiID          = $pai->id;
      $paiD[ 'text' ] = $pai->getContaNome();
      $paiD[ 'href' ] = route( 'cadastros.planodecontas.edit', [ $paiID, 0 ] );
      $filhos         = $pai->PlanoDeContasItem()->orderBy( 'conta' )->get();
      $paiD[ 'tags' ] = [ count( $filhos ) ];

      foreach ( $filhos as $filho ) {
        /** @var PlanoDeContasItem $filho */
        $filhoD            = [];
        $filhoID           = $filho->id;
        $filhoD[ 'text' ]  = $filho->getContaNomeCompleto();
        $filhoD[ 'href' ]  = route( 'cadastros.planodecontas.edit', [ $paiID, $filhoID ] );
        $paiD[ 'nodes' ][] = $filhoD;
      }
      $planodecontas[] = $paiD;
    }

    return json_encode( $planodecontas );
  }

  /**
   * "conta - nome" desta Despesa.
   *
   * @return string
   */
  public function getContaNome() {
    return sprintf( '3.1.2.%02d.0000 - %s', $this->conta, $this->descricao );
  }

  /**
   * "conta - nome" desta Despesa.
   *
   * @return string
   */
  public function getContaReduzidaNome() {
    return $this->descricao;
  }

  /**
   * Retorna os Itens desta Despesa.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function PlanoDeContasItem() {
    return $this->hasMany( PlanoDeContasItem::class, 'pai_id' );
  }
}
