<?php

namespace App\Models\Cadastros;

use App\Models\Financeiro\ContaDeConsumo;
use App\Models\Financeiro\ContaDeConsumoGerador;
use App\Models\Financeiro\Ferias;
use App\Models\Financeiro\Rescisao;
use App\Models\Financeiro\Salario;
use App\Models\Financeiro\Salario13;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Cadastros\PlanoDeContasItem
 *
 * @property int $id
 * @property int $pai_id
 * @property int $conta
 * @property int $conta_reduzida
 * @property string $descricao
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\ContaDeConsumo[] $ContasDeConsumo
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\ContaDeConsumoGerador[] $ContasDeConsumoGeradas
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\Ferias[] $Ferias
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\Rescisao[] $Rescisao
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\Salario[] $Salario
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\Salario13[] $Salario13
 * @property-read \App\Models\Cadastros\PlanoDeContas $PlanoDeContas
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem whereConta( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem whereContaReduzida( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem whereDescricao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem wherePaiId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\PlanoDeContasItem whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class PlanoDeContasItem extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'cadastro_plano_de_contas_itens';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'conta',
    'conta_reduzida',
    'descricao',
    'pai_id',
  ];

  /**
   * "conta - nome" desta Despesa.
   *
   * @return string
   */
  public function getContaNome() {
    return sprintf( '3.1.2.%02d.%04d - %s', $this->PlanoDeContas->conta, $this->conta, $this->descricao );
  }

  /**
   * "conta - nome" desta Despesa.
   *
   * @return string
   */
  public function getContaReduzidaNome() {
    return sprintf( '%d - %s', $this->conta_reduzida, $this->descricao );
  }

  /**
   * "conta - [reduzido] nome" desta Despesa.
   *
   * @return string
   */
  public function getContaNomeCompleto() {
    return sprintf( '3.1.2.%02d.%04d - [%d] %s', $this->PlanoDeContas->conta, $this->conta, $this->conta_reduzida, $this->descricao );
  }

  /**
   * Retorna o pai deste Item de Despesa.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function PlanoDeContas() {
    return $this->belongsTo( PlanoDeContas::class, 'pai_id' );
  }

  /**
   * Retorna as Contas de Consumos q utilizam este Item.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ContasDeConsumoGeradas() {
    return $this->hasMany( ContaDeConsumoGerador::class, 'despesa_id' );
  }

  /**
   * Retorna as Contas de Consumos q utilizam este Item.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ContasDeConsumo() {
    return $this->hasMany( ContaDeConsumo::class, 'despesa_id' );
  }

  /**
   * Retorna as Contas de Consumos q utilizam este Item.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Salario() {
    return $this->hasMany( Salario::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna as Contas de Consumos q utilizam este Item.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Salario13() {
    return $this->hasMany( Salario13::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna as Contas de Consumos q utilizam este Item.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Ferias() {
    return $this->hasMany( Ferias::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna as Contas de Consumos q utilizam este Item.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Rescisao() {
    return $this->hasMany( Rescisao::class, 'plano_de_contas_item_id' );
  }
}
