<?php

namespace App\Models\Cadastros;

use App\CRP;
use App\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Notifications\Notifiable;
use Kyslik\ColumnSortable\Sortable;

/**
 * App\Models\Cadastros\Usuarios
 *
 * @property int $id
 * @property string $name
 * @property string $email
 * @property string $password
 * @property string $remember_token
 * @property bool $crp_role
 * @property int $funcionarios_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\Funcionarios $Funcionario
 * @property-read \Illuminate\Notifications\DatabaseNotificationCollection|\Illuminate\Notifications\DatabaseNotification[] $notifications
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios sortable( $defaultSortParameters = null )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereCrpRole( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereEmail( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereFuncionariosId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereName( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios wherePassword( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereRememberToken( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Cadastros\Usuarios whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class Usuarios extends Model {
  use Notifiable;

  use Sortable;
  /**
   * metodos de Sortable e quais colunas são ordenaveis.
   *
   * @var array
   */
  public $sortable = [ 'name', 'email', 'crp_role' ];

  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'users';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'name',
    'email',
    'password',
    'funcionarios_id',
    'crp_role'
  ];

  public static function enum_Roles() {
    return [
      1 => 'Administrador',
      2 => 'Diretor',
      3 => 'Funcionários Financeiro',
      4 => 'Funcionários Planejamento',
      5 => 'Funcionários Produção',
      6 => 'Funcionários RH',
      7 => 'Cliente', //??
      8 => 'Permissão Mínima',
    ];
  }

  public function get_enum_Roles() {
    $id = $this->crp_role;
    if ( $id >= 1 && $id <= 8 ) {
      return Usuarios::enum_Roles()[ $id ];
    }
    return 'Sem Função';
  }

  /**
   * Configurar a Role do Usuario
   */
  public function ConfigRole() {
    $role = $this->crp_role;

    /** @var User $user */
    $user = User::findOrFail( $this->id );

    switch ( $role ) {
      case 1:
        // Administrador
        $user->syncRoles( [ CRP::R_Admin ] );
        break;
      case 2:
        // Diretor
        $user->syncRoles( [ CRP::R_Diretor ] );
        break;
      case 3:
        // Funcionários Financeiro
        $user->syncRoles( [ CRP::R_Func_Financeiro ] );
        break;
      case 4:
        // Funcionários Planejamento
        $user->syncRoles( [ CRP::R_Func_Planejamento ] );
        break;
      case 5:
        // Funcionários Producao
        $user->syncRoles( [ CRP::R_Func_Producao ] );
        break;
      case 6:
        // Funcionários RH
        $user->syncRoles( [ CRP::R_Func_RH ] );
        break;
      case 7:
        // Cliente
        $user->syncRoles( [ CRP::R_Cliente ] );
        break;
      case 8:
        // Minimal
        $user->syncRoles( [ CRP::R_Minimal ] );
        break;
      default:
        $user->syncRoles( [] );
        break;
    }
  }

  /**
   * Retorna o Funcionario do Usuario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionarios_id' );
  }

  /**
   * Retorna os Funcionarios q ainda nao sao users.
   *
   * @return array
   */
  public static function enum_Funcionarios_sem_Usuario() {
    $fTable = ( new Funcionarios )->getTable();
    $uTable = ( new Usuarios )->getTable();

    $funcionarios =
      Funcionarios
        ::leftJoin(
          $uTable . '',
          $fTable . '.id',
          '=',
          $uTable . '.funcionarios_id' )
        ->whereNull( $uTable . '.funcionarios_id' )
        ->get( [
          $fTable . '.id as fid',
          $fTable . '.nome as fnome' ] )
        ->sortBy( 'fnome' );

    $funcs = [];
    foreach ( $funcionarios as $f ) {
      $funcs[ $f->fid ] = $f->fnome;
    }

    return $funcs;
  }

}
