<?php

namespace App\Models\Comercial;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Comercial\BriefingBrinde
 *
 * @property int $id
 * @property int $job_id
 * @property string $nome_material
 * @property mixed $resumo
 * @property string $formato_aberto_altura
 * @property string $formato_aberto_largura
 * @property string $formato_fechado_altura
 * @property string $formato_fechado_largura
 * @property string $material_tipo
 * @property string $material_cores
 * @property int $material_cores_escala
 * @property string $tiragem
 * @property string $tiragem_descricao
 * @property int $tipo_gravacao
 * @property mixed $referencias
 * @property string $entrega_data
 * @property string $entrega_hora
 * @property mixed $entrega_endereco
 * @property string $entrega_telefone
 * @property string $entrega_responsavel
 * @property mixed $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Comercial\Jobs $Job
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereEntregaData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereEntregaEndereco( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereEntregaHora( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereEntregaResponsavel( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereEntregaTelefone( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereFormatoAbertoAltura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereFormatoAbertoLargura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereFormatoFechadoAltura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereFormatoFechadoLargura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereJobId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereMaterialCores( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereMaterialCoresEscala( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereMaterialTipo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereNomeMaterial( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereReferencias( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereResumo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereTipoGravacao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereTiragem( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereTiragemDescricao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingBrinde whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class BriefingBrinde extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'comercial_job_briefing_brinde';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome_material',
    'resumo',
    'formato_aberto_altura',
    'formato_aberto_largura',
    'formato_fechado_altura',
    'formato_fechado_largura',
    'tiragem',
    'tiragem_descricao',
    'material_tipo',
    'material_cores',
    'material_cores_escala',
    'tipo_gravacao', // enum
    'referencias', // CKeditor
    'entrega_data',
    'entrega_hora',
    'entrega_endereco',
    'entrega_telefone',
    'entrega_responsavel',
    'obs',
  ];

  /**
   * Enumerador do tipo de gravacao
   *
   * @return array
   */
  public static function enum_tipo_gravacao() {
    return [
      1 => 'Transfer',
      2 => 'Silk Screen',
      3 => 'Sublimação',
      4 => 'Serigrafia',
      5 => 'Tampografia',
      6 => 'Impressão Digital UV'
    ];
  }

  /**
   * Retorna o valor do Enumerador da escala de cores.
   *
   * @param $v
   * @return mixed|string
   */
  public static function enum_tipo_gravacao_v( $v ) {
    if ( $v == '' || $v == null ) {
      return '';
    }
    return BriefingBrinde::enum_tipo_gravacao()[ $v ];
  }

  /**
   * Enumerador da escala de cores.
   *
   * @return array
   */
  public static function enum_cores_escala() {
    return [
      1 => 'CMYK',
      2 => 'RGB',
      3 => 'Pantone',
      4 => 'Outro',
    ];
  }

  /**
   * Retorna o valor do Enumerador da escala de cores.
   *
   * @param $v
   * @return string
   */
  public static function enum_cores_escala_v( $v ) {
    if ( $v == '' || $v == null ) {
      return '';
    }
    return BriefingBrinde::enum_cores_escala()[ $v ];
  }

  /**
   * Retorna o Job do BriefingBrinde.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Job() {
    return $this->belongsTo( Jobs::class );
  }
}
