<?php

namespace App\Models\Comercial;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Comercial\BriefingGrafico
 *
 * @property int $id
 * @property int $job_id
 * @property string $medida_aberto_altura
 * @property string $medida_aberto_largura
 * @property string $medida_fechado_altura
 * @property string $medida_fechado_largura
 * @property string $material_tipo
 * @property string $material_cores
 * @property int $material_cores_escala
 * @property string $paginas
 * @property string $laminas
 * @property string $acabamento
 * @property string $faca
 * @property string $tiragem
 * @property string $tiragem_descricao
 * @property string $entrega_data
 * @property string $entrega_hora
 * @property mixed $entrega_endereco
 * @property string $entrega_telefone
 * @property string $entrega_responsavel
 * @property mixed $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Comercial\Jobs $Job
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereAcabamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereEntregaData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereEntregaEndereco( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereEntregaHora( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereEntregaResponsavel( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereEntregaTelefone( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereFaca( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereJobId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereLaminas( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMaterialCores( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMaterialCoresEscala( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMaterialTipo( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMedidaAbertoAltura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMedidaAbertoLargura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMedidaFechadoAltura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereMedidaFechadoLargura( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico wherePaginas( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereTiragem( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereTiragemDescricao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\BriefingGrafico whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class BriefingGrafico extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'comercial_job_briefing_grafico';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    // Medida
    'medida_aberto_altura',
    'medida_aberto_largura',
    'medida_fechado_altura',
    'medida_fechado_largura',

    // Material
    'material_tipo',
    'material_cores',
    'material_cores_escala',

    // Quantidade de Páginas/Lâminas
    'paginas',
    'laminas',

    // Acabamento
    'acabamento',
    'faca',

    // Tiragem
    'tiragem',
    'tiragem_descricao',

    // Entrega
    'entrega_data',
    'entrega_hora',
    'entrega_endereco',
    'entrega_telefone',
    'entrega_responsavel',

    //  DADOS PARA FATURA ?
    //  ENDEREÇO PARA ENTREGA DE FATURA ?
    //  LOCAL ONDE COTAR (PREENCHIMENTO MARIS OU JULIANA) ?

    'obs'
  ];

  /**
   * Retorna o Job do BriefingGrafico.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Job() {
    return $this->belongsTo( Jobs::class );
  }

  /**
   * Enumerador da escala de cores.
   *
   * @return array
   */
  public static function enum_cores_escala() {
    return [
      1 => 'CMYK',
      2 => 'RGB',
      3 => 'Pantone',
      4 => 'Outro',
    ];
  }

  /**
   * Retorna o valor do Enumerador da escala de cores.
   *
   * @param $v
   * @return mixed|string
   */
  public static function enum_cores_escala_v( $v ) {
    if ( $v == '' || $v == null ) {
      return '';
    }
    return BriefingGrafico::enum_cores_escala()[ $v ];
  }
}
