<?php

namespace App\Models\Comercial;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Comercial\JobLogs
 *
 * @property int $id
 * @property int $job_id
 * @property \Carbon\Carbon $data
 * @property string $etapa
 * @property int $tipo
 * @property string $nome_funcionario
 * @property-read \App\Models\Comercial\Jobs $Job
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\JobLogs whereData( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\JobLogs whereEtapa( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\JobLogs whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\JobLogs whereJobId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\JobLogs whereNomeFuncionario( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\JobLogs whereTipo( $value )
 * @mixin \Eloquent
 */
class JobLogs extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'comercial_job_logs';

  public $timestamps = false;

  protected $dates = [ 'data' ];

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'job_id',
    'data',
    'etapa',
    'tipo',
    'nome_funcionario',
  ];

  const LOG_RETORNAR = 1;
  const LOG_SALVAR   = 2;
  const LOG_AVANCAR  = 3;

  /**
   * Retorna o Job do Log.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Job() {
    return $this->belongsTo( Jobs::class );
  }

  /**
   * Retornar a classe modificadora do Alert.
   *
   * @return string
   */
  public function getAlertClass() {
    if ( $this->tipo == JobLogs::LOG_RETORNAR ) {
      return 'warning';
    }
    if ( $this->tipo == JobLogs::LOG_SALVAR ) {
      return 'info';
    }
    if ( $this->tipo == JobLogs::LOG_AVANCAR ) {
      return 'success';
    }
    return '';
  }

  /**
   * Retorna a classe do Fa.
   *
   * @return string
   */
  public function getFaClass() {
    if ( $this->tipo == JobLogs::LOG_SALVAR ) {
      return 'save';
    }
    if ( $this->tipo == JobLogs::LOG_AVANCAR ) {
      return 'arrow-right';
    }
    if ( $this->tipo == JobLogs::LOG_RETORNAR ) {
      return 'arrow-left';
    }
    return '';
  }

  /**
   * Retorna o texto do Alert.
   *
   * @return string
   */
  public function getText() {
    if ( $this->tipo == JobLogs::LOG_SALVAR ) {
      return 'salvou um rascunho deste Job em';
    }
    if ( $this->tipo == JobLogs::LOG_AVANCAR ) {
      return 'enviou este Job para';
    }
    if ( $this->tipo == JobLogs::LOG_RETORNAR ) {
      return 'retornou este Job para';
    }
    return '';
  }
}
