<?php

namespace App\Models\Comercial;

use App\ListagemPadronizada;
use App\Models\Cadastros\ClientesCentrosDeCustos;
use App\Models\Cadastros\ClientesCentrosDeCustosContatos;
use App\Models\Cadastros\ClientesContas;
use App\Models\Cadastros\ClientesEmpresas;
use App\Models\Cadastros\ClientesEmpresasUnidades;
use App\Models\Cadastros\Funcionarios;
use App\Models\Financeiro\JobParcela;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Comercial\Jobs
 *
 * @property int $id
 * @property string $etapa_atual
 * @property string $nome_job
 * @property int|null $campanha_id
 * @property int|null $responsavel_id
 * @property int|null $cliente_unidd_id
 * @property int|null $cliente_cdc_id
 * @property int|null $cod_receita
 * @property string|null $descricao_evento
 * @property \Carbon\Carbon|null $previsao_proposta
 * @property \Carbon\Carbon|null $previsao_entrega
 * @property string|null $condpagto
 * @property mixed|null $condpagto_obs
 * @property int|null $aprov_diretoria
 * @property mixed|null $aprov_diretoria_obs
 * @property int|null $aprov_cliente
 * @property mixed|null $aprov_cliente_obs
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property-read \App\Models\Comercial\BriefingBrinde $BriefingBrinde
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\BriefingFiles[] $BriefingFiles
 * @property-read \App\Models\Comercial\BriefingGrafico $BriefingGrafico
 * @property-read \App\Models\Comercial\BriefingLivre $BriefingLivre
 * @property-read \App\Models\Comercial\BriefingWeb $BriefingWeb
 * @property-read \App\Models\Comercial\Campanhas|null $Campanha
 * @property-read \App\Models\Cadastros\ClientesContas|null $ClienteConta
 * @property-read \App\Models\Cadastros\ClientesEmpresasUnidades|null $ClienteUnidade
 * @property-read \App\Models\Comercial\Cronograma $Cronograma
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\JobLogs[] $Logs
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\Orcamento[] $Orcamentos
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\JobParcela[] $Parcelas
 * @property-read \App\Models\Cadastros\Funcionarios|null $Responsavel
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\Stages[] $Stages
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs sortable( $defaultSortParameters = null )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereAprovCliente( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereAprovClienteObs( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereAprovDiretoria( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereAprovDiretoriaObs( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereCampanhaId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereClienteCdcId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereClienteUniddId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereCodReceita( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereCondpagto( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereCondpagtoObs( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereCreatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereDescricaoEvento( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereEtapaAtual( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereNomeJob( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs wherePrevisaoEntrega( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs wherePrevisaoProposta( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereResponsavelId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Comercial\Jobs whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class Jobs extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'comercial_jobs';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'etapa_atual',
    'nome_job',
    'responsavel_id',
    'cliente_unidd_id',
    'cliente_cdc_id',
    'campanha_id',
    'cod_receita',
    'descricao_evento',
    'previsao_proposta',
    'previsao_entrega',
    'condpagto',
    'condpagto_obs',
    'orc_descricao',
    'aprov_diretoria',
    'aprov_diretoria_obs',
    'aprov_cliente',
    'aprov_cliente_obs',
  ];

  /**
   * Propriedades q sao datas.
   *
   * @return array
   */
  public function getDates() {
    return [ 'created_at', 'updated_at', 'previsao_proposta', 'previsao_entrega' ];
  }

  /**
   * enumerador dos Centros de Custos dos Clientes.
   *
   * @return array
   */
  public static function enum_clientes_centro_de_custo() {
    $itens = [];
    foreach ( ClientesEmpresas::orderBy( 'codigo' )->get() as $emp ) {
      /** @var ClientesEmpresas $emp */
      $cod_emp           = $emp->codigo . ' - ' . $emp->nome;
      $itens[ $cod_emp ] = [];
      foreach ( $emp->CentrosDeCustos()->orderBy( 'codigo' )->get() as $cdc ) {
        /** @var ClientesCentrosDeCustos $cdc */
        $cod_cdc           = $emp->codigo . '.' . $cdc->codigo . ' - ' . $cdc->nome;
        $itens[ $cod_cdc ] = [];
        foreach ( $cdc->Contas()->orderBy( 'codigo' )->get() as $cnt ) {
          /** @var ClientesContas $cnt */
          $itens[ $cod_cdc ]  [ $cnt->id ] = $emp->codigo . '.' . $cdc->codigo . '.' . $cnt->codigo . ' - ' . $cnt->nome;
        }
      }
    }

    return $itens;
  }

  /**
   * enumerador das Unidades dos Clientes.
   *
   * @return array
   */
  public static function enum_clientes_unidades() {
    $itens = [];
    foreach ( ClientesEmpresas::orderBy( 'codigo' )->get() as $emp ) {
      /** @var ClientesEmpresas $emp */
      $unidades = [];
      foreach ( $emp->Unidades()->orderBy( 'nome' )->get() as $uni ) {
        /** @var ClientesEmpresasUnidades $uni */
        $unidades[ $uni->id ] = $emp->codigo . ' - ' . $uni->nome;
      }
      $itens[ $emp->codigo . ' - ' . $emp->nome ] = $unidades;
    }

    return $itens;
  }

  /**
   * Nome da Unidade do Cliente.
   *
   * @return string
   */
  public function _ClienteUnidade() {
    if ( $this->cliente_unidd_id == null ) {
      return 'SEM CLIENTE';
    }
    if ( $this->ClienteUnidade == null ) {
      return 'SEM CLIENTE';
    }

    return $this->ClienteUnidade->getCodigoNome();
  }

  /**
   * Nome da Conta do Cliente.
   *
   * @return string
   */
  public function _ClienteConta() {
    if ( $this->cliente_cdc_id == null ) {
      return 'SEM CLIENTE';
    }
    if ( $this->ClienteConta == null ) {
      return 'SEM CLIENTE';
    }

    return $this->ClienteConta->getCodigoNome();
  }

  /**
   * Enumerado de responsaveis.
   *
   * @return array
   */
  public static function enum_responsaveis() {
    $resp = [];
    foreach ( Funcionarios::orderBy( 'nome' )->get() as $f ) {
      $resp[ $f->id ] = $f->nome;
    }

    return $resp;
  }

  /**
   * Retorna o codigo da receita deste Job.
   *
   * @return string
   */
  public function _codReceitaNome() {
    return \App\Models\Cadastros\CodigoReceita::getCodReceitaNome( $this->cod_receita );
  }

  /**
   * Enumerador das Campanhas.
   *
   * @return array
   */
  public static function enum_campanhas() {
    $camp = [];
    foreach ( Campanhas::orderBy( 'nome' )->get() as $c ) {
      $camp[ $c->id ] = $c->nome;
    }

    return $camp;
  }

  /**
   * enumerador da Aprovação da Diretoria.
   *
   * @return array
   */
  public static function enum_aprovacaoDiretoria() {
    return [
      1 => '[B] Não Aprovado (retorna para o Financeiro)',
      2 => '[D] Aprovado (segue para o Atendimento)'
    ];
  }

  /**
   * Retorna a da Aprovação da Diretoria.
   *
   * @param $id
   * @return mixed|string
   */
  public static function _enum_aprovacaoDiretoria( $id ) {
    if ( $id >= 1 && $id <= 2 ) {
      return self::enum_aprovacaoDiretoria()[ $id ];
    }

    return '';
  }

  /**
   * enumerador da Aprovação do Cliente.
   *
   * @return array
   */
  public static function enum_aprovacaoCliente() {
    return [
      1 => '[Z] Não Aprovado (Arquivar)',
      2 => '[A] Não Aprovado (Retorna para o Comercial)',
      3 => '[E] Aprovado (Avança para a Produção)'
    ];
  }

  /**
   * Retorna da Aprovação do Cliente.
   *
   * @param $id
   * @return mixed|string
   */
  public static function _enum_aprovacaoCliente( $id ) {
    if ( $id >= 1 && $id <= 3 ) {
      return self::enum_aprovacaoCliente()[ $id ];
    }

    return '';
  }


  /**
   * enumerador dos contados do Cliente.
   *
   * @return array
   */
  public function enum_ContatosCliente() {
    if ( $this->ClienteConta == null ) {
      return [];
    }
    try {
      /** @var ClientesContas $conta */
      $conta = $this->ClienteConta;
      /** @var ClientesCentrosDeCustos $centro */
      $centro = $conta->CentroDeCusto;
      /** @var ClientesCentrosDeCustosContatos[] $contatos */
      $contatos = $centro->Contatos;
      $itens    = [];
      foreach ( $contatos as $contato ) {
        $itens[ $contato->id ] = $contato->nome;
      }
      asort( $itens );

      return $itens;
    } catch ( \Exception $e ) {
      return [];
    }
  }

  /**
   * enumerador dos Orçamentos.
   *
   * @return array
   */
  public function enum_Orcamentos() {
    $orcs  = $this->Orcamentos;
    $itens = [];
    foreach ( $orcs as $orc ) {
      $itens[ $orc->id ] = $orc->nome;
    }

    return $itens;
  }

  /**
   * enumerador dos Modelos de PDF.
   *
   * @return array
   */
  public static function enum_pdfModelos() {
    return [
      'A1' => 'A1 - Descrição Geral e só com Custos Internos',
      'A2' => 'A2 - Descrição Geral e só com Custos de Operacionalização',
      'B'  => 'B - Descrição Geral e Custo Geral',
      'C'  => 'C - Descrição Geral, Custo por Item (Interno e Operacionalização) e Total Geral',
      'D'  => 'D - Descrição Geral, Só com Custos por Item (Interno e Operacionalização) e sem o Total Geral',
    ];
  }

  /**
   * enumerador da logo do PDF.
   *
   * @return array
   */
  public static function enum_pdfLogo() {
    return [
      1 => 'Cadaris',
      2 => 'Cadaris Empreendedor'
    ];
  }

  /**
   * Retorna o Stage atual do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo|Stages
   */
  public function StageTop() {
    return $this->Stages()->latest()->first();
  }

  /**
   * Retorna os Stages do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Stages() {
    return $this->hasMany( Stages::class, 'job_id' );
  }

  /**
   * Retorna o Funcionario Responsavel do job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Responsavel() {
    return $this->belongsTo( Funcionarios::class, 'responsavel_id' );
  }

  /**
   * Retorna o nome do Funcionario Responsavel do job.
   *
   * @return string
   */
  public function _Responsavel() {
    if ( $this->responsavel_id == null ) {
      return 'Funcionário Deletado';
    }

    return $this->Responsavel->nome;
  }

  /**
   * Retorna o Cliente Unidade do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function ClienteUnidade() {
    return $this->belongsTo( ClientesEmpresasUnidades::class, 'cliente_unidd_id' );
  }

  /**
   * Retorna o Cliente do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function ClienteConta() {
    return $this->belongsTo( ClientesContas::class, 'cliente_cdc_id' );
  }

  /**
   * Retorna o BriefingLivre do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasOne | \Illuminate\Database\Query\Builder
   */
  public function BriefingLivre() {
    return $this->hasOne( BriefingLivre::class, 'job_id' );
  }

  /**
   * Retorna o BriefingLivre do Job.
   *
   * @return BriefingLivre
   */
  public function _BriefingLivre() {
    $bl = $this->BriefingLivre;
    if ( $bl == null ) {
      return new BriefingLivre();
    }

    return $bl;
  }

  /**
   * Retorna o BriefingGrafico do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasOne | \Illuminate\Database\Query\Builder
   */
  public function BriefingGrafico() {
    return $this->hasOne( BriefingGrafico::class, 'job_id' );
  }

  /**
   * Retorna o BriefingGrafico do Job.
   *
   * @return BriefingGrafico
   */
  public function _BriefingGrafico() {
    $bg = $this->BriefingGrafico;
    if ( $bg == null ) {
      return new BriefingGrafico();
    }

    return $bg;
  }

  /**
   * Retorna o BriefingWeb do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasOne | \Illuminate\Database\Query\Builder
   */
  public function BriefingWeb() {
    return $this->hasOne( BriefingWeb::class, 'job_id' );
  }

  /**
   * Retorna o BriefingWeb do Job.
   *
   * @return BriefingWeb
   */
  public function _BriefingWeb() {
    $bw = $this->BriefingWeb;
    if ( $bw == null ) {
      return new BriefingWeb();
    }

    return $bw;
  }

  /**
   * Retorna o BriefingBrinde do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasOne | \Illuminate\Database\Query\Builder
   */
  public function BriefingBrinde() {
    return $this->hasOne( BriefingBrinde::class, 'job_id' );
  }

  /**
   * Retorna o BriefingBrinde do Job.
   *
   * @return BriefingBrinde
   */
  public function _BriefingBrinde() {
    $bb = $this->BriefingBrinde;
    if ( $bb == null ) {
      return new BriefingBrinde();
    }

    return $bb;
  }

  /**
   * Retorna o BriefingFiles do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function BriefingFiles() {
    return $this->hasMany( BriefingFiles::class, 'job_id' );
  }

  /**
   * Retorna o Cronograma do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasOne | \Illuminate\Database\Query\Builder
   */
  public function Cronograma() {
    return $this->hasOne( Cronograma::class, 'job_id' );
  }

  /**
   * Retorna o Cronograma do Job.
   *
   * @return Cronograma
   */
  public function _Cronograma() {
    $cr = $this->Cronograma;
    if ( $cr == null ) {
      return new Cronograma();
    }

    return $cr;
  }

  /**
   * Retorna o Campanha do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Campanha() {
    return $this->belongsTo( Campanhas::class, 'campanha_id' );
  }

  /**
   * Retorna o Orcamento do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Orcamentos() {
    return $this->hasMany( Orcamento::class, 'job_id' );
  }

  /**
   * Retorna o Orcamento do Job.
   *
   * @param integer $id
   * @return Orcamento|\Illuminate\Database\Eloquent\Relations\HasMany|\Illuminate\Database\Query\Builder
   */
  public function _Orcamentos( $id ) {
    return $this->Orcamentos()->find( $id );
  }


  /**
   * Retorna o nome do Orcamento Aprovado pela Diretoria do Job.
   *
   */
  public function _OrcamentoAprovado_nome() {
    dd( 'fix : Models/Jobs->_OrcamentoAprovado_nome()' );
  }

  /**
   * Retorna os Orcamentos Aprovados pela Diretoria do Job.
   *
   * @return Orcamento[]
   */
  public function _OrcamentosAprovados_Diretoria() {
    return $this->Orcamentos()->where( 'orc_aprov_diretor', '=', 1 )->get() ?? [];
  }

  /**
   * Retorna os Orcamentos Aprovados pelo Diretor do Job.
   *
   * @return Orcamento[]
   */
  public function _OrcamentosAprovados_Cliente() {
    return $this->Orcamentos()->where( 'orc_aprov_cliente', '=', 1 )->get() ?? [];
  }

  /**
   * Enumerador dos Orcamentos Aprovados pelo Diretor do Job.
   *
   * @return array
   */
  public function enum_OrcamentosAprovados_Diretoria() {
    $data = [];
    foreach ( $this->_OrcamentosAprovados_Diretoria() as $orc ) {
      /** @var Orcamento $orc */
      $data[ $orc->id ] = $orc->nome;
    }

    return $data;
  }

  /**
   * Enumerador dos Orcamentos Aprovados pelo Diretor do Job.
   *
   * @return array
   */
  public function enum_OrcamentosAprovados_Cliente() {
    $data = [];
    foreach ( $this->_OrcamentosAprovados_Cliente() as $orc ) {
      /** @var Orcamento $orc */
      $data[ $orc->id ] = $orc->nome;
    }

    return $data;
  }


  /**
   * Retorna o Valor dos Orçamentos aprovados pelo Cliente.
   *
   * @return int
   */
  public function ValorProposta() {
    $valor = 0;
    foreach ( $this->_OrcamentosAprovados_Cliente() as $orc ) {
      /** @var Orcamento $orc */
      $valor += $orc->CalcularValorTotal();
    }

    return $valor;
  }

  /**
   * Retorna o Valor dos Orçamentos aprovados pelo Cliente Formatado.
   *
   * @return string
   */
  public function ValorPropostaFormatado() {
    $valor = $this->ValorProposta();
    if ( $valor ) {
      return number_format( $valor / 100, 2, ',', '.' );
    }

    return '--';
  }

  /**
   * Utilizado para saber o icone da extensao do BriefingFile.
   *
   * @param string $ext
   * @return string
   */
  public static function faIcon( $ext ) {
    switch ( strtolower( $ext ) ) {
      case'doc';
      case'docx';
        return 'fa-file-word-o';
      case'xls';
      case'xlsx';
      case'cvs';
        return 'fa-file-excel-o';
      case'ppt';
      case'pptx';
        return 'fa-file-powerpoint-o';
      case'pdf';
        return 'fa-file-pdf-o';
      case'txt';
        return 'fa-file-text-o';
      case'jpg';
      case'png';
      case'webp';
        return 'fa-file-image-o';
      case'xml';
      case'json';
      case'html';
      case'js';
      case'css';
        return 'fa-file-code-o';
      case'mp4';
        return 'fa-file-video-o';
      case'mp3';
        return 'fa-file-audio-o';
      default;
        return 'fa-file-o';
    }
  }


  /**
   * Retorna o Array de Arquivos deste Job
   *
   * @return array
   */
  public function getAllBriefingFiles() {
    $arquivos = [];
    foreach ( $this->BriefingFiles as $f ) {
      $arq = [
        'id'       => $f->id,
        'local'    => '/uploads/jobs/' . $this->id . '/' . $f->arquivo,
        'arquivo'  => $f->arquivo,
        'extensao' => $f->extensao,
        'fa'       => Jobs::faIcon( $f->extensao )
      ];
      array_push( $arquivos, $arq );
    }

    return $arquivos;
  }

  /**
   * Valor Total deste Job.
   *
   * @var integer
   */
  public $valor_total;

  /**
   * Retorna a soma do Valor Total dos Orcamentos Aprovados pelo Cliente deste Job.
   *
   * @return integer
   */
  public function _OrcamentoAprovado_valor_total() {
    $valor = 0;
    foreach ( $this->_OrcamentosAprovados_Cliente() as $orc ) {
      $valor += $orc->CalcularValorTotal();
    }

    return $valor;
  }

  /**
   * Retorna as Parcelas deste Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Parcelas() {
    return $this->hasMany( JobParcela::class, 'job_id' );
  }

  /**
   * Retorna os JobLogs deste Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Logs() {
    return $this->hasMany( JobLogs::class, 'job_id' );
  }

  /**
   * Retorna os Logs deste Job.
   *
   * @return JobLogs[]
   */
  public function _Logs() {
    return $this->Logs()->orderBy( 'data', 'desc' )->get();
  }

  use ListagemPadronizada;

  public $sortable = [ 'id', 'nome_job', 'created_at', 'responsavel_id', 'cliente_cdc_id' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'id', 'nome_job' ],
        'label'  => 'Pesquise pelo ID ou Nome do Job'
      ],
      'search_advanced' => [
        'cliente_cdc_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Cliente:',
          'options' => Jobs::enum_clientes_centro_de_custo()
        ],
        'responsavel_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Responsável:',
          'options' => Funcionarios::enum_Funcionarios()
        ],
        'created_at'     => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Abertura após:',
          'label_before' => 'Abertura antes de:',
        ]
      ],
    ];
  }
}
