<?php

namespace App\Models\Comercial;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Comercial\Orcamento
 *
 * @property int $id
 * @property int $job_id
 * @property string $nome
 * @property string $data
 * @property mixed $descricao_geral
 * @property bool $orc_aprov_diretor
 * @property bool $orc_aprov_cliente
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\OrcamentoItemCI[] $ItensCI
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\OrcamentoItemCO[] $ItensCO
 * @property-read \App\Models\Comercial\Jobs $Job
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereDescricaoGeral( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereJobId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereOrcAprovCliente( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereOrcAprovDiretor( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\Orcamento whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class Orcamento extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'comercial_job_orc';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'data',
    'descricao_geral',
    'orc_aprov_diretor',
    'orc_aprov_cliente',
  ];

  /**
   * Retorna o CustosInternos do Job.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Job() {
    return $this->belongsTo( Jobs::class, 'job_id' );
  }

  /**
   * Retorna os itens de CustoInterno do Orcamento.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ItensCI() {
    return $this->hasMany( OrcamentoItemCI::class, 'orc_id' );
  }

  /**
   * Retorna um item especifico do CustoInterno do Orcamento.
   *
   * @param $id
   * @return OrcamentoItemCI|\Illuminate\Database\Eloquent\Relations\HasMany|\Illuminate\Database\Query\Builder
   */
  public function _ItensCI( $id ) {
    return $this->ItensCI()->find( $id );
  }

  /**
   * Retorna os itens de CustoOperacionalizacao do Orcamento.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ItensCO() {
    return $this->hasMany( OrcamentoItemCO::class, 'orc_id' );
  }

  /**
   * Retorna um item especifico do CustoOperacionalizacao do Orcamento.
   *
   * @param $id
   * @return OrcamentoItemCO|\Illuminate\Database\Eloquent\Relations\HasMany|\Illuminate\Database\Query\Builder
   */
  public function _ItensCO( $id ) {
    return $this->ItensCO()->find( $id );
  }

  /**
   * Retorna se eh aprovado pela Diretoria.
   *
   * @return string
   */
  public function _aprovDiretoria() {
    if ( $this->orc_aprov_diretor == 1 ) {
      return 'Aprovado';
    } elseif ( $this->orc_aprov_diretor == 2 ) {
      return 'Não Aprovado';
    } elseif ( $this->orc_aprov_diretor == 3 ) {
      return 'Reprovado';
    } else {
      return '';
    }
  }

  /**
   * Enumerador para o select de aprovacao do Diretoria.
   *
   * @return array
   */
  const enum_aprov_diretoria = [
    1 => 'Aprovado',
    2 => 'Não Aprovado',
    3 => 'Reprovado (Arquivar)',
  ];

  /**
   * Retorna se eh aprovado pelo Cliente.
   *
   * @return string
   */
  public function _aprovCliente() {
    if ( $this->orc_aprov_cliente == 1 ) {
      return 'Aprovado';
    } elseif ( $this->orc_aprov_cliente == 2 ) {
      return 'Não Aprovado';
    } else {
      return '';
    }
  }

  /**
   * Enumerador para o select de aprovacao do Cliente.
   *
   * @return array
   */
  const enum_aprov_cliente = [
    1 => 'Aprovado',
    2 => 'Não Aprovado',
  ];

  /**
   * Retorna a cor da aprovacao pela Diretoria.
   *
   * @return string
   */
  public function orc_aprov_diretoria_color() {
    if ( $this->orc_aprov_diretor == 1 ) {
      return 'success';
    } elseif ( $this->orc_aprov_diretor == 2 ) {
      return 'warning';
    } elseif ( $this->orc_aprov_diretor == 3 ) {
      return 'danger';
    } else {
      return '';
    }
  }

  /**
   * Retorna a cor da aprovacao do Cliente.
   *
   * @return string
   */
  public function orc_aprov_cliente_color() {
    if ( $this->orc_aprov_cliente == 1 ) {
      return 'success';
    } elseif ( $this->orc_aprov_cliente == 2 ) {
      return 'danger';
    } else {
      return '';
    }
  }

  /**
   * Calcula o Valor Total deste Orcamento.
   *
   * @return integer
   */
  public function CalcularValorTotal() {
    $valor_total = 0;
    foreach ( $this->ItensCI as $ci ) {
      $valor_total += $ci->Calcular() [ 'total' ];
    }
    foreach ( $this->ItensCO as $co ) {
      $valor_total += $co->Calcular() [ 'total' ];
    }

    return $valor_total;
  }

  /**
   * Calcula Todos os Valores deste Orcamento.
   *
   * @return array
   */
  public function CalcularTodosValores() {
    $valores = [
      'ci'          => [
        "valor"        => 0,
        "comissao"     => 0,
        "planejamento" => 0,
        "impostos"     => 0,
        "subtotal"     => 0,
      ],
      'co'          => [
        "valor"        => 0,
        "bv"           => 0,
        "planejamento" => 0,
        "impostos"     => 0,
        "subtotal"     => 0,
      ],
      'valor_total' => 0
    ];

    foreach ( $this->ItensCI as $ci ) {
      $v                                 = $ci->Calcular();
      $valores[ 'ci' ][ 'valor' ]        += $v[ 'sub_total' ];
      $valores[ 'ci' ][ 'comissao' ]     += $v[ 'comissao' ];
      $valores[ 'ci' ][ 'planejamento' ] += $v[ 'planejamento' ];
      $valores[ 'ci' ][ 'impostos' ]     += $v[ 'impostos' ];
      $valores[ 'ci' ][ 'subtotal' ]     += $v[ 'total' ];
    }
    foreach ( $this->ItensCO as $co ) {
      $v                                 = $co->Calcular();
      $valores[ 'co' ][ 'valor' ]        += $v[ 'sub_total' ];
      $valores[ 'co' ][ 'bv' ]           += $v[ 'bv' ];
      $valores[ 'co' ][ 'planejamento' ] += $v[ 'planejamento' ];
      $valores[ 'co' ][ 'impostos' ]     += $v[ 'impostos' ];
      $valores[ 'co' ][ 'subtotal' ]     += $v[ 'total' ];
    }
    $valores[ 'valor_total' ] = $valores[ 'ci' ][ 'subtotal' ] + $valores[ 'co' ][ 'subtotal' ];

    return $valores;
  }
}
