<?php

namespace App\Models\Comercial;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Comercial\OrcamentoItemCO
 *
 * @property int $id
 * @property int $orc_id
 * @property string $nome
 * @property mixed $descricao
 * @property int $arredondamento
 * @property int $taxa_bv
 * @property int $taxa_planejamento
 * @property int $taxa_impostos
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Comercial\Orcamento $Orcamento
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Comercial\OrcamentoItemCOServico[] $Servicos
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereArredondamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereDescricao( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereOrcId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereTaxaBv( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereTaxaImpostos( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereTaxaPlanejamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Comercial\OrcamentoItemCO whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class OrcamentoItemCO extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'comercial_job_orc_co';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'descricao',
    'arredondamento',
    'taxa_bv',
    'taxa_planejamento',
    'taxa_impostos',
  ];

  public static $custo_operacionalizacao_default = [
    'arredondamento'    => 0,
    'taxa_bv'           => 10,
    'taxa_planejamento' => 0,
    'taxa_impostos'     => 20
  ];

  /**
   * Retorna os Servicos deste OrcamentoItemCO.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function Servicos() {
    return $this->hasMany( OrcamentoItemCOServico::class, 'co_id' );
  }

  /**
   * Retorna um Servico deste OrcamentoItemCO.
   *
   * @param $id
   * @return OrcamentoItemCIServico | \Illuminate\Database\Query\Builder
   */
  public function _Servicos( $id ) {
    return $this->Servicos()->find( $id );
  }

  /**
   * Retorna o Orcamento q este Item pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Orcamento() {
    return $this->belongsTo( Orcamento::class, 'orc_id' );
  }

  /**
   * Calcula o valor total deste Item.
   *
   * @return array
   */
  public function Calcular() {
    /*
      subTT * 1+bv *1+planej * 1+impost = TT
      (subTT + arr) * 1+bv *1+planej * 1+impost = ceil(TT)
      falta = ceil(TT) - TT
      arr = falta / 1+impost / 1+planej / 1+bv
    */
    $servicos = $this->Servicos;

    // 0. SOMA OS ITENS
    $sub_total = 0;
    foreach ( $servicos as $servico ) {
      $sub_total += $servico->valor_total;
    }
    $sub_total = round( $sub_total );

    // 1. calcular valor com centavos
    $v1 = $sub_total;
    $v1 *= 1 + ( $this->taxa_bv / 100 );
    $v1 *= 1 + ( $this->taxa_planejamento / 100 );
    $v1 *= 1 + ( $this->taxa_impostos / 100 );
    $v1 = round( $v1 );

    $falta = ( ceil( $v1 / 100 ) * 100 ) - $v1;

    // 2. descobre o valor para chegar no arredondado e salva
    $arredondamento = 0;
    if ( $falta > 0 ) {
      $arredondamento = $falta;
      $arredondamento /= 1 + ( $this->taxa_impostos / 100 );
      $arredondamento /= 1 + ( $this->taxa_planejamento / 100 );
      $arredondamento /= 1 + ( $this->taxa_bv / 100 );
      $arredondamento = round( $arredondamento );
    }
    $this->arredondamento = $arredondamento;
    $this->save();

    // 3. Calcula com o arredondamento incluso
    $sub_total    = round( $sub_total + $arredondamento );
    $bv           = round( $sub_total * $this->taxa_bv / 100 );
    $planejamento = round( ( $sub_total + $bv ) * $this->taxa_planejamento / 100 );
    $impostos     = round( ( $sub_total + $bv + $planejamento ) * $this->taxa_impostos / 100 );
    $total        = round( $sub_total + $bv + $planejamento + $impostos, -2 );

    $dados                        = [];
    $dados[ 'itens' ]             = $servicos;
    $dados[ 'arredondamento' ]    = intval( $this->arredondamento );
    $dados[ 'sub_total' ]         = intval( $sub_total );
    $dados[ 'taxa_bv' ]           = intval( $this->taxa_bv );
    $dados[ 'bv' ]                = intval( $bv );
    $dados[ 'taxa_planejamento' ] = intval( $this->taxa_planejamento );
    $dados[ 'planejamento' ]      = intval( $planejamento );
    $dados[ 'taxa_impostos' ]     = intval( $this->taxa_impostos );
    $dados[ 'impostos' ]          = intval( $impostos );
    $dados[ 'total' ]             = intval( $total );

    return $dados;
  }
}
