<?php

namespace App\Models\Config;

use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Config\FaixaSalarial
 *
 * @property integer $id
 * @property integer $nivel
 * @property integer $inferior
 * @property integer $media
 * @property integer $superior
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereNivel( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereInferior( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereMedia( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereSuperior( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Config\FaixaSalarial whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class FaixaSalarial extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'configadmin_faixasalarial';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nivel', 'inferior', 'media', 'superior'
  ];


  /**
   * Retorna um nivel ja presente no DB, senao nulls
   *
   * @param $nivel
   * @return FaixaSalarial
   */
  public static function getUmPorNivel( $nivel ) {
    $fs = FaixaSalarial::where( 'nivel', '=', $nivel )->first();
    if ( $fs == null ) {
      $fs           = new FaixaSalarial();
      $fs->inferior = null;
      $fs->media    = '0,00';
      $fs->superior = null;
    }
    return $fs;
  }

  /**
   * Denominacao generica dos niveis
   *
   * @return array
   */
  public static function enum_NivelGenerico() {
    return [
      1  => '1 - Estagiário',
      2  => '2 - Auxiliar',
      3  => '3 - Analista I',
      4  => '4 - Analista II',
      5  => '5 - Analista III',
      6  => '6 - Especialista I',
      7  => '7 - Especialista II',
      8  => '8 - Especialista III',
      9  => '9 - Coordenação I',
      10 => '10 - Coordenação II',
      11 => '11 - Coordenação III',
      12 => '12 - Gerencia I',
      13 => '13 - Gerencia II',
      14 => '14 - Gerencia III',
      15 => '15 - Direção Operacional I',
      16 => '16 - Direção Operacional II',
      17 => '17 - Direção Executiva'
    ];
  }

  public static function getfaixas() {
    $f = [];
    foreach ( range( 1, 17 ) as $r ) {
      $f[ $r ] = FaixaSalarial::getUmPorNivel( $r );
    }
    return $f;
  }
}
