<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\ContaDeConsumo
 *
 * @property int $id
 * @property string $nome
 * @property string $data
 * @property int $valor
 * @property bool $pago
 * @property string $frequencia
 * @property string $forma_pagamento
 * @property string $nota_fiscal
 * @property string $boleto
 * @property string $comprovante
 * @property int $gerador_id
 * @property int $despesas_id
 * @property int $conta_id
 * @property int $centros_de_custo_cadaris_id
 * @property mixed $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria $ContaBancaria
 * @property-read \App\Models\Cadastros\PlanoDeContasItem $Despesa
 * @property-read \App\Models\Financeiro\ContaDeConsumoGerador $GeradoPor
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereBoleto( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereComprovante( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereContaId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereDespesasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereFormaPagamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereFrequencia( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereGeradorId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereNotaFiscal( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo wherePago( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumo whereValor( $value )
 * @mixin \Eloquent
 */
class ContaDeConsumo extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_contas_consumo';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'data',
    'valor',
    'pago',
    'frequencia',
    'forma_pagamento',
    'nota_fiscal',
    'boleto',
    'comprovante',
    'gerador_id',
    'despesas_id',
    'conta_id',
    'centros_de_custo_cadaris_id',
    'obs',
  ];

  /**
   * Pasta do Boletos desta Conta.
   *
   * @return string
   */
  public function getLocalBoleto() {
    return public_path( 'uploads/contas_de_consumo/boletos' . $this->id );
  }

  /**
   * Link para o Boleto.
   *
   * @return string
   */
  public function getLocalBoletoLink() {
    return 'uploads/contas_de_consumo/boletos/' . $this->id . '/' . $this->boleto;
  }

  /**
   * Pasta dos Comprovante desta Conta.
   *
   * @return string
   */
  public function getLocalComprovante() {
    return public_path( 'uploads/contas_de_consumo/comprovantes/' . $this->id );
  }

  /**
   * Link para o Comprovante.
   *
   * @return string
   */
  public function getLocalComprovanteLink() {
    return 'uploads/contas_de_consumo/comprovantes/' . $this->id . '/' . $this->comprovante;
  }

  /**
   * Retorna a ContaDeConsumoGerador q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function GeradoPor() {
    return $this->belongsTo( ContaDeConsumoGerador::class, 'gerador_id' );
  }

  /**
   * Retorna o nome da ContaDeConsumoGerador q esta Conta pertence.
   *
   * @return string
   */
  public function GeradoPorNome() {
    return $this->gerador_id ? ( $this->GeradoPor ? $this->GeradoPor->nome : '' ) : '';
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna a PlanoDeContasItem q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( PlanoDeContasItem::class, 'despesas_id' );
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna o Codigo e Nome da Despesa q esta Conta pertence.
   *
   * @return string
   */
  public function DespesaCodigoNome() {
    return $this->Despesa ? $this->Despesa->getContaNome() : 'SEM DESPESA ASSOCIADA';
  }

  /**
   * Retorna o Codigo Reduzido da Despesa desta Conta.
   *
   * @return string
   */
  public function DespesaCodigoReduzida() {
    return $this->Despesa ? $this->Despesa->conta_reduzida : '?';
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta ContaDeConsumo.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_cc_cdcc_fk' );
  }

  /**
   * Retorna os ContaDeConsumo entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | ContaDeConsumo[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return ContaDeConsumo
      ::whereBetween( 'data', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  use ListagemPadronizada;

  public $sortable = [ 'nome', 'data', 'valor', 'pago', 'despesas_id' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'nome' ],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'conta_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'pago' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'despesas_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Despesa:',
          'options' => \App\Models\Cadastros\PlanoDeContas::enum_despesas_reduzida()
        ],
        'data'     => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Vencimento após:',
          'label_before' => 'Vencimento antes de:',
        ]
      ],
    ];
  }
}
