<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\ContaDeConsumoGerador
 *
 * @property int $id
 * @property string $nome
 * @property string $frequencia
 * @property string $forma_pagamento
 * @property int $despesas_id
 * @property mixed $obs
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Models\Financeiro\ContaDeConsumo[] $ContasGeradas
 * @property-read \App\Models\Cadastros\PlanoDeContasItem $Despesa
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereDespesasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereFormaPagamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereFrequencia( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereObs( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaDeConsumoGerador whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class ContaDeConsumoGerador extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_contas_consumo_gerador';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'frequencia',
    'forma_pagamento',
    'despesas_id',
    'obs'
  ];

  /**
   * Retorna as Contas de Consumos gerados por este Gerador.
   *
   * @return \Illuminate\Database\Eloquent\Relations\HasMany | \Illuminate\Database\Query\Builder
   */
  public function ContasGeradas() {
    return $this->hasMany( ContaDeConsumo::class, 'gerador_id' );
  }

  /**
   * Retorna a PlanoDeContasItem q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( PlanoDeContasItem::class, 'despesas_id' );
  }

  /**
   * Enum de Contas de Consumos Gerador.
   *
   * @return array
   */
  public static function enum_geradores() {
    $contas = [];
    foreach ( ContaDeConsumoGerador::orderBy( 'nome' )->get() as $c ) {
      $contas[ $c->id ] = $c->nome;
    }

    return $contas;
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function DespesaCodigoNome() {
    return $this->Despesa ? $this->Despesa->getContaNome() : 'SEM CONTA ASSOCIADA';
  }

  use ListagemPadronizada;

  public $sortable = [ 'nome', 'frequencia', 'forma_pagamento', 'despesas_id' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'nome' ],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'despesas_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Despesa:',
          'options' => \App\Models\Cadastros\PlanoDeContas::enum_despesas_reduzida()
        ]
      ],
    ];
  }
}
