<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\FornecedoresEmpresas;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\ContaFornecedor
 *
 * @property int $id
 * @property string $nome
 * @property string $data
 * @property bool $pago
 * @property int $valor
 * @property string $forma_pagamento
 * @property string $nota_fiscal
 * @property string $boleto
 * @property string $comprovante
 * @property int $fornecedor_id
 * @property int $conta_id
 * @property int|null $plano_de_contas_id
 * @property int $centros_de_custo_cadaris_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria $ContaBancaria
 * @property-read \App\Models\Cadastros\FornecedoresEmpresas $Fornecedor
 * @property-read \App\Models\Cadastros\PlanoDeContasItem $PlanoDeContas
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereBoleto( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereComprovante( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereContaId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereFormaPagamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereFornecedorId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereNotaFiscal( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor wherePago( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor wherePlanoDeContasId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\ContaFornecedor whereValor( $value )
 * @mixin \Eloquent
 */
class ContaFornecedor extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_contas_fornecedores';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'data',
    'pago',
    'valor',
    'forma_pagamento',
    'nota_fiscal',
    'boleto',
    'comprovante',
    'fornecedor_id',
    'conta_id',
    'plano_de_contas_id',
    'centros_de_custo_cadaris_id',
  ];

  /**
   * Propriedades q sao datas.
   *
   * @return array
   */
  public function getDates() {
    return [ 'created_at', 'updated_at' ];
  }

  /**
   * Pasta do Boleto desta Conta.
   *
   * @return string
   */
  public function getLocalBoleto() {
    return public_path( 'uploads/contas_de_fornecedor/boletos/' . $this->id );
  }

  /**
   * Link para o Boleto.
   *
   * @return string
   */
  public function getLocalBoletoLink() {
    return 'uploads/contas_de_fornecedor/boletos/' . $this->id . '/' . $this->boleto;
  }

  /**
   * Pasta do Comprovante desta Conta.
   *
   * @return string
   */
  public function getLocalComprovante() {
    return public_path( 'uploads/contas_de_fornecedor/comprovantes/' . $this->id );
  }

  /**
   * Link para o Comprovante.
   *
   * @return string
   */
  public function getLocalComprovanteLink() {
    return 'uploads/contas_de_fornecedor/comprovantes/' . $this->id . '/' . $this->comprovante;
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna o FornecedoresEmpresas q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Fornecedor() {
    return $this->belongsTo( FornecedoresEmpresas::class, 'fornecedor_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta ContaFornecedor.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_cf_cdcc_fk' );
  }

  /**
   * Retorna o PlanoDeContas (Despesa) desta ContaFornecedor.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | PlanoDeContasItem
   */
  public function PlanoDeContas() {
    return $this->belongsTo( PlanoDeContasItem::class, 'plano_de_contas_id' );
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function FornecedorNome() {
    return $this->Fornecedor ? $this->Fornecedor->getCodigoNome() : 'FORNECEDOR NÃO ASSOCIADO';
  }

  /**
   * Retorna os ContaFornecedor entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | ContaFornecedor[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return ContaFornecedor
      ::whereBetween( 'data', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  use ListagemPadronizada;

  public $sortable = [ 'nome', 'data', 'pago', 'valor', 'conta_id' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'nome'],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'conta_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'pago' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'data'     => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Data após:',
          'label_before' => 'Data antes de:',
        ]
      ],
    ];
  }
}
