<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\Funcionarios;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\Ferias
 *
 * @property int $id
 * @property string $data_pagamento
 * @property int $pago
 * @property int $dias
 * @property string $data_inicio
 * @property string $data_fim
 * @property int $valor_salario_mensal
 * @property int $valor_acrescimo
 * @property int $valor_ferias
 * @property int $valor_retido
 * @property int $valor_total_bruto
 * @property int $valor_total_liquido
 * @property int|null $funcionario_id
 * @property int|null $conta_id
 * @property int|null $centros_de_custo_cadaris_id
 * @property int|null $plano_de_contas_item_id
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria|null $ContaBancaria
 * @property-read \App\Models\Cadastros\Funcionarios|null $Funcionario
 * @property-read \App\Models\Cadastros\PlanoDeContasItem|null $Despesa
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereContaId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereCreatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereDataFim( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereDataInicio( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereDataPagamento( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereDias( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereFuncionarioId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias wherePago( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereDespesa( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereValorAcrescimo( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereValorFerias( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereValorRetido( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereValorSalarioMensal( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereValorTotalBruto( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias whereValorTotalLiquido( $value )
 * @mixin \Eloquent
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Ferias wherePlanoDeContasItemId( $value )
 */
class Ferias extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_ferias';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'funcionario_id',
    'dias',
    'data_inicio',
    'data_fim',

    'conta_id',
    'centros_de_custo_cadaris_id',
    'plano_de_contas_item_id',
    'data_pagamento',
    'pago',

    'valor_salario_mensal',
    'valor_ferias',
    'valor_acrescimo',

    'valor_retido',
    'valor_total_bruto',
    'valor_total_liquido',
  ];

  /**
   * Propriedades q sao datas.
   *
   * @return array
   */
  public function getDates() {
    return [ 'created_at', 'updated_at' ];
  }

  /**
   * Retorna o Funcionario q esta Ferias pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionario_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta Ferias.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_ff_cdcc_fk' );
  }

  /**
   * Retorna o nome do Funcionario.
   *
   * @return string
   */
  public function FuncionarioNome() {
    return $this->funcionario_id ? $this->Funcionario->nome : 'Funcionário não Associado';
  }

  /**
   * Retorna a ContaBancaria q este Salario pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna a ContaBancaria q este Salario pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna a PlanoDeContasItem q esta Ferias pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( PlanoDeContasItem::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna o Codigo e Nome da Despesa q esta Ferias pertence.
   *
   * @return string
   */
  public function DespesaCodigoNome() {
    return $this->Despesa ? $this->Despesa->getContaNome() : 'SEM DESPESA ASSOCIADA';
  }

  /**
   * Retorna o Codigo Reduzido da Despesa desta Ferias.
   *
   * @return string
   */
  public function DespesaCodigoReduzida() {
    return $this->Despesa ? $this->Despesa->conta_reduzida : '?';
  }

  /**
   * Retorna os Salarios entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | Ferias[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return Ferias
      ::whereBetween( 'data_pagamento', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data_pagamento' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data_pagamento;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data_pagamento < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data_pagamento );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data_pagamento );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data_pagamento );
    }
  }

  use ListagemPadronizada;

  public $sortable = [ 'pago', 'funcionario_id', 'data_pagamento', 'conta_id', 'data_inicio', 'valor_total_bruto' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'Funcionario.nome' ],
        'label'  => 'Pesquise pelo Nome do Funcionário'
      ],
      'search_advanced' => [
        'pago'           => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'conta_id'       => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'funcionario_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Funcionário:',
          'options' => Funcionarios::enum_Funcionarios()
        ],
        'data_pagamento' => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Data após:',
          'label_before' => 'Data antes de:',
        ]
      ],
    ];
  }
}
