<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\FornecedoresEmpresas;
use App\Models\Cadastros\PlanoDeContasItem;
use App\Models\Comercial\Jobs;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Arr;

/**
 * App\Models\Financeiro\OutroRecebimento
 *
 * @property int $id
 * @property string $nome
 * @property string $data
 * @property int $pago
 * @property int $valor
 * @property string|null $forma_pagamento
 * @property string|null $nota_fiscal
 * @property string|null $boleto
 * @property string|null $comprovante
 * @property int|null $fornecedor_id
 * @property int|null $conta_id
 * @property int|null $cod_receita
 * @property int|null $centros_de_custo_cadaris_id
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria|null $ContaBancaria
 * @property-read \App\Models\Cadastros\FornecedoresEmpresas|null $Fornecedor
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereBoleto( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereCodReceita( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereComprovante( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereContaId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereCreatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereData( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereFormaPagamento( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereFornecedorId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereNome( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereNotaFiscal( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento wherePago( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\OutroRecebimento whereValor( $value )
 * @mixin \Eloquent
 */
class OutroRecebimento extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_outros_recebimentos';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'data',
    'pago',
    'valor',
    'forma_pagamento',
    'nota_fiscal',
    'boleto',
    'comprovante',
    'fornecedor_id',
    'conta_id',
    'cod_receita',
    'centros_de_custo_cadaris_id',
  ];

  /**
   * Propriedades q sao datas.
   *
   * @return array
   */
  public function getDates() {
    return [ 'created_at', 'updated_at' ];
  }

  /**
   * Pasta do Boleto desta Conta.
   *
   * @return string
   */
  public function getLocalBoleto() {
    return public_path( 'uploads/outros_recebimentos/boletos/' . $this->id );
  }

  /**
   * Link para o Boleto.
   *
   * @return string
   */
  public function getLocalBoletoLink() {
    return 'uploads/outros_recebimentos/boletos/' . $this->id . '/' . $this->boleto;
  }

  /**
   * Pasta do Comprovante desta Conta.
   *
   * @return string
   */
  public function getLocalComprovante() {
    return public_path( 'uploads/outros_recebimentos/comprovantes/' . $this->id );
  }

  /**
   * Link para o Comprovante.
   *
   * @return string
   */
  public function getLocalComprovanteLink() {
    return 'uploads/outros_recebimentos/comprovantes/' . $this->id . '/' . $this->comprovante;
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna o FornecedoresEmpresas q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Fornecedor() {
    return $this->belongsTo( FornecedoresEmpresas::class, 'fornecedor_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta ContaFornecedor.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_or_cdcc_fk' );
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function FornecedorNome() {
    return $this->Fornecedor ? $this->Fornecedor->getCodigoNome() : 'FORNECEDOR NÃO ASSOCIADO';
  }

  /**
   * Retorna o codigo da receita deste Job.
   *
   * @return string
   */
  public function _codReceitaNome() {
    return \App\Models\Cadastros\CodigoReceita::getCodReceitaNome( $this->cod_receita );
  }

  /**
   * Retorna os ContaFornecedor entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | OutroRecebimento[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return OutroRecebimento
      ::whereBetween( 'data', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }


  use ListagemPadronizada;

  public $sortable = [ 'nome', 'data', 'pago', 'valor', 'conta_id', ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'nome' ],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'conta_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'pago' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'data'     => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Vencimento após:',
          'label_before' => 'Vencimento antes de:',
        ]
      ],
    ];
  }
}
