<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\Funcionarios;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\Rescisao
 *
 * @property int $id
 * @property string $nome
 * @property string $data
 * @property int $pago
 * @property int $salario_trabalhado
 * @property int $terco_ferias
 * @property int $ferias
 * @property int $hora_extra
 * @property int $dsr_salario
 * @property int $ferias_proporcionais
 * @property int $aviso_previo
 * @property int $salario_13_proporcional
 * @property int $salario_13
 * @property int $ferias_paga
 * @property int $previdencia
 * @property int $previdencia_salario_13
 * @property int $inss_ferias
 * @property int $desc_vr
 * @property int $desc_vt
 * @property int $valor_total
 * @property int|null $funcionario_id
 * @property int|null $conta_id
 * @property int|null $centros_de_custo_cadaris_id
 * @property int|null $plano_de_contas_item_id
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria|null $ContaBancaria
 * @property-read \App\Models\Cadastros\Funcionarios|null $Funcionario
 * @property-read \App\Models\Cadastros\PlanoDeContasItem|null $Despesa
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereAvisoPrevio( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereContaId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereCreatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereData( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereDescVr( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereDescVt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereDsrSalario( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereFerias( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereFeriasPaga( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereFeriasProporcionais( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereFuncionarioId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereHoraExtra( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereInssFerias( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereNome( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao wherePago( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereDespesa( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao wherePrevidencia( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao wherePrevidenciaSalario13( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereSalario13( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereSalario13Proporcional( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereSalarioTrabalhado( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereTercoFerias( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereValorTotal( $value )
 * @mixin \Eloquent
 * @property int $indenizacao
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao whereIndenizacao( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Rescisao wherePlanoDeContasItemId( $value )
 */
class Rescisao extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_rescisao';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'data',
    'pago',

    'salario_trabalhado',
    'terco_ferias',
    'ferias',
    'hora_extra',
    'dsr_salario',
    'ferias_proporcionais',
    'aviso_previo',
    'salario_13_proporcional',
    'salario_13',
    'ferias_paga',

    'previdencia',
    'previdencia_salario_13',
    'inss_ferias',
    'indenizacao',
    'desc_vr',
    'desc_vt',

    'valor_total',

    'funcionario_id',
    'conta_id',
    'centros_de_custo_cadaris_id',
    'plano_de_contas_item_id',
  ];


  /**
   * Retorna a ContaBancaria q esta Rescisao pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna o Funcionarios q esta Rescisao pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionario_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta Rescisao.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_r_cdcc_fk' );
  }

  /**
   * Retorna a PlanoDeContasItem q esta Rescisao pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( PlanoDeContasItem::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna o Codigo e Nome da Despesa q esta Rescisao pertence.
   *
   * @return string
   */
  public function DespesaCodigoNome() {
    return $this->Despesa ? $this->Despesa->getContaNome() : 'SEM DESPESA ASSOCIADA';
  }

  /**
   * Retorna o Codigo Reduzido da Despesa desta Rescisao.
   *
   * @return string
   */
  public function DespesaCodigoReduzida() {
    return $this->Despesa ? $this->Despesa->conta_reduzida : '?';
  }

  /**
   * Retorna a ContaBancaria q esta Rescisao pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna a Funcionario q esta Rescisao pertence.
   *
   * @return string
   */
  public function FuncionarioNome() {
    return $this->Funcionario ? $this->Funcionario->nome : 'FUNCIONÁRIO NÃO ASSOCIADO';
  }

  /**
   * Retorna as Rescisões entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | Rescisao[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return Rescisao
      ::whereBetween( 'data', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  use ListagemPadronizada;

  public $sortable = [ 'nome', 'data', 'pago', 'conta_id', 'valor_total' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'nome' ],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'pago'     => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'conta_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'data'     => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Data após:',
          'label_before' => 'Data antes de:',
        ]
      ],
    ];
  }
}
