<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\Funcionarios;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\RetiradaDeSocios
 *
 * @property int $id
 * @property string $nome
 * @property string $data
 * @property bool $pago
 * @property int $valor
 * @property string $forma_pagamento
 * @property string $nota_fiscal
 * @property string $boleto
 * @property string $comprovante
 * @property int $funcionario_id
 * @property int $conta_id
 * @property int $centros_de_custo_cadaris_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria $ContaBancaria
 * @property-read \App\Models\Cadastros\Funcionarios $Funcionario
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereBoleto( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereComprovante( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereContaId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereData( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereFormaPagamento( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereFuncionarioId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereNome( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereNotaFiscal( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios wherePago( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Financeiro\RetiradaDeSocios whereValor( $value )
 * @mixin \Eloquent
 */
class RetiradaDeSocios extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_retirada_de_socios';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'nome',
    'data',
    'pago',
    'valor',
    'forma_pagamento',
    'nota_fiscal',
    'boleto',
    'comprovante',
    'funcionario_id',
    'conta_id',
    'centros_de_custo_cadaris_id',
  ];

  /**
   * Propriedades q sao datas.
   *
   * @return array
   */
  public function getDates() {
    return [ 'created_at', 'updated_at' ];
  }

  /**
   * Pasta do Boleto desta Conta.
   *
   * @return string
   */
  public function getLocalBoleto() {
    return public_path( 'uploads/retirada_de_socios/boletos/' . $this->id );
  }

  /**
   * Link para o Boleto.
   *
   * @return string
   */
  public function getLocalBoletoLink() {
    return 'uploads/retirada_de_socios/boletos/' . $this->id . '/' . $this->boleto;
  }

  /**
   * Pasta do Comprovante desta Conta.
   *
   * @return string
   */
  public function getLocalComprovante() {
    return public_path( 'uploads/retirada_de_socios/comprovantes/' . $this->id );
  }

  /**
   * Link para o Comprovante.
   *
   * @return string
   */
  public function getLocalComprovanteLink() {
    return 'uploads/retirada_de_socios/comprovantes/' . $this->id . '/' . $this->comprovante;
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna o Funcionarios q esta Retirada de Socios pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionario_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta ContaFornecedor.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_rs_cdcc_fk' );
  }

  /**
   * Retorna a ContaBancaria q esta Conta pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna a Funcionario q esta Conta pertence.
   *
   * @return string
   */
  public function FuncionarioNome() {
    return $this->Funcionario ? $this->Funcionario->nome : 'FUNCIONÁRIO NÃO ASSOCIADO';
  }

  /**
   * Retorna os ContaFornecedor entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | RetiradaDeSocios[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return RetiradaDeSocios
      ::whereBetween( 'data', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  use ListagemPadronizada;

  public $sortable = [ 'pago', 'nome', 'data', 'conta_id', 'valor' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'nome' ],
        'label'  => 'Pesquise pelo Nome'
      ],
      'search_advanced' => [
        'pago'     => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'conta_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'data'     => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Data após:',
          'label_before' => 'Data antes de:',
        ]
      ],
    ];
  }
}
