<?php

namespace App\Models\Financeiro;

use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\Funcionarios;
use App\Models\Cadastros\PlanoDeContasItem;
use App\Models\Cadastros\Usuarios;
use App\Notifications\HoleriteNotification;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\Salario
 *
 * @property int $id
 * @property int $ano
 * @property int $mes
 * @property string $data_pagamento
 * @property int $dias_uteis
 * @property int $pago
 * @property int $valor_salario
 * @property int $valor_salario_desc
 * @property int $valor_salario_total
 * @property int $valor_vr_unitario
 * @property int $valor_vr
 * @property int $valor_vr_desc_dia
 * @property int $valor_vr_desc
 * @property int $valor_vr_total
 * @property int $valor_vt_unitario
 * @property int $valor_vt
 * @property int $valor_vt_desc_dia
 * @property int $valor_vt_desc
 * @property int $valor_vt_total
 * @property int $comissao
 * @property int $reembolso
 * @property int $valor_total
 * @property int|null $funcionario_id
 * @property int|null $conta_id
 * @property int|null $centros_de_custo_cadaris_id
 * @property int|null $plano_de_contas_item_id
 * @property string|null $holerite
 * @property string|null $holerite_nome
 * @property int $holerite_visited
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria|null $ContaBancaria
 * @property-read \App\Models\Cadastros\PlanoDeContasItem|null $Despesa
 * @property-read \App\Models\Cadastros\Funcionarios|null $Funcionario
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereAno( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereComissao( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereContaId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereCreatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereDataPagamento( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereDiasUteis( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereFuncionarioId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereHolerite( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereHoleriteNome( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereHoleriteVisited( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereMes( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario wherePago( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario wherePlanoDeContasItemId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereReembolso( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorSalario( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorSalarioDesc( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorSalarioTotal( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorTotal( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVr( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVrDesc( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVrDescDia( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVrTotal( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVrUnitario( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVtDesc( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVtDescDia( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVtTotal( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario whereValorVtUnitario( $value )
 * @mixin \Eloquent
 */
class Salario extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_salarios';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'funcionario_id',
    'ano',
    'mes',
    'data_pagamento',
    'dias_uteis',
    'conta_id',
    'centros_de_custo_cadaris_id',
    'plano_de_contas_item_id',
    'pago',

    // Salario
    'valor_salario',
    'valor_salario_desc',
    'valor_salario_total',

    // VR
    'valor_vr_unitario',
    'valor_vr',
    'valor_vr_desc_dia',
    'valor_vr_desc',
    'valor_vr_total',

    // VT
    'valor_vt_unitario',
    'valor_vt',
    'valor_vt_desc_dia',
    'valor_vt_desc',
    'valor_vt_total',

    // Acrescimos
    'comissao',
    'reembolso',

    'valor_total',

    'holerite',
    'holerite_nome',
    'holerite_visited',
  ];

  /**
   * Propriedades q sao datas.
   *
   * @return array
   */
  public function getDates() {
    return [ 'created_at', 'updated_at', 'data' ];
  }


  public static $enum_mes = [
    1  => 'Janeiro',
    2  => 'Fevereiro',
    3  => 'Março',
    4  => 'Abril',
    5  => 'Maio',
    6  => 'Junho',
    7  => 'Julho',
    8  => 'Agosto',
    9  => 'Setembro',
    10 => 'Outubro',
    11 => 'Novembro',
    12 => 'Dezembro'
  ];

  /**
   * Retorna o Funcionario q este Salario pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionario_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris deste Salario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_fs_cdcc_fk' );
  }

  /**
   * Retorna a Salario q esta Conta pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( PlanoDeContasItem::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna o Codigo e Nome da Despesa q este Salario pertence.
   *
   * @return string
   */
  public function DespesaCodigoNome() {
    return $this->Despesa ? $this->Despesa->getContaNome() : 'SEM DESPESA ASSOCIADA';
  }

  /**
   * Retorna o Codigo Reduzido da Despesa deste Salario.
   *
   * @return string
   */
  public function DespesaCodigoReduzida() {
    return $this->Despesa ? $this->Despesa->conta_reduzida : '?';
  }

  /**
   * Retorna o nome do Funcionario.
   *
   * @return string
   */
  public function FuncionarioNome() {
    return $this->funcionario_id ? $this->Funcionario->nome : 'Funcionário não Associado';
  }

  /**
   * Retorna a ContaBancaria q este Salario pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna a ContaBancaria q este Salario pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna os Salarios entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | Salario[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return Salario
      ::whereBetween( 'data_pagamento', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data_pagamento' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data_pagamento;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data_pagamento < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data_pagamento );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data_pagamento );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data_pagamento );
    }
  }

  /**
   * @param \Illuminate\Http\UploadedFile $file
   */
  public function storeHolerite( \Illuminate\Http\UploadedFile $file ) {
    $filename = $file->getClientOriginalName();
    $local    = $this->getLocalHolerite();

    $local_hash =
      $this->ano . '_' .
      $this->mes . '_' .
      $this->funcionario_id . '_' .
      $this->id . '_' .
      \time();

    $file->move( $local, $local_hash );

    $this->update( [
      'holerite'         => $local_hash,
      'holerite_nome'    => $filename,
      'holerite_visited' => self::HOLERITE_VISITED_SENT
    ] );

    // Send Notification
    $funcionario = $this->Funcionario;
    if ( !$funcionario ) {
      return;
    }
    $usuario = $funcionario->user;
    if ( !$usuario ) {
      $usuario                  = new Usuarios();
      $usuario->name            = $funcionario->nome;
      $usuario->email           = $funcionario->email;
      $usuario->funcionarios_id = $funcionario->id;
    }
    $usuario->notify( new HoleriteNotification( $this, $funcionario ) );
  }

  /**
   * @return string
   */
  public function getLocalHolerite() {
    return storage_path( 'app/salarios_holerites' );
  }

  /**
   * Path Absoluto do holerite armazenado em /storage/app.
   *
   * @return string
   */
  public function getHoleriteFileAbsolutePath() {
    return storage_path( 'app/salarios_holerites/' . $this->holerite );
  }

  const HOLERITE_VISITED_NONE       = 0;
  const HOLERITE_VISITED_SENT       = 1;
  const HOLERITE_VISITED_VISUALIZED = 2;
}
