<?php

namespace App\Models\Financeiro;

use App\ListagemPadronizada;
use App\Models\Cadastros\CentrosDeCustoCadaris;
use App\Models\Cadastros\Funcionarios;
use App\Models\Cadastros\PlanoDeContasItem;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Financeiro\Salario13
 *
 * @property int $id
 * @property string $data
 * @property int $pago
 * @property int $valor_salario_13
 * @property int $valor_desc
 * @property int $valor_total
 * @property int|null $funcionario_id
 * @property int|null $conta_id
 * @property int|null $centros_de_custo_cadaris_id
 * @property int|null $plano_de_contas_item_id
 * @property \Carbon\Carbon|null $created_at
 * @property \Carbon\Carbon|null $updated_at
 * @property-read \App\Models\Cadastros\CentrosDeCustoCadaris $CentrosDeCustoCadaris
 * @property-read \App\Models\Financeiro\ContaBancaria|null $ContaBancaria
 * @property-read \App\Models\Cadastros\Funcionarios|null $Funcionario
 * @property-read \App\Models\Cadastros\PlanoDeContasItem|null $Despesa
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereCentrosDeCustoCadarisId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereContaId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereCreatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereData( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereFuncionarioId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereId( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 wherePago( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereDespesa( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereUpdatedAt( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereValorDesc( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereValorSalario13( $value )
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 whereValorTotal( $value )
 * @mixin \Eloquent
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Financeiro\Salario13 wherePlanoDeContasItemId( $value )
 */
class Salario13 extends Model {
  /**
   * A tabela associada com este Model.
   *
   * @var string
   */
  protected $table = 'financeiro_salarios_13';

  /**
   * Os atributos que são atribuíveis em massa.
   *
   * @var array
   */
  protected $fillable = [
    'data',
    'pago',

    'valor_salario_13',
    'valor_desc',
    'valor_total',

    'funcionario_id',
    'conta_id',
    'centros_de_custo_cadaris_id',
    'plano_de_contas_item_id',
  ];

  /**
   * Retorna a ContaBancaria q esta 13o Salario pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function ContaBancaria() {
    return $this->belongsTo( ContaBancaria::class, 'conta_id' );
  }

  /**
   * Retorna o Funcionarios q esta 13o Salario pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionario_id' );
  }

  /**
   * Retorna o CentrosDeCustoCadaris desta 13o Salario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | CentrosDeCustoCadaris
   */
  public function CentrosDeCustoCadaris() {
    return $this->belongsTo( CentrosDeCustoCadaris::class, 'financeiro_r_cdcc_fk' );
  }

  /**
   * Retorna a PlanoDeContasItem q esta Salario13 pertence.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
   */
  public function Despesa() {
    return $this->belongsTo( PlanoDeContasItem::class, 'plano_de_contas_item_id' );
  }

  /**
   * Retorna o Codigo e Nome da Despesa q este Salario13 pertence.
   *
   * @return string
   */
  public function DespesaCodigoNome() {
    return $this->Despesa ? $this->Despesa->getContaNome() : 'SEM DESPESA ASSOCIADA';
  }

  /**
   * Retorna o Codigo Reduzido da Despesa deste Salario13.
   *
   * @return string
   */
  public function DespesaCodigoReduzida() {
    return $this->Despesa ? $this->Despesa->conta_reduzida : '?';
  }

  /**
   * Retorna a ContaBancaria q esta 13o Salario pertence.
   *
   * @return string
   */
  public function ContaBancariaNome() {
    return $this->ContaBancaria ? $this->ContaBancaria->nome : 'SEM CONTA ASSOCIADA';
  }

  /**
   * Retorna a Funcionario q esta 13o Salario pertence.
   *
   * @return string
   */
  public function FuncionarioNome() {
    return $this->Funcionario ? $this->Funcionario->nome : 'FUNCIONÁRIO NÃO ASSOCIADO';
  }

  /**
   * Retorna as Rescisoes entre as datas de uma conta.
   *
   * @param string $inicio
   * @param string $fim
   * @param int $conta_id
   * @return \Illuminate\Database\Eloquent\Collection|\Illuminate\Support\Collection|static[] | Salario13[]
   */
  public static function Periodo( $inicio, $fim, $conta_id ) {
    return Salario13
      ::whereBetween( 'data', [ $inicio, $fim ] )
      ->whereContaId( $conta_id )
      ->orderBy( 'data' )
      ->get();
  }

  /**
   * Armazena a data antiga antes do update.
   *
   * @var string
   */
  private $dtAntiga = null;

  /**
   * Armazena se estava pago antes do update.
   *
   * @var bool
   */
  private $pagoAntiga = null;

  /**
   * Armazena a data antiga para o reSync da Conta Bancaria.
   */
  public function reSyncUpdateBegin() {
    $this->dtAntiga   = $this->data;
    $this->pagoAntiga = $this->pago;
  }

  /**
   * Realiza o reSync da Conta Bancaria quando update.
   */
  public function reSyncUpdateEnd() {
    if ( $this->dtAntiga === null || $this->pagoAntiga === null ) {
      dd( 'reSync_update_End sem reSync_update_Begin' );
    }

    if ( $this->pago || $this->pagoAntiga ) {
      if ( $this->data < $this->dtAntiga ) {
        $this->ContaBancaria->reSyncConta( $this->data );
      } else {
        $this->ContaBancaria->reSyncConta( $this->dtAntiga );
      }
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando criado este Evento.
   */
  public function reSyncStore() {
    if ( $this->pago == true ) {
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  /**
   * Realiza o reSync da Conta Bancaria quando deletado este Evento.
   */
  public function reSyncDestroy() {
    if ( $this->pago == true ) {
      $this->pago = false;
      $this->save();
      $this->ContaBancaria->reSyncConta( $this->data );
    }
  }

  use ListagemPadronizada;

  public $sortable = [ 'pago', 'funcionario_id', 'data', 'conta_id', 'valor_total' ];

  public static function IndexSearchMap() : array {
    return [
      'search_text'     => [
        'fields' => [ 'Funcionario.nome' ],
        'label'  => 'Pesquise pelo Nome do Funcionário'
      ],
      'search_advanced' => [
        'pago'           => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Pago:',
          'options' => [ 0 => 'Não', 1 => 'Sim' ]
        ],
        'conta_id'       => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Conta Bancária:',
          'options' => ContaBancaria::enum_contas()
        ],
        'funcionario_id' => [
          'type'    => self::$LB_TYPE_SELECT,
          'label'   => 'Funcionário:',
          'options' => Funcionarios::enum_Funcionarios()
        ],
        'data' => [
          'type'         => self::$LB_TYPE_DATE_RANGE,
          'label_after'  => 'Data após:',
          'label_before' => 'Data antes de:',
        ]
      ],
    ];
  }
}
