<?php

namespace App\Notifications;

use App\Models\Cadastros\Funcionarios;
use App\Models\Financeiro\Salario;
use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use function route;


/**
 * Class HoleriteNotification
 *
 * @property Salario salario
 * @property Funcionarios funcionario
 * @package App\Notifications
 */
class HoleriteNotification extends Notification {
  use Queueable;

  /** @var Salario */
  private $salario;
  /**
   * @var Funcionarios
   */
  private $funcionario;

  /**
   * Create a new notification instance.
   *
   * @param Salario $salario
   * @param Funcionarios $funcionario
   */
  public function __construct( Salario $salario, Funcionarios $funcionario ) {
    $this->salario     = $salario;
    $this->funcionario = $funcionario;
    $this->onQueue( 'emails' );
  }

  /**
   * Get the notification's delivery channels.
   *
   * @param mixed $notifiable
   * @return array
   */
  public function via( $notifiable ) {
    return [ 'mail' ];
  }

  /**
   * Get the mail representation of the notification.
   *
   * @param mixed $notifiable
   * @return \Illuminate\Notifications\Messages\MailMessage
   */
  public function toMail( $notifiable ) {
    $mes = $this->salario->mes . '/' . $this->salario->ano;

    return ( new MailMessage )
      ->subject( "[Sistema Cadaris] Holerite/Recibo de $mes está disponível!" )
      ->greeting( "Olá {$this->funcionario->nome}!" )
      ->line( "Informamos que o Holerite/Recibo do mês <strong>$mes</strong> já está disponível no Sistema Cadaris." )
      ->line( 'Para acessar clique no botão abaixo.<br>Ou logue no sistema e acesse no menu flutuante superior direito de seu nome, a opção <strong>Meus Holerites/Recibos</strong>.' )
      ->action( 'Acessar os Meus Holerites/Recibos', route( 'usuario.holerites.index' ) );
  }

  /**
   * Get the array representation of the notification.
   *
   * @param mixed $notifiable
   * @return array
   */
  public function toArray( $notifiable ) {
    $mes = $this->salario->mes . '/' . $this->salario->ano;

    return [
      "[Sistema Cadaris] Holerite/Recibo de $mes está disponível!",
      "Olá {$this->funcionario->nome}!",
      "Informamos que o Holerite/Recibo do mês <strong>$mes</strong> já está disponível no Sistema Cadaris.",
      'Para acessar clique no botão abaixo.<br>Ou logue no sistema e acesse no menu flutuante superior direito de seu nome, a opção <strong>Meus Holerites/Recibos</strong>.',
      'Acessar os Meus Holerites/Recibos: ' . route( 'usuario.holerites.index' ),
    ];
  }
}
