<?php

namespace App\Notifications;

use App\CRP;
use App\Models\Comercial\Jobs;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class JobStageNotification extends Notification implements ShouldQueue {
  use Queueable;

  const texto = [
    CRP::P_Comercial_email_A_entrou   => [
      'title' => 'Uma Proposta Comercial foi criada',
      'msg'   => ' para confeccionar o seu Briefing e o seu Cronograma' ],
    CRP::P_Comercial_email_B_entrou   => [
      'title' => 'Uma Proposta Comercial aguarda orçamento',
      'msg'   => ' para confeccionar seu Orçamento e sua Condição de Pagamento' ],
    CRP::P_Comercial_email_C_entrou   => [
      'title' => 'Uma Proposta Comercial aguarda aprovação da Diretoria',
      'msg'   => ' para aprová-lo' ],
    CRP::P_Comercial_email_C_aprovou  => [
      'title' => 'Uma Proposta Comercial foi aprovada pela Diretoria',
      'msg'   => '' ],
    CRP::P_Comercial_email_C_reprovou => [
      'title' => 'Uma Proposta Comercial não foi aprovada pela Diretoria',
      'msg'   => ' para confeccionar seu Orçamento e sua Condição de Pagamento' ],
    CRP::P_Comercial_email_D_entrou   => [
      'title' => 'Uma Proposta Comercial aguarda aprovação do Cliente',
      'msg'   => ' para gerar o PDF do orçamento e pedir a Aprovação do Cliente' ],
    CRP::P_Comercial_email_D_aprovou  => [
      'title' => 'Uma Proposta Comercial foi aprovada pelo Cliente',
      'msg'   => '' ],
    CRP::P_Comercial_email_D_reprovou => [
      'title' => 'Uma Proposta Comercial não foi aprovada pelo Cliente e necessita de ajustes',
      'msg'   => ' para confeccionar um novo Briefing e um novo Cronograma' ],
    CRP::P_Comercial_email_D_arquivou => [
      'title' => 'Uma Proposta Comercial foi arquivada',
      'msg'   => '' ],
    CRP::P_Comercial_email_E_entrou   => [
      'title' => 'Uma Proposta Comercial entrou em produção',
      'msg'   => ' para acessar o Job' ],
    CRP::P_Comercial_email_F_entrou   => [
      'title' => 'Uma Proposta Comercial aguarda o faturamento',
      'msg'   => '' ],
    CRP::P_Comercial_email_G_entrou   => [
      'title' => 'Um Job foi finalizado',
      'msg'   => '' ],
  ];

  /**
   * @var string
   */
  private $etapa;

  /**
   * @var integer
   */
  private $job_id;

  /**
   * @var string
   */
  private $job_nome;

  /**
   * @var string
   */
  private $job_conta;

  /**
   * @var string
   */
  private $job_responsavel;

  /**
   * @var string
   */
  private $email_title;

  /**
   * @var string
   */
  private $email_msg;

  /**
   * Create a new notification instance.
   *
   * @param Jobs $job
   * @param string $tipo
   */
  public function __construct( Jobs $job, $tipo ) {
    $this->email_title     = self::texto[ $tipo ][ 'title' ];
    $this->email_msg       = self::texto[ $tipo ][ 'msg' ];
    $this->job_id          = $job->id;
    $this->job_nome        = $job->nome_job;
    $this->job_conta       = $job->_ClienteConta();
    $this->job_responsavel = $job->_Responsavel();
    $this->etapa           = $job->etapa_atual;
    $this->onQueue( 'emails' );
  }

  /**
   * Get the notification's delivery channels.
   *
   * @param  mixed $notifiable
   * @return array
   */
  public function via( $notifiable ) {
    return [ 'mail' ];
  }

  /**
   * Get the mail representation of the notification.
   *
   * @param  mixed $notifiable
   * @return \Illuminate\Notifications\Messages\MailMessage
   */
  public function toMail( $notifiable ) {

    return ( new MailMessage )
      ->subject( '[Sistema Cadaris] ' . $this->email_title )
      ->line( $this->email_title . '!' )
      ->line( 'Código do Job: <strong>' . $this->job_id . '</strong><br>' .
        'Nome do Job: <strong>' . $this->job_nome . '</strong><br>' .
        'Cliente: <strong>' . $this->job_conta . '</strong><br>' .
        'Responsável: <strong>' . $this->job_responsavel . '</strong>' )
      ->line( 'Acesse-o clicando no botão abaixo' . $this->email_msg . '.' )
      ->action( 'Acessar Proposta Comercial', route( 'jobs.show', $this->job_id ) );
  }

  /**
   * Get the array representation of the notification.
   *
   * @param  mixed $notifiable
   * @return array
   */
  public function toArray( $notifiable ) {
    return [
      //
    ];
  }
}
