<?php

namespace App\Notifications;

use Carbon\Carbon;
use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class TesteNotification extends Notification {
  use Queueable;

  /**
   * Data e Hora desta Notificação.
   *
   * @var string
   */
  private $data;

  /**
   * Create a new notification instance.
   */
  public function __construct() {
    $this->data = Carbon::now()->format( 'd/m/Y H:i:s' );
    $this->onQueue( 'emails' );
  }

  /**
   * Get the notification's delivery channels.
   *
   * @param  mixed $notifiable
   * @return array
   */
  public function via( $notifiable ) {
    return [ 'mail' ];
  }

  /**
   * Get the mail representation of the notification.
   *
   * @param  mixed $notifiable
   * @return \Illuminate\Notifications\Messages\MailMessage
   */
  public function toMail( $notifiable ) {

    return ( new MailMessage )
      ->subject( '[Sistema Cadaris] Teste de Notificação por E-mail ' . $this->data )
      ->line( 'Se vc recebeu este e-mail, é porque a fila de e-mail esta funcionando conforme esperado!' )
      ->line( 'Data e hora de envio: ' . $this->data )
      ->action( 'TESTAR NOVAMENTE', route( 'teste' ) );
  }

  /**
   * Get the array representation of the notification.
   *
   * @param  mixed $notifiable
   * @return array
   */
  public function toArray( $notifiable ) {
    return [
      'Teste de Notificação por E-mail',
      'Data e hora de envio: ' . $this->data,
      'TESTAR NOVAMENTE: ' . route( 'teste.email' )
    ];
  }
}
