<?php

namespace App;

use App\Models\Cadastros\Funcionarios;
use App\Notifications\RedefinirSenhaNotification;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Spatie\Permission\Traits\HasRoles;

/**
 * App\User
 *
 * @property int $id
 * @property string $name
 * @property string $email
 * @property string $password
 * @property string $remember_token
 * @property bool $crp_role
 * @property int $funcionarios_id
 * @property \Carbon\Carbon $created_at
 * @property \Carbon\Carbon $updated_at
 * @property-read Funcionarios $Funcionario
 * @property-read \Illuminate\Notifications\DatabaseNotificationCollection|\Illuminate\Notifications\DatabaseNotification[] $notifications
 * @property-read \Illuminate\Database\Eloquent\Collection|\Spatie\Permission\Models\Permission[] $permissions
 * @property-read \Illuminate\Database\Eloquent\Collection|\Spatie\Permission\Models\Role[] $roles
 * @method static \Illuminate\Database\Query\Builder|\App\User role( $roles )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereCreatedAt( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereCrpRole( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereEmail( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereFuncionariosId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereId( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereName( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User wherePassword( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereRememberToken( $value )
 * @method static \Illuminate\Database\Query\Builder|\App\User whereUpdatedAt( $value )
 * @mixin \Eloquent
 */
class User extends Authenticatable {
  use Notifiable;
  use HasRoles;

  /**
   * The attributes that are mass assignable.
   *
   * @var array
   */
  protected $fillable = [
    'name', 'email', 'password',
  ];

  /**
   * The attributes that should be hidden for arrays.
   *
   * @var array
   */
  protected $hidden = [
    'password', 'remember_token',
  ];

  /**
   * Retorna o Funcionario do Usuario.
   *
   * @return \Illuminate\Database\Eloquent\Relations\BelongsTo | \Illuminate\Database\Query\Builder
   */
  public function Funcionario() {
    return $this->belongsTo( Funcionarios::class, 'funcionarios_id' );
  }

  /**
   * Send the password reset notification.
   *
   * @param  string $token
   * @return void
   */
  public function sendPasswordResetNotification( $token ) {
    $this->notify( new RedefinirSenhaNotification( $token ) );
  }
}
