<?php

/*
|--------------------------------------------------------------------------
| Model Factories
|--------------------------------------------------------------------------
|
| Here you may define all of your model factories. Model factories give
| you a convenient way to create models for testing and seeding your
| database. Just tell the factory how a default model should look.
|
*/


$factory->define( App\User::class, function ( Faker\Generator $faker ) {
  static $password;

  return [
    'name'           => $faker->name,
    'email'          => $faker->safeEmail,
    'password'       => $password ?: $password = bcrypt( 'secret' ),
    'remember_token' => str_random( 10 ),
  ];
} );

$factory->define( App\Models\Cadastros\Funcionarios::class, function ( Faker\Generator $faker ) {
  $faker = Faker\Factory::create( 'pt_BR' );

  return [
    'nome'             => $faker->name,
    'sexo'             => $faker->randomElement( [ 'M', 'F' ] ),
    'email'            => $faker->safeEmail,
    'rg'               => $faker->rg,
    'cpf'              => $faker->cpf,
    'foto'             => null,
    'dt_nascimento'    => $faker->date(),
    'estado_civil'     => random_int( 0, 3 ),
    'nome_pai'         => $faker->name( $gender = 'male' ),
    'nome_mae'         => $faker->name( $gender = 'female' ),
    'end_cep'          => sprintf( '%d-%d', $faker->numerify( '####' ), $faker->numerify( '###' ) ),
    'end_logradouro'   => str_random( 30 ),
    'end_numero'       => random_int( 1, 100 ),
    'end_complemento'  => null,
    'end_bairro'       => str_random( 30 ),
    'end_cidade'       => str_random( 30 ),
    'end_estado'       => 'SP',
    'teste_mbti'       => random_int( 0, 15 ),
    'regime'           => random_int( 0, 3 ),
    'hr_entrada'       => '09:00:00',
    'hr_saida'         => '18:00:00',
    'inativo'          => random_int( 0, 1 ),
    'departamentos_id' => random_int( 1, count( FuncionariosSeeder::$enum_dep ) ),
  ];
} );


$factory->defineAs( App\Models\Cadastros\FuncHistoricos::class, 'contratacao', function ( Faker\Generator $faker ) {
  $nv           = random_int( 1, 17 );
  $fs           = App\Models\Config\FaixaSalarial::getUmPorNivel( $nv );
  $fs->superior = $fs->superior === null ? 0 : $fs->superior;
  $fs->inferior = $fs->inferior === null ? 0 : $fs->inferior;
  $sal          = ( random_int( 0, ( $fs->superior - $fs->inferior ) ) ) + $fs->inferior;
  return [
    'data'              => $faker->date,
    'tipo'              => 0,
    'cargo'             => random_int( 0, count( App\Models\Cadastros\FuncHistoricos::enum_cargos() ) - 1 ),
    'nivel'             => $nv,
    'salario'           => $sal,
    'vr'                => '1250',
    'vt'                => '760',
    'seguro_vida'       => '1',
    'ferias_dt_inicio'  => null,
    'ferias_dt_termino' => null
  ];
} );

$factory->defineAs( App\Models\Cadastros\FuncHistoricos::class, 'aquisitivo', function ( Faker\Generator $faker ) {
  return [
    'data'              => '2016-10-25',
    'tipo'              => 8,
    'cargo'             => null,
    'nivel'             => null,
    'salario'           => null,
    'vr'                => null,
    'vt'                => null,
    'seguro_vida'       => null,
    'ferias_dt_inicio'  => '2016-01-01',
    'ferias_dt_termino' => '2016-12-31'
  ];
} );

$factory->defineAs( App\Models\Cadastros\FuncTelefones::class, 'tel1', function ( Faker\Generator $faker ) {
  $faker = Faker\Factory::create( 'pt_BR' );
  return [
    'telefone' => $faker->cellphoneNumber,
    'tipo'     => 1,
    'recado'   => 0,
    'obs'      => null,
  ];
} );

$factory->defineAs( App\Models\Cadastros\FuncTelefones::class, 'tel2', function ( Faker\Generator $faker ) {
  $faker = Faker\Factory::create( 'pt_BR' );
  return [
    'telefone' => $faker->cellphoneNumber,
    'tipo'     => 2,
    'recado'   => 1,
    'obs'      => 'minha tia avo',
  ];
} );

$factory->define( App\Models\Cadastros\FuncDependentes::class, function ( Faker\Generator $faker ) {
  return [
    'nome'            => $faker->name,
    'parentesco'      => $faker->word,
    'data_nascimento' => $faker->date(),
//    'falecido'        => $faker->randomElement( $array = [ true, false ] ),
    'falecido'        => 0, //[ true, false ][ random_int( 0, 1 ) ],
  ];
} );
