<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabClientes extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    // CRUD dos Clientes -> Empresas > CentrosDeCustos > Contas

    // Empresas
    Schema::create( 'clientes_empresas', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'codigo' );
      $table->string( 'nome' );

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    // Unidades
    Schema::create( 'clientes_empresas_unidades', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->string( 'nome' );

      $table->integer( 'clientes_empresas_id' )->unsigned();
      $table->foreign( 'clientes_empresas_id', 'clientes_emp_unidd_fk' )
            ->references( 'id' )
            ->on( 'clientes_empresas' )
            ->onDelete( 'cascade' );

      // DADOS BASICOS
      $table->string( 'cnpj', 18 )->nullable();
      $table->string( 'razao_social' )->nullable();
      $table->string( 'inscr_estadual' )->nullable();
      $table->string( 'inscr_municipal' )->nullable();
      $table->string( 'condpagamento' )->nullable();

      // DADOS BANCARIOS
      $table->integer( 'bancario_banco' )->nullable(); //
      $table->string( 'bancario_agencia', 10 )->nullable(); // 00.000-X
      $table->string( 'bancario_conta', 10 )->nullable(); // 0000000-X

      // ENDERECO
      $table->string( 'end_cep', 9 );
      $table->string( 'end_logradouro' );
      $table->string( 'end_numero' );
      $table->string( 'end_complemento' )->nullable();
      $table->string( 'end_bairro' );
      $table->string( 'end_cidade' );
      $table->string( 'end_estado', 2 );

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    // CentrosDeCustos
    Schema::create( 'clientes_centros_de_custos', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'codigo' );
      $table->string( 'nome' );

      $table->integer( 'clientes_empresas_id' )->unsigned();
      $table->foreign( 'clientes_empresas_id', 'clientes_cdc_e_id_foreign' )
            ->references( 'id' )
            ->on( 'clientes_empresas' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );

    // CentrosDeCusto 1 -> N Contatos
    Schema::create( 'clientes_centros_de_custos_contatos', function ( Blueprint $table ) {
      $table->increments( 'id' );

      // CONTATOS
      $table->string( 'nome' )->nullable();
      $table->string( 'tel', 14 )->nullable();
      $table->string( 'cel', 15 )->nullable();
      $table->string( 'email' )->nullable();

      $table->integer( 'clientes_centros_de_custos_id' )->unsigned();
      $table->foreign( 'clientes_centros_de_custos_id', 'clientes_cdc_cdcc_id_foreign' )
            ->references( 'id' )
            ->on( 'clientes_centros_de_custos' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );

    // Contas
    Schema::create( 'clientes_contas', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'codigo' );
      $table->string( 'nome' );

      $table->integer( 'clientes_centros_de_custos_id' )->unsigned();
      $table->foreign( 'clientes_centros_de_custos_id', 'clientes_c_cdc_id_foreign' )
            ->references( 'id' )
            ->on( 'clientes_centros_de_custos' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'clientes_contas' );
    Schema::dropIfExists( 'clientes_centros_de_custos_contatos' );
    Schema::dropIfExists( 'clientes_centros_de_custos' );
    Schema::dropIfExists( 'clientes_empresas_unidades' );
    Schema::dropIfExists( 'clientes_empresas' );
  }
}
