<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabFornecedores extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    // TODO: tirar os NULLABLEs
    //    CRUD dos Fornecedores -> Empresas > Servicos/Produtos > Contas
    Schema::create( 'fornecedores_empresas', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'codigo' );
      $table->string( 'nome' );

      $table->string( 'cnpj', 18 )->nullable();
      $table->string( 'razao_social' )->nullable();
      $table->string( 'inscr_estadual' )->nullable();
      $table->string( 'inscr_municipal' )->nullable();
      $table->string( 'condpagamento' )->nullable();  // TODO

      // DADOS BANCARIOS
      $table->integer( 'bancario_banco' )->nullable(); //
      $table->string( 'bancario_agencia', 10 )->nullable(); // 00.000-X
      $table->string( 'bancario_conta', 10 )->nullable(); // 0000000-X

      // CLISSIFICACAO
      $table->tinyInteger( 'nota_geral' )->default( 1 );
      $table->tinyInteger( 'nota_qualidade' )->default( 1 );
      $table->tinyInteger( 'nota_atendimento' )->default( 1 );
      $table->tinyInteger( 'nota_prazo' )->default( 1 );
      $table->binary( 'nota_obs' )->nullable();
      $table->binary( 'nota_recomendacao' )->nullable();

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'fornecedores_despesas', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->integer( 'codigo' );
      $table->string( 'nome' );

      $table->timestamps();
    } );

    Schema::create( 'fornecedores_servicos_produtos', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'codigo' );
      $table->string( 'nome' );

      $table->integer( 'fornecedores_despesas_id' )->unsigned()->nullable();
      $table->foreign( 'fornecedores_despesas_id', 'fornecedores_fe_fd_fk' )
            ->references( 'id' )
            ->on( 'fornecedores_despesas' )
            ->onDelete( 'set null' );

      $table->integer( 'fornecedores_empresas_id' )->unsigned();
      $table->foreign( 'fornecedores_empresas_id' )
            ->references( 'id' )
            ->on( 'fornecedores_empresas' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );

    Schema::create( 'fornecedores_tags', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->string( 'nome' );

      $table->timestamps();
    } );

    Schema::create( 'fornecedores_servico_produto_tag', function ( Blueprint $table ) {
      $table->integer( 'fornecedores_servicos_produtos_id' )->unsigned()->index( 'fornecedores_sp_id_idx' );
      $table->foreign( 'fornecedores_servicos_produtos_id', 'fornecedores_sp_pivot_foreign' )
            ->references( 'id' )
            ->on( 'fornecedores_servicos_produtos' )
            ->onDelete( 'cascade' );

      $table->integer( 'fornecedores_tags_id' )->unsigned()->index( 'fornecedores_tag_id_idx' );
      $table->foreign( 'fornecedores_tags_id', 'fornecedores_tags_pivot_foreign' )
            ->references( 'id' )
            ->on( 'fornecedores_tags' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );


    // Empresas 1 -> N enderecos
    Schema::create( 'fornecedores_empresas_enderecos', function ( Blueprint $table ) {
      $table->increments( 'id' );

      // ENDERECO
      $table->string( 'apelido' );
      $table->string( 'cep', 9 );
      $table->string( 'logradouro' );
      $table->string( 'numero' );
      $table->string( 'complemento' )->nullable();
      $table->string( 'bairro' );
      $table->string( 'cidade' );
      $table->string( 'estado', 2 );

      $table->integer( 'fornecedores_empresas_id' )->unsigned();
      $table->foreign( 'fornecedores_empresas_id', 'fornecedores_ee_e_id_foreign' )
            ->references( 'id' )
            ->on( 'fornecedores_empresas' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );

    // ServicosProdutos 1 -> N Contatos
    Schema::create( 'fornecedores_servicos_produtos_contatos', function ( Blueprint $table ) {
      $table->increments( 'id' );

      // CONTATOS
      $table->string( 'nome' )->nullable();
      $table->string( 'tel', 14 )->nullable();
      $table->string( 'cel', 15 )->nullable();
      $table->string( 'email' )->nullable();

      $table->integer( 'fornecedores_servicos_produtos_id' )->unsigned();
      $table->foreign( 'fornecedores_servicos_produtos_id', 'fornecedores_spc_sp_id_foreign' )
            ->references( 'id' )
            ->on( 'fornecedores_servicos_produtos' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'fornecedores_servicos_produtos_contatos' );
    Schema::dropIfExists( 'fornecedores_empresas_enderecos' );
    Schema::dropIfExists( 'fornecedores_servico_produto_tag' );
    Schema::dropIfExists( 'fornecedores_tags' );
    Schema::dropIfExists( 'fornecedores_servicos_produtos' );
    Schema::dropIfExists( 'fornecedores_despesas' );
    Schema::dropIfExists( 'fornecedores_empresas' );
  }
}
