<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabJob0 extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    Schema::create( 'comercial_campanhas', function ( Blueprint $table ) {
      $table->engine = 'InnoDB';
      $table->increments( 'id' );
      $table->string( 'nome' );
      $table->timestamps();
    } );

    Schema::create( 'comercial_jobs', function ( Blueprint $table ) {
      $table->engine = 'InnoDB';
      $table->increments( 'id' );

      $table->string( 'etapa_atual' );

      // 0: Criacao do Job
      $table->string( 'nome_job' );
      $table->integer( 'campanha_id' )->unsigned()->nullable();
      $table->integer( 'responsavel_id' )->unsigned()->nullable();
      $table->integer( 'cliente_unidd_id' )->unsigned()->nullable();
      $table->integer( 'cliente_cdc_id' )->unsigned()->nullable();
      $table->integer( 'cod_receita' )->unsigned()->nullable();
      $table->string( 'descricao_evento' )->nullable();
      $table->date( 'previsao_proposta' )->nullable();
      $table->dateTime( 'previsao_entrega' )->nullable();

      // B: Condicao de pagamento
      $table->string( 'condpagto' )->nullable();
      $table->binary( 'condpagto_obs' )->nullable();

      // C: Aprovacao da Diretoria
      $table->unsignedTinyInteger( 'aprov_diretoria' )->nullable();
      $table->binary( 'aprov_diretoria_obs' )->nullable();

      // D: Aprovacao do Cliente
      $table->unsignedTinyInteger( 'aprov_cliente' )->nullable();
      $table->binary( 'aprov_cliente_obs' )->nullable();

      $table->timestamps();
    } );

    Schema::table( 'comercial_jobs', function ( Blueprint $table ) {
      $table->engine = 'InnoDB';
      $table->foreign( 'campanha_id', 'jobs_camp_fk' )
            ->references( 'id' )
            ->on( 'comercial_campanhas' )
            ->onDelete( 'set null' );
      $table->foreign( 'responsavel_id', 'jobs_func_fk' )
            ->references( 'id' )
            ->on( 'funcionarios' )
            ->onDelete( 'set null' );
      $table->foreign( 'cliente_unidd_id', 'jobs_client_unidd_fk' )
            ->references( 'id' )
            ->on( 'clientes_empresas_unidades' )
            ->onDelete( 'set null' );
      $table->foreign( 'cliente_cdc_id', 'jobs_client_cnt_fk' )
            ->references( 'id' )
            ->on( 'clientes_contas' )
            ->onDelete( 'set null' );
    } );

    DB::update( "ALTER TABLE comercial_jobs AUTO_INCREMENT = 2405;" );

    Schema::create( 'comercial_stages', function ( Blueprint $table ) {
      $table->bigIncrements( 'id' );

      $table->string( 'etapa', 1 );

      $table->dateTime( 'entrada' )->nullable();
      $table->dateTime( 'salvo' )->nullable();
      $table->dateTime( 'saida' )->nullable();

      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      $table->timestamps();
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'comercial_stages' );
    Schema::dropIfExists( 'comercial_jobs' );
    Schema::dropIfExists( 'comercial_campanhas' );
  }
}
