<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabJobA extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {

    Schema::create( 'comercial_job_briefing_livre', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      $table->binary( 'texto' )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'comercial_job_briefing_grafico', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      $table->string( 'medida_aberto_altura' )->nullable();
      $table->string( 'medida_aberto_largura' )->nullable();
      $table->string( 'medida_fechado_altura' )->nullable();
      $table->string( 'medida_fechado_largura' )->nullable();

      $table->string( 'material_tipo' )->nullable();
      $table->string( 'material_cores' )->nullable();
      $table->integer( 'material_cores_escala' )->nullable();

      $table->string( 'paginas' )->nullable();
      $table->string( 'laminas' )->nullable();

      $table->string( 'acabamento' )->nullable();
      $table->string( 'faca' )->nullable();
      // ?

      $table->string( 'tiragem' )->nullable();
      $table->string( 'tiragem_descricao' )->nullable();

      $table->date( 'entrega_data' )->nullable();
      $table->time( 'entrega_hora' )->nullable();
      $table->binary( 'entrega_endereco' )->nullable();
      $table->string( 'entrega_telefone' )->nullable();
      $table->string( 'entrega_responsavel' )->nullable();

      // ?
      //  DADOS PARA FATURA
      //  ENDEREÇO PARA ENTREGA DE FATURA
      //  LOCAL ONDE COTAR (PREENCHIMENTO MARIS OU JULIANA)

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'comercial_job_briefing_web', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      // Resumo
      $table->binary( 'descricao' )->nullable();

      // arquitetura de navegacao
      $table->binary( 'arquitetura' )->nullable();

      // go live
      $table->date( 'data_online' )->nullable();

      // Quais são as características do servidor?
      $table->string( 'server_web' )->nullable();
      $table->string( 'server_db' )->nullable();
      $table->string( 'server_linguagem' )->nullable();
      $table->string( 'server_so' )->nullable();
      $table->string( 'server_navegador' )->nullable();
      $table->string( 'server_dominio' )->nullable();

      // Quais são as características do servidor do cliente?
      $table->string( 'server_tamanho' )->nullable();
      $table->string( 'server_trafego' )->nullable();
      $table->string( 'server_disponibilidade' )->nullable();
      $table->string( 'server_bd' )->nullable(); // enum  (mesma instância ou instância separada?)

      // A Cadaris deverá efetuar a compra do domínio?
      $table->string( 'dominio_principal' )->nullable();
      $table->string( 'dominio_secundario1' )->nullable();
      $table->string( 'dominio_secundario2' )->nullable();

      // Tipo do Trabalho
      $table->string( 'tipo_site' )->nullable();
      $table->string( 'tipo_portal' )->nullable();
      $table->string( 'tipo_app_web' )->nullable();
      $table->string( 'tipo_app_ios' )->nullable();
      $table->string( 'tipo_app_android' )->nullable();
      $table->string( 'tipo_app_windows_phone' )->nullable();


      // Tecnologia
      // Front-End
      $table->tinyInteger( 'tec_front_bootstrap' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_front_html5' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_front_css' )->nullable()->default( '0' );
      $table->string( 'tec_front_outra' )->nullable();

      // CMS
      $table->tinyInteger( 'tec_cms_wordpress' )->nullable()->default( '0' );
      $table->string( 'tec_cms_outra' )->nullable();

      // Bibliotecas Javascript
      $table->tinyInteger( 'tec_js_jquery' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_js_angularjs' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_js_createjs' )->nullable()->default( '0' );
      $table->string( 'tec_js_outra' )->nullable();

      // Linguagem
      $table->tinyInteger( 'tec_linguagem_php' )->nullable()->default( '0' );
      $table->string( 'tec_linguagem_outra' )->nullable();

      // Banco de dados
      $table->tinyInteger( 'tec_bd_mysql' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_bd_sqlserver' )->nullable()->default( '0' );
      $table->string( 'tec_bd_outra' )->nullable();

      // Plugins
      $table->tinyInteger( 'tec_plugin_ga' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_plugin_sm' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_plugin_metatag' )->nullable()->default( '0' );
      $table->string( 'tec_plugin_outra' )->nullable();

      // Servidor
      $table->tinyInteger( 'tec_os_linux' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_os_windows' )->nullable()->default( '0' );
      $table->string( 'tec_os_outra' )->nullable();

      // Mobile
      $table->tinyInteger( 'tec_mobile_phonegap' )->nullable()->default( '0' );
      $table->tinyInteger( 'tec_mobile_cordova' )->nullable()->default( '0' );
      $table->string( 'tec_mobile_outra' )->nullable();


      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'comercial_job_briefing_files', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      $table->string( 'arquivo' );
      $table->string( 'extensao', 4 )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'comercial_job_briefing_brinde', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      $table->string( 'nome_material' )->nullable();
      $table->binary( 'resumo' )->nullable();

      $table->string( 'formato_aberto_altura' )->nullable();
      $table->string( 'formato_aberto_largura' )->nullable();
      $table->string( 'formato_fechado_altura' )->nullable();
      $table->string( 'formato_fechado_largura' )->nullable();

      $table->string( 'material_tipo' )->nullable();
      $table->string( 'material_cores' )->nullable();
      $table->integer( 'material_cores_escala' )->nullable();

      $table->string( 'tiragem' )->nullable();
      $table->string( 'tiragem_descricao' )->nullable();

      $table->integer( 'tipo_gravacao' )->nullable(); // enum

      $table->binary( 'referencias' )->nullable(); // CKeditor

      $table->date( 'entrega_data' )->nullable();
      $table->time( 'entrega_hora' )->nullable();
      $table->binary( 'entrega_endereco' )->nullable();
      $table->string( 'entrega_telefone' )->nullable();
      $table->string( 'entrega_responsavel' )->nullable();

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'comercial_job_cronograma', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      $table->binary( 'json' );

      $table->timestamps();
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'comercial_job_cronograma' );
    Schema::dropIfExists( 'comercial_job_briefing_brinde' );
    Schema::dropIfExists( 'comercial_job_briefing_files' );
    Schema::dropIfExists( 'comercial_job_briefing_web' );
    Schema::dropIfExists( 'comercial_job_briefing_grafico' );
    Schema::dropIfExists( 'comercial_job_briefing_livre' );
  }
}
