<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabJobB extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    Schema::create( 'comercial_servicos_custos_internos', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->string( 'nome' );
      $table->integer( 'sinapro_min' )->unsigned();
      $table->integer( 'sinapro_max' )->unsigned();
      $table->integer( 'desc_15' )->unsigned();
      $table->integer( 'desc_30' )->unsigned();
      $table->integer( 'desc_50' )->unsigned();

      $table->timestamps();
    } );

    // VERSAO DO ORCAMENTO DESTE JOB
    Schema::create( 'comercial_job_orc', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'job_id' )->unsigned();
      $table->foreign( 'job_id' )
            ->references( 'id' )
            ->on( 'comercial_jobs' )
            ->onDelete( 'cascade' );

      // $table->integer( 'versao', true, true );
      $table->string( 'nome' );
      $table->date( 'data' );
      $table->binary( 'descricao_geral' )->nullable();
      $table->unsignedTinyInteger( 'orc_aprov_diretor' )->nullable();
      $table->unsignedTinyInteger( 'orc_aprov_cliente' )->nullable();

      $table->timestamps();
    } );

    // ITENS DE CI
    Schema::create( 'comercial_job_orc_ci', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'orc_id' )->unsigned();
      $table->foreign( 'orc_id', 'orc_ci_fk' )
            ->references( 'id' )
            ->on( 'comercial_job_orc' )
            ->onDelete( 'cascade' );

      $table->string( 'nome' );
      $table->binary( 'descricao' )->nullable();

      $table->integer( 'custos_apoio' )->unsigned();
      $table->integer( 'arredondamento' )->unsigned()->nullable();
      $table->integer( 'taxa_comissao' )->unsigned();
      $table->integer( 'taxa_planejamento' )->unsigned();
      $table->integer( 'taxa_impostos' )->unsigned();

      $table->timestamps();
    } );

    // SERVICOS DO CI_ITEM
    Schema::create( 'comercial_job_orc_ci_servicos', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'ci_id' )->unsigned();
      $table->foreign( 'ci_id', 'orc_ci_serv_fk' )
            ->references( 'id' )
            ->on( 'comercial_job_orc_ci' )
            ->onDelete( 'cascade' );

      $table->integer( 'tipo_servico' )->unsigned();
      $table->integer( 'tipo_servico_nivel' )->unsigned();
      $table->string( 'tipo_servico_string' );
      $table->binary( 'obs' )->nullable();
      $table->integer( 'valor_unitario' )->unsigned();
      $table->decimal( 'horas', 8, 2 )->unsigned();
      $table->integer( 'valor_total' )->unsigned();

      $table->timestamps();
    } );

    // ITENS DE CO
    Schema::create( 'comercial_job_orc_co', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'orc_id' )->unsigned();
      $table->foreign( 'orc_id', 'orc_co_fk' )
            ->references( 'id' )
            ->on( 'comercial_job_orc' )
            ->onDelete( 'cascade' );

      $table->string( 'nome' );
      $table->binary( 'descricao' )->nullable();

      $table->integer( 'arredondamento' )->unsigned()->nullable();
      $table->integer( 'taxa_bv' )->unsigned();
      $table->integer( 'taxa_planejamento' )->unsigned();
      $table->integer( 'taxa_impostos' )->unsigned();

      $table->timestamps();
    } );

    // SERVICOS DO CO_ITEM
    Schema::create( 'comercial_job_orc_co_servicos', function ( Blueprint $table ) {
      $table->increments( 'id' );
      $table->integer( 'co_id' )->unsigned();
      $table->foreign( 'co_id', 'orc_co_serv_fk' )
            ->references( 'id' )
            ->on( 'comercial_job_orc_co' )
            ->onDelete( 'cascade' );

      $table->integer( 'fornecedor_id' )->unsigned()->nullable();
      $table->foreign( 'fornecedor_id', 'orc_co_forn_fk' )
            ->references( 'id' )
            ->on( 'fornecedores_servicos_produtos' )
            ->onDelete( 'set null' );
      $table->string( 'fornecedor_string' )->nullable();
      $table->binary( 'obs' )->nullable();
      $table->decimal( 'valor_unitario', 8, 2 )->unsigned(); // 0,00 a 42.949.672,95
      $table->integer( 'quantidade' )->unsigned();
      $table->integer( 'valor_total' )->unsigned();// 0 a 42.949.672,95

      $table->timestamps();
    } );

  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'comercial_job_orc_co_servicos' );
    Schema::dropIfExists( 'comercial_job_orc_ci_servicos' );
    Schema::dropIfExists( 'comercial_job_orc_co' );
    Schema::dropIfExists( 'comercial_job_orc_ci' );
    Schema::dropIfExists( 'comercial_job_orc' );
    Schema::dropIfExists( 'comercial_servicos_custos_internos' );
  }
}
/*
orcamento_versao:
  nome
  data
  descricao geral
  CI_ITEM:
    nome
    descricao
    taxas
    servicos:
      nome
      serv
      tipo
      obs
      preco_unit
      horas
      valor
  CO_ITEM:
    nome
    descricao
    taxas
    servicos:
      nome
      fornecedor
      obs
      preco_unit
      quantidade
      valor
*/