<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabFinanceiroContasConsumo extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    Schema::create( 'financeiro_contas_consumo_gerador', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->string( 'nome' );
      $table->string( 'frequencia' )->nullable();
      $table->string( 'forma_pagamento' )->nullable();

      $table->unsignedInteger( 'despesas_id' )->nullable();
      $table->foreign( 'despesas_id', 'fin_consumo_gerador_despesa_fk' )
            ->references( 'id' )
            ->on( 'cadastro_plano_de_contas_itens' )
            ->onDelete( 'set null' );

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );

    Schema::create( 'financeiro_contas_consumo', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->string( 'nome' );
      $table->date( 'data' );
      $table->integer( 'valor' );
      $table->boolean( 'pago' )->default( false );
      $table->string( 'frequencia' )->nullable();
      $table->string( 'forma_pagamento' )->nullable();

      $table->string( 'nota_fiscal' )->nullable();
      $table->string( 'boleto' )->nullable();
      $table->string( 'comprovante' )->nullable();

      $table->unsignedInteger( 'gerador_id' )->nullable();
      $table->foreign( 'gerador_id' )
            ->references( 'id' )
            ->on( 'financeiro_contas_consumo_gerador' )
            ->onDelete( 'set null' );

      $table->unsignedInteger( 'despesas_id' )->nullable();
      $table->foreign( 'despesas_id', 'fin_consumo_despesa_fk' )
            ->references( 'id' )
            ->on( 'cadastro_plano_de_contas_itens' )
            ->onDelete( 'set null' );

      $table->unsignedInteger( 'conta_id' )->nullable();
      $table->foreign( 'conta_id' )
            ->references( 'id' )
            ->on( 'financeiro_contas_bancarias' )
            ->onDelete( 'set null' );

      $table->binary( 'obs' )->nullable();

      $table->timestamps();
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'financeiro_contas_consumo' );
    Schema::dropIfExists( 'financeiro_contas_consumo_gerador' );
  }
}
