<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabFinanceiroSalarios extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    Schema::create( 'financeiro_salarios', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->unsignedInteger( 'ano' );
      $table->unsignedInteger( 'mes' );
      $table->date( 'data_pagamento' );
      $table->integer( 'dias_uteis' );
      $table->boolean( 'pago' )->default( false );

      // Salario
      $table->integer( 'valor_salario' )->default( 0 );
      $table->integer( 'valor_salario_desc' )->default( 0 );
      $table->integer( 'valor_salario_total' )->default( 0 ); // calc

      // VR
      $table->integer( 'valor_vr_unitario' )->default( 0 );
      $table->integer( 'valor_vr' )->default( 0 );
      $table->integer( 'valor_vr_desc_dia' )->default( 0 );
      $table->integer( 'valor_vr_desc' )->default( 0 );
      $table->integer( 'valor_vr_total' )->default( 0 ); // calc

      // VT
      $table->integer( 'valor_vt_unitario' )->default( 0 );
      $table->integer( 'valor_vt' )->default( 0 );
      $table->integer( 'valor_vt_desc_dia' )->default( 0 );
      $table->integer( 'valor_vt_desc' )->default( 0 );
      $table->integer( 'valor_vt_total' )->default( 0 ); // calc

      // Acrescimos
      $table->integer( 'comissao' )->default( 0 );
      $table->integer( 'reembolso' )->default( 0 );

      $table->integer( 'valor_total' )->default( 0 ); // calc

      $table->unsignedInteger( 'funcionario_id' )->nullable();
      $table->foreign( 'funcionario_id' )
            ->references( 'id' )
            ->on( 'funcionarios' )
            ->onDelete( 'set null' );

      $table->unsignedInteger( 'conta_id' )->nullable();
      $table->foreign( 'conta_id' )
            ->references( 'id' )
            ->on( 'financeiro_contas_bancarias' )
            ->onDelete( 'set null' );

      $table->timestamps();
    } );

    Schema::create( 'financeiro_ferias', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->date( 'data_pagamento' );
      $table->boolean( 'pago' )->default( false );

      $table->unsignedInteger( 'dias' )->default( 0 );
      $table->date( 'data_inicio' );
      $table->date( 'data_fim' );

      $table->integer( 'valor_salario_mensal' )->default( 0 );
      $table->integer( 'valor_acrescimo' )->default( 0 );
      $table->integer( 'valor_ferias' )->default( 0 );

      $table->integer( 'valor_retido' )->default( 0 );
      $table->integer( 'valor_total_bruto' )->default( 0 );
      $table->integer( 'valor_total_liquido' )->default( 0 );

      $table->unsignedInteger( 'funcionario_id' )->nullable();
      $table->foreign( 'funcionario_id' )
            ->references( 'id' )
            ->on( 'funcionarios' )
            ->onDelete( 'set null' );

      $table->unsignedInteger( 'conta_id' )->nullable();
      $table->foreign( 'conta_id' )
            ->references( 'id' )
            ->on( 'financeiro_contas_bancarias' )
            ->onDelete( 'set null' );

      $table->timestamps();
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::dropIfExists( 'financeiro_ferias' );
    Schema::dropIfExists( 'financeiro_salarios' );
  }
}
