<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class TabFinanceiroCentrosDeCustoCadaris extends Migration {
  /**
   * Run the migrations.
   *
   * @return void
   */
  public function up() {
    Schema::create( 'cadastro_centros_de_custo_cadaris', function ( Blueprint $table ) {
      $table->increments( 'id' );

      $table->unsignedInteger( 'codigo' );
      $table->string( 'nome' );

      $table->timestamps();
    } );

    Schema::table( 'financeiro_contas_consumo', function ( Blueprint $table ) {
      $table->unsignedInteger( 'centros_de_custo_cadaris_id' )
            ->after( 'conta_id' )
            ->nullable();
      $table->foreign( 'centros_de_custo_cadaris_id', 'financeiro_cc_cdcc_fk' )
            ->references( 'id' )
            ->on( 'cadastro_centros_de_custo_cadaris' )
            ->onDelete( 'set null' );
    } );

    Schema::table( 'financeiro_contas_fornecedores', function ( Blueprint $table ) {
      $table->unsignedInteger( 'centros_de_custo_cadaris_id' )
            ->after( 'conta_id' )
            ->nullable();
      $table->foreign( 'centros_de_custo_cadaris_id', 'financeiro_cf_cdcc_fk' )
            ->references( 'id' )->on( 'cadastro_centros_de_custo_cadaris' )
            ->onDelete( 'set null' );
    } );

    Schema::table( 'financeiro_salarios', function ( Blueprint $table ) {
      $table->unsignedInteger( 'centros_de_custo_cadaris_id' )
            ->after( 'conta_id' )
            ->nullable();
      $table->foreign( 'centros_de_custo_cadaris_id', 'financeiro_fs_cdcc_fk' )
            ->references( 'id' )->on( 'cadastro_centros_de_custo_cadaris' )
            ->onDelete( 'set null' );
    } );

    Schema::table( 'financeiro_ferias', function ( Blueprint $table ) {
      $table->unsignedInteger( 'centros_de_custo_cadaris_id' )
            ->after( 'conta_id' )
            ->nullable();
      $table->foreign( 'centros_de_custo_cadaris_id', 'financeiro_ff_cdcc_fk' )
            ->references( 'id' )->on( 'cadastro_centros_de_custo_cadaris' )
            ->onDelete( 'set null' );
    } );
  }

  /**
   * Reverse the migrations.
   *
   * @return void
   */
  public function down() {
    Schema::table( 'financeiro_ferias', function ( Blueprint $table ) {
      $table->dropForeign( 'financeiro_ff_cdcc_fk' );
      $table->dropColumn( 'centros_de_custo_cadaris_id' );
    } );
    Schema::table( 'financeiro_salarios', function ( Blueprint $table ) {
      $table->dropForeign( 'financeiro_fs_cdcc_fk' );
      $table->dropColumn( 'centros_de_custo_cadaris_id' );
    } );
    Schema::table( 'financeiro_contas_fornecedores', function ( Blueprint $table ) {
      $table->dropForeign( 'financeiro_cf_cdcc_fk' );
      $table->dropColumn( 'centros_de_custo_cadaris_id' );
    } );
    Schema::table( 'financeiro_contas_consumo', function ( Blueprint $table ) {
      $table->dropForeign( 'financeiro_cc_cdcc_fk' );
      $table->dropColumn( 'centros_de_custo_cadaris_id' );
    } );

    Schema::dropIfExists( 'cadastro_centros_de_custo_cadaris' );
  }
}
