<?php

use App\CRP;
use Illuminate\Database\Seeder;

class UsuariosDevSeeder extends Seeder {
  /**
   * Run the database seeds.
   *
   * @return void
   */
  public function run() {
    if ( config( 'app.env', 'production' ) !== 'production' ) {
      App\Models\Cadastros\Funcionarios::getQuery()->delete();
      \App\User::getQuery()->delete();
    }
    $this->add_dev( 'admin', CRP::R_Admin, 1 );
    if ( config( 'app.env', 'production' ) === 'production' ) {
      return;
    }
    $this->add_dev( 'diretor', CRP::R_Diretor, 2 );
    $this->add_dev( 'financeiro', CRP::R_Func_Financeiro, 3 );
    $this->add_dev( 'planejamento', CRP::R_Func_Planejamento, 4 );
    $this->add_dev( 'producao', CRP::R_Func_Producao, 5 );
    $this->add_dev( 'rh', CRP::R_Func_RH, 6 );
    $this->add_dev( 'cliente', CRP::R_Cliente, 7 );
    $this->add_dev( 'minimal', CRP::R_Minimal, 8 );
  }


  /**
   * Add user DEV.
   *
   * @param string $username
   * @param string $role
   * @param integer $crp_role
   */
  private function add_dev( $username, $role, $crp_role ) {

    /** @var App\Models\Cadastros\Funcionarios $f */
    $f = App\Models\Cadastros\Funcionarios::create( [
      'nome'             => 'DEV_' . $username,
      'sexo'             => 'M',
      'email'            => 'dev_' . strtolower( $username ) . '@cadaris.dev',
      'rg'               => '12.123.123-1',
      'cpf'              => '123.123.123-12',
      'foto'             => null,
      'dt_nascimento'    => '1990-01-01',
      'estado_civil'     => 0,
      'nome_pai'         => str_random( 30 ),
      'nome_mae'         => str_random( 30 ),
      'end_cep'          => '12345-678',
      'end_logradouro'   => str_random( 30 ),
      'end_numero'       => random_int( 1, 100 ),
      'end_complemento'  => null,
      'end_bairro'       => str_random( 30 ),
      'end_cidade'       => str_random( 30 ),
      'end_estado'       => 'SP',
      'teste_mbti'       => random_int( 0, 15 ),
      'regime'           => random_int( 0, 3 ),
      'hr_entrada'       => '09:00:00',
      'hr_saida'         => '18:00:00',
      'inativo'          => 0,
      'created_at'       => '2016-09-10 00:00:00',
      'updated_at'       => '2016-09-10 00:00:00',
      'departamentos_id' => null
    ] );

    $f->Telefones()->create( [
      'telefone' => '(11) 98765-4321',
      'tipo'     => '1',
      'recado'   => '0',
      'obs'      => null,
    ] );

    $f->Historicos()->create( factory( App\Models\Cadastros\FuncHistoricos::class, 'contratacao' )->make()->toArray() );
    $f->Historicos()->create( factory( App\Models\Cadastros\FuncHistoricos::class, 'aquisitivo' )->make()->toArray() );

    /** @var \App\User $u */
    $u = \App\User::create( [
      'name'            => $f->nome,
      'email'           => $f->email,
      'password'        => bcrypt( '123456' ),
      'remember_token'  => null,
      'crp_role'        => $crp_role,
      'funcionarios_id' => $f->id,
      'created_at'      => '2016-09-10 00:00:00',
      'updated_at'      => '2016-09-10 00:00:00',
    ] );

    $u->assignRole( $role );
  }
}
