@extends('app')

@section('content')
  <div class="row">
    <div class="col-md-9">
      <h1>
        <a href="{{route('clientes.index')}}" class="btn btn-default" data-toggle="tooltip" title="Voltar">
          <i class="fa fa-arrow-left fa-2x" aria-hidden="true"></i>
        </a>
        Visualizar Cliente:
        @if($tipo==1) Empresa
        @elseif($tipo==2) Centro de Custo
        @elseif($tipo==3) Conta
        @endif
      </h1>
    </div>

    @can(CRP::P_Cadastro_edit)
      <div class="col-md-3 h1 text-right">
        {{ Form::open(['route' => ['clientes.destroy' , $empCod, $cdcCod, $cntCod ]]) }}
        {{ Form::hidden('_method', 'DELETE') }}
        <a href="{{route('clientes.edit', [$empCod, $cdcCod, $cntCod ])}}" class="btn btn-warning">
          <i class="fa fa-pencil" aria-hidden="true"></i> Editar
        </a>
        <button type="submit" class="btn btn-danger" name="deleta_item">
          <i class="fa fa-trash-o" aria-hidden="true"></i> Deletar
        </button>
        {{ Form::close() }}
      </div>
    @endcan
  </div>


  @if($tipo==1)

    @include('flash::message')

    {{--EMPRESA--}}
    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-briefcase" aria-hidden="true"></i> Empresa</h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-2 grupo">
        <p class="chave">Código:</p>
        <p class="valor">{{ sprintf('%02d',$empresa->codigo) }}</p>
      </div>
      <div class="col-md-10 grupo">
        <p class="chave">Nome Fantasia da Empresa:</p>
        <p class="valor">{{ $empresa->nome }}</p>
      </div>
    </div>

    <hr>
    <div class="row">
      <div class="col-md-12">
        <h3>
          <i class="fa fa-th-list" aria-hidden="true"></i>
          Unidades
          <a class="btn btn-success pull-right" href="{{ route('clientes_unidades.create', $empresa->id) }}">
            <i class="fa fa-plus" aria-hidden="true"></i>
            Adicionar Unidade
          </a>
        </h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-12">
        <div class="table-responsive">
          <table class="table table-hover">
            <thead>
            <tr>
              <th class="col-md-6">Nome</th>
              <th class="col-md-4">CNPJ</th>
              <th class="col-md-2 text-right">Ações</th>
            </tr>
            </thead>
            <tbody>
            @foreach($unidades as $unidade)
              <tr>
                <td>{{ $unidade->nome }}</td>
                <td>{{ $unidade->cnpj }}</td>
                <td class="text-right">
                  <a class="btn btn-primary btn-xs" href="{{ route('clientes_unidades.show',[ $empresa->id, $unidade->id]) }}">
                    <i class="fa fa-eye" aria-hidden="true"></i>
                  </a>
                  @can(CRP::P_Cadastro_edit)
                    <a class="btn btn-warning btn-xs" href="{{ route('clientes_unidades.edit',[ $empresa->id, $unidade->id]) }}">
                      <i class="fa fa-pencil" aria-hidden="true"></i>
                    </a>
                    {{ Form::open(['route' => ['clientes_unidades.destroy' , $empresa->id, $unidade->id], 'style'=>'display:inline;']) }}
                    {{ Form::hidden('_method', 'DELETE') }}
                    <button type="submit" class="btn btn-danger btn-xs inline" name="deleta_item">
                      <i class="fa fa-trash-o" aria-hidden="true"></i>
                    </button>
                    {{ Form::close() }}
                  @endcan
                </td>
              </tr>
            @endforeach
            </tbody>
          </table>
        </div>
      </div>
    </div>

    <hr>
    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-sticky-note-o" aria-hidden="true"></i> Observações</h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-12">
        <p class="valor" style="height: 100%">{!!  nl2br(e($empresa->obs)) !!}</p>
      </div>
    </div>


  @elseif($tipo==2)
    {{--CETNROS DE CUSTO--}}
    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-briefcase" aria-hidden="true"></i> Empresa</h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-2 grupo">
        <p class="chave">Código:</p>
        <p class="valor">{{ sprintf('%02d',$empresa->codigo) }}</p>
      </div>
      <div class="col-md-10 grupo">
        <p class="chave">Nome Fantasia da Empresa:</p>
        <p class="valor">{{ $empresa->nome }}</p>
      </div>
    </div>

    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-briefcase" aria-hidden="true"></i> Centro de Custo</h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-2 grupo">
        <p class="chave">Código:</p>
        <p class="valor">{{ sprintf('%02d',$centro->codigo) }}</p>
      </div>
      <div class="col-md-10 grupo">
        <p class="chave">Nome do Departamento:</p>
        <p class="valor">{{ $centro->nome }}</p>
      </div>
    </div>

    <hr>
    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-address-book-o" aria-hidden="true"></i> Contatos</h3>
      </div>
    </div>

    @if(count($contatos)==0)
      <div class="alert alert-warning alert-important">
        <h4 style="margin-bottom: 0">
          <i class="fa fa-exclamation-circle fa-lg" aria-hidden="true"></i>
          Não há Contatos cadastrados.
        </h4>
      </div>
    @else
      @foreach($contatos as $contato)
        <div class="row">
          <div class="col-md-4 grupo">
            <p class="chave">Nome:</p>
            <p class="valor">{{ $contato->nome }}</p>
          </div>
          <div class="col-md-2 grupo">
            <p class="chave">Telefone:</p>
            <p class="valor">{{ $contato->tel }}</p>
          </div>
          <div class="col-md-2 grupo">
            <p class="chave">Celular:</p>
            <p class="valor">{{ $contato->cel }}</p>
          </div>
          <div class="col-md-4 grupo">
            <p class="chave">E-mail:</p>
            <p class="valor">{{ $contato->email }}</p>
          </div>
        </div>
        <br>
      @endforeach
    @endif


  @elseif($tipo==3)
    {{--CONTA--}}
    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-briefcase" aria-hidden="true"></i> Empresa</h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-2 grupo">
        <p class="chave">Código:</p>
        <p class="valor">{{ sprintf('%02d',$empresa->codigo) }}</p>
      </div>
      <div class="col-md-10 grupo">
        <p class="chave">Nome Fantasia da Empresa:</p>
        <p class="valor">{{ $empresa->nome }}</p>
      </div>
    </div>

    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-briefcase" aria-hidden="true"></i> Centro de Custo</h3>
      </div>
    </div>

    <div class="row">
      <div class="col-md-2 grupo">
        <p class="chave">Código:</p>
        <p class="valor">{{ sprintf('%02d',$centro->codigo) }}</p>
      </div>
      <div class="col-md-10 grupo">
        <p class="chave">Nome do Departamento:</p>
        <p class="valor">{{ $centro->nome }}</p>
      </div>
    </div>

    <div class="row">
      <div class="col-md-12">
        <h3><i class="fa fa-briefcase" aria-hidden="true"></i> Conta</h3>
      </div>
    </div>
    <div class="row">
      <div class="col-md-2 grupo">
        <p class="chave">Código:</p>
        <p class="valor">{{ sprintf('%02d',$conta->codigo ) }}</p>
      </div>
      <div class="col-md-10 grupo">
        <p class="chave">Nome Fantasia da Conta:</p>
        <p class="valor">{{ $conta->nome }}</p>
      </div>
    </div>
  @endif

  <br><br><br>

  @if($tipo==1)
    @include('_fragments.modal', ['titulo'=>'a Empresa deste Cliente'])
  @elseif($tipo==2)
    @include('_fragments.modal', ['titulo'=>'o Departamento deste Cliente'])
  @elseif($tipo==3)
    @include('_fragments.modal', ['titulo'=>'a Conta deste Cliente'])
  @endif

@endsection