@extends('app')

@section('content')
  <div class="row">
    <div class="col-md-12 form-group">
      <h1>
        <a href="{{route('jobs.index')}}" class="btn btn-default" data-toggle="tooltip" title="Voltar">
          <i class="fa fa-arrow-left fa-2x" aria-hidden="true"></i>
        </a>
        <i class="fa fa-money" aria-hidden="true"></i> Serviços do Custo Interno
      </h1>
    </div>
  </div>
  
  @include('flash::message')
  
  <div class="row">
    <div class="col-md-10 col-md-offset-1">
      {{ Form::open(['route' => 'jobs.servicoCustoInternoCreate', 'style'=>'display:inline;']) }}
      <div class="row">
        <div class="col-md-6 form-group">
          {{Form::label('nome','Nome do Serviço:')}}
          {{ Form::text('nome', null, ['class'=>'form-control']) }}
        </div>
        <div class="col-md-3 col-sm-6 form-group">
          {{Form::label('sinapro_min','Sinapro Min:')}}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {{ Form::text('sinapro_min', null, ['class'=>'form-control', 'id'=>'sinapro_min']) }}
            <span class="input-group-addon">.00</span>
          </div>
        </div>
        <div class="col-md-3 col-sm-6 form-group">
          {{Form::label('sinapro_max','Sinapro Max:')}}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {{ Form::text('sinapro_max', null, ['class'=>'form-control']) }}
            <span class="input-group-addon">.00</span>
          </div>
        </div>
      </div>
      <div class="row">
        <div class="col-md-3 col-sm-4 form-group">
          {{Form::label('desc_15','Desconto 15%:')}}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {{ Form::text('desc_15', null, ['class'=>'form-control', 'readonly', 'id'=>'desc_15']) }}
            <span class="input-group-addon">.00</span>
          </div>
        </div>
        <div class="col-md-3 col-sm-4 form-group">
          {{Form::label('desc_30','Desconto 30%:')}}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {{ Form::text('desc_30', null, ['class'=>'form-control', 'readonly', 'id'=>'desc_30']) }}
            <span class="input-group-addon">.00</span>
          </div>
        </div>
        <div class="col-md-3 col-sm-4 form-group">
          {{Form::label('desc_50','Desconto 50%:')}}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {{ Form::text('desc_50', null, ['class'=>'form-control', 'readonly', 'id'=>'desc_50']) }}
            <span class="input-group-addon">.00</span>
          </div>
        </div>
        <div class="col-md-1 form-group hidden-xs hidden-sm">
        </div>
        <div class="col-md-2 form-group">
          <label for="" class="control-label hidden-xs hidden-sm">&nbsp;</label>
          <button class="btn btn-success form-control" type="submit">
            <i class="fa fa-plus" aria-hidden="true"></i> Inserir
          </button>
        </div>
      </div>
      {{ Form::close() }}
    </div>
  </div>
  <br>
  
  @if($servicosCount === 0)
    <div id="list" class="row">
      <div class="col-md-10 col-md-offset-1">
        <div class="alert alert-warning alert-important">
          <h4 style="margin-bottom: 0">
            <i class="fa fa-exclamation-circle fa-lg" aria-hidden="true"></i>
            Não há Servicos do Custo Interno cadastrados.
          </h4>
        </div>
      </div>
    </div>
  @else
    <div class="table-responsive">
      <table class="table table-hover table-responsive">
        <thead>
        <tr>
          <th>Serviço</th>
          <th>Sinapro Min</th>
          <th>Sinapro Max</th>
          <th>Desconto 15%</th>
          <th>Desconto 30%</th>
          <th>Desconto 50%</th>
          <th class="actions" style="text-align: right">Ações</th>
        </tr>
        </thead>
        <tbody>
        @foreach($servicos as $servico)
          <tr>
            <td>{{$servico->nome}}</td>
            <td>R$ {{$servico->sinapro_min}},00</td>
            <td>R$ {{$servico->sinapro_max}},00</td>
            <td>R$ {{$servico->desc_15}},00</td>
            <td>R$ {{$servico->desc_30}},00</td>
            <td>R$ {{$servico->desc_50}},00</td>
            <td class="actions" style="text-align: right">
              {{ Form::open(['route' => ['jobs.servicoCustoInternosDestroy' , $servico->id], 'style'=>'display:inline;']) }}
              {{ Form::hidden('_method', 'DELETE') }}
              <button type="submit" class="btn btn-danger btn-xs inline" name="deleta_item">
                <i class="fa fa-trash-o" aria-hidden="true"></i>
              </button>
              {{ Form::close() }}
            
            </td>
          </tr>
        @endforeach
        </tbody>
      </table>
    </div>
  @endif
  
  @include('_fragments.modal', ['titulo'=>'Serviço do Custo Interno'])

@endsection

@section('scripts')
  <script>
    $( function () {
      $( '#sinapro_min' ).on( 'blur', function () {
        var val = $( '#sinapro_min' ).val();
        $( '#desc_15' ).val( Math.round( val * 0.85 ) );
        $( '#desc_30' ).val( Math.round( val * 0.70 ) );
        $( '#desc_50' ).val( Math.round( val * 0.50 ) );
      } )
    } );
  </script>

@endsection