<?php /**  @var \App\Models\Financeiro\ContaDeConsumo $consumo */ ?>
@extends('app')

@section('content')
  <div class="row">
    <div class="col-md-4 form-group">
      <h2>
        @if( $caixaVoltar )
          <a href="{{ $caixaVoltar }}" class="btn btn-default" data-toggle="tooltip" title="Voltar">
            <i class="fa fa-arrow-left fa-2x" aria-hidden="true"></i>
          </a>
        @endif
        <i class="fa fa-minus" aria-hidden="true"></i>
        Contas de Consumo
      </h2>
    </div>
    <div class="col-md-6 form-group">
      @include('_fragments.ListagemPadronizada_form')
    </div>
    <div class="col-md-2 form-group">
      <div class="dropdown pull-right h2">
        <button class="btn btn-success dropdown-toggle" type="button" id="dropdownMenu1" data-toggle="dropdown">
          <i class="fa fa-plus" aria-hidden="true"></i>
          Adicionar Conta
          <span class="caret"></span>
        </button>
        <ul class="dropdown-menu" role="menu" aria-labelledby="dropdownMenu1">
          <li role="presentation">
            <a role="menuitem" tabindex="-1" href="{{ route('financeiro.contasdeconsumo.create') }}">
              <i class="fa fa-plus" aria-hidden="true"></i>
              Conta Independente
            </a>
          </li>
          <li role="presentation">
            <a role="menuitem" tabindex="-1" data-toggle="modal" href="#modal_gerar">
              <i class="fa fa-clone" aria-hidden="true"></i>
              A partir de um Gerador
            </a>
          </li>
          <li role="separator" class="divider"></li>
          <li role="presentation">
            <a role="menuitem" tabindex="-1" href="{{ route('financeiro.contasdeconsumogerador.index') }}">
              <i class="fa fa-plus-square" aria-hidden="true"></i>
              Contas Geradoras
            </a>
          </li>
        </ul>
      </div>
    </div>
  </div>

  @include('flash::message')

  <div class="row">
    <div class="col-md-12 form-group">
      <div class="table-responsive">
        <table class="table table-hover">
          <thead>
          <tr>
            <th class="text-left" style="width: 7%">@sortablelink('pago','Pago')</th>
            <th class="text-left" style="width: 25%">@sortablelink('nome','Nome')</th>
            <th class="text-left" style="width: 15%">@sortablelink('data','Vencimento')</th>
            <th class="text-left" style="width: 30%">@sortablelink('despesas_id','Despesa')</th>
            <th class="text-right" style="width: 15%">@sortablelink('valor','Valor')</th>
            <th class="text-right" style="width: 7%">Ações</th>
          </tr>
          </thead>
          <tbody>
          @foreach($consumos as $consumo)
            <tr>
              <td class="text-left"><i class="fa {{ $consumo->pago? 'fa-check-square' : 'fa-square-o' }}" aria-hidden="true"></i></td>
              <td class="text-left">{{ $consumo->nome }}</td>
              <td class="text-left">{{ \Carbon\Carbon::parse($consumo->data)->format('d/m/Y')}}</td>
              {{--<td class="text-left">{{ $consumo->ContaBancariaNome() }}</td>--}}
              <td class="text-left">{{ $consumo->DespesaCodigoNome() }}</td>
              <td class="text-right">R$ {{ number_format($consumo->valor/100, 2, ',','.') }}</td>
              <td class="text-right">
                <a class="btn btn-warning btn-xs" href="{{ route('financeiro.contasdeconsumo.edit',[$consumo->id]) }}">
                  <i class="fa fa-pencil" aria-hidden="true"></i>
                </a>
                {{ Form::open(['route' => ['financeiro.contasdeconsumo.destroy' , $consumo->id], 'style'=>'display:inline;']) }}
                {{ Form::hidden('_method', 'DELETE') }}
                <button type="submit" class="btn btn-danger btn-xs inline" name="deleta_item">
                  <i class="fa fa-trash-o" aria-hidden="true"></i>
                </button>
                {{ Form::close() }}
              </td>
            </tr>
          @endforeach
          </tbody>
        </table>
      </div>

    </div>
  </div>

  <div class="row">
    <div class="col-md-12 text-center">
      {!! $consumos->appends(\Request::except('page'))->render() !!}
    </div>
  </div>

  @include('_fragments.modal', ['titulo'=>'Conta de Consumo'])

  {!! Form::open([
    'route' => 'financeiro.contasdeconsumo.create',
    'method'=>'get',
  ]) !!}
  <div class="modal fade" id="modal_gerar">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
          <h4 class="modal-title">Gerar Conta a partir de uma Conta Geradora</h4>
        </div>
        <div class="modal-body">
          <div class="row">
            <div class="col-md-12 form-group">
              {!! Form::label('gerador', 'Selecione a Conta Geradora:', ['class'=>'control-label']) !!}
              {!! Form::select('gerador', \App\Models\Financeiro\ContaDeConsumoGerador::enum_geradores(), null, ['class'=>'form-control', 'required']) !!}
            </div>
          </div>
        </div>
        <div class="modal-footer">
          <button type="button" class="btn btn-default" data-dismiss="modal">Cancelar</button>
          <button type="submit" class="btn btn-primary">Criar</button>
        </div>
      </div><!-- /.modal-content -->
    </div><!-- /.modal-dialog -->
  </div><!-- /.modal -->
  {!! Form::close() !!}
@endsection
