@extends('app')

@section('content')

  <div class="row">
    <div class="col-md-12 form-group">
      <div class="h1">
        <a href="{{ $voltar }}" class="btn btn-default" data-toggle="tooltip" title="Voltar">
          <i class="fa fa-arrow-left fa-2x" aria-hidden="true"></i>
        </a>
        <i class="fa fa-briefcase" aria-hidden="true"></i>
        Editar Parcela do Job:
        <span style="color: #777">{{ $job->nome_job }}</span>
      </div>
    </div>
  </div>


  <div class="row">
    <div class="col-md-10 col-md-offset-1 form-group">
      {!!  Form::open([
          'route' => ['financeiro.jobs.parcela.update', $job->id, $parcela->id],
          'method'=>'PUT',
          'id'=>'form_parcela_edit'
      ]) !!}

      {{ Form::hidden('_voltar', $periodo) }}

      <div class="row">
        <div class="col-md-8 form-group">
          {!! Form::label('nome', 'Nome da Parcela:', ['class'=>'control-label']) !!}
          {!! Form::text('nome', $parcela->nome, ['class'=>'form-control', 'required'] ) !!}
        </div>
        <div class="col-md-4 grupo">
          <p class="chave">Código de Receita:</p>
          <p class="valorReadOnly">{{ \App\Models\Cadastros\CodigoReceita::getCodReceitaNome( $job->cod_receita ) }}</p>
        </div>
      </div>

      <div class="row">
        <div class="col-md-4 form-group">
          {!! Form::label('data', 'Data de Pagamento:', ['class'=>'control-label']) !!}
          {!! Form::date('data', $parcela->data, ['class'=>'form-control', 'required'] ) !!}
        </div>
        <div class="col-md-5 form-group">
          {!! Form::label('conta_id', 'Conta Bancária:') !!}
          {!! Form::select('conta_id', \App\Models\Financeiro\ContaBancaria::enum_contas_pelo_cliente(), $parcela->conta_id, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione uma Conta Bancária --']) !!}
        </div>
        <div class="col-md-3 form-group">
          {!! Form::label('pago', 'Está Paga:', ['class'=>'control-label']) !!}
          {!! Form::select('pago', [ 0=>'Não', 1=>'Sim' ], $parcela->pago, ['class'=>'form-control', 'required', 'id'=>'input_paga'] ) !!}
        </div>
      </div>

      <div class="row">
        <div class="col-md-4 form-group">
          {!! Form::label('valor_bruto', 'Valor Bruto desta Parcela:', ['class'=>'control-label']) !!}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {!! Form::text('valor_bruto', number_format($parcela->valor_bruto/100, 2, ',', '.'), ['class'=>'form-control', 'id'=>'input_valor_bruto', 'required'] ) !!}
          </div>
        </div>

        <div class="col-md-4 form-group">
          {!! Form::label('valor_imposto', 'Valor Retido:', ['class'=>'control-label']) !!}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {!! Form::text('valor_imposto', number_format($parcela->valor_imposto/100, 2, ',', '.'), ['class'=>'form-control', 'id'=>'input_valor_imposto', 'required'] ) !!}
          </div>
        </div>

        <div class="col-md-4 form-group">
          {!! Form::label('valor_liquido', 'Valor Líquido desta Parcela:', ['class'=>'control-label']) !!}
          <div class="input-group">
            <span class="input-group-addon">R$</span>
            {!! Form::text('valor_liquido', number_format($parcela->valor_liquido/100, 2, ',', '.'), ['class'=>'form-control', 'id'=>'input_valor_liquido', 'required'] ) !!}
          </div>
        </div>
      </div>

      <div class="row">
        <div class="col-md-9 form-group">
          {!! Form::label('nota_fiscal', 'Nota Fiscal:', ['class'=>'control-label']) !!}
          {!! Form::text('nota_fiscal', $parcela->nota_fiscal, ['class'=>'form-control'] ) !!}
        </div>
        <div class="col-md-3 form-group">
          {!! Form::label('nota_fiscal_data_emissao', 'Data de Emissão:', ['class'=>'control-label']) !!}
          {!! Form::date('nota_fiscal_data_emissao', $parcela->nota_fiscal_data_emissao, ['class'=>'form-control'] ) !!}
        </div>
      </div>

      <div class="row">
        <div class="col-md-12 form-group">
          <button type="submit" class="btn btn-primary">
            <i class="fa fa-floppy-o" aria-hidden="true"></i>
            Salvar
          </button>
          <a href="{{ $voltar }}" class="btn btn-default">
            <i class="fa fa-ban" aria-hidden="true"></i>
            Cancelar
          </a>
        </div>
      </div>

      {!! Form::close() !!}
    </div>
  </div>
@endsection
@section('scripts')
  <script type="application/javascript">
    function calc_imposto() {
      var valor_b = $( '#input_valor_bruto' ).val().replace( /\D/g, '' );
      var imposto = $( '#input_valor_imposto' ).val().replace( /\D/g, '' );
      var valor_l = parseInt( valor_b - imposto );
      $( '#input_valor_liquido' ).val( formatDinheiro( valor_l ).replace( /\./g, '' ) );
    }
    $( function () {
      $( '#input_valor_bruto' ).maskMoney( { thousands: '.', decimal: ',', allowZero: true, allowNegative: true } );
      $( '#input_valor_bruto' ).on( 'blur', calc_imposto );
      $( '#input_valor_liquido' ).maskMoney( { thousands: '.', decimal: ',', allowZero: true, allowNegative: true } );
      $( '#input_valor_liquido' ).on( 'blur', calc_imposto );
      $( '#input_valor_imposto' ).maskMoney( { thousands: '.', decimal: ',', allowZero: true, allowNegative: true } );
      $( '#input_valor_imposto' ).on( 'blur', calc_imposto );
      $( '#form_parcela_edit' ).submit( function () {
        calc_imposto();

        var valorB = $( '#input_valor_bruto' );
        valorB.maskMoney( 'unmasked' );
        valorB.val( valorB.val().replace( /\D/g, '' ) );

        var valorI = $( '#input_valor_imposto' );
        valorI.maskMoney( 'unmasked' );
        valorI.val( valorI.val().replace( /\D/g, '' ) );

        var valorL = $( '#input_valor_liquido' );
        valorL.maskMoney( 'unmasked' );
        valorL.val( valorL.val().replace( /\D/g, '' ) );

        return true;
      } );
    } );
  </script>
@endsection
