<?php /** @var \App\Models\Financeiro\Salario13 $salario13 */ ?>

<div class="row">
  <div class="col-md-10 form-group">
    {!! Form::label('funcionario_id', 'Funcionário:', ['class'=>'control-label']) !!}
    {!! Form::select('funcionario_id', \App\Models\Cadastros\Funcionarios::enum_Funcionarios(), null, ['class'=>'form-control', 'required', 'placeholder'=>'-- Atribua esta conta a um Funcionário --']) !!}
  </div>
  <div class="col-md-2 form-group">
    {!! Form::label('pago', 'Está Paga:', ['class'=>'control-label']) !!}
    {!! Form::select('pago', [ 0=>'Não', 1=>'Sim' ], null, ['class'=>'form-control', 'required'] ) !!}
  </div>
</div>

<div class="row">
  <div class="col-md-3 form-group">
    {!! Form::label('data', 'Data de Pagamento:', ['class'=>'control-label']) !!}
    {!! Form::date('data', ( ( isset( $ehEdit ) && $ehEdit ) ? null : \Carbon\Carbon::now()->format( 'Y-m-d' ) ), ['class'=>'form-control', 'required'] ) !!}
  </div>
  <div class="col-md-3 form-group">
    {!! Form::label('conta_id', 'Conta Bancária:') !!}
    {!! Form::select('conta_id', \App\Models\Financeiro\ContaBancaria::enum_contas(), null, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione uma Conta Bancária --']) !!}
  </div>
  <div class="col-md-3 form-group">
    {!! Form::label('centros_de_custo_cadaris_id', 'Centro de Custo da Cadaris:') !!}
    {!! Form::select('centros_de_custo_cadaris_id', \App\Models\Cadastros\CentrosDeCustoCadaris::enum_centros_de_custo_cadaris(), null, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione um Centro de Custo da Cadaris --']) !!}
  </div>
  <div class="col-md-3 form-group">
    {!! Form::label('plano_de_contas_item_id', 'Código de Despesa:', ['class'=>'control-label']) !!}
    {!! Form::select('plano_de_contas_item_id', \App\Models\Cadastros\PlanoDeContas::enum_despesas_reduzida(), null, [ 'placeholder'=>'-- Selecione um item --', 'class'=>'form-control', 'required']) !!}
  </div>
</div>

<div class="row">
  <div class="col-md-4 form-group">
    {!! Form::label('valor_salario_13', 'Valor do 13º Salário:', ['class'=>'control-label']) !!}
    <div class="input-group">
      <span class="input-group-addon">R$</span>
      {!! Form::text('valor_salario_13', (isset($ehEdit) ? number_format($salario13->valor_salario_13/100 ,2, ',','.') : '0,00'), ['class'=>'form-control', 'id'=>'input_valor_salario_13', 'required'] ) !!}
    </div>
  </div>
  <div class="col-md-4 form-group">
    {!! Form::label('valor_desc', 'Valor de Desconto:', ['class'=>'control-label']) !!}
    <div class="input-group">
      <span class="input-group-addon">R$</span>
      {!! Form::text('valor_desc', (isset($ehEdit) ? number_format($salario13->valor_desc/100 ,2, ',','.') : '0,00'), ['class'=>'form-control', 'id'=>'input_valor_desc', 'required'] ) !!}
    </div>
  </div>
  <div class="col-md-4 form-group-lg">
    {!! Form::label('valor_total', 'Valor Total:', ['class'=>'control-label']) !!}
    <div class="input-group">
      <span class="input-group-addon">R$</span>
      {!! Form::text('valor_total', (isset($ehEdit) ? number_format($salario13->valor_total/100 ,2, ',','.') : '0,00'), ['class'=>'form-control', 'id'=>'input_valor_total', 'required'] ) !!}
    </div>
  </div>
</div>

<br>
<br>

@include('errors.list')

@section('scripts')
  <script type="application/javascript">
    function moneyValorSet( id ) {
      var input = $( '#input_' + id );
      input.maskMoney( 'unmasked' );
      var valor = parseInt( input.val().replace( /\D/g, '' ) );
      input.val( valor );
      return valor;
    }

    function moneyValorGet( id ) {
      var v = parseInt( $( '#input_' + id ).val().replace( /\D/g, '' ) );
      console.log( v );
      return v;
    }

    function calc_salario13() {
      var valor_soma = moneyValorGet( 'valor_salario_13' );
      var valor_sub  = moneyValorGet( 'valor_desc' );

      var valor_total = valor_soma - valor_sub;
      $( '#input_valor_total' ).val( formatDinheiro( valor_total ) );
      console.log( valor_total );
    }

    $( function () {
      var inputs = [ 'valor_salario_13',
        'valor_desc' ];

      for ( var id in inputs ) {
        $( '#input_' + inputs[ id ] ).maskMoney( { thousands: '.', decimal: ',', allowZero: true, allowNegative: false } );
        $( '#input_' + inputs[ id ] ).on( 'blur', calc_salario13 );
      }
      $( '#input_valor_total' ).maskMoney( { thousands: '.', decimal: ',', allowZero: true, allowNegative: false } );
      $( '#form_salario13' ).submit( function () {
        var valor_salario_13 = moneyValorSet( 'valor_salario_13' );
        var valor_desc       = moneyValorSet( 'valor_desc' );

        var valor_soma  = valor_salario_13;
        var valor_sub   = valor_desc;
        var valor_total = valor_soma - valor_sub;
        $( '#input_valor_total' ).val( valor_total );

        return true;
      } );
    } );
  </script>
@endsection