<?php /**  @var \App\Models\Financeiro\Salario $salario */ ?>
@extends('app')

@section('content')
  <div class="row">
    <div class="col-md-12 form-group">
      <div class="h1">
        @if( $caixaVoltar )
          <a href="{{ $caixaVoltar }}" class="btn btn-default" data-toggle="tooltip" title="Voltar">
            <i class="fa fa-arrow-left fa-2x" aria-hidden="true"></i>
          </a>
        @endif
        <i class="fa fa-minus" aria-hidden="true"></i>
        Folha de Pagamento
        <a class="btn btn-success pull-right" data-toggle="modal" href="#modal_lancar">
          <i class="fa fa-plus" aria-hidden="true"></i>
          Lançar Salários de um Mês
        </a>
      </div>
    </div>
  </div>

  @include('flash::message')

  {!! Form::open([
    'method'=> 'GET',
    'route' => 'financeiro.salarios.index',
  ]) !!}

  <div class="row">
    <div class="col-md-8 col-md-offset-2 form-group">
      <div class="row">
        <div class="col-md-5 form-group">
          {!! Form::label('ano', 'Ano Referente:', ['class'=>'control-label']) !!}
          {!! Form::select('ano', $anos, $ano, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione um Ano --']) !!}
        </div>
        <div class="col-md-5 form-group">
          {!! Form::label('mes', 'Mês Referente:', ['class'=>'control-label']) !!}
          {!! Form::select('mes', \App\Models\Financeiro\Salario::$enum_mes, $mes, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione um Mês --']) !!}
        </div>
        <div class="col-md-2 form-group">
          {!! Form::label('', '&nbsp;', ['class'=>'control-label hidden-xs hidden-sm']) !!}
          <button type="submit" class="form-control btn btn-primary">
            Acessar &nbsp;
            <i class="fa fa-arrow-right" aria-hidden="true"></i>
          </button>
        </div>
      </div>
    </div>
  </div>
  {!! Form::close() !!}

  @if($ano=='' || $mes=='')
    <div class="row">
      <div class="col-md-8 col-md-offset-2 form-group">
        <div class="alert alert-info alert-important">
          <i class="fa fa-exclamation-circle" aria-hidden="true"></i>
          <strong>Selecione um Ano e Mês para exibir o Folha de Pagamento</strong>
        </div>
      </div>
    </div>
  @elseif(count($salarios)==0)
    <div class="row">
      <div class="col-md-8 col-md-offset-2 form-group">
        <div class="alert alert-warning alert-important">
          <i class="fa fa-exclamation-triangle" aria-hidden="true"></i>
          <strong>Não Há Folha de Pagamento a ser exibida para este Ano e Mês</strong>
        </div>
      </div>
    </div>
  @else

    <div class="row">
      <div class="col-md-12 form-group">
        <div class="table-responsive">
          <table class="table table-hover">
            <thead>
            <tr>
              <th class="text-left" style="width: 6%;"></th>
              <th class="text-left" style="width: 24%;">Nome do Funcionário</th>
              <th class="text-left" style="width: 8%;">Data</th>
              <th class="text-left" style="width: 16%;">Conta Bancária</th>
              <th class="text-right" style="width: 4%;" title="Dias Úteis" data-toggle="tooltip" data-container="body">DÚ</th>
              <th class="text-right" style="width: 10%;">Salários</th>
              <th class="text-right" style="width: 8%;">VR</th>
              <th class="text-right" style="width: 8%;">VT</th>
              <th class="text-right" style="width: 10%;">Valor Total</th>
              <th class="text-right" style="width: 6%;">Ações</th>
            </tr>
            </thead>
            <tbody>
            @foreach($salarios as $salario)
              <tr>
                <td class="text-left" style="padding-right: 0;">
                  <i class="fa {{ $salario->pago? 'fa-check-square' : 'fa-square-o' }}" aria-hidden="true"></i>
                  @if ( !empty( $salario->holerite ) )
                    <i class="fa fa-paperclip fa-lg" aria-hidden="true" data-toggle="tooltip" title="Há Holerite/Recibo anexo"></i>
                    @if ( $salario->holerite_visited === \App\Models\Financeiro\Salario::HOLERITE_VISITED_VISUALIZED )
                      <i class="fa fa-eye fa-lg" aria-hidden="true" data-toggle="tooltip" title="Visualizado pelo Funcionário"></i>
                    @endif
                  @endif
                </td>
                <td class="text-left">{{ $salario->FuncionarioNome() }}</td>
                <td class="text-left">{{ \Carbon\Carbon::parse($salario->data_pagamento)->format('d/m/Y')}}</td>
                <td class="text-left">{{ $salario->ContaBancariaNome() }}</td>
                <td class="text-right">{{ $salario->dias_uteis }}</td>
                <td class="text-right">R$ {{ number_format($salario->valor_salario/100, 2, ',', '.') }}</td>
                <td class="text-right">R$ {{ number_format($salario->valor_vr/100, 2, ',', '.') }}</td>
                <td class="text-right">R$ {{ number_format($salario->valor_vt/100, 2, ',', '.') }}</td>
                <td class="text-right">R$ {{ number_format($salario->valor_total/100, 2, ',', '.') }}</td>
                <td class="text-right">
                  <a class="btn btn-warning btn-xs" href="{{ route('financeiro.salarios.edit',[$salario->id]) }}">
                    <i class="fa fa-pencil" aria-hidden="true"></i>
                  </a>
                  {{ Form::open(['route' => ['financeiro.salarios.destroy' , $salario->id], 'style'=>'display:inline;']) }}
                  {{ Form::hidden('_method', 'DELETE') }}
                  <button type="submit" class="btn btn-danger btn-xs inline" name="deleta_item">
                    <i class="fa fa-trash-o" aria-hidden="true"></i>
                  </button>
                  {{ Form::close() }}
                </td>
              </tr>
            @endforeach
            </tbody>
            <tfoot>
            <tr>
              <td colspan="5" class="text-right">
                <strong>
                  Total
                </strong>
              </td>
              <td class="text-right">
                <strong>
                  R$ {{ number_format($total['valor_salario_total']/100, 2, ',','.') }}
                </strong>
              </td>
              <td class="text-right">
                <strong>
                  R$ {{ number_format($total['valor_vr_total']/100, 2, ',','.') }}
                </strong>
              </td>
              <td class="text-right">
                <strong>
                  R$ {{ number_format($total['valor_vt_total']/100, 2, ',','.') }}
                </strong>
              </td>
              <td class="text-right">
                <strong>
                  R$ {{ number_format($total['valor_total']/100, 2, ',','.') }}
                </strong>
              </td>
              <td></td>
            </tr>
            </tfoot>
          </table>
        </div>

      </div>
    </div>
  @endif

  <br>
  <br>
  <br>
  <br>

  @include('_fragments.modal', ['titulo'=>'Salário'])

  {!! Form::open([
    'route' => 'financeiro.salarios.store',
    'method'=>'POST',
  ]) !!}

  <div class="modal fade" id="modal_lancar">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
          <h4 class="modal-title">Lançar Folha de Pagamento</h4>
        </div>
        <div class="modal-body">

          <div class="row">
            <div class="col-md-6 form-group">
              {!! Form::label('ano', 'Ano:', ['class'=>'control-label']) !!}
              {!! Form::number('ano', \Carbon\Carbon::now()->year, ['class'=>'form-control', 'required']) !!}
            </div>
            <div class="col-md-6 form-group">
              {!! Form::label('mes', 'Mês:', ['class'=>'control-label']) !!}
              {!! Form::select('mes', \App\Models\Financeiro\Salario::$enum_mes, $mes, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione um Mês --']) !!}
            </div>
          </div>

          <div class="row">
            <div class="col-md-12 form-group">
              {!! Form::label('conta_id', 'Conta Bancária:', ['class'=>'control-label']) !!}
              {!! Form::select('conta_id', \App\Models\Financeiro\ContaBancaria::enum_contas(), null, ['class'=>'form-control', 'required', 'placeholder'=>'-- Selecione uma Conta Bancária --']) !!}
            </div>
          </div>

          <div class="row">
            <div class="col-md-6 form-group">
              {!! Form::label('data_pagamento', 'Data de Pagamento:', ['class'=>'control-label']) !!}
              {!! Form::date('data_pagamento', \Carbon\Carbon::now()->format('Y-m-d'), ['class' => 'form-control', 'required']) !!}
            </div>
            <div class="col-md-6 form-group">
              {!! Form::label('dias_uteis', 'Dias Úteis:', ['class'=>'control-label']) !!}
              {!! Form::text('dias_uteis', 22, ['class' => 'form-control somenteNumeros', 'required']) !!}
            </div>
          </div>

        </div>
        <div class="modal-footer">
          <button type="button" class="btn btn-default" data-dismiss="modal">Cancelar</button>
          <button type="submit" class="btn btn-success">
            <i class="fa fa-plus" aria-hidden="true"></i>
            Lançar Salarios
          </button>
        </div>
      </div><!-- /.modal-content -->
    </div><!-- /.modal-dialog -->
  </div><!-- /.modal -->
  {!! Form::close() !!}
@endsection
@section('scripts')
  <script type="application/javascript">
    $( function () {

    } );
  </script>
@endsection
