@extends('appLogin')

@section('content')
  <div class="row">
    <div class="col-xs-12 col-sm-8 col-sm-offset-2 col-md-6 col-md-offset-3 col-lg-4 col-lg-offset-4">
      <div class="panel panel-primary">
        <div class="panel-heading text-center">
          <div class="h4">
            <img alt="Logo Cadaris" src="/images/logo_cadaris_branco.png" style="margin-top: -12px; height:45px" class="pull-left">
            Acesso ao Sistema Cadaris
          </div>
        </div>
        <div class="panel-body">
          <form role="form" method="POST" action="{{ url('/login') }}" id="login_form">
            {{ csrf_field() }}
            
            <div class="row form-group">
              <div class="col-xs-12{{ $errors->has('email') ? ' has-error' : '' }}" id="div_email">
                <div class="input-group">
                  <span class="input-group-addon"><i class="fa fa-envelope-o" aria-hidden="true"></i></span>
                  <input id="email" type="email" placeholder="E-mail" class="form-control no-autofill-bgcolor"
                         name="email"
                         value="{{ old('email') }}" required autofocus>
                </div>
                @if ($errors->has('email'))
                  <span class="help-block">
                        <strong>{{ $errors->first('email') }}</strong>
                    </span>
                @endif
              </div>
            </div>
            <div class="row form-group">
              <div class="col-xs-12{{ $errors->has('password') ? ' has-error' : '' }}" id="div_pass">
                <div class="input-group">
                  <span class="input-group-addon"><i class="fa fa-key" aria-hidden="true"></i></span>
                  <input id="password" type="password" placeholder="Senha" class="form-control no-autofill-bgcolor"
                         name="password" required>
                </div>
                @if ($errors->has('password'))
                  <span class="help-block">
                        <strong>{{ $errors->first('password') }}</strong>
                    </span>
                @endif
              </div>
            </div>
            @if (session('message'))
              <div class="row" id="div_msg">
                <div class="col-xs-12">
                  <div class="alert alert-warning alert-important" style="margin-bottom: 10px;">
                    <i class="fa fa-exclamation-circle fa-lg"></i>
                    <strong>{{ session('message') }}</strong>
                  </div>
                </div>
              </div>
            @endif
            
            <div class="row" id="div_error" style="display: none;">
              <div class="col-xs-12">
                <div class="alert alert-danger alert-important" style="margin-bottom: 10px;">
                  <i class="fa fa-exclamation-triangle fa-lg"></i>
                  <strong>Credenciais informadas não correspondem com nossos registros.</strong>
                </div>
              </div>
            </div>
            
            <div class="row" id="div_load" style="display: none;">
              <div class="col-xs-12">
                <div class="alert alert-info alert-important" style="margin-bottom: 10px;">
                  <i class="fa fa-spinner fa-pulse fa-fw fa-lg"></i>
                  <strong>Entrando...</strong>
                </div>
              </div>
            </div>
            
            <div class="row" id="div_ok" style="display: none;">
              <div class="col-xs-12">
                <div class="alert alert-success alert-important" style="margin-bottom: 10px;">
                  <i class="fa fa-check fa-lg" aria-hidden="true"></i>
                  <strong>Entrou Com Sucesso!</strong>
                </div>
              </div>
            </div>
            
            <div class="row">
              <div class="col-xs-6">
                <div class="checkbox">
                  <label>
                    <input type="checkbox" name="remember"> Lembrar-me
                  </label>
                </div>
              </div>
              <div class="col-xs-6">
                <button type="submit" class="btn btn-success form-control" id="logar">
                  ENTRAR&nbsp;<i class="fa fa-sign-in" aria-hidden="true"></i>
                </button>
              </div>
            </div>
          </form>
        </div>
        
        <div class="panel-footer">
          <div class="row">
            <div class="col-xs-12">
              <a class="btn btn-link" href="{{ url('/password/reset') }}">
                Esqueceu Sua Senha?
              </a>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
  
  @if( config( 'app.env' ) == 'local' )
    <!-- Botoes das contas DEV -->
    <div class="row form-group">
      <div class="col-xs-12 text-center">
        <div class="row">
          <div class="col-xs-12 text-center">
            LOGINs DEV:
          </div>
        </div>
        <div class="row">
          <div class="col-xs-12 text-center">
            <div class="btn-group btn-group-sm" role="group" aria-label="...">
              <button class="btn btn-default" onclick="preencher('dev_admin@cadaris.dev','123456')">Admin</button>
              <button class="btn btn-default" onclick="preencher('dev_diretor@cadaris.dev','123456')">Diretor</button>
              <button class="btn btn-default" onclick="preencher('dev_financeiro@cadaris.dev','123456')">Financeiro</button>
              <button class="btn btn-default" onclick="preencher('dev_planejamento@cadaris.dev','123456')">Planejamento</button>
              <button class="btn btn-default" onclick="preencher('dev_producao@cadaris.dev','123456')">Produção</button>
              <button class="btn btn-default" onclick="preencher('dev_rh@cadaris.dev','123456')">RH</button>
              <button class="btn btn-default" onclick="preencher('dev_cliente@cadaris.dev','123456')">Cliente</button>
            </div>
          </div>
        </div>
      </div>
    </div>
  @endif
@endsection
@section('scripts')
  <script>
    // http://itsolutionstuff.com/post/laravel-52-api-using-jwt-authentication-tutorial-from-scratch-exampleexample.html
    // https://github.com/tymondesigns/jwt-auth/wiki/Authentication
    // https://www.sitepoint.com/php-authorization-jwt-json-web-tokens/
    function errou() {
      $( '#div_email' ).addClass( 'has-error' );
      $( '#div_pass' ).addClass( 'has-error' );
      $( '#div_msg' ).hide();
      $( '#div_error' ).show();
      $( '#div_load' ).hide();
      $( '#div_ok' ).hide();
    }
    function entrando() {
      $( '#div_email' ).removeClass( 'has-error' );
      $( '#div_pass' ).removeClass( 'has-error' );
      $( '#div_msg' ).hide();
      $( '#div_error' ).hide();
      $( '#div_load' ).show();
      $( '#div_ok' ).hide();
    }
    function entrou() {
      $( '#div_msg' ).hide();
      $( '#div_error' ).hide();
      $( '#div_load' ).hide();
      $( '#div_ok' ).show();
    }
    $( function () {
      $( '#login_form' ).submit( function ( e ) {
        // this code prevents form from actually being submitted
        e.preventDefault();
        e.returnValue = false;
        
        entrando();
        
        var email = $( '#email' ).val();
        var pass = $( '#password' ).val();
        
        $.ajax( {
          url: '{{ route('api.logar') }}',
          type: 'POST',
          data: { "email": email, "password": pass },
          context: $( this ), // context will be "this" in your handlers
          success: function ( data ) {
            entrou();
            window.localStorage[ 'jwtToken' ] = data.token;
            // make sure that you are no longer handling the submit event; clear handler
            this.off( 'submit' );
            // actually submit the form
            this.submit();
          },
          error: function () {
            console.error( 'jwtToken logar error' );
            errou();
          }
        } );
      } );
    } );
  </script>
  @if( config( 'app.env' ) == 'local' )
    <script type="application/javascript">
      function preencher( email, password ) {
        $( '#email' ).val( email );
        $( '#password' ).val( password );
        $( '#logar' ).click();
      }
    </script>
  @endif
@endsection
