<?php

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

/// AUTENTICACAO e HOME
Route::group( [ 'as' => 'api.' ], function () {
  // Rota para o AJAX logar e reveber seu token
  Route::post( 'logar', 'Auth\AuthenticateController@authenticate' )->name( 'logar' );
} );


// CADASTROS API
Route::group( [ 'prefix' => 'cadastros', 'namespace' => 'Cadastros', 'middleware' => 'jwt.auth', 'as' => 'api.' ], function () {
  Route::get( '/funcionarios/{id}',
    [ 'as'   => 'funcionarios.show',
      'uses' => 'FuncionariosApi@getFuncionario'
    ]
  );

  // Controle de Ponto
  Route::get( 'funcionarios/{id}/controledeponto/', [
    'uses' => 'ControleDePontoApiController@index',
    'as'   => 'controledeponto.index',
  ] );
  Route::post( 'funcionarios/{id}/controledeponto/', [
    'uses' => 'ControleDePontoApiController@store',
    'as'   => 'controledeponto.store',
  ] );
  Route::get( 'funcionarios/{id}/controledeponto/calc', [
    'uses' => 'ControleDePontoApiController@calc',
    'as'   => 'controledeponto.calc',
  ] );
  Route::get( 'funcionarios/{id}/controledeponto/{id2}', [
    'uses' => 'ControleDePontoApiController@edit',
    'as'   => 'controledeponto.edit',
  ] );
  Route::put( 'funcionarios/{id}/controledeponto/{id2}', [
    'uses' => 'ControleDePontoApiController@update',
    'as'   => 'controledeponto.update',
  ] );
  Route::delete( 'funcionarios/{id}/controledeponto/{id2}', [
    'uses' => 'ControleDePontoApiController@destroy',
    'as'   => 'controledeponto.destroy',
  ] );

  // Calculo do Dissidio
  Route::get( 'funcionarios/{id}/calcdissidio',
    [ 'as'   => 'funchistoricos.calcdissidio',
      'uses' => 'FuncionariosApi@calcDissidio'
    ]
  );

  Route::get( 'clientes/getcentrosdecustos',
    [ 'as'   => 'clientes.getcentrosdecustos',
      'uses' => 'ClientesApi@getCentrosDeCustos'
    ]
  );

  Route::get( '/faixasalarial/{cargo}/{nivel}',
    [ 'as'   => 'FaixaSalarial.show',
      'uses' => 'Config\FaixaSalarialApi@getFaixa'
    ]
  );
} );


// COMERCIAL API
Route::group( [ 'prefix' => 'comercial', 'namespace' => 'Comercial', 'middleware' => 'jwt.auth', 'as' => 'api.' ], function () {
  Route::post( '/jobs/{id}/upload',
    [ 'as'   => 'jobs.upload_file',
      'uses' => 'JobsControllerApi@upload'
    ]
  );
  Route::get( '/jobs/{id}/upload/',
    [ 'as'   => 'jobs.list_file',
      'uses' => 'JobsControllerApi@listFile'
    ]
  );
  Route::get( '/jobs/{id}/upload/{arq}',
    [ 'as'   => 'jobs.delete_file',
      'uses' => 'JobsControllerApi@deleteFile'
    ]
  );

  // Proposta Comercial - A: Cronograma
  Route::get( '/busca_cronos', 'JobsControllerApi@busca_cronos' )->name( 'crono.busca_cronos' );
  Route::get( '/get_cronos/{job_id}', 'JobsControllerApi@get_crono' )->name( 'crono.get_crono' );

  // Proposta Comercial - B: Orcamento - Estimativa de Custo
  Route::resource( '/jobs/{id}/orc_est', 'OrcamentoEstimativaControllerApi', [
    'names'      => 'orc_est',
    'except'     => [ 'create', 'edit' ],
    'parameters' => [ 'orc_est' => 'id2' ]
  ] );
  Route::get( '/jobs/{id}/orc_est_duplicar/{id2}', 'OrcamentoEstimativaControllerApi@est_duplicar' )->name( 'orc_est.duplicar' );
  Route::get( '/busca_jobs', 'OrcamentoEstimativaControllerApi@busca_jobs' )->name( 'orc_est.busca_jobs' );
  Route::get( '/busca_jobs_estimativas/{id}', 'OrcamentoEstimativaControllerApi@busca_jobs_estimativas' )->name( 'orc_est.busca_jobs_estimativas' );
  Route::resource( '/jobs/{id}/orc_ci_item', 'OrcamentoItemCIControllerApi', [
    'names'      => 'orc_ci_item',
    'except'     => [ 'create', 'edit' ],
    'parameters' => [ 'orc_ci_item' => 'id2' ]
  ] );
  Route::resource( '/jobs/{id}/orc_co_item', 'OrcamentoItemCOControllerApi', [
    'names'      => 'orc_co_item',
    'except'     => [ 'create', 'edit' ],
    'parameters' => [ 'orc_co_item' => 'id2' ]
  ] );
  Route::resource( '/jobs/{id}/orc_ci_serv', 'OrcamentoServCIControllerApi', [
    'names'      => 'orc_ci_serv',
    'except'     => [ 'create', 'edit' ],
    'parameters' => [ 'orc_ci_serv' => 'id2' ]
  ] );
  Route::resource( '/jobs/{id}/orc_co_serv', 'OrcamentoServCOControllerApi', [
    'names'      => 'orc_co_serv',
    'except'     => [ 'create', 'edit' ],
    'parameters' => [ 'orc_co_serv' => 'id2' ]
  ] );

} );


// FINANCEIRO API
Route::group( [ 'prefix' => 'financeiro', 'namespace' => 'Financeiro', 'middleware' => 'jwt.auth', 'as' => 'api.' ], function () {

} );
