<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

/// AUTENTICACAO e HOME
Route::group( [], function () {
  // Welcome do link raiz redireciona para Login
  Route::get( '/', function () {
    return redirect()->route( 'login' );
  } );

  // rotas de autenticação default do Laravel
  Auth::routes();
  // desabilita o Register
  Route::any( 'register', 'HomeController@index' );

  // HOME/Dashboard
  Route::get( '/home', 'HomeController@index' )->name( 'home' );
} );


// USUARIO
Route::group( [
  'prefix'    => 'usuario',
  'namespace' => 'Usuario',
  'as'        => 'usuario.'
], function () {
  //Configuracao da conta do User
  Route::get( 'configurarconta', 'ConfigurarContaController@getConfigurarConta' )->name( 'ConfigurarConta.get' );
  Route::post( 'configurarconta/alterasenha', 'ConfigurarContaController@postConfigurarConta_alteraSenha' )->name( 'ConfigurarConta.AlteraSenha' );

  // Holerites/Recibos
  Route::get( 'holerites', 'HoleritesController@listarHolerites' )->name( 'holerites.index' );
  Route::get( 'holerites/{id}', 'HoleritesController@downloadHolerite' )->name( 'holerites.download' );
} );


// CADASTROS
Route::group( [ 'prefix' => 'cadastros', 'namespace' => 'Cadastros' ], function () {
  // TODO: add ['as'=>'cadastros.'] this group.
  // Redirect to Home
  Route::any( '/', function () {
    return redirect()->route( 'home' );
  } );

  // Historico em lote dos Funcionarios
  Route::get( 'funcionarios/historicolote', [
    'as'   => 'funcionarios.getHistoricoLote',
    'uses' => 'FuncionariosHistoricosController@getHistoricoLote'
  ] );
  Route::post( 'funcionarios/historicolote', [
    'as'   => 'funcionarios.postHistoricoLote',
    'uses' => 'FuncionariosHistoricosController@postHistoricoLote'
  ] );

  // Relatorio Salarial
  Route::get( 'funcionarios/relsalarial', [
    'as'   => 'funcionarios.relSalarial',
    'uses' => 'FuncionariosController@relSalarial'
  ] );

  // Relatorio Ferias
  Route::get( 'funcionarios/relferias', [
    'as'   => 'funcionarios.relFerias',
    'uses' => 'FuncionariosController@relFerias'
  ] );

  // CRUD dos Funcionarios
  Route::resource( 'funcionarios', 'FuncionariosController' );
  Route::get( 'funcionarios_contatos_export', 'FuncionariosController@export_contatos_funcionarios_XLSX' )->name( 'export_contatos_funcionarios' );

  // CRUD do Hitorico do Funcionario
  Route::resource( 'funcionarios/{id}/historicos', 'FuncionariosHistoricosController', [ 'except' => 'show' ] );

  // CRUD dos Departamentos
  Route::resource( 'departamentos', 'DepartamentosController' );

  // CRUD dos Usuarios
  Route::resource( 'usuarios', 'UsuariosController' );

  // index dinamico do Controle de ponto do Funcionario
  Route::get( 'funcionarios/{id}/controledeponto', 'ControleDePontoController@index' )->name( 'controledeponto.index' );
  Route::get( 'funcionarios/{id}/controledeponto/relatorio', 'ControleDePontoController@relatorio_individual' )->name( 'controledeponto.relatorio_individual' );
  Route::get( 'controledeponto/relatorio', 'ControleDePontoController@relatorio_todos' )->name( 'controledeponto.relatorio_todos' );

  // CRUD dos Clientes -> Empresas > Departamentos > Contas
  Route::get( 'clientes', 'ClientesController@index' )->name( 'clientes.index' );
  Route::get( 'clientes/create', 'ClientesController@create' )->name( 'clientes.create' );
  Route::post( 'clientes', 'ClientesController@store' )->name( 'clientes.store' );
  Route::get( 'clientes/{id1}/{id2}/{id3}', 'ClientesController@show' )->name( 'clientes.show' );
  Route::get( 'clientes/{id1}/{id2}/{id3}/edit', 'ClientesController@edit' )->name( 'clientes.edit' );
  Route::put( 'clientes/{id1}/{id2}/{id3}', 'ClientesController@update' )->name( 'clientes.update' );
  Route::delete( 'clientes/{id1}/{id2}/{id3}', 'ClientesController@destroy' )->name( 'clientes.destroy' );

  // Unidades do Cliente
  Route::get( 'clientes_unidades/{id1}/create', 'ClientesController@unidades_create' )->name( 'clientes_unidades.create' );
  Route::post( 'clientes_unidades/{id1}', 'ClientesController@unidades_store' )->name( 'clientes_unidades.store' );
  Route::get( 'clientes_unidades/{id1}/{id2}', 'ClientesController@unidades_show' )->name( 'clientes_unidades.show' );
  Route::get( 'clientes_unidades/{id1}/{id2}/edit', 'ClientesController@unidades_edit' )->name( 'clientes_unidades.edit' );
  Route::put( 'clientes_unidades/{id1}/{id2}', 'ClientesController@unidades_update' )->name( 'clientes_unidades.update' );
  Route::delete( 'clientes_unidades/{id1}/{id2}', 'ClientesController@unidades_destroy' )->name( 'clientes_unidades.destroy' );

  Route::get( 'clientes_contatos_export', 'ClientesController@export_contatos_clientes_XLSX' )->name( 'export_contatos_clientes' );

  // CRUD dos Fornecedores -> Empresas > Servicos/Produtos > Contas
  Route::get( 'fornecedores/orcamento', 'FornecedoresController@testeOrcamento' )->name( 'fornecedores.testeOrcamento' );
  Route::get( 'fornecedores', 'FornecedoresController@index' )->name( 'fornecedores.index' );
  Route::get( 'fornecedores/tags', 'FornecedoresController@tagIndex' )->name( 'fornecedores.tagIndex' );
  Route::post( 'fornecedores/tags', 'FornecedoresController@tagCreate' )->name( 'fornecedores.tagCreate' );
  Route::delete( 'fornecedores/tags/{id1}', 'FornecedoresController@tagDestroy' )->name( 'fornecedores.tagDestroy' );
  Route::get( 'fornecedores/despesas', 'FornecedoresController@despesasIndex' )->name( 'fornecedores.despesasIndex' );
  Route::post( 'fornecedores/despesas', 'FornecedoresController@despesasCreate' )->name( 'fornecedores.despesasCreate' );
  Route::delete( 'fornecedores/despesas/{id1}', 'FornecedoresController@despesasDestroy' )->name( 'fornecedores.despesasDestroy' );
  Route::get( 'fornecedores/create', 'FornecedoresController@create' )->name( 'fornecedores.create' );
  Route::post( 'fornecedores', 'FornecedoresController@store' )->name( 'fornecedores.store' );
  Route::get( 'fornecedores/{id1}/{id2}', 'FornecedoresController@show' )->name( 'fornecedores.show' );
  Route::get( 'fornecedores/{id1}/{id2}/edit', 'FornecedoresController@edit' )->name( 'fornecedores.edit' );
  Route::put( 'fornecedores/{id1}/{id2}', 'FornecedoresController@update' )->name( 'fornecedores.update' );
  Route::delete( 'fornecedores/{id1}/{id2}', 'FornecedoresController@destroy' )->name( 'fornecedores.destroy' );

  // CONFIGURACOES ADMINISTRATIVAS
  Route::group( [ 'prefix' => 'config', 'namespace' => 'Config', ], function () {
    Route::get( 'faixasalarial', [
      'as'   => 'configadmin.faixasalarial.get',
      'uses' => 'FaixaSalarialController@get'
    ] );
    Route::post( 'faixasalarial', [
      'as'   => 'configadmin.faixasalarial.post',
      'uses' => 'FaixaSalarialController@post'
    ] );
  } );

  // Plano de Contas
  Route::get( 'planodecontas', 'PlanoDeContasController@index' )->name( 'cadastros.planodecontas.index' );
  Route::post( 'planodecontas', 'PlanoDeContasController@store' )->name( 'cadastros.planodecontas.store' );
  Route::get( 'planodecontas/{grupoID}/{itemID}/edit', 'PlanoDeContasController@edit' )->name( 'cadastros.planodecontas.edit' );
  Route::put( 'planodecontas/{grupoID}/{itemID}', 'PlanoDeContasController@update' )->name( 'cadastros.planodecontas.update' );
  Route::delete( 'planodecontas/{grupoID}/{itemID}', 'PlanoDeContasController@destroy' )->name( 'cadastros.planodecontas.destroy' );

  // Centros de Custo da Cadaris
  Route::resource( 'centrosdecustocadaris', 'CentrosDeCustoCadarisController', [
    'except' => [ 'create', 'show' ],
    'as'     => 'cadastros',
  ] );
} );


// COMERCIAL
Route::group( [ 'prefix' => 'comercial', 'namespace' => 'Comercial' ], function () {
  // TODO: add ['as'=>'comercial.'] this group.
  // Redirect to Home
  Route::any( '/', function () {
    return redirect()->route( 'home' );
  } );

  // Job
  Route::resource( 'jobs', 'JobsController', [ 'except' => 'edit' ] );
  // Campanhas do Job
  Route::get( 'campanhas', 'JobsController@campanhasIndex' )->name( 'jobs.campanhasIndex' );
  Route::post( 'campanhas', 'JobsController@campanhasCreate' )->name( 'jobs.campanhasCreate' );
  Route::delete( 'campanhas/{id}', 'JobsController@campanhasDestroy' )->name( 'jobs.campanhasDestroy' );
  // Servicos Internos
  Route::get( 'servicoscustosinternos', 'JobsController@ServicoCustoInternoIndex' )->name( 'jobs.servicoCustoInternoIndex' );
  Route::post( 'servicoscustosinternos', 'JobsController@ServicoCustoInternoCreate' )->name( 'jobs.servicoCustoInternoCreate' );
  Route::delete( 'servicoscustosinternos/{id}', 'JobsController@ServicoCustoInternosDestroy' )->name( 'jobs.servicoCustoInternosDestroy' );
  // PDF Cronograma
  Route::get( 'jobs/{jobs}/pdf_cronograma', 'JobsPDFController@cronogramaPDF' )->name( 'jobs.cronograma_pdf' );
  Route::get( 'jobs/{jobs}/csv_cronograma', 'JobsPDFController@cronogramaCSV' )->name( 'jobs.cronograma_csv' );
  Route::get( 'jobs/{jobs}/xlsx_cronograma', 'JobsPDFController@cronogramaXLSX' )->name( 'jobs.cronograma_xlsx' );
  // PDF Orcamento
  Route::get( 'jobs/{jobs}/pdf', 'JobsPDFController@gerarPDF' )->name( 'jobs.pdf' );
  // Exportar Todos os Jobs
  Route::get( 'export_jobs', 'JobsPDFController@export_jobs_XLSX' )->name( 'export_jobs' );
} );


// FINANCEIRO
Route::group( [ 'prefix' => 'financeiro', 'namespace' => 'Financeiro', 'as' => 'financeiro.' ], function () {
  // Redirect to Home
  Route::any( '/', function () {
    return redirect()->route( 'home' );
  } );

  // Contas Bancarias
  Route::resource( 'contas', 'ContaBancariaController', [
    'except' => [ 'show' ],
  ] );

  // Transferencias entre Contas Bancarias
  Route::resource( 'transferencias', 'TransferenciaController', [
    'except' => [ 'show' ],
  ] );

  // Fluxo de Caixa
  Route::get( 'caixa', 'CaixaController@index' )->name( 'caixa.index' );
  Route::get( 'caixa/{periodo}', 'CaixaController@showPeriodo' )->name( 'caixa.show_periodo' );
  Route::get( 'caixa/{periodo}/xlsx', 'CaixaController@fluxoDeCaixaXLSX' )->name( 'caixa.fluxo_de_caixa_xlsx' );
  Route::put( 'caixa/{id}', 'CaixaController@update' )->name( 'caixa.update' );
  Route::delete( 'caixa/{id}', 'CaixaController@destroy' )->name( 'caixa.destroy' );

  // Faturamento do job
  Route::get( 'jobs', 'JobReceberController@index' )->name( 'jobs.index' );
  Route::get( 'jobs_xlsx', 'JobReceberController@jobFaturamentoXLSX' )->name( 'jobs.xlsx' );
  Route::get( 'jobs/{id}', 'JobReceberController@show' )->name( 'jobs.show' );
  Route::post( 'jobs/{id}/add_parcela_manual', 'JobReceberController@add_parcela_manual' )->name( 'jobs.add_parcela_manual' );
  Route::post( 'jobs/{id}/add_parcela_iguais', 'JobReceberController@add_parcela_iguais' )->name( 'jobs.add_parcela_iguais' );
  Route::post( 'jobs/{id}/add_parcela_iguais', 'JobReceberController@add_parcela_porcentagem' )->name( 'jobs.add_parcela_porcentagem' );
  Route::get( 'jobs/{id1}/parcela/{id2}/edit', 'JobReceberController@parcela_edit' )->name( 'jobs.parcela.edit' );
  Route::put( 'jobs/{id1}/parcela/{id2}', 'JobReceberController@parcela_update' )->name( 'jobs.parcela.update' );
  Route::delete( 'jobs/{id1}/parcela/{id2}', 'JobReceberController@parcela_destroy' )->name( 'jobs.parcela.destroy' );

  // Salarios dos Funcionarios
  Route::post( 'salario/lancar/{ano}/{mes}', 'SalarioController@lancar' )->name( 'salario.lancar' );
  Route::get( 'salario/lancar/{ano}/{mes}', 'SalarioController@lancar' )->name( 'salario.lancar.get' );

  // Outros Recebimentos
  Route::resource( 'recebimentos', 'OutroRecebimentoController', [
    'except' => [ 'show' ],
  ] );

  // Contas de Fornecedores
  Route::resource( 'fornecedores', 'ContaFornecedorController', [
    'except' => [ 'show' ],
  ] );

  // Contas de Consumos
  Route::resource( 'contasdeconsumogerador', 'ContaDeConsumoGeradorController', [
    'except' => [ 'show' ],
  ] );
  Route::resource( 'contasdeconsumo', 'ContaDeConsumoController', [
    'except' => [ 'show' ],
  ] );

  // Folha de Pagamento
  Route::resource( 'salarios', 'SalarioController', [
    'except' => [ 'create', 'show' ],
  ] );
  Route::get( 'salarios/{id}/holerite', 'SalarioController@downloadHolerite' )
       ->name( 'salarios.holerite' );

  // Ferias
  Route::resource( 'ferias', 'FeriasController', [
    'except' => [ 'show' ],
  ] );

  // Conta de Investimento
  Route::resource( 'investimentos', 'InvestimentosController', [
    'except' => [ 'show' ]
  ] );

  // Retirada de Socios
  Route::resource( 'retiradadesocios', 'RetiradaDeSociosController', [
    'except' => [ 'show' ],
  ] );

  // Rescisao
  Route::resource( 'rescisao', 'RescisaoController', [
    'except' => [ 'show' ],
  ] );

  // Salario 13
  Route::resource( 'salario13', 'Salario13Controller', [
    'except' => [ 'show' ],
  ] );
} );


// TESTES
Route::group( [ 'prefix' => 'teste', 'middleware' => 'auth' ], function () {
  Route::get( '/', function () {
    $teste_email1        = route( 'teste.email' );
    $teste_email2        = route( 'teste.email2' );
    $teste_email3        = route( 'teste.email3' );
    $teste_pdf           = route( 'teste.pdf' );
    $teste_recache_caixa = route( 'teste.recache_caixa' );

    return "<!doctype html>
<html lang=\"pt-br\">
  <head>
    <meta charset=\"UTF-8\">
    <title>Testes do Sistema</title>
  </head>
  <body>
    <h1>:: Sistema Cadaris ::</h1>
    <h2>Executar Testes:</h2>
    <ul>
      <li><a href=\"$teste_email1\">E-MAIL @gmail</a></li>
      <li><a href=\"$teste_email2\">E-MAIL @cadaris</a></li>
      <li><a href=\"$teste_email3\">E-MAIL Jobs @cadaris</a></li>
      <li><a href=\"$teste_pdf\">PDF</a></li>
    </ul>
    <h2>Re-Cache:</h2>
    <ul>
      <li><a href=\"$teste_recache_caixa\">Caixas</a></li>
    </ul>
  </body>
</html>";
  } )->name( 'teste' );

  Route::get( 'email', function () {
    /** @var \App\User $rafa */
    $rafa        = new \App\User();
    $rafa->name  = 'Rafa';
    $rafa->email = 'sistema@cadaris.com.br';
    $rafa->notify( new App\Notifications\TesteNotification() );

    return 'Teste de E-mail enviado para a fila com sucesso (' . \Carbon\Carbon::now()->format( 'd/m/Y H:i:s' ) . '): ' . $rafa->email;
  } )->name( 'teste.email' );

  Route::get( 'email2', function () {
    /** @var \App\User $rafa */
    $rafa        = new \App\User();
    $rafa->name  = 'RafaCadaris';
    $rafa->email = 'sistema@cadaris.com.br';
    $rafa->notify( new App\Notifications\TesteNotification() );

    return 'Teste de E-mail enviado para a fila com sucesso (' . \Carbon\Carbon::now()->format( 'd/m/Y H:i:s' ) . '): ' . $rafa->email;
  } )->name( 'teste.email2' );

  Route::get( 'email3', function () {
    /** @var \App\User $rafa */
    $rafa = App\User::find( 5 );
    $job  = App\Models\Comercial\Jobs::first();
    Notification::send( $rafa, new App\Notifications\JobStageNotification( $job, CRP::P_Comercial_email_B_entrou ) );

    return 'Teste de E-mail do JOB enviado para a fila com sucesso (' . \Carbon\Carbon::now()->format( 'd/m/Y H:i:s' ) . '): ' . $rafa->email;
  } )->name( 'teste.email3' );

  Route::get( 'pdf', function () {
    $html = '<h1>Teste de PDF</h1><p>Se vc est&aacute; vendo este PDF, ent&atilde;o funcionou como o esperado!</p>';
    $pdf  = PDF::loadHTML( $html );
    $pdf->setOption( 'lowquality', false );
    $pdf->setOption( 'page-size', 'A4' );
    $pdf->setOption( 'dpi', 300 );
    $pdf->setOption( 'image-dpi', 300 );

    return $pdf->inline( 'Teste PDF.pdf' );
  } )->name( 'teste.pdf' );

  Route::get( 'recache_caixa', function () {
    \Artisan::call( 'recache:caixa' );
    dd( 'Caixa re-cached!', Artisan::output() );
  } )->name( 'teste.recache_caixa' );
} );
