const { mix } = require( 'laravel-mix' );

/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your Laravel application. By default, we are compiling the Sass
 | file for the application as well as bundling up all the JS files.
 |
 */
/**
 * Return the assets path.
 *
 * @param local {string}
 * @return {string}
 */
function RES( local ) {
  return 'resources/assets/' + local;
}
/**
 * Return the vendor assets path.
 *
 * @param local {string}
 * @return {string}
 */
function RESv( local ) {
  return 'resources/assets/vendor/' + local;
}
/**
 * Return the public path.
 *
 * @param local {string}
 * @return {string}
 */
function PUB( local ) {
  return 'public/' + local;
}

var assets = {
  css: [],
  css_vendor: [],
  css_vendor_print: [],
  css_vendor_login: [],
  js: [],
  js_vendor: [],
  js_vendor_login: [],
  copy: [],
  fonts: [],
};

// ..:: APP ::..
// favIcon
assets.copy.push( RES( 'favicon/*' ) );

// CSS
assets.css.push( RES( 'css/app.css' ) );

// JS
assets.js.push( RES( 'js/app.js' ) );


// ..:: VENDOR ::..
// jQuery
assets.js_vendor.push( RESv( 'jQuery-3.2.1/jquery-3.2.1.js' ) );
assets.js_vendor_login.push( RESv( 'jQuery-3.2.1/jquery-3.2.1.js' ) );

// jQueryUI stable
assets.css_vendor.push( RESv( 'jQueryUI-1.12.1/jquery-ui.css' ) );
assets.js_vendor.push( RESv( 'jQueryUI-1.12.1/jquery-ui.js' ) );

// Bootstrap
assets.css_vendor.push( RESv( 'bootstrap-3.3.7/bootstrap.css' ) );
assets.css_vendor_login.push( RESv( 'bootstrap-3.3.7/bootstrap.css' ) );
assets.css_vendor.push( RESv( 'bootstrap-3.3.7/bootstrap-theme.css' ) ); // gradiente nos btn
assets.fonts.push( RESv( 'bootstrap-3.3.7/fonts/*' ) );
assets.js_vendor.push( RESv( 'bootstrap-3.3.7/bootstrap.js' ) );
assets.js_vendor_login.push( RESv( 'bootstrap-3.3.7/bootstrap.js' ) );

// font-awesome-4.7.0
assets.css_vendor.push( RESv( 'font-awesome-4.7.0/font-awesome.css' ) );
assets.css_vendor_login.push( RESv( 'font-awesome-4.7.0/font-awesome.css' ) );
assets.fonts.push( RESv( 'font-awesome-4.7.0/fonts/*' ) );

// igorescobar/jQueryMaskPlugin
assets.js_vendor.push( RESv( 'jQueryMaskPlugin-1.7.7/jquery.mask.js' ) );

// plentz/jquery-maskmoney
assets.js_vendor.push( RESv( 'jQueryMaskMoney-3.1.1/jquery.maskMoney.js' ) );

// moment-2.18.1
assets.js_vendor.push( RESv( 'moment-2.18.1/moment.js' ) );
assets.js_vendor.push( RESv( 'moment-2.18.1/locale/pt-br.js' ) );

// Select2-4.0.3
assets.css_vendor.push( RESv( 'Select2-4.0.3/select2.css' ) );
assets.css_vendor.push( RESv( 'Select2-4.0.3/select2-bootstrap.css' ) );
assets.js_vendor.push( RESv( 'Select2-4.0.3/select2.full.js' ) );
assets.js_vendor.push( RESv( 'Select2-4.0.3/pt-BR.js' ) );

// jonmiles/bootstrap-treeview
assets.css_vendor.push( RESv( 'bootstrap-treeview-1.2.0/bootstrap-treeview.css' ) );
assets.js_vendor.push( RESv( 'bootstrap-treeview-1.2.0/bootstrap-treeview.js' ) );

// bootstrap-star-rating-4.0.1
assets.css_vendor.push( RESv( 'bootstrap-star-rating-4.0.1/star-rating.css' ) );
assets.css_vendor.push( RESv( 'bootstrap-star-rating-4.0.1/theme-krajee-fa.css' ) );
assets.js_vendor.push( RESv( 'bootstrap-star-rating-4.0.1/star-rating.js' ) );
assets.js_vendor.push( RESv( 'bootstrap-star-rating-4.0.1/star-rating_locale_pt-br.js' ) );

// bootstrap-datepicker-1.6.4
assets.css_vendor.push( RESv( 'bootstrap-datepicker-1.6.4/bootstrap-datepicker3.css' ) );
assets.js_vendor.push( RESv( 'bootstrap-datepicker-1.6.4/bootstrap-datepicker.js' ) );
assets.js_vendor.push( RESv( 'bootstrap-datepicker-1.6.4/bootstrap-datepicker.pt-BR.min.js' ) );

// weareoutman/clockpicker
assets.css_vendor.push( RESv( 'bootstrap-clockpicker-0.0.7/bootstrap-clockpicker.css' ) );
assets.js_vendor.push( RESv( 'bootstrap-clockpicker-0.0.7/bootstrap-clockpicker.js' ) );

// bootstrap-year-calendar-1.1.0
assets.css_vendor.push( RESv( 'bootstrap-year-calendar-1.1.0/bootstrap-year-calendar.css' ) );
assets.js_vendor.push( RESv( 'bootstrap-year-calendar-1.1.0/bootstrap-year-calendar.js' ) );
assets.js_vendor.push( RESv( 'bootstrap-year-calendar-1.1.0/bootstrap-year-calendar.pt.js' ) );

// fullcalendar-3.3.1
assets.css_vendor.push( RESv( 'fullcalendar-3.3.1/fullcalendar.css' ) );
assets.css_vendor_print.push( RESv( 'fullcalendar-3.3.1/fullcalendar.print.css' ) );
assets.js_vendor.push( RESv( 'fullcalendar-3.3.1/fullcalendar.js' ) );
assets.js_vendor.push( RESv( 'fullcalendar-3.3.1/fullcalendar.pt-br.js' ) );

// CKEditor-4.6.2 nao tem suporte ao WebPack

// Font Raleway
assets.fonts.push( RESv( 'Raleway/*' ) );


// ..:: WEBPACK ::..
mix.scripts( assets.js_vendor, PUB( 'js/vendor.js' ) ).sourceMaps()
   .scripts( assets.js_vendor_login, PUB( 'js/vendor_login.js' ) ).sourceMaps()
   .styles( assets.css_vendor, PUB( 'css/vendor.css' ) )
   .styles( assets.css_vendor_print, PUB( 'css/vendor_print.css' ) )
   .styles( assets.css_vendor_login, PUB( 'css/vendor_login.css' ) )
   .scripts( assets.js, PUB( 'js/app.js' ) ).sourceMaps()
   .styles( assets.css, PUB( 'css/app.css' ) )
   .copy( assets.fonts, PUB( 'fonts/' ) )
   .copy( assets.copy, PUB( '' ) )
   .copyDirectory( RESv( 'CKEditor-4.6.2/' ), PUB( 'ckeditor/' ) )
   .copy( RES( 'images/*' ), PUB( 'images/' ) )
;
// Versioning
if ( mix.config.inProduction ) {
  mix.version();
}
mix.version();
// Disable Notifications
//mix.disableNotifications();